DROP TABLE IF EXISTS `#__activity`;
CREATE TABLE IF NOT EXISTS `#__activity` (
  `activity_id` mediumint(9) NOT NULL AUTO_INCREMENT COMMENT '活动自增ID',
  `activity_title` varchar(255) NOT NULL COMMENT '活动标题',
  `activity_type` enum('1','2') DEFAULT NULL COMMENT '活动类型 1:商品 2:抢购',
  `activity_banner` varchar(255) NOT NULL COMMENT '活动图片',
  `activity_banner_mobile` varchar(255) NOT NULL COMMENT '手机活动图片',
  `activity_style` varchar(255) NOT NULL DEFAULT 'default' COMMENT '活动页面样式',
  `activity_desc` varchar(1000) NOT NULL COMMENT '活动描述',
  `activity_startdate` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '活动开始时间',
  `activity_enddate` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '活动结束时间',
  `activity_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '活动排序',
  `activity_state` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '活动状态 0为关闭 1为开启',
  PRIMARY KEY (`activity_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='活动表';



DROP TABLE IF EXISTS `#__activitydetail`;
CREATE TABLE IF NOT EXISTS `#__activitydetail` (
  `activitydetail_id` mediumint(9) NOT NULL AUTO_INCREMENT COMMENT '活动详情自增ID',
  `activity_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '活动ID',
  `item_id` int(11) NOT NULL COMMENT '商品或抢购的编号',
  `item_name` varchar(255) NOT NULL COMMENT '商品或抢购名称',
  `store_id` int(11) NOT NULL COMMENT '店铺ID',
  `store_name` varchar(255) NOT NULL COMMENT '店铺名称',
  `activitydetail_state` enum('0','1','2','3') NOT NULL DEFAULT '0' COMMENT '审核状态 0:(默认)待审核 1:通过 2:未通过 3:再次申请',
  `activitydetail_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '活动详情排序',
  PRIMARY KEY (`activitydetail_id`),
  KEY `activity_id` (`activity_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='活动详情表';



DROP TABLE IF EXISTS `#__address`;
CREATE TABLE IF NOT EXISTS `#__address` (
  `address_id` mediumint(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '地址ID',
  `member_id` mediumint(10) unsigned NOT NULL DEFAULT '0' COMMENT '会员ID',
  `address_realname` varchar(50) NOT NULL COMMENT '会员姓名',
  `city_id` mediumint(9) DEFAULT NULL COMMENT '市级ID',
  `area_id` mediumint(10) unsigned NOT NULL DEFAULT '0' COMMENT '地区ID',
  `area_info` varchar(255) NOT NULL DEFAULT '' COMMENT '地区内容',
  `address_detail` varchar(255) NOT NULL COMMENT '详细地址',
  `address_tel_phone` varchar(20) DEFAULT NULL COMMENT '座机',
  `address_mob_phone` varchar(15) DEFAULT NULL COMMENT '手机',
  `address_is_default` enum('0','1') NOT NULL DEFAULT '0' COMMENT '1默认收货地址',
  `chain_id` int(11) DEFAULT '0' COMMENT '门店ID',
  `address_longitude` varchar(20) DEFAULT '' COMMENT '经度',
  `address_latitude` varchar(20) DEFAULT '' COMMENT '纬度',
  PRIMARY KEY (`address_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='买家地址信息表';



DROP TABLE IF EXISTS `#__admin`;
CREATE TABLE IF NOT EXISTS `#__admin` (
  `admin_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '管理员自增ID',
  `admin_name` varchar(20) NOT NULL COMMENT '管理员名称',
  `admin_password` varchar(32) NOT NULL DEFAULT '' COMMENT '管理员密码',
  `admin_login_time` int(10) NOT NULL DEFAULT '0' COMMENT '登录时间',
  `admin_login_num` int(11) NOT NULL DEFAULT '0' COMMENT '登录次数',
  `admin_is_super` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否超级管理员',
  `admin_gid` smallint(6) DEFAULT '0' COMMENT '权限组ID',
  PRIMARY KEY (`admin_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='管理员表';



DROP TABLE IF EXISTS `#__adminlog`;
CREATE TABLE IF NOT EXISTS `#__adminlog` (
  `adminlog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '管理员记录自增ID',
  `admin_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '管理员ID',
  `admin_name` char(20) NOT NULL COMMENT '管理员名称',
  `adminlog_content` varchar(255) NOT NULL COMMENT '操作内容',
  `adminlog_time` int(10) unsigned DEFAULT NULL COMMENT '发生时间',
  `adminlog_ip` char(15) NOT NULL COMMENT '管理员操作IP',
  `adminlog_url` varchar(50) NOT NULL DEFAULT '' COMMENT 'controller/action',
  PRIMARY KEY (`adminlog_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='管理员操作日志';



DROP TABLE IF EXISTS `#__adv`;
CREATE TABLE IF NOT EXISTS `#__adv` (
  `adv_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '广告自增ID',
  `ap_id` mediumint(8) unsigned NOT NULL COMMENT '广告位ID',
  `adv_title` varchar(255) NOT NULL COMMENT '广告内容描述',
  `adv_link` varchar(255) NOT NULL COMMENT '广告链接地址',
  `adv_code` varchar(1000) DEFAULT NULL COMMENT '广告图片地址',
  `adv_startdate` int(10) DEFAULT NULL COMMENT '广告开始时间',
  `adv_enddate` int(10) DEFAULT NULL COMMENT '广告结束时间',
  `adv_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '广告图片排序',
  `adv_enabled` tinyint(1) unsigned DEFAULT '1' COMMENT '广告是否有效',
  `adv_clicknum` int(10) unsigned DEFAULT '0' COMMENT '广告点击次数',
  `adv_bgcolor` varchar(50) DEFAULT NULL COMMENT '广告背景颜色',
  PRIMARY KEY (`adv_id`),
  KEY `ap_id` (`ap_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='广告表';



DROP TABLE IF EXISTS `#__advposition`;
CREATE TABLE IF NOT EXISTS `#__advposition` (
  `ap_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '广告位置自增ID',
  `ap_name` varchar(100) NOT NULL COMMENT '广告位名称',
  `ap_intro` varchar(255) NOT NULL DEFAULT '' COMMENT '广告位简介',
  `ap_isuse` smallint(1) unsigned NOT NULL DEFAULT '1' COMMENT '广告位是否启用：0不启用1启用',
  `ap_width` int(10) DEFAULT '0' COMMENT '广告位宽度',
  `ap_height` int(10) DEFAULT '0' COMMENT '广告位高度',
  PRIMARY KEY (`ap_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='广告位表';



DROP TABLE IF EXISTS `#__albumclass`;
CREATE TABLE IF NOT EXISTS `#__albumclass` (
  `aclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '相册自增ID',
  `aclass_name` varchar(100) NOT NULL COMMENT '相册名称',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `aclass_des` varchar(255) NOT NULL COMMENT '相册描述',
  `aclass_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '相册排序',
  `aclass_cover` varchar(255) DEFAULT NULL COMMENT '相册封面',
  `aclass_uploadtime` int(10) unsigned NOT NULL COMMENT '图片上传时间',
  `aclass_isdefault` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '是否为默认相册,1代表默认',
  PRIMARY KEY (`aclass_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='相册表';



DROP TABLE IF EXISTS `#__albumpic`;
CREATE TABLE IF NOT EXISTS `#__albumpic` (
  `apic_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '相册图片自增ID',
  `apic_name` varchar(100) NOT NULL COMMENT '图片名称',
  `apic_tag` varchar(255) NOT NULL COMMENT '图片标签',
  `aclass_id` int(10) unsigned NOT NULL COMMENT '相册ID',
  `apic_cover` varchar(255) NOT NULL COMMENT '图片路径',
  `apic_size` int(10) unsigned NOT NULL COMMENT '图片大小',
  `apic_spec` varchar(100) NOT NULL COMMENT '图片规格',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `apic_uploadtime` int(10) unsigned NOT NULL COMMENT '图片上传时间',
  PRIMARY KEY (`apic_id`),
  KEY `aclass_id` (`aclass_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='相册图片表';



DROP TABLE IF EXISTS `#__appadv`;
CREATE TABLE IF NOT EXISTS `#__appadv` (
  `adv_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'APP广告自增ID',
  `ap_id` mediumint(8) unsigned NOT NULL COMMENT 'APP广告位ID',
  `adv_title` varchar(255) NOT NULL COMMENT 'APP广告内容描述',
  `adv_type` varchar(255) DEFAULT NULL COMMENT 'APP广告类型,goods,store,article',
  `adv_typedate` text COMMENT 'APP广告类型对应的值,判断具体跳转内容',
  `adv_code` varchar(1000) DEFAULT NULL COMMENT 'APP广告图片地址',
  `adv_startdate` int(10) DEFAULT NULL COMMENT 'APP广告开始时间',
  `adv_enddate` int(10) DEFAULT NULL COMMENT 'APP广告结束时间',
  `adv_sort` int(10) unsigned DEFAULT '255' COMMENT 'APP广告图片排序',
  `adv_enabled` tinyint(1) unsigned DEFAULT '1' COMMENT 'APP广告是否有效',
  PRIMARY KEY (`adv_id`),
  KEY `ap_id` (`ap_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='APP广告表';



DROP TABLE IF EXISTS `#__appadvposition`;
CREATE TABLE IF NOT EXISTS `#__appadvposition` (
  `ap_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'APP广告位自增ID',
  `ap_name` varchar(100) NOT NULL COMMENT 'APP广告位名称',
  `ap_intro` varchar(255) NOT NULL DEFAULT '' COMMENT 'APP广告位简介',
  `ap_isuse` smallint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'APP广告位是否启用：0不启用1启用',
  `ap_width` int(10) DEFAULT '0' COMMENT 'APP广告位宽度',
  `ap_height` int(10) DEFAULT '0' COMMENT 'APP广告位高度',
  PRIMARY KEY (`ap_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='APP广告位表';



DROP TABLE IF EXISTS `#__area`;
CREATE TABLE IF NOT EXISTS `#__area` (
  `area_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '地区自增ID',
  `area_name` varchar(50) NOT NULL COMMENT '地区名称',
  `area_parent_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '地区上级ID',
  `area_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '地区排序',
  `area_deep` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '地区深度',
  `area_region` varchar(3) DEFAULT NULL COMMENT '大区名称',
  `area_initial` varchar(1) DEFAULT NULL COMMENT '品牌首字母',
  PRIMARY KEY (`area_id`),
  KEY `area_parent_id` (`area_parent_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='地区表';



DROP TABLE IF EXISTS `#__arrivalnotice`;
CREATE TABLE IF NOT EXISTS `#__arrivalnotice` (
  `arrivalnotice_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '到货通知自增ID',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `arrivalnotice_addtime` int(10) unsigned NOT NULL COMMENT '到货通知添加时间',
  `arrivalnotice_email` varchar(100) NOT NULL COMMENT '邮箱',
  `arrivalnotice_mobile` varchar(11) NOT NULL COMMENT '手机号',
  `arrivalnotice_type` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态 1:到货通知 2:预售',
  `arrivalnotice_state` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '到货通知状态 1:未通知 2:已通知',
  `arrivalnotice_time` int(10) DEFAULT '0' COMMENT '通知时间',
  PRIMARY KEY (`arrivalnotice_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品到货通知表';



DROP TABLE IF EXISTS `#__article`;
CREATE TABLE IF NOT EXISTS `#__article` (
  `article_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '文章自增ID',
  `ac_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '分类id',
  `article_url` varchar(100) DEFAULT NULL COMMENT '文章跳转链接',
  `article_show` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '文章是否显示，0为否，1为是，默认为1',
  `article_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '文章排序',
  `article_title` varchar(100) DEFAULT NULL COMMENT '文章标题',
  `article_content` text COMMENT '内容',
  `article_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '文章发布时间',
  `article_pic` varchar(255) NOT NULL DEFAULT '' COMMENT '文章主图',
  PRIMARY KEY (`article_id`),
  KEY `ac_id` (`ac_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='文章表';



DROP TABLE IF EXISTS `#__articleclass`;
CREATE TABLE IF NOT EXISTS `#__articleclass` (
  `ac_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '文章分类自增ID',
  `ac_code` varchar(20) DEFAULT NULL COMMENT '文章分类标识码',
  `ac_name` varchar(100) NOT NULL COMMENT '文章分类名称',
  `ac_parent_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '文章分类父ID',
  `ac_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '文章分类排序',
  PRIMARY KEY (`ac_id`),
  KEY `ac_parent_id` (`ac_parent_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='文章分类表';



DROP TABLE IF EXISTS `#__attribute`;
CREATE TABLE IF NOT EXISTS `#__attribute` (
  `attr_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '属性自增ID',
  `attr_name` varchar(100) NOT NULL COMMENT '属性名称',
  `type_id` int(10) unsigned NOT NULL COMMENT '所属类型id',
  `attr_value` text NOT NULL COMMENT '属性值',
  `attr_show` tinyint(1) unsigned NOT NULL COMMENT '属性是否显示。0不显示、1显示',
  `attr_sort` tinyint(1) unsigned NOT NULL COMMENT '属性排序',
  PRIMARY KEY (`attr_id`),
  KEY `attr_id` (`attr_id`,`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品属性表';



DROP TABLE IF EXISTS `#__attributevalue`;
CREATE TABLE IF NOT EXISTS `#__attributevalue` (
  `attrvalue_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '属性值id',
  `attrvalue_name` varchar(100) NOT NULL COMMENT '属性值名称',
  `attr_id` int(10) unsigned NOT NULL COMMENT '所属属性id',
  `type_id` int(10) unsigned NOT NULL COMMENT '类型id',
  `attrvalue_sort` tinyint(1) unsigned NOT NULL COMMENT '属性值排序',
  PRIMARY KEY (`attrvalue_id`),
  KEY `attr_id` (`attr_id`),
  KEY `type_id` (`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品属性值表';



DROP TABLE IF EXISTS `#__bonus`;
CREATE TABLE IF NOT EXISTS `#__bonus` (
  `bonus_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '红包自增ID',
  `bonus_type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '红包类型 1活动红包 2关注红包 3奖品红包',
  `bonus_name` varchar(20) NOT NULL DEFAULT '' COMMENT '红包名称',
  `bonus_blessing` varchar(255) NOT NULL DEFAULT '' COMMENT '红包祝福语',
  `bonus_totalprice` decimal(10,2) NOT NULL COMMENT '总面额',
  `bonus_pricetype` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否固定金额 1固定金额',
  `bonus_fixedprice` decimal(10,2) NOT NULL COMMENT '固定金额',
  `bonus_randomprice_start` decimal(10,2) NOT NULL COMMENT '金额范围',
  `bonus_randomprice_end` decimal(10,2) NOT NULL COMMENT '金额范围',
  `bonus_receivecount` int(11) NOT NULL DEFAULT '0' COMMENT '领取人数',
  `bonus_receiveprice` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '领取金额',
  `bonus_state` tinyint(2) NOT NULL DEFAULT '0' COMMENT '红包状态 1正在进行 2过期 3失效',
  `bonus_begintime` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '开始时间',
  `bonus_endtime` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '结束时间',
  `bonus_remark` varchar(255) NOT NULL DEFAULT '' COMMENT '红包备注',
  PRIMARY KEY (`bonus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='吸粉红包表';



DROP TABLE IF EXISTS `#__bonusreceive`;
CREATE TABLE IF NOT EXISTS `#__bonusreceive` (
  `bonusreceive_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `bonus_id` int(11) NOT NULL COMMENT '吸粉红包ID',
  `member_id` int(11) NOT NULL DEFAULT '0' COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL DEFAULT '' COMMENT '会员名',
  `bonusreceive_time` int(11) NOT NULL DEFAULT '0' COMMENT '领取时间',
  `bonusreceive_price` decimal(10,2) NOT NULL COMMENT '领取金额',
  `bonusreceive_transformed` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否转入预存款',
  PRIMARY KEY (`bonusreceive_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='吸粉红包领取信息表';



DROP TABLE IF EXISTS `#__brand`;
CREATE TABLE IF NOT EXISTS `#__brand` (
  `brand_id` mediumint(11) NOT NULL AUTO_INCREMENT COMMENT '品牌自增ID',
  `store_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `gc_id` int(10) unsigned DEFAULT '0' COMMENT '商品分类id',
  `brand_name` varchar(100) DEFAULT NULL COMMENT '品牌名称',
  `brand_initial` varchar(1) DEFAULT NULL COMMENT '品牌首字母',
  `brand_class` varchar(50) DEFAULT NULL COMMENT '类别名称',
  `brand_pic` varchar(100) DEFAULT NULL COMMENT '品牌图片',
  `brand_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '品牌排序',
  `brand_recommend` tinyint(1) DEFAULT '0' COMMENT '品牌推荐，0为否，1为是',
  `brand_apply` tinyint(1) NOT NULL DEFAULT '1' COMMENT '品牌申请，0为申请中，1为通过，默认为1，申请功能是会员使用',
  `brand_showtype` tinyint(1) NOT NULL DEFAULT '0' COMMENT '品牌展示类型 0表示图片 1表示文字 ',
  PRIMARY KEY (`brand_id`),
  KEY `store_id` (`store_id`),
  KEY `gc_id` (`gc_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='品牌表';



DROP TABLE IF EXISTS `#__cart`;
CREATE TABLE IF NOT EXISTS `#__cart` (
  `cart_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '购物车自增ID',
  `buyer_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '买家ID',
  `store_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL DEFAULT '' COMMENT '店铺名称',
  `goods_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_price` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '商品价格',
  `goods_num` smallint(5) unsigned NOT NULL DEFAULT '1' COMMENT '商品数量',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `bl_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '组合套装ID',
  PRIMARY KEY (`cart_id`),
  KEY `member_id` (`buyer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='购物车数据表';




DROP TABLE IF EXISTS `#__complain`;
CREATE TABLE IF NOT EXISTS `#__complain` (
  `complain_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '投诉自增ID',
  `order_id` int(11) NOT NULL COMMENT '订单ID',
  `order_goods_id` int(10) unsigned DEFAULT '0' COMMENT '订单商品ID',
  `accuser_id` int(11) NOT NULL COMMENT '原告ID',
  `accuser_name` varchar(50) NOT NULL COMMENT '原告用户名',
  `accused_id` int(11) NOT NULL COMMENT '被告ID',
  `accused_name` varchar(50) NOT NULL COMMENT '被告名称',
  `complain_subject_content` varchar(50) NOT NULL COMMENT '投诉主题',
  `complain_subject_id` int(11) NOT NULL COMMENT '投诉主题id',
  `complain_content` varchar(255) NOT NULL COMMENT '投诉内容',
  `complain_pic1` varchar(100) DEFAULT NULL COMMENT '投诉图片1',
  `complain_pic2` varchar(100) DEFAULT NULL COMMENT '投诉图片2',
  `complain_pic3` varchar(100) DEFAULT NULL COMMENT '投诉图片3',
  `complain_datetime` int(11) DEFAULT NULL COMMENT '投诉时间',
  `complain_handle_datetime` int(11) DEFAULT NULL COMMENT '投诉处理时间',
  `complain_handle_member_id` int(11) DEFAULT NULL COMMENT '投诉处理人ID',
  `appeal_message` varchar(255) DEFAULT NULL COMMENT '申诉内容',
  `appeal_datetime` int(11) DEFAULT NULL COMMENT '申诉时间',
  `appeal_pic1` varchar(100) DEFAULT NULL COMMENT '申诉图片1',
  `appeal_pic2` varchar(100) DEFAULT NULL COMMENT '申诉图片2',
  `appeal_pic3` varchar(100) DEFAULT NULL COMMENT '申诉图片3',
  `final_handle_message` varchar(255) DEFAULT NULL COMMENT '最终处理意见',
  `final_handle_datetime` int(11) DEFAULT NULL COMMENT '最终处理时间',
  `final_handle_member_id` int(11) DEFAULT NULL COMMENT '最终处理人ID',
  `complain_state` tinyint(4) DEFAULT NULL COMMENT '投诉状态 10:新投诉 20:投诉通过转给被投诉人 30:被投诉人已申诉 40:提交仲裁 99:已关闭',
  `complain_active` tinyint(4) DEFAULT '1' COMMENT '投诉是否通过平台审批 1:未通过 2:通过',
  PRIMARY KEY (`complain_id`),
  KEY `accuser_id` (`accuser_id`),
  KEY `accused_id` (`accused_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='投诉表';



DROP TABLE IF EXISTS `#__complainsubject`;
CREATE TABLE IF NOT EXISTS `#__complainsubject` (
  `complainsubject_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '投诉主题id',
  `complainsubject_content` varchar(50) NOT NULL COMMENT '投诉主题',
  `complainsubject_desc` varchar(100) NOT NULL COMMENT '投诉主题描述',
  `complainsubject_state` tinyint(4) NOT NULL COMMENT '投诉主题状态 1:有效 2:失效',
  PRIMARY KEY (`complainsubject_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='投诉主题表';



DROP TABLE IF EXISTS `#__complaintalk`;
CREATE TABLE IF NOT EXISTS `#__complaintalk` (
  `talk_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '投诉对话自增ID',
  `complain_id` int(11) NOT NULL COMMENT '投诉ID',
  `talk_member_id` int(11) NOT NULL COMMENT '发言人ID',
  `talk_member_name` varchar(50) NOT NULL COMMENT '发言人用户名',
  `talk_member_type` varchar(10) NOT NULL COMMENT '发言人类型(1-投诉人/2-被投诉人/3-平台)',
  `talk_content` varchar(255) NOT NULL COMMENT '发言内容',
  `talk_state` tinyint(4) NOT NULL COMMENT '发言状态(1-显示/2-不显示)',
  `talk_admin` int(11) NOT NULL DEFAULT '0' COMMENT '对话管理员，屏蔽对话人的id',
  `talk_datetime` int(11) NOT NULL COMMENT '对话发表时间',
  PRIMARY KEY (`talk_id`),
  KEY `complain_id` (`complain_id`),
  KEY `talk_member_id` (`talk_member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='投诉对话表';



DROP TABLE IF EXISTS `#__config`;
CREATE TABLE IF NOT EXISTS `#__config` (
  `id` smallint(5) NOT NULL AUTO_INCREMENT,
  `code` varchar(30) NOT NULL,
  `value` text,
  `remark` varchar(100) DEFAULT '解释,备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='配置参数表';



DROP TABLE IF EXISTS `#__consult`;
CREATE TABLE IF NOT EXISTS `#__consult` (
  `consult_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '咨询自增ID',
  `goods_id` int(11) unsigned DEFAULT '0' COMMENT '商品编号',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `member_id` int(11) NOT NULL DEFAULT '0' COMMENT '咨询发布者会员ID 0:游客',
  `member_name` varchar(100) DEFAULT NULL COMMENT '会员名称',
  `store_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `consulttype_id` int(10) unsigned NOT NULL COMMENT '咨询类型',
  `consult_content` varchar(255) DEFAULT NULL COMMENT '咨询内容',
  `consult_addtime` int(10) DEFAULT NULL COMMENT '咨询发布时间',
  `consult_reply` varchar(255) DEFAULT '' COMMENT '咨询回复内容',
  `consult_replytime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '咨询回复时间',
  `consult_isanonymous` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0表示不匿名 1表示匿名',
  PRIMARY KEY (`consult_id`),
  KEY `goods_id` (`goods_id`),
  KEY `seller_id` (`store_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品咨询表';



DROP TABLE IF EXISTS `#__consulttype`;
CREATE TABLE IF NOT EXISTS `#__consulttype` (
  `consulttype_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '咨询类型ID',
  `consulttype_name` varchar(10) NOT NULL COMMENT '咨询类型名称',
  `consulttype_introduce` text NOT NULL COMMENT '咨询类型详细介绍',
  `consulttype_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '咨询类型排序',
  PRIMARY KEY (`consulttype_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='咨询类型表';



DROP TABLE IF EXISTS `#__cron`;
CREATE TABLE IF NOT EXISTS `#__cron` (
  `cron_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '执行自增ID',
  `cron_type` varchar(255) NOT NULL COMMENT '任务类型',
  `cron_value` text NOT NULL COMMENT '关联任务的值',
  `cron_exetime` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '执行时间',
  PRIMARY KEY (`cron_id`),
  KEY `cron_type` (`cron_type`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='任务队列表';



DROP TABLE IF EXISTS `#__daddress`;
CREATE TABLE IF NOT EXISTS `#__daddress` (
  `daddress_id` mediumint(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '发货地址ID',
  `store_id` mediumint(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `seller_name` varchar(50) NOT NULL DEFAULT '' COMMENT '联系人',
  `city_id` mediumint(9) DEFAULT NULL COMMENT '市级ID',
  `area_id` mediumint(10) unsigned NOT NULL DEFAULT '0' COMMENT '地区ID',
  `area_info` varchar(100) DEFAULT NULL COMMENT '省市县',
  `daddress_detail` varchar(100) NOT NULL COMMENT '发货地址',
  `daddress_telphone` varchar(40) DEFAULT NULL COMMENT '发货电话',
  `daddress_company` varchar(50) NOT NULL COMMENT '发货公司',
  `daddress_isdefault` enum('0','1') NOT NULL DEFAULT '0' COMMENT '是否默认 1:是0:不是',
  PRIMARY KEY (`daddress_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='卖家发货地址信息表';




DROP TABLE IF EXISTS `#__chain`;
CREATE TABLE IF NOT EXISTS `#__chain` (
  `chain_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '门店自增ID',
  `store_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `chain_name` varchar(50) NOT NULL COMMENT '门店登录名',
  `chain_passwd` varchar(32) NOT NULL COMMENT '门店登录密码',
  `chain_truename` varchar(20) NOT NULL COMMENT '真实姓名',
  `chain_mobile` varchar(11) NOT NULL COMMENT '手机号码',
  `chain_telephony` varchar(20) DEFAULT NULL COMMENT '座机号码',
  `chain_addressname` varchar(20) NOT NULL COMMENT '服务站名称',
  `chain_area_2` int(10) unsigned NOT NULL COMMENT '二级地区id',
  `chain_area_3` int(10) unsigned NOT NULL COMMENT '三级地区id',
  `chain_area_info` varchar(255) NOT NULL COMMENT '门店地区内容',
  `chain_address` varchar(255) NOT NULL COMMENT '门店详细地址',
  `chain_idcard` varchar(18) NOT NULL DEFAULT '' COMMENT '身份证号码',
  `chain_idcardimage` varchar(255) NOT NULL DEFAULT '' COMMENT '身份证照片',
  `chain_addtime` int(10) unsigned NOT NULL COMMENT '门店添加时间',
  `chain_state` tinyint(3) unsigned NOT NULL COMMENT '门店状态 0关闭，1开启，10等待审核, 20审核失败',
  `chain_failreason` varchar(255) DEFAULT NULL COMMENT '失败原因',
  `chain_longitude` varchar(20) DEFAULT '' COMMENT '经度',
  `chain_latitude` varchar(20) DEFAULT '' COMMENT '纬度',
  `chain_if_pickup` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '是否支持自提',
  `chain_if_collect` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '是否支持代收',
  PRIMARY KEY (`chain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='门店表';


DROP TABLE IF EXISTS `#__chain_goods`;
CREATE TABLE IF NOT EXISTS `#__chain_goods` (
  `chain_goods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `chain_id` int(10) unsigned NOT NULL COMMENT '门店ID',
  `goods_storage` int(10) unsigned NOT NULL COMMENT '库存',
  PRIMARY KEY (`chain_goods_id`),
  UNIQUE KEY `goods_id_2` (`goods_id`,`chain_id`),
  KEY `goods_id` (`goods_id`),
  KEY `goods_commonid` (`goods_commonid`),
  KEY `store_id` (`store_id`),
  KEY `chain_id` (`chain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='门店商品' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__chain_order`;
CREATE TABLE IF NOT EXISTS `#__chain_order` (
  `chain_order_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `order_id` int(11) NOT NULL COMMENT '订单ID',
  `order_goods_id` int(10) unsigned DEFAULT '0' COMMENT '订单商品ID,0:全部商品',
  `chain_order_type` tinyint(11) unsigned NOT NULL DEFAULT '0' COMMENT '门店订单类型（1代收2自提）',
  `chain_order_pickup_code` varchar(4) DEFAULT NULL COMMENT '订单提货码',
  `chain_order_add_time` int(11) DEFAULT '0' COMMENT '订单生成时间',
  `order_sn` varchar(20) DEFAULT NULL COMMENT '订单号',
  `chain_id` int(11) DEFAULT NULL COMMENT '门店ID',
  `store_id` int(11) unsigned NOT NULL COMMENT '卖家店铺ID',
  `payment_code` char(20) NOT NULL DEFAULT '' COMMENT '支付方式名称代码',
  `shipping_code` varchar(50) DEFAULT NULL COMMENT '物流单号',
  `express_code` varchar(30) DEFAULT NULL COMMENT '快递公司编码',
  `express_name` varchar(30) DEFAULT NULL COMMENT '快递公司名称',
  `chain_order_state` tinyint(1) unsigned NOT NULL DEFAULT '10' COMMENT '门店订单状态（0:取消 10:默认 20:未到站 30:已发货 35:待自提 40:已收货）',
  `chain_order_refund_state` tinyint(1) unsigned DEFAULT '0' COMMENT '退款状态 0:无退款 2:全部退款',
  `chain_order_lock_state` tinyint(1) unsigned DEFAULT '0' COMMENT '锁定状态:0:正常,大于0:锁定',
  PRIMARY KEY (`chain_order_id`),
  KEY `order_id` (`order_id`),
  KEY `order_goods_id` (`order_goods_id`),
  KEY `chain_id` (`chain_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='门店订单表';

DROP TABLE IF EXISTS `#__document`;
CREATE TABLE IF NOT EXISTS `#__document` (
  `document_id` mediumint(11) NOT NULL AUTO_INCREMENT COMMENT '系统文章自增ID',
  `document_code` varchar(255) NOT NULL COMMENT '调用标识码',
  `document_title` varchar(255) NOT NULL COMMENT '系统文章标题',
  `document_content` text NOT NULL COMMENT '系统文章内容',
  `document_time` int(10) unsigned NOT NULL COMMENT '添加时间/修改时间',
  PRIMARY KEY (`document_id`),
  UNIQUE KEY `document_code` (`document_code`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='系统文章表';



DROP TABLE IF EXISTS `#__editable_page`;
CREATE TABLE IF NOT EXISTS `#__editable_page` (
  `editable_page_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '页面类型id',
  `editable_page_name` varchar(60) NOT NULL COMMENT '页面名称',
  `editable_page_path` varchar(60) NOT NULL DEFAULT '' COMMENT 'index/index商场首页store/index店铺首页special/index专题活动页',
  `editable_page_item_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '页面项目id',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺id',
  `editable_page_client` varchar(10) NOT NULL COMMENT '客户端pc、h5',
  `editable_page_theme` varchar(60) NOT NULL COMMENT '页面主题',
  `editable_page_theme_config` text NOT NULL COMMENT '页面主题配置',
  `editable_page_edit_time` int(10) unsigned NOT NULL COMMENT '页面编辑时间',
  PRIMARY KEY (`editable_page_id`),
  KEY `store_id` (`store_id`),
  KEY `editable_page_item_id` (`editable_page_item_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='可编辑页面表';



DROP TABLE IF EXISTS `#__editable_page_config`;
CREATE TABLE IF NOT EXISTS `#__editable_page_config` (
  `editable_page_config_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '页面配置id',
  `editable_page_id` int(10) unsigned NOT NULL COMMENT '页面id',
  `editable_page_model_id` int(10) unsigned NOT NULL COMMENT '页面模块id',
  `editable_page_config_sort_order` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '排序',
  `editable_page_config_content` text COMMENT '配置内容',
  PRIMARY KEY (`editable_page_config_id`),
  KEY `editable_page_id` (`editable_page_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='可编辑页面配置表';



DROP TABLE IF EXISTS `#__editable_page_model`;
CREATE TABLE IF NOT EXISTS `#__editable_page_model` (
  `editable_page_model_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '页面模块id',
  `editable_page_model_name` varchar(60) NOT NULL COMMENT '页面模块名称',
  `editable_page_model_intro` varchar(255) NOT NULL DEFAULT '' COMMENT '页面模块简介',
  `editable_page_model_type` text NOT NULL COMMENT 'mall商城store店铺，空表示通用',
  `editable_page_theme` text NOT NULL COMMENT '页面主题，多个用|分隔，空表示通用',
  `editable_page_model_client` varchar(10) NOT NULL DEFAULT '' COMMENT '客户端pc、h5，空表示通用',
  `editable_page_model_content` text NOT NULL COMMENT '配置内容',
  PRIMARY KEY (`editable_page_model_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='可编辑页面模块表';



DROP TABLE IF EXISTS `#__evaluategoods`;
CREATE TABLE IF NOT EXISTS `#__evaluategoods` (
  `geval_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '信誉评价自增ID',
  `geval_orderid` int(11) NOT NULL COMMENT '订单表ID',
  `geval_orderno` varchar(20) NOT NULL COMMENT '订单编号',
  `geval_ordergoodsid` int(11) NOT NULL COMMENT '订单商品表编号',
  `geval_goodsid` int(11) NOT NULL COMMENT '商品表编号',
  `geval_goodsname` varchar(100) NOT NULL COMMENT '商品名称',
  `geval_goodsprice` decimal(10,2) DEFAULT NULL COMMENT '商品价格',
  `geval_goodsimage` varchar(255) DEFAULT NULL COMMENT '商品图片',
  `geval_scores` tinyint(1) NOT NULL COMMENT '1-5分',
  `geval_content` varchar(255) DEFAULT NULL COMMENT '信誉评价内容',
  `geval_isanonymous` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0:不是 1:匿名评价',
  `geval_addtime` int(11) NOT NULL COMMENT '评价时间',
  `geval_storeid` int(11) NOT NULL COMMENT '店铺编号',
  `geval_storename` varchar(100) NOT NULL COMMENT '店铺名称',
  `geval_frommemberid` int(11) NOT NULL COMMENT '评价人编号',
  `geval_frommembername` varchar(100) NOT NULL COMMENT '评价人名称',
  `geval_state` tinyint(1) NOT NULL DEFAULT '0' COMMENT '评价信息的状态 0为正常 1为禁止显示',
  `geval_remark` varchar(255) DEFAULT NULL COMMENT '管理员对评价的处理备注',
  `geval_explain` varchar(255) DEFAULT NULL COMMENT '解释内容',
  `geval_image` varchar(255) DEFAULT NULL COMMENT '晒单图片',
  PRIMARY KEY (`geval_id`),
  KEY `geval_orderid` (`geval_orderid`),
  KEY `geval_ordergoodsid` (`geval_ordergoodsid`),
  KEY `geval_goodsid` (`geval_goodsid`),
  KEY `geval_storeid` (`geval_storeid`),
  KEY `geval_frommemberid` (`geval_frommemberid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='信誉评价表';



DROP TABLE IF EXISTS `#__evaluatestore`;
CREATE TABLE IF NOT EXISTS `#__evaluatestore` (
  `seval_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '店铺评分自增ID',
  `seval_orderid` int(11) unsigned NOT NULL COMMENT '订单ID',
  `seval_orderno` varchar(100) NOT NULL COMMENT '订单编号',
  `seval_addtime` int(11) unsigned NOT NULL COMMENT '评价时间',
  `seval_storeid` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `seval_storename` varchar(100) NOT NULL COMMENT '店铺名称',
  `seval_memberid` int(11) unsigned NOT NULL COMMENT '买家ID',
  `seval_membername` varchar(100) NOT NULL COMMENT '买家名称',
  `seval_desccredit` tinyint(1) unsigned NOT NULL DEFAULT '5' COMMENT '描述相符评分',
  `seval_servicecredit` tinyint(1) unsigned NOT NULL DEFAULT '5' COMMENT '服务态度评分',
  `seval_deliverycredit` tinyint(1) unsigned NOT NULL DEFAULT '5' COMMENT '发货速度评分',
  PRIMARY KEY (`seval_id`),
  KEY `seval_orderid` (`seval_orderid`),
  KEY `seval_storeid` (`seval_storeid`),
  KEY `seval_memberid` (`seval_memberid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺评分表';



DROP TABLE IF EXISTS `#__exppointslog`;
CREATE TABLE IF NOT EXISTS `#__exppointslog` (
  `explog_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '经验值日志自增ID',
  `explog_memberid` int(11) NOT NULL COMMENT '会员ID',
  `explog_membername` varchar(100) NOT NULL COMMENT '会员名称',
  `explog_points` int(11) NOT NULL DEFAULT '0' COMMENT '经验值负数表示扣除',
  `explog_addtime` int(11) NOT NULL COMMENT '经验值添加时间',
  `explog_desc` varchar(100) NOT NULL COMMENT '经验值操作描述',
  `explog_stage` varchar(50) NOT NULL COMMENT '经验值操作状态',
  PRIMARY KEY (`explog_id`),
  KEY `explog_memberid` (`explog_memberid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='经验值日志表';



DROP TABLE IF EXISTS `#__express`;
CREATE TABLE IF NOT EXISTS `#__express` (
  `express_id` tinyint(1) unsigned NOT NULL AUTO_INCREMENT COMMENT '快递公司自增ID',
  `express_name` varchar(50) NOT NULL COMMENT '快递公司名称',
  `express_state` enum('0','1') NOT NULL DEFAULT '1' COMMENT '快递公司状态',
  `express_code` varchar(50) NOT NULL COMMENT '快递公司编号',
  `express_letter` char(1) NOT NULL COMMENT '快递公司首字母',
  `express_order` enum('1','2') NOT NULL DEFAULT '2' COMMENT '1:常用2:不常用',
  `express_url` varchar(100) NOT NULL COMMENT '快递公司网址',
  PRIMARY KEY (`express_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='快递公司';


DROP TABLE IF EXISTS `#__expresscf_kdn_config`;
CREATE TABLE IF NOT EXISTS `#__expresscf_kdn_config` (
  `expresscf_kdn_config_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '快递鸟电子面单ID',
  `expresscf_kdn_config_customer_name` varchar(50) NOT NULL COMMENT '账号',
  `expresscf_kdn_config_customer_pwd` varchar(30) NOT NULL COMMENT '密钥',
  `expresscf_kdn_config_send_site` varchar(30) NOT NULL COMMENT '所属网点',
  `expresscf_kdn_config_send_staff` varchar(30) NOT NULL COMMENT '收件员',
  `expresscf_kdn_config_month_code` varchar(20) NOT NULL COMMENT '月结号',
  `express_code` varchar(30) NOT NULL COMMENT '快递公司编码',
  `expresscf_kdn_config_pay_type` int(1) unsigned NOT NULL COMMENT '运费支付方式',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  PRIMARY KEY (`expresscf_kdn_config_id`),
  UNIQUE KEY `express_code` (`express_code`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='快递鸟电子面单' AUTO_INCREMENT=1 ;


DROP TABLE IF EXISTS `#__favorites`;
CREATE TABLE IF NOT EXISTS `#__favorites` (
  `favlog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '收藏记录自增ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员名',
  `fav_id` int(10) unsigned NOT NULL COMMENT '商品ID或店铺ID',
  `fav_type` char(5) NOT NULL DEFAULT 'goods' COMMENT '类型:goods为商品,store为店铺',
  `fav_time` int(10) unsigned NOT NULL COMMENT '收藏时间',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(20) NOT NULL COMMENT '店铺名称',
  `storeclass_id` int(10) unsigned DEFAULT '0' COMMENT '店铺分类ID',
  `goods_name` varchar(200) DEFAULT NULL COMMENT '商品名称',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `gc_id` int(10) unsigned DEFAULT '0' COMMENT '商品分类ID',
  `favlog_price` decimal(10,2) DEFAULT '0.00' COMMENT '商品收藏时价格',
  `favlog_msg` varchar(20) DEFAULT NULL COMMENT '收藏备注',
  PRIMARY KEY (`favlog_id`),
  KEY `member_id` (`member_id`),
  KEY `fav_id` (`fav_id`,`fav_type`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='收藏表';



DROP TABLE IF EXISTS `#__feedback`;
CREATE TABLE IF NOT EXISTS `#__feedback` (
  `fb_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '反馈自增ID',
  `fb_content` varchar(500) DEFAULT NULL COMMENT '反馈内容',
  `fb_type` varchar(50) DEFAULT NULL COMMENT '1:手机端 2:PC端',
  `fb_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '反馈时间',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  PRIMARY KEY (`fb_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='意见反馈';



DROP TABLE IF EXISTS `#__flea`;
CREATE TABLE IF NOT EXISTS `#__flea` (
  `goods_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '闲置自增ID',
  `goods_name` varchar(200) NOT NULL COMMENT '闲置名称',
  `fleaclass_id` int(11) NOT NULL COMMENT '闲置分类ID',
  `fleaclass_name` varchar(200) NOT NULL COMMENT '闲置分类名称',
  `member_id` int(11) NOT NULL COMMENT '店铺ID',
  `member_name` varchar(110) NOT NULL COMMENT '会员名称',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '闲置默认封面图片',
  `goods_tag` varchar(100) NOT NULL COMMENT '闲置标签',
  `goods_price` decimal(10,2) NOT NULL COMMENT '闲置原价',
  `goods_store_price` decimal(10,2) NOT NULL COMMENT '闲置转让价格',
  `goods_show` tinyint(1) NOT NULL COMMENT '闲置上架',
  `goods_click` int(11) NOT NULL DEFAULT '0' COMMENT '闲置浏览数',
  `flea_collect_num` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '闲置物品总收藏次数',
  `goods_commend` tinyint(1) NOT NULL DEFAULT '0' COMMENT '闲置推荐',
  `goods_addtime` varchar(10) NOT NULL COMMENT '闲置添加时间',
  `goods_keywords` varchar(255) NOT NULL COMMENT '闲置关键字',
  `goods_description` varchar(255) NOT NULL COMMENT '闲置描述',
  `goods_body` text NOT NULL COMMENT '商品详细内容',
  `flea_commentnum` int(11) NOT NULL DEFAULT '0' COMMENT '评论次数',
  `flea_salenum` int(11) NOT NULL DEFAULT '0' COMMENT '售出数量',
  `flea_quality` tinyint(4) NOT NULL DEFAULT '0' COMMENT '闲置物品成色，0未选择，9-5九五成新，3是低于五成新',
  `flea_pname` varchar(20) DEFAULT NULL COMMENT '闲置商品联系人',
  `flea_pphone` varchar(20) DEFAULT NULL COMMENT '闲置商品联系人电话',
  `fleaarea_id` int(11) unsigned NOT NULL COMMENT '闲置物品地区id',
  `fleaarea_name` varchar(50) NOT NULL COMMENT '闲置物品地区名称',
  PRIMARY KEY (`goods_id`),
  KEY `goods_name` (`goods_name`,`fleaclass_id`,`member_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='闲置商品';



DROP TABLE IF EXISTS `#__fleaarea`;
CREATE TABLE IF NOT EXISTS `#__fleaarea` (
  `fleaarea_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '闲置地区自增ID',
  `fleaarea_name` varchar(50) NOT NULL COMMENT '闲置地区名称',
  `fleaarea_parent_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '闲置地区上级地区ID',
  `fleaarea_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '闲置地区排序',
  `fleaarea_deep` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '闲置地区层级',
  `fleaarea_hot` int(11) NOT NULL DEFAULT '0' COMMENT '地区检索热度',
  PRIMARY KEY (`fleaarea_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='闲置地区';



DROP TABLE IF EXISTS `#__fleaclass`;
CREATE TABLE IF NOT EXISTS `#__fleaclass` (
  `fleaclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '闲置分类自增ID',
  `fleaclass_name` varchar(100) NOT NULL COMMENT '闲置分类名称',
  `fleaclass_name_index` varchar(100) DEFAULT NULL COMMENT '闲置首页显示的名称',
  `fleaclass_parent_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上级ID',
  `fleaclass_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '闲置分类排序',
  `fleaclass_show` tinyint(1) NOT NULL DEFAULT '1' COMMENT '前台显示 0:否 1:是',
  `fleaclass_index_show` tinyint(1) NOT NULL DEFAULT '1' COMMENT '首页显示 1:显示 0:不显示',
  PRIMARY KEY (`fleaclass_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='闲置分类';



DROP TABLE IF EXISTS `#__fleaclassindex`;
CREATE TABLE IF NOT EXISTS `#__fleaclassindex` (
  `fcindex_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增id',
  `fcindex_class` varchar(50) NOT NULL COMMENT '类别名称',
  `fcindex_code` varchar(50) NOT NULL COMMENT '类别code',
  `fcindex_id1` varchar(50) NOT NULL DEFAULT '0' COMMENT '分类id1',
  `fcindex_name1` varchar(50) NOT NULL,
  `fcindex_id2` varchar(50) NOT NULL DEFAULT '0' COMMENT '分类id2',
  `fcindex_name2` varchar(50) NOT NULL,
  `fcindex_id3` varchar(50) NOT NULL DEFAULT '0' COMMENT '分类id3',
  `fcindex_name3` varchar(50) NOT NULL,
  `fcindex_id4` varchar(50) NOT NULL DEFAULT '0' COMMENT '分类id4',
  `fcindex_name4` varchar(50) NOT NULL,
  PRIMARY KEY (`fcindex_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='闲置首页分类';



DROP TABLE IF EXISTS `#__fleaconsult`;
CREATE TABLE IF NOT EXISTS `#__fleaconsult` (
  `fleaconsult_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '闲置咨询自增ID',
  `goods_id` int(11) DEFAULT '0' COMMENT '商品ID',
  `member_id` int(11) NOT NULL DEFAULT '0' COMMENT '咨询发布者会员编号(0：游客)',
  `seller_id` int(11) NOT NULL COMMENT '信息发布者编号',
  `fleaconsult_email` varchar(255) DEFAULT NULL COMMENT '闲置咨询发布者邮箱',
  `fleaconsult_content` varchar(4000) DEFAULT NULL COMMENT '闲置咨询内容',
  `fleaconsult_addtime` int(10) DEFAULT NULL COMMENT '闲置咨询发布时间',
  `fleaconsult_reply` varchar(4000) DEFAULT NULL COMMENT '闲置咨询回复内容',
  `fleaconsult_reply_time` int(10) DEFAULT NULL COMMENT '闲置咨询回复时间',
  `fleaconsult_type` varchar(20) NOT NULL DEFAULT 'flea' COMMENT '闲置咨询类型',
  PRIMARY KEY (`fleaconsult_id`),
  KEY `member_id` (`member_id`),
  KEY `seller_id` (`seller_id`),
  KEY `goods_id` (`goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='闲置咨询';



DROP TABLE IF EXISTS `#__fleafavorites`;
CREATE TABLE IF NOT EXISTS `#__fleafavorites` (
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `fleafav_id` int(10) unsigned NOT NULL COMMENT '收藏ID',
  `fleafav_type` varchar(20) NOT NULL COMMENT '闲置收藏类型',
  `fleafav_time` varchar(10) NOT NULL COMMENT '闲置收藏时间',
  KEY `member_id` (`member_id`),
  KEY `fleafav_id` (`fleafav_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='买家闲置收藏表';



DROP TABLE IF EXISTS `#__fleaupload`;
CREATE TABLE IF NOT EXISTS `#__fleaupload` (
  `fleaupload_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '闲置上传文件自增ID',
  `fleafile_name` varchar(100) DEFAULT NULL COMMENT '文件名',
  `fleafile_size` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '文件大小',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '会员ID',
  `fleaupload_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '默认为0，12为商品切换图片，13为商品内容图片',
  `fleaupload_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '添加时间',
  `item_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '信息ID',
  PRIMARY KEY (`fleaupload_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='闲置上传文件表';



DROP TABLE IF EXISTS `#__flowstat`;
CREATE TABLE IF NOT EXISTS `#__flowstat` (
  `flowstat_stattime` int(11) unsigned NOT NULL COMMENT '访问日期',
  `flowstat_clicknum` int(11) unsigned NOT NULL COMMENT '访问量',
  `flowstat_type` varchar(10) NOT NULL COMMENT '类型',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `goods_id` int(11) unsigned NOT NULL COMMENT '商品ID',
  KEY `store_id` (`store_id`),
  KEY `goods_id` (`goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='访问量统计表';



DROP TABLE IF EXISTS `#__gadmin`;
CREATE TABLE IF NOT EXISTS `#__gadmin` (
  `gid` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT '权限自增id',
  `gname` varchar(50) DEFAULT NULL COMMENT '权限组名',
  `glimits` text COMMENT '权限组序列',
  PRIMARY KEY (`gid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='权限组';



DROP TABLE IF EXISTS `#__goods`;
CREATE TABLE IF NOT EXISTS `#__goods` (
  `goods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品自增ID(SKU)',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表id',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称+规格名称',
  `goods_advword` varchar(150) DEFAULT NULL COMMENT '商品广告词',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类ID',
  `gc_id_1` int(10) DEFAULT NULL COMMENT '一级分类ID',
  `gc_id_2` int(10) DEFAULT NULL COMMENT '二级分类ID',
  `gc_id_3` int(10) DEFAULT NULL COMMENT '三级分类ID',
  `brand_id` int(10) unsigned DEFAULT '0' COMMENT '品牌ID',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `goods_promotion_price` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '商品促销价格',
  `goods_promotion_type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '促销类型 0:无促销 1:抢购 2:限时折扣',
  `goods_marketprice` decimal(10,2) DEFAULT NULL COMMENT '商品市场价',
  `goods_serial` varchar(50) NOT NULL COMMENT '商家编号',
  `goods_storage_alarm` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品库存报警值',
  `goods_click` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品点击数量',
  `goods_salenum` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品销售数量',
  `goods_collect` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品收藏数量',
  `goods_spec` text NOT NULL COMMENT '商品规格序列化',
  `goods_storage` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品库存',
  `goods_weight` decimal(5,3) unsigned NOT NULL DEFAULT '0.000' COMMENT '商品重量',
  `goods_image` varchar(100) DEFAULT '' COMMENT '商品主图',
  `goods_lock` tinyint(3) unsigned DEFAULT '0' COMMENT '商品锁定 0未锁，1已锁',
  `goods_state` tinyint(3) unsigned DEFAULT '0' COMMENT '商品状态 0:下架 1:正常，10:违规（禁售）',
  `goods_verify` tinyint(3) unsigned DEFAULT NULL COMMENT '商品审核 1:通过 0:未通过 10:审核中',
  `goods_addtime` int(10) unsigned NOT NULL COMMENT '商品添加时间',
  `goods_edittime` int(10) unsigned NOT NULL COMMENT '商品编辑时间',
  `areaid_1` int(10) unsigned DEFAULT NULL COMMENT '一级地区id',
  `areaid_2` int(10) unsigned DEFAULT NULL COMMENT '二级地区id',
  `region_id` int(10) unsigned DEFAULT '0' COMMENT '一级地区id',
  `color_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '颜色规格id',
  `transport_id` mediumint(8) unsigned DEFAULT '0' COMMENT '售卖区域id',
  `goods_freight` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '运费 0:免运费',
  `goods_vat` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否开具增值税发票 1:是 0:否',
  `goods_commend` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品推荐 1:是 0:否',
  `goods_stcids` varchar(255) NOT NULL DEFAULT '' COMMENT '店铺分类ID 首尾用,隔开',
  `evaluation_good_star` tinyint(3) unsigned NOT NULL DEFAULT '5' COMMENT '好评星级',
  `evaluation_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '评价数',
  `is_virtual` tinyint(3) DEFAULT '0' COMMENT '是否为虚拟商品 1:是 0:否',
  `virtual_indate` int(10) DEFAULT NULL COMMENT '虚拟商品有效期',
  `virtual_limit` tinyint(3) unsigned DEFAULT NULL COMMENT '虚拟商品购买上限',
  `virtual_invalid_refund` tinyint(3) unsigned DEFAULT '1' COMMENT '是否允许过期退款 1:是 0:否',
  `virtual_content` TEXT COMMENT '虚拟商品内容',
  `is_goodsfcode` tinyint(4) DEFAULT '0' COMMENT '是否为F码商品 1:是 0:否',
  `is_appoint` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否是预约商品 1:是 0:否',
  `is_have_gift` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否拥有赠品',
  `is_platform_store` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否为平台自营',
  `goods_mgdiscount` text COMMENT '序列化会员等级折扣(商品)',
  `goods_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺排序',
  PRIMARY KEY (`goods_id`),
  KEY `store_id` (`store_id`),
  KEY `gc_id` (`gc_id`),
  KEY `gc_id_1` (`gc_id_1`),
  KEY `gc_id_2` (`gc_id_2`),
  KEY `gc_id_3` (`gc_id_3`),
  KEY `brand_id` (`brand_id`),
  KEY `goods_commonid` (`goods_commonid`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品表';



DROP TABLE IF EXISTS `#__goodsattrindex`;
CREATE TABLE IF NOT EXISTS `#__goodsattrindex` (
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表ID',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类ID',
  `type_id` int(10) unsigned NOT NULL COMMENT '类型ID',
  `attr_id` int(10) unsigned NOT NULL COMMENT '属性ID',
  `attrvalue_id` int(10) unsigned NOT NULL COMMENT '属性值ID',
  PRIMARY KEY (`goods_id`,`gc_id`,`attrvalue_id`),
  KEY `goods_id` (`goods_id`),
  KEY `attrvalue_id` (`attrvalue_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品与属性对应表';



DROP TABLE IF EXISTS `#__goodsbrowse`;
CREATE TABLE IF NOT EXISTS `#__goodsbrowse` (
  `goodsbrowse_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `goods_id` int(11) NOT NULL COMMENT '商品ID',
  `member_id` int(11) NOT NULL COMMENT '会员ID',
  `goodsbrowse_time` int(11) NOT NULL COMMENT '浏览时间',
  `gc_id` int(11) NOT NULL COMMENT '商品分类',
  `gc_id_1` int(11) NOT NULL COMMENT '商品一级分类',
  `gc_id_2` int(11) NOT NULL COMMENT '商品二级分类',
  `gc_id_3` int(11) NOT NULL COMMENT '商品三级分类',
  PRIMARY KEY (`goodsbrowse_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品浏览历史表';



DROP TABLE IF EXISTS `#__goodsclass`;
CREATE TABLE IF NOT EXISTS `#__goodsclass` (
  `gc_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品分类自增ID',
  `gc_name` varchar(100) NOT NULL COMMENT '商品分类名称',
  `gc_image` varchar(100) DEFAULT '' COMMENT '商品分类图',
  `type_id` int(10) unsigned NOT NULL COMMENT '类型id',
  `type_name` varchar(100) NOT NULL COMMENT '类型名称',
  `gc_parent_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品分类上级ID',
  `commis_rate` float unsigned NOT NULL DEFAULT '0' COMMENT '商品分类佣金比例',
  `gc_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '商品分类排序',
  `gc_virtual` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否允许发布虚拟商品 1:是 0:否',
  `gc_title` varchar(200) DEFAULT NULL COMMENT '商品分类名称',
  `gc_keywords` varchar(255) DEFAULT '' COMMENT '商品分类关键词',
  `gc_description` varchar(255) DEFAULT '' COMMENT '商品分类描述',
  `gc_show` tinyint(1) NOT NULL DEFAULT '1' COMMENT '商品分类前台显示 0:否 1:是',
  PRIMARY KEY (`gc_id`),
  KEY `store_id` (`gc_parent_id`),
  KEY `gc_parent_id` (`gc_parent_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品分类表';



DROP TABLE IF EXISTS `#__goodsclassnav`;
CREATE TABLE IF NOT EXISTS `#__goodsclassnav` (
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类ID',
  `goodscn_alias` varchar(100) DEFAULT '' COMMENT '商品分类别名',
  `goodscn_classids` varchar(100) DEFAULT '' COMMENT '推荐子级分类',
  `goodscn_brandids` varchar(100) DEFAULT '' COMMENT '推荐的品牌',
  `goodscn_pic` varchar(100) DEFAULT '' COMMENT '分类图片',
  `goodscn_adv1` varchar(100) DEFAULT '' COMMENT '广告图1',
  `goodscn_adv1_link` varchar(100) DEFAULT '' COMMENT '广告1链接',
  `goodscn_adv2` varchar(100) DEFAULT '' COMMENT '广告图2',
  `goodscn_adv2_link` varchar(100) NOT NULL COMMENT '广告2链接',
  PRIMARY KEY (`gc_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='分类导航表';



DROP TABLE IF EXISTS `#__goodsclassstaple`;
CREATE TABLE IF NOT EXISTS `#__goodsclassstaple` (
  `staple_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '常用分类id',
  `staple_counter` int(10) unsigned NOT NULL DEFAULT '1' COMMENT '计数器',
  `staple_name` varchar(255) NOT NULL COMMENT '常用分类名称',
  `gc_id_1` int(10) unsigned NOT NULL COMMENT '一级分类id',
  `gc_id_2` int(10) unsigned NOT NULL COMMENT '二级商品分类',
  `gc_id_3` int(10) unsigned NOT NULL COMMENT '三级商品分类',
  `type_id` int(10) unsigned NOT NULL COMMENT '类型id',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员id',
  PRIMARY KEY (`staple_id`),
  KEY `store_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺常用分类表';



DROP TABLE IF EXISTS `#__goodsclasstag`;
CREATE TABLE IF NOT EXISTS `#__goodsclasstag` (
  `gctag_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'TAG自增ID',
  `gctag_name` varchar(255) NOT NULL COMMENT '分类TAG名称',
  `gctag_value` text NOT NULL COMMENT '分类TAG值',
  `type_id` int(10) unsigned NOT NULL COMMENT '类型ID',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类ID',
  `gc_id_1` int(10) unsigned NOT NULL COMMENT '一级分类ID',
  `gc_id_2` int(10) unsigned NOT NULL COMMENT '二级分类ID',
  `gc_id_3` int(10) unsigned NOT NULL COMMENT '三级分类ID',
  PRIMARY KEY (`gctag_id`),
  KEY `gc_id` (`gc_id`),
  KEY `type_id` (`type_id`),
  KEY `gc_id_1` (`gc_id_1`),
  KEY `gc_id_2` (`gc_id_2`),
  KEY `gc_id_3` (`gc_id_3`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品分类TAG表';



DROP TABLE IF EXISTS `#__goodscombo`;
CREATE TABLE IF NOT EXISTS `#__goodscombo` (
  `combo_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '推荐组合自增ID ',
  `goods_id` int(10) unsigned NOT NULL COMMENT '主商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  `combo_goodsid` int(10) unsigned NOT NULL COMMENT '推荐组合商品ID',
  PRIMARY KEY (`combo_id`),
  KEY `goods_id` (`goods_id`),
  KEY `combo_goodsid` (`combo_goodsid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品推荐组合表';



DROP TABLE IF EXISTS `#__goodscommon`;
CREATE TABLE IF NOT EXISTS `#__goodscommon` (
  `goods_commonid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品公共表id',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_advword` varchar(150) DEFAULT NULL COMMENT '商品广告词',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类',
  `gc_id_1` int(10) unsigned DEFAULT NULL COMMENT '一级分类id',
  `gc_id_2` int(10) unsigned DEFAULT NULL COMMENT '二级分类id',
  `gc_id_3` int(10) unsigned DEFAULT NULL COMMENT '三级分类id',
  `gc_name` varchar(200) NOT NULL COMMENT '商品分类',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `spec_name` varchar(255) NOT NULL COMMENT '规格名称',
  `spec_value` text NOT NULL COMMENT '规格值',
  `brand_id` int(10) unsigned DEFAULT '0' COMMENT '品牌id',
  `brand_name` varchar(100) DEFAULT NULL COMMENT '品牌名称',
  `type_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '类型id',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品主图',
  `goodsvideo_name` varchar(100) DEFAULT NULL COMMENT '商品视频名称',
  `goods_attr` text NOT NULL COMMENT '商品属性',
  `goods_body` text COMMENT '商品内容',
  `mobile_body` text COMMENT '手机端商品描述',
  `goods_state` tinyint(3) unsigned DEFAULT '0' COMMENT '商品状态 0:下架 1:正常 10:违规（禁售）',
  `goods_stateremark` varchar(255) DEFAULT NULL COMMENT '违规原因',
  `goods_verify` tinyint(3) unsigned DEFAULT NULL COMMENT '商品审核 1通过，0未通过，10审核中',
  `goods_verifyremark` varchar(255) DEFAULT NULL COMMENT '审核失败原因',
  `goods_lock` tinyint(3) unsigned DEFAULT '0' COMMENT '商品锁定 0未锁，1已锁',
  `goods_addtime` int(10) unsigned NOT NULL COMMENT '商品添加时间',
  `goods_shelftime` int(10) unsigned NOT NULL COMMENT '上架时间',
  `goods_specname` text COMMENT '规格名称序列化（下标为规格id）',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `goods_marketprice` decimal(10,2) DEFAULT NULL COMMENT '商品市场价',
  `goods_costprice` decimal(10,2) NOT NULL COMMENT '商品成本价',
  `goods_discount` float unsigned NOT NULL COMMENT '商品折扣',
  `goods_serial` varchar(50) NOT NULL COMMENT '商家编号',
  `goods_storage_alarm` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品库存报警值',
  `transport_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '商品售卖区域',
  `transport_title` varchar(60) DEFAULT '' COMMENT '商品售卖区域名称',
  `goods_commend` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品推荐 1:是 0:否',
  `goods_freight` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '商品运费 0为免运费',
  `goods_vat` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品是否开具增值税发票 1:是 0:否',
  `areaid_1` int(10) DEFAULT NULL COMMENT '一级地区id',
  `areaid_2` int(10) DEFAULT NULL COMMENT '二级地区id',
  `goods_stcids` varchar(255) NOT NULL DEFAULT '' COMMENT '店铺分类id 首尾用,隔开',
  `plateid_top` int(10) unsigned DEFAULT NULL COMMENT '顶部关联板式',
  `plateid_bottom` int(10) unsigned DEFAULT NULL COMMENT '底部关联板式',
  `is_virtual` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否为虚拟商品 1:是 0:否',
  `virtual_type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '虚拟商品类型 0:核销商品 1:卡券商品 2:网盘商品 3:下载商品',
  `virtual_indate` int(10) unsigned DEFAULT NULL COMMENT '虚拟商品有效期',
  `virtual_limit` tinyint(3) unsigned DEFAULT NULL COMMENT '虚拟商品购买上限',
  `virtual_invalid_refund` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '是否允许过期退款 1:是 0:否',
  `is_goodsfcode` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否为F码商品 1:是 0:否',
  `is_appoint` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否是预约商品 1:是 0:否',
  `appoint_satedate` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '预约商品出售时间',
  `is_platform_store` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否为平台自营',
  `goods_mgdiscount` text COMMENT '序列化会员等级折扣(商品)',
  `inviter_ratio` decimal(4,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '分销比例',
  `inviter_total_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '已分销的商品数量',
  `inviter_total_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '已分销的商品金额',
  `inviter_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '商品已结算的分销佣金',
  `inviter_open` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '开启推广',
  `mall_goods_commend` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品推荐 1:是 0:否',
  `mall_goods_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '商品推荐排序',
  `goods_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺排序',
  `store_service_ids` text COMMENT '店铺服务ID列表 首尾用,隔开',
  PRIMARY KEY (`goods_commonid`),
  KEY `store_id` (`store_id`),
  KEY `gc_id` (`gc_id`),
  KEY `gc_id_1` (`gc_id_1`),
  KEY `gc_id_2` (`gc_id_2`),
  KEY `gc_id_3` (`gc_id_3`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品公共内容表';



DROP TABLE IF EXISTS `#__goodsfcode`;
CREATE TABLE IF NOT EXISTS `#__goodsfcode` (
  `goodsfcode_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'F码自增ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共ID',
  `goodsfcode_code` varchar(20) NOT NULL COMMENT 'F码内容',
  `goodsfcode_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态 0:未使用 1:已使用',
  PRIMARY KEY (`goodsfcode_id`),
  KEY `goods_commonid` (`goods_commonid`),
  KEY `goodsfcode_code` (`goodsfcode_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品F码';

DROP TABLE IF EXISTS `#__goodsvideo`;
CREATE TABLE IF NOT EXISTS `#__goodsvideo` (
  `goodsvideo_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品视频id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `goodsvideo_name` varchar(100) NOT NULL COMMENT '视频文件名',
  `goodsvideo_add_time` int(10) unsigned NOT NULL COMMENT '新增时间',
  PRIMARY KEY (`goodsvideo_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品视频' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__goodsgift`;
CREATE TABLE IF NOT EXISTS `#__goodsgift` (
  `gift_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '赠品ID',
  `gift_goodsid` int(10) unsigned NOT NULL COMMENT '赠品商品ID',
  `gift_goodsname` varchar(50) NOT NULL COMMENT '主商品名称',
  `gift_goodsimage` varchar(100) NOT NULL COMMENT '主商品图片',
  `gift_amount` tinyint(3) unsigned NOT NULL COMMENT '赠品数量',
  `goods_id` int(10) unsigned NOT NULL COMMENT '主商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  PRIMARY KEY (`gift_id`),
  KEY `goods_id` (`goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品赠品表';



DROP TABLE IF EXISTS `#__goodsimages`;
CREATE TABLE IF NOT EXISTS `#__goodsimages` (
  `goodsimage_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品图片自增ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `color_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '颜色规格值ID',
  `goodsimage_url` varchar(1000) NOT NULL COMMENT '商品图片',
  `goodsimage_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '商品图片排序',
  `goodsimage_isdefault` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '商品图片默认主图，1是，0否',
  PRIMARY KEY (`goodsimage_id`),
  KEY `goods_commonid` (`goods_commonid`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品图片';


DROP TABLE IF EXISTS `#__goods_resource`;
CREATE TABLE IF NOT EXISTS `#__goods_resource` (
  `goods_resource_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '商品资源id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `file_name` varchar(100) DEFAULT NULL COMMENT '上传文件名',
  `file_size` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上传文件大小',
  `goods_resource_name` varchar(100) NOT NULL COMMENT '资源文件名',
  `goods_resource_add_time` int(10) unsigned NOT NULL COMMENT '新增时间',
  PRIMARY KEY (`goods_resource_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品资源' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__groupbuy`;
CREATE TABLE IF NOT EXISTS `#__groupbuy` (
  `groupbuy_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '抢购自增ID',
  `groupbuy_name` varchar(255) NOT NULL COMMENT '抢购活动名称',
  `groupbuy_starttime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '抢购开始时间',
  `groupbuy_endtime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '抢购结束时间',
  `goods_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品原价',
  `groupbuy_price` decimal(10,2) NOT NULL COMMENT '抢购价格',
  `groupbuy_rebate` decimal(10,2) NOT NULL COMMENT '折扣',
  `virtual_quantity` int(10) unsigned NOT NULL COMMENT '虚拟购买数量',
  `groupbuy_upper_limit` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '购买上限',
  `groupbuy_buyer_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '已购买人数',
  `groupbuy_buy_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '购买数量',
  `groupbuy_intro` text COMMENT '本团介绍',
  `groupbuy_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '抢购状态 10-审核中 20-正常 30-审核失败 31-管理员关闭 32-已结束',
  `groupbuy_recommended` tinyint(1) unsigned NOT NULL COMMENT '是否推荐 0.未推荐 1.已推荐',
  `groupbuy_views` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '查看次数',
  `gclass_id` int(10) unsigned NOT NULL COMMENT '抢购类别编号',
  `s_gclass_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '抢购2级分类id',
  `groupbuy_image` varchar(100) NOT NULL COMMENT '抢购图片',
  `groupbuy_image1` varchar(100) DEFAULT NULL COMMENT '抢购图片1',
  `groupbuy_remark` varchar(255) NOT NULL COMMENT '备注',
  `groupbuy_is_vr` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否虚拟抢购 1是0否',
  `vr_class_id` int(11) DEFAULT NULL COMMENT '虚拟抢购大分类id',
  `vr_s_class_id` int(11) DEFAULT NULL COMMENT '虚拟抢购小分类id',
  PRIMARY KEY (`groupbuy_id`),
  KEY `goods_id` (`goods_id`),
  KEY `store_id` (`store_id`),
  KEY `gclass_id` (`gclass_id`),
  KEY `s_gclass_id` (`s_gclass_id`),
  KEY `vr_class_id` (`vr_class_id`),
  KEY `vr_s_class_id` (`vr_s_class_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='抢购商品表';



DROP TABLE IF EXISTS `#__groupbuyclass`;
CREATE TABLE IF NOT EXISTS `#__groupbuyclass` (
  `gclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '抢购类别自增ID',
  `gclass_name` varchar(20) NOT NULL COMMENT '抢购类别名称',
  `gclass_parent_id` int(10) unsigned NOT NULL COMMENT '抢购上级类别ID',
  `gclass_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '抢购类别排序',
  `gclass_deep` tinyint(1) unsigned DEFAULT NULL COMMENT '抢购类别深度',
  PRIMARY KEY (`gclass_id`),
  KEY `gclass_parent_id` (`gclass_parent_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='抢购类别表';



DROP TABLE IF EXISTS `#__groupbuypricerange`;
CREATE TABLE IF NOT EXISTS `#__groupbuypricerange` (
  `gprange_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '抢购价格区间ID',
  `gprange_name` varchar(20) NOT NULL COMMENT '抢购价格区间名称',
  `gprange_start` int(10) unsigned NOT NULL COMMENT '抢购价格区间下限',
  `gprange_end` int(10) unsigned NOT NULL COMMENT '抢购价格区间上限',
  PRIMARY KEY (`gprange_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='抢购价格区间表';



DROP TABLE IF EXISTS `#__groupbuyquota`;
CREATE TABLE IF NOT EXISTS `#__groupbuyquota` (
  `groupbuyquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '抢购套餐ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户编号',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺编号',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `groupbuyquota_starttime` int(10) unsigned NOT NULL COMMENT '抢购套餐开始时间',
  `groupbuyquota_endtime` int(10) unsigned NOT NULL COMMENT '抢购套餐结束时间',
  PRIMARY KEY (`groupbuyquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='抢购套餐表';



DROP TABLE IF EXISTS `#__help`;
CREATE TABLE IF NOT EXISTS `#__help` (
  `help_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '帮助自增ID',
  `help_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '帮助排序',
  `help_title` varchar(100) NOT NULL COMMENT '帮助标题',
  `help_info` text COMMENT '帮助内容',
  `help_url` varchar(100) DEFAULT '' COMMENT '帮助跳转链接',
  `help_updatetime` int(10) unsigned NOT NULL COMMENT '帮助更新时间',
  `helptype_id` int(10) unsigned NOT NULL COMMENT '帮助类型',
  `page_show` tinyint(1) unsigned DEFAULT '1' COMMENT '页面类型 1:店铺 2:会员',
  PRIMARY KEY (`help_id`),
  KEY `helptype_id` (`helptype_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='帮助内容表';



DROP TABLE IF EXISTS `#__helptype`;
CREATE TABLE IF NOT EXISTS `#__helptype` (
  `helptype_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '帮助类型自增ID',
  `helptype_name` varchar(50) NOT NULL COMMENT '帮助类型名称',
  `helptype_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '帮助类型',
  `helptype_code` varchar(10) DEFAULT 'auto' COMMENT '调用编号(auto的可删除)',
  `helptype_show` tinyint(1) unsigned DEFAULT '1' COMMENT '帮助类型是否显示 0:否 1:是',
  `page_show` tinyint(1) unsigned DEFAULT '1' COMMENT '页面类型:1:店铺 2:会员',
  PRIMARY KEY (`helptype_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='帮助类型表';



DROP TABLE IF EXISTS `#__inform`;
CREATE TABLE IF NOT EXISTS `#__inform` (
  `inform_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '举报自增ID',
  `inform_member_id` int(11) NOT NULL COMMENT '举报人ID',
  `inform_member_name` varchar(50) NOT NULL COMMENT '举报人会员名',
  `inform_goods_id` int(11) NOT NULL COMMENT '被举报的商品ID',
  `inform_goods_name` varchar(200) NOT NULL COMMENT '被举报的商品名称',
  `informsubject_id` int(11) NOT NULL COMMENT '举报主题ID',
  `informsubject_content` varchar(50) NOT NULL COMMENT '举报主题',
  `inform_content` varchar(100) NOT NULL COMMENT '举报信息',
  `inform_pic1` varchar(100) NOT NULL COMMENT '图片1',
  `inform_pic2` varchar(100) NOT NULL COMMENT '图片2',
  `inform_pic3` varchar(100) NOT NULL COMMENT '图片3',
  `inform_datetime` int(11) NOT NULL COMMENT '举报时间',
  `inform_store_id` int(11) NOT NULL COMMENT '被举报商品的店铺ID',
  `inform_state` tinyint(4) NOT NULL COMMENT '举报状态(1未处理/2已处理)',
  `inform_handle_type` tinyint(4) DEFAULT NULL COMMENT '举报处理结果(1无效举报/2恶意举报/3有效举报)',
  `inform_handle_message` varchar(100) NOT NULL COMMENT '举报处理信息',
  `inform_handle_datetime` int(11) NOT NULL DEFAULT '0' COMMENT '举报处理时间',
  `inform_handle_member_id` int(11) NOT NULL DEFAULT '0' COMMENT '管理员ID',
  `inform_goods_image` varchar(150) DEFAULT NULL COMMENT '商品图',
  `inform_store_name` varchar(100) DEFAULT NULL COMMENT '店铺名',
  PRIMARY KEY (`inform_id`),
  KEY `inform_member_id` (`inform_member_id`),
  KEY `inform_store_id` (`inform_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='举报表';



DROP TABLE IF EXISTS `#__informsubject`;
CREATE TABLE IF NOT EXISTS `#__informsubject` (
  `informsubject_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '举报主题自增ID',
  `informsubject_content` varchar(100) NOT NULL COMMENT '举报主题内容',
  `informsubject_type_id` int(11) NOT NULL COMMENT '举报类型ID',
  `informsubject_type_name` varchar(50) NOT NULL COMMENT '举报类型名称 ',
  `informsubject_state` tinyint(3) NOT NULL COMMENT '举报主题状态 1:可用 2:失效',
  PRIMARY KEY (`informsubject_id`),
  KEY `informsubject_type_id` (`informsubject_type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='举报主题表';



DROP TABLE IF EXISTS `#__informsubjecttype`;
CREATE TABLE IF NOT EXISTS `#__informsubjecttype` (
  `informtype_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '举报类型自增ID',
  `informtype_name` varchar(50) NOT NULL COMMENT '举报类型名称 ',
  `informtype_desc` varchar(100) NOT NULL COMMENT '举报类型描述',
  `informtype_state` tinyint(4) NOT NULL COMMENT '举报类型状态 1:有效 2:失效',
  PRIMARY KEY (`informtype_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='举报类型表';

DROP TABLE IF EXISTS `#__instant_message`;
CREATE TABLE IF NOT EXISTS `#__instant_message` (
  `instant_message_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '消息自增ID',
  `instant_message_from_id` int(10) unsigned NOT NULL COMMENT '发送ID',
  `instant_message_from_type` tinyint(1) unsigned NOT NULL COMMENT '发送类型（0用户1商家2直播）',
  `instant_message_from_name` varchar(500) NOT NULL COMMENT '发送名称',
  `instant_message_from_ip` varchar(15) NOT NULL COMMENT '发自IP',
  `instant_message_to_id` int(10) unsigned NOT NULL COMMENT '接收ID',
  `instant_message_to_type` tinyint(1) unsigned NOT NULL COMMENT '接收类型（0用户1商家2直播）',
  `instant_message_to_name` varchar(500) NOT NULL COMMENT '接收名称',
  `instant_message` text COMMENT '消息内容',
  `instant_message_type` tinyint(1) unsigned DEFAULT '0' COMMENT '消息类型（0文字1商品）',
  `instant_message_state` tinyint(1) unsigned DEFAULT '2' COMMENT '状态:1为已读,2为未读,默认为2',
  `instant_message_add_time` int(10) unsigned DEFAULT '0' COMMENT '添加时间',
  PRIMARY KEY (`instant_message_id`),
  KEY `instant_message_from_id` (`instant_message_from_id`,`instant_message_from_type`),
  KEY `instant_message_to_id` (`instant_message_to_id`,`instant_message_to_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='消息表';


DROP TABLE IF EXISTS `#__inviter`;
CREATE TABLE IF NOT EXISTS `#__inviter` (
  `inviter_id` int(10) unsigned NOT NULL COMMENT '推广员id即会员id',
  `inviter_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '推广员状态（0审核中1已审核2已清退）',
  `inviter_total_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '总共结算的佣金 ',
  `inviter_1_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '1级成员数量',
  `inviter_2_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '2级成员数量',
  `inviter_3_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '3级成员数量',
  `inviter_applytime` int(10) unsigned NOT NULL COMMENT '申请时间',
  `inviter_goods_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '总共分销的商品件数',
  `inviter_goods_amount` decimal(10,0) unsigned NOT NULL DEFAULT '0' COMMENT '总共分销的商品金额',
  PRIMARY KEY (`inviter_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='推广员表';



DROP TABLE IF EXISTS `#__inviterclass`;
CREATE TABLE IF NOT EXISTS `#__inviterclass` (
  `inviterclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '推广员等级id',
  `inviterclass_name` varchar(60) NOT NULL COMMENT '等级名',
  `inviterclass_amount` decimal(10,2) NOT NULL COMMENT '等级门槛',
  PRIMARY KEY (`inviterclass_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='推广等级表';



DROP TABLE IF EXISTS `#__invoice`;
CREATE TABLE IF NOT EXISTS `#__invoice` (
  `invoice_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '发票信息ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `invoice_state` enum('1','2') DEFAULT NULL COMMENT '发票类型 1:普通发票 2:增值税发票',
  `invoice_title` varchar(50) DEFAULT '' COMMENT '发票抬头[普通发票]',
  `invoice_code` varchar(50) DEFAULT '' COMMENT '纳税人识别号[普通发票]',
  `invoice_content` varchar(10) DEFAULT '' COMMENT '发票内容[普通发票]',
  `invoice_company` varchar(50) DEFAULT '' COMMENT '单位名称',
  `invoice_company_code` varchar(50) DEFAULT '' COMMENT '纳税人识别号',
  `invoice_reg_addr` varchar(50) DEFAULT '' COMMENT '注册地址',
  `invoice_reg_phone` varchar(30) DEFAULT '' COMMENT '注册电话',
  `invoice_reg_bname` varchar(30) DEFAULT '' COMMENT '开户银行',
  `invoice_reg_baccount` varchar(30) DEFAULT '' COMMENT '银行帐户',
  `invoice_rec_name` varchar(20) DEFAULT '' COMMENT '收票人姓名',
  `invoice_rec_mobphone` varchar(15) DEFAULT '' COMMENT '收票人手机号',
  `invoice_rec_province` varchar(30) DEFAULT '' COMMENT '收票人省份',
  `invoice_goto_addr` varchar(50) DEFAULT '' COMMENT '送票地址',
  PRIMARY KEY (`invoice_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='买家发票信息表';



DROP TABLE IF EXISTS `#__link`;
CREATE TABLE IF NOT EXISTS `#__link` (
  `link_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '友情链接自增ID',
  `link_title` varchar(100) DEFAULT NULL COMMENT '友情链接标题',
  `link_url` varchar(100) DEFAULT NULL COMMENT '友情链接地址',
  `link_pic` varchar(100) DEFAULT NULL COMMENT '友情链接图片',
  `link_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '友情链接排序',
  PRIMARY KEY (`link_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='友情链接';

DROP TABLE IF EXISTS `#__live_apply`;
CREATE TABLE IF NOT EXISTS `#__live_apply` (
  `live_apply_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '直播申请id',
  `live_apply_name` varchar(255) NOT NULL COMMENT '直播标题',
  `live_apply_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '直播申请状态(0申请中1已通过2已拒绝)',
  `live_apply_push_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '推流状态（0主播未进入直播间1主播已进入2主播停止直播）',
  `live_apply_push_message` varchar(255) NOT NULL DEFAULT '' COMMENT '断流提示信息',
  `live_apply_play_time` int(10) unsigned NOT NULL COMMENT '直播时间',
  `live_apply_end_time` int(10) unsigned DEFAULT NULL COMMENT '过期时间',
  `live_apply_video` varchar(500) DEFAULT NULL COMMENT '回放视频',
  `live_apply_cover_image` varchar(255) DEFAULT NULL COMMENT '封面图片',
  `live_apply_cover_video` varchar(255) DEFAULT NULL COMMENT '封面视频',
  `live_apply_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '申请类别 0:无 1:课程 2:商品',
  `live_apply_type_id` int(10) NOT NULL DEFAULT '0' COMMENT '申请类别id',
  `live_apply_add_time` int(10) unsigned NOT NULL COMMENT '申请时间',
  `live_apply_user_type` tinyint(1) unsigned NOT NULL COMMENT '申请用户类型（1用户2商家）',
  `live_apply_user_id` int(10) unsigned NOT NULL COMMENT '申请用户id',
  `live_apply_remark` varchar(255) NOT NULL COMMENT '备注',
  `live_apply_like_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '喜欢数',
  `live_apply_view_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '观看数',
  PRIMARY KEY (`live_apply_id`),
  KEY `live_apply_state` (`live_apply_state`),
  KEY `live_apply_type_id` (`live_apply_type_id`,`live_apply_user_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='直播申请';

DROP TABLE IF EXISTS `#__live_apply_goods`;
CREATE TABLE IF NOT EXISTS `#__live_apply_goods` (
  `live_apply_id` int(10) unsigned NOT NULL COMMENT '直播申请id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(200) NOT NULL COMMENT '店铺名称',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品id',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类',
  `gc_id_1` int(10) unsigned DEFAULT NULL COMMENT '一级分类id',
  `gc_id_2` int(10) unsigned DEFAULT NULL COMMENT '二级分类id',
  `gc_id_3` int(10) unsigned DEFAULT NULL COMMENT '三级分类id',
  `gc_name` varchar(200) NOT NULL COMMENT '商品分类',
  PRIMARY KEY (`live_apply_id`,`goods_commonid`),
  KEY `goods_commonid` (`goods_commonid`),
  KEY `gc_id` (`gc_id`),
  KEY `gc_id_1` (`gc_id_1`),
  KEY `gc_id_2` (`gc_id_2`),
  KEY `gc_id_3` (`gc_id_3`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='直播申请商品';


DROP TABLE IF EXISTS `#__mailcron`;
CREATE TABLE IF NOT EXISTS `#__mailcron` (
  `mailcron_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '消息任务计划自增ID',
  `mailcron_address` varchar(100) NOT NULL COMMENT '邮箱地址',
  `mailcron_subject` varchar(255) NOT NULL COMMENT '邮件标题',
  `mailcron_contnet` text NOT NULL COMMENT '邮件内容',
  PRIMARY KEY (`mailcron_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='邮件任务计划表';



DROP TABLE IF EXISTS `#__mailmsgtemlates`;
CREATE TABLE IF NOT EXISTS `#__mailmsgtemlates` (
  `mailmt_name` varchar(100) NOT NULL COMMENT '模板名称',
  `mailmt_title` varchar(100) DEFAULT NULL COMMENT '模板标题',
  `mailmt_code` varchar(30) NOT NULL COMMENT '模板调用代码',
  `mailmt_content` text NOT NULL COMMENT '模板内容',
  `ali_template_code` varchar(255) DEFAULT NULL COMMENT '阿里云短信模板ID',
  `ten_template_code` varchar(255) DEFAULT NULL COMMENT '腾讯云短信模板ID',
  PRIMARY KEY (`mailmt_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='邮件模板表';



DROP TABLE IF EXISTS `#__mallconsult`;
CREATE TABLE IF NOT EXISTS `#__mallconsult` (
  `mallconsult_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '平台客服咨询自增ID',
  `mallconsulttype_id` int(10) unsigned NOT NULL COMMENT '咨询类型ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `mallconsult_content` varchar(500) NOT NULL COMMENT '咨询内容',
  `mallconsult_addtime` int(10) unsigned NOT NULL COMMENT '咨询时间',
  `mallconsult_isreply` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否回复 1:是 0:否',
  `mallconsult_reply_content` varchar(500) NOT NULL DEFAULT '' COMMENT '平台回复内容',
  `mallconsult_replytime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '平台回复时间',
  `admin_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '管理员id',
  `admin_name` varchar(50) NOT NULL DEFAULT '' COMMENT '管理员名称',
  PRIMARY KEY (`mallconsult_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='平台客服咨询表';



DROP TABLE IF EXISTS `#__mallconsulttype`;
CREATE TABLE IF NOT EXISTS `#__mallconsulttype` (
  `mallconsulttype_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '平台客服咨询类型ID',
  `mallconsulttype_name` varchar(50) NOT NULL COMMENT '咨询类型名称',
  `mallconsulttype_introduce` text NOT NULL COMMENT '平台客服咨询类型备注',
  `mallconsulttype_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '咨询类型排序',
  PRIMARY KEY (`mallconsulttype_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='平台客服咨询类型表';

DROP TABLE IF EXISTS `#__mallvouchertemplate`;
CREATE TABLE IF NOT EXISTS `#__mallvouchertemplate` (
  `mallvouchertemplate_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '平台代金券类型ID',
  `mallvouchertemplate_title` varchar(50) NOT NULL COMMENT '平台代金券类型标题',
  `mallvouchertemplate_price` int(11) NOT NULL COMMENT '平台代金券面额',
  `mallvouchertemplate_startdate` int(11) NOT NULL COMMENT '平台代金券使用开始时间',
  `mallvouchertemplate_enddate` int(11) NOT NULL COMMENT '平台代金券使用结束时间',
  `mallvouchertemplate_limit` int(11) NOT NULL COMMENT '平台代金券订单使用限额',
  `mallvouchertemplate_gcidarr` text COMMENT '商品分类ID组成的串，以，隔开，两端也有，',
  `mallvouchertemplate_gcid` int(11) NOT NULL COMMENT '平台代金券所属商品分类ID',
  `mallvouchertemplate_gcname` varchar(50) NOT NULL COMMENT '平台代金券所属分类名称',
  `mallvouchertemplate_points` int(11) NOT NULL DEFAULT '0' COMMENT '领取代金券所需积分',
  `mallvouchertemplate_quantity` int(11) NOT NULL COMMENT '代金券发放总数',
  `mallvouchertemplate_giveout` int(11) NOT NULL COMMENT '代金券已领取数量',
  `mallvouchertemplate_used` int(11) NOT NULL COMMENT '代金券已使用数量',
  `mallvouchertemplate_eachlimit` int(11) NOT NULL COMMENT '每人限制领取数',
  PRIMARY KEY (`mallvouchertemplate_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='平台代金券模板表';

DROP TABLE IF EXISTS `#__mallvoucheruser`;
CREATE TABLE IF NOT EXISTS `#__mallvoucheruser` (
  `mallvoucheruser_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '平台代金券ID',
  `mallvoucheruser_code` varchar(32) DEFAULT NULL COMMENT '平台代金券编码',
  `mallvoucheruser_title` varchar(50) NOT NULL COMMENT '平台代金券标题',
  `mallvoucheruser_startdate` int(11) NOT NULL COMMENT '平台代金券有效期开始时间',
  `mallvoucheruser_enddate` int(11) NOT NULL COMMENT '平台代金券有效期结束时间',
  `mallvoucheruser_price` int(11) NOT NULL COMMENT '平台代金券面额',
  `mallvoucheruser_limit` decimal(10,2) NOT NULL COMMENT '平台代金券使用时的订单限额',
  `mallvoucheruser_activedate` int(11) NOT NULL COMMENT '平台代金券发放时间',
  `mallvoucheruser_ownerid` int(11) NOT NULL COMMENT '平台代金券所有者ID',
  `mallvoucheruser_ownername` varchar(50) NOT NULL COMMENT '平台代金券所有者名称',
  `mallvoucheruser_state` tinyint(4) DEFAULT '0' COMMENT '使用状态 0：未使用 1：已使用 2:已过期',
  `mallvouchertemplate_id` int(11) NOT NULL DEFAULT '0' COMMENT '平台代金券ID',
  `mallvouchertemplate_gcidarr` text COMMENT '商品分类ID组成的串，以，隔开，两端也有，',
  `mallvouchertemplate_gcid` int(11) NOT NULL COMMENT '平台代金券所属商品分类ID',
  `mallvouchertemplate_points` int(11) NOT NULL DEFAULT '0' COMMENT '领取代金券所需积分',
  PRIMARY KEY (`mallvoucheruser_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='平台代金券会员表';



DROP TABLE IF EXISTS `#__marketmanage`;
CREATE TABLE IF NOT EXISTS `#__marketmanage` (
  `marketmanage_id` int(11) NOT NULL AUTO_INCREMENT,
  `marketmanage_name` varchar(100) NOT NULL DEFAULT '' COMMENT '营销活动活动名称',
  `marketmanage_detail` varchar(255) NOT NULL DEFAULT '' COMMENT '营销活动详情',
  `marketmanage_begintime` int(11) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `marketmanage_endtime` int(11) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `marketmanage_jointype` tinyint(2) NOT NULL DEFAULT '0' COMMENT '参与类型 0共几次 1每天几次 2无限制',
  `marketmanage_joincount` int(11) NOT NULL DEFAULT '0' COMMENT '参与次数限制',
  `marketmanage_totalcount` int(11) NOT NULL DEFAULT '0' COMMENT '总参与次数',
  `marketmanage_totalwin` int(11) NOT NULL DEFAULT '0' COMMENT '总中奖次数',
  `marketmanage_point` int(11) NOT NULL DEFAULT '0' COMMENT '0不消耗积分 大于0消耗积分',
  `marketmanage_addtime` int(11) NOT NULL DEFAULT '0' COMMENT '添加时间',
  `marketmanage_failed` varchar(255) NOT NULL DEFAULT '' COMMENT '未中奖说明',
  `marketmanage_type` tinyint(3) NOT NULL DEFAULT '0' COMMENT '营销活动类型 1刮刮卡2大转盘3砸金蛋4生肖翻翻看',
  PRIMARY KEY (`marketmanage_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='营销活动活动 刮刮卡大转盘砸金蛋生肖翻翻看';



DROP TABLE IF EXISTS `#__marketmanageaward`;
CREATE TABLE IF NOT EXISTS `#__marketmanageaward` (
  `marketmanageaward_id` int(11) NOT NULL AUTO_INCREMENT,
  `marketmanage_id` int(11) NOT NULL DEFAULT '0' COMMENT '营销活动ID',
  `marketmanageaward_level` tinyint(3) NOT NULL COMMENT '奖品等级',
  `marketmanageaward_type` tinyint(3) NOT NULL DEFAULT '0' COMMENT '奖品类型 1积分 2红包 3优惠券',
  `marketmanageaward_count` int(11) NOT NULL DEFAULT '0' COMMENT '奖品数量',
  `marketmanageaward_send` int(11) NOT NULL DEFAULT '0' COMMENT '中奖数量',
  `marketmanageaward_probability` int(3) NOT NULL DEFAULT '0' COMMENT '奖品概率',
  `marketmanageaward_point` int(11) NOT NULL DEFAULT '0' COMMENT '奖品积分',
  `bonus_id` int(11) NOT NULL DEFAULT '0' COMMENT '红包ID',
  `vouchertemplate_id` int(11) NOT NULL DEFAULT '0' COMMENT '优惠券ID',
  PRIMARY KEY (`marketmanageaward_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='营销活动活动奖品记录';



DROP TABLE IF EXISTS `#__marketmanagelog`;
CREATE TABLE IF NOT EXISTS `#__marketmanagelog` (
  `marketmanagelog_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `member_id` int(11) NOT NULL DEFAULT '0' COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员名',
  `marketmanage_id` int(11) NOT NULL DEFAULT '0' COMMENT '营销活动活动ID',
  `marketmanageaward_id` int(11) NOT NULL DEFAULT '0' COMMENT '中奖的奖品ID',
  `marketmanagelog_win` tinyint(2) NOT NULL DEFAULT '0' COMMENT '是否中奖 0未中奖 1中奖',
  `marketmanagelog_time` int(11) NOT NULL DEFAULT '0' COMMENT '参与时间',
  `marketmanagelog_remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注领取信息',
  PRIMARY KEY (`marketmanagelog_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='营销活动活动领取记录';


DROP TABLE IF EXISTS `#__mbchaintoken`;
CREATE TABLE IF NOT EXISTS `#__mbchaintoken` (
  `chain_token_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '令牌编号',
  `chain_id` int(10) unsigned NOT NULL COMMENT '门店编号',
  `chain_name` varchar(60) NOT NULL COMMENT '门店登录名',
  `chain_token` varchar(60) NOT NULL COMMENT 'token',
  `chain_logintime` int(10) unsigned NOT NULL COMMENT '登录时间',
  `chain_clienttype` varchar(10) NOT NULL COMMENT '客户端类型',
  PRIMARY KEY (`chain_token_id`),
  UNIQUE KEY `chain_token` (`chain_token`),
  UNIQUE KEY `chain_id` (`chain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='门店登录token表';

DROP TABLE IF EXISTS `#__mbsellertoken`;
CREATE TABLE IF NOT EXISTS `#__mbsellertoken` (
  `seller_token_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '令牌编号',
  `seller_id` int(10) unsigned NOT NULL COMMENT '用户编号',
  `seller_name` varchar(50) NOT NULL COMMENT '用户名',
  `seller_token` varchar(50) NOT NULL COMMENT '登录令牌',
  `seller_logintime` int(10) unsigned NOT NULL COMMENT '登录时间',
  `seller_clienttype` varchar(10) NOT NULL COMMENT '客户端类型 windows',
  PRIMARY KEY (`seller_token_id`),
  KEY `seller_token` (`seller_token`),
  KEY `seller_id` (`seller_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='客户端商家登录令牌表';



DROP TABLE IF EXISTS `#__mbusertoken`;
CREATE TABLE IF NOT EXISTS `#__mbusertoken` (
  `member_token_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '令牌编号',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户编号',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `member_token` varchar(50) NOT NULL COMMENT '登录令牌',
  `member_logintime` int(10) unsigned NOT NULL COMMENT '登录时间',
  `member_clienttype` varchar(10) NOT NULL COMMENT '客户端类型 android wap',
  `member_openid` varchar(50) DEFAULT NULL COMMENT '微信支付jsapi的openid缓存',
  PRIMARY KEY (`member_token_id`),
  KEY `member_id` (`member_id`),
  KEY `member_token` (`member_token`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='移动端登录令牌表';



DROP TABLE IF EXISTS `#__member`;
CREATE TABLE IF NOT EXISTS `#__member` (
  `member_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '会员自增ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员用户名',
  `member_truename` varchar(20) DEFAULT NULL COMMENT '会员真实姓名',
  `member_nickname` varchar(20) DEFAULT NULL COMMENT '会员昵称',
  `member_auth_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '实名认证状态（0默认1审核中2未通过3已认证）',
  `member_idcard` varchar(255) DEFAULT NULL COMMENT '实名认证身份证号',
  `member_idcard_image1` varchar(255) DEFAULT NULL COMMENT '手持身份证照',
  `member_idcard_image2` varchar(255) DEFAULT NULL COMMENT '身份证正面照',
  `member_idcard_image3` varchar(255) DEFAULT NULL COMMENT '身份证反面照',
  `member_avatar` varchar(50) DEFAULT NULL COMMENT '会员头像',
  `member_sex` tinyint(1) DEFAULT NULL COMMENT '会员性别',
  `member_birthday` int(11) DEFAULT NULL COMMENT '会员生日',
  `member_password` varchar(32) NOT NULL COMMENT '会员密码',
  `member_paypwd` varchar(32) DEFAULT NULL COMMENT '支付密码',
  `member_email` varchar(50) DEFAULT NULL COMMENT '会员邮箱',
  `member_emailbind` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否绑定邮箱',
  `member_mobile` varchar(11) DEFAULT NULL COMMENT '手机号码',
  `member_mobilebind` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否绑定手机',
  `member_qq` varchar(20) DEFAULT NULL COMMENT '会员QQ',
  `member_ww` varchar(20) DEFAULT NULL COMMENT '会员旺旺',
  `member_loginnum` int(11) NOT NULL DEFAULT '0' COMMENT '会员登录次数',
  `member_addtime` int(11) NOT NULL COMMENT '会员添加时间',
  `member_logintime` int(11) DEFAULT '0' COMMENT '会员当前登录时间',
  `member_old_logintime` int(11) DEFAULT '0' COMMENT '会员上次登录时间',
  `member_login_ip` varchar(20) DEFAULT NULL COMMENT '会员当前登录IP',
  `member_old_login_ip` varchar(20) DEFAULT NULL COMMENT '会员上次登录IP',
  `member_qqopenid` varchar(100) DEFAULT NULL COMMENT 'qq互联id',
  `member_qqinfo` text COMMENT 'qq账号相关信息',
  `member_sinaopenid` varchar(100) DEFAULT NULL COMMENT '新浪微博登录id',
  `member_sinainfo` text COMMENT '新浪账号相关信息序列化值',
  `member_wxopenid` varchar(100) DEFAULT '' COMMENT '微信互联openid',
  `member_wxunionid` varchar(100) DEFAULT '' COMMENT '微信用户统一标识',
  `member_wxinfo` text COMMENT '微信用户相关信息',
  `member_points` int(11) NOT NULL DEFAULT '0' COMMENT '会员积分',
  `available_predeposit` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '预存款可用金额',
  `freeze_predeposit` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '预存款冻结金额',
  `available_rc_balance` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '可用充值卡余额',
  `freeze_rc_balance` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '冻结充值卡余额',
  `inform_allow` tinyint(1) NOT NULL DEFAULT '1' COMMENT '是否允许举报(1可以/2不可以)',
  `is_buylimit` tinyint(1) NOT NULL DEFAULT '1' COMMENT '会员是否有购买权限 1为开启 0为关闭',
  `is_allowtalk` tinyint(1) NOT NULL DEFAULT '1' COMMENT '会员是否有咨询和发送站内信的权限 1为开启 0为关闭',
  `member_state` tinyint(1) NOT NULL DEFAULT '1' COMMENT '会员的开启状态 1为开启 0为关闭',
  `member_areaid` int(11) DEFAULT NULL COMMENT '地区ID',
  `member_cityid` int(11) DEFAULT NULL COMMENT '城市ID',
  `member_provinceid` int(11) DEFAULT NULL COMMENT '省份ID',
  `member_areainfo` varchar(255) DEFAULT NULL COMMENT '地区内容',
  `member_privacy` text COMMENT '隐私设定',
  `member_exppoints` int(11) NOT NULL DEFAULT '0' COMMENT '会员经验值',
  `inviter_id` int(11) DEFAULT NULL COMMENT '邀请人ID',
  `member_signin_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '最后一次签到时间',
  `member_signin_days_cycle` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '持续签到天数，每周期后清零',
  `member_signin_days_total` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '签到总天数',
  `member_signin_days_series` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '持续签到天数总数，非连续周期清零',
  PRIMARY KEY (`member_id`),
  KEY `member_name` (`member_name`),
  KEY `member_email` (`member_email`,`member_emailbind`),
  KEY `member_mobile` (`member_mobile`,`member_mobilebind`),
  KEY `member_wxunionid` (`member_wxunionid`),
  KEY `member_qqopenid` (`member_qqopenid`),
  KEY `member_sinaopenid` (`member_sinaopenid`),
  KEY `inviter_id` (`inviter_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='会员表';



DROP TABLE IF EXISTS `#__memberbank`;
CREATE TABLE IF NOT EXISTS `#__memberbank` (
  `memberbank_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `memberbank_type` varchar(10) NOT NULL DEFAULT 'bank' COMMENT 'bank银行 alipay 支付宝收款',
  `memberbank_truename` varchar(20) NOT NULL COMMENT '收款方真实姓名',
  `memberbank_name` varchar(20) NOT NULL DEFAULT '' COMMENT '收款银行',
  `memberbank_no` varchar(30) NOT NULL COMMENT '收款银行卡号/支付宝账户',
  `member_id` int(11) NOT NULL COMMENT '所属用户id',
  PRIMARY KEY (`memberbank_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户收款账户表';



DROP TABLE IF EXISTS `#__membermsgsetting`;
CREATE TABLE IF NOT EXISTS `#__membermsgsetting` (
  `membermt_code` varchar(50) NOT NULL COMMENT '用户消息模板代码',
  `membermt_isreceive` tinyint(3) unsigned NOT NULL COMMENT '是否接收 1是，0否',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  PRIMARY KEY (`membermt_code`,`member_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户消息接收设置表';



DROP TABLE IF EXISTS `#__membermsgtpl`;
CREATE TABLE IF NOT EXISTS `#__membermsgtpl` (
  `membermt_code` varchar(50) NOT NULL COMMENT '用户消息模板编号',
  `membermt_name` varchar(50) NOT NULL COMMENT '模板名称',
  `membermt_message_switch` tinyint(3) unsigned NOT NULL COMMENT '站内信接收开关',
  `membermt_message_content` varchar(255) NOT NULL COMMENT '站内信消息内容',
  `membermt_short_switch` tinyint(3) unsigned NOT NULL COMMENT '短信接收开关',
  `membermt_short_content` varchar(255) NOT NULL COMMENT '短信接收内容',
  `membermt_mail_switch` tinyint(3) unsigned NOT NULL COMMENT '邮件接收开关',
  `membermt_mail_subject` varchar(255) NOT NULL COMMENT '邮件标题',
  `membermt_mail_content` text NOT NULL COMMENT '邮件内容',
  `membermt_weixin_switch` tinyint(3) unsigned NOT NULL COMMENT '微信接收开关',
  `membermt_weixin_code` varchar(255) NOT NULL COMMENT '微信消息code',
  `ali_template_code` varchar(255) DEFAULT NULL COMMENT '阿里云短信模板ID',
  `ten_template_code` varchar(255) DEFAULT NULL COMMENT '腾讯云短信模板ID',
  PRIMARY KEY (`membermt_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户消息模板';



DROP TABLE IF EXISTS `#__message`;
CREATE TABLE IF NOT EXISTS `#__message` (
  `message_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '短消息自增ID',
  `message_parent_id` int(11) NOT NULL COMMENT '回复短消息message_id',
  `from_member_id` int(11) NOT NULL COMMENT '短消息发送人',
  `to_member_id` varchar(1000) NOT NULL COMMENT '短消息接收人',
  `message_title` varchar(50) DEFAULT NULL COMMENT '短消息标题',
  `message_body` varchar(255) NOT NULL COMMENT '短消息内容',
  `message_time` varchar(10) NOT NULL COMMENT '短消息发送时间',
  `message_update_time` varchar(10) DEFAULT NULL COMMENT '短消息回复更新时间',
  `message_open` tinyint(1) NOT NULL DEFAULT '0' COMMENT '短消息打开状态',
  `message_state` tinyint(1) NOT NULL DEFAULT '0' COMMENT '短消息状态，0为正常状态，1为发送人删除状态，2为接收人删除状态',
  `message_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0为私信、1为系统消息、2为留言',
  `read_member_id` varchar(1000) DEFAULT NULL COMMENT '已经读过该消息的会员id',
  `del_member_id` varchar(1000) DEFAULT NULL COMMENT '已经删除该消息的会员id',
  `message_ismore` tinyint(1) NOT NULL DEFAULT '0' COMMENT '站内信是否为一条发给多个用户 0为否 1为多条 ',
  `from_member_name` varchar(100) DEFAULT NULL COMMENT '发信息人用户名',
  `to_member_name` varchar(100) DEFAULT NULL COMMENT '接收人用户名',
  PRIMARY KEY (`message_id`),
  KEY `from_member_id` (`from_member_id`),
  KEY `to_member_id` (`to_member_id`(255)),
  KEY `message_ismore` (`message_ismore`),
  KEY `message_parent_id` (`message_parent_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='短消息';



DROP TABLE IF EXISTS `#__minipro_live`;
CREATE TABLE IF NOT EXISTS `#__minipro_live` (
  `minipro_live_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `minipro_live_name` varchar(60) NOT NULL COMMENT '直播间名称',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `minipro_live_wxid` varchar(60) NOT NULL COMMENT '微信号',
  `minipro_live_nickname` varchar(60) NOT NULL COMMENT '微信昵称',
  `minipro_live_start_time` int(10) unsigned NOT NULL COMMENT '开始时间',
  `minipro_live_end_time` int(10) unsigned NOT NULL COMMENT '结束时间',
  `minipro_live_image` varchar(60) NOT NULL COMMENT '封面图地址',
  `minipro_live_add_time` int(10) unsigned NOT NULL COMMENT '添加时间',
  `minipro_live_room_id` int(10) unsigned NOT NULL COMMENT '直播间id',
  `minipro_live_video` text NOT NULL DEFAULT '' COMMENT '回放视频',
  PRIMARY KEY (`minipro_live_id`),
  KEY `member_id` (`member_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='小程序直播' AUTO_INCREMENT=1 ;


DROP TABLE IF EXISTS `#__minipro_live_room_goods`;
CREATE TABLE IF NOT EXISTS `#__minipro_live_room_goods` (
  `minipro_live_room_goods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `minipro_live_id` int(10) unsigned NOT NULL COMMENT '直播间id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(60) NOT NULL COMMENT '店铺名称',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品id',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共id',
  `goods_name` varchar(255) NOT NULL COMMENT '商品名称',
  `goods_image` varchar(255) NOT NULL COMMENT '商品图片',
  `goods_price` decimal(10,2) unsigned NOT NULL COMMENT '商品价格',
  `minipro_live_goods_result_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '直播商品id',
  `gc_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '商品分类',
  `gc_id_1` int(10) unsigned DEFAULT NULL DEFAULT '0' COMMENT '一级分类id',
  `gc_id_2` int(10) unsigned DEFAULT NULL DEFAULT '0' COMMENT '二级分类id',
  `gc_id_3` int(10) unsigned DEFAULT NULL DEFAULT '0' COMMENT '三级分类id',
  `gc_name` varchar(200) NOT NULL DEFAULT '' COMMENT '商品分类',
  PRIMARY KEY (`minipro_live_room_goods_id`),
  KEY `store_id` (`store_id`),
  KEY `minipro_live_goods_result_id` (`minipro_live_goods_result_id`),
  KEY `goods_id` (`goods_id`),
  KEY `goods_commonid` (`goods_commonid`),
  KEY `gc_id` (`gc_id`),
  KEY `gc_id_1` (`gc_id_1`),
  KEY `gc_id_2` (`gc_id_2`),
  KEY `gc_id_3` (`gc_id_3`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='小程序直播商品' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__minipro_live_goods`;
CREATE TABLE IF NOT EXISTS `#__minipro_live_goods` (
  `minipro_live_goods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(60) NOT NULL COMMENT '店铺名称',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品id',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共id',
  `goods_name` varchar(255) NOT NULL COMMENT '商品名称',
  `goods_image` varchar(255) NOT NULL COMMENT '商品图片',
  `goods_price` decimal(10,2) unsigned NOT NULL COMMENT '商品价格',
  `minipro_live_goods_add_time` int(10) unsigned NOT NULL COMMENT '添加时间',
  `minipro_live_goods_state` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '状态',
  `minipro_live_goods_result_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '直播商品id',
  `minipro_live_goods_verify_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '直播商品审核id',
  `minipro_live_goods_close` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '关闭',
  PRIMARY KEY (`minipro_live_goods_id`),
  KEY `store_id` (`store_id`),
  KEY `minipro_live_goods_result_id` (`minipro_live_goods_result_id`),
  KEY `goods_id` (`goods_id`),
  KEY `goods_commonid` (`goods_commonid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='小程序直播商品' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__navigation`;
CREATE TABLE IF NOT EXISTS `#__navigation` (
  `nav_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '页面导航自增ID',
  `nav_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '页面导航类别，0自定义导航，1商品分类，2文章导航，3活动导航，默认为0',
  `nav_title` varchar(100) DEFAULT NULL COMMENT '页面导航标题',
  `nav_url` varchar(255) DEFAULT NULL COMMENT '页面导航链接',
  `nav_location` varchar(10) NOT NULL COMMENT '页面导航位置，header头部，middle中部，footer底部',
  `nav_new_open` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否以新窗口打开，0为否，1为是，默认为0',
  `nav_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '页面导航排序',
  `item_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '页面导航类别ID，对应着nav_type中的内容，默认为0',
  `nav_is_close` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否前台显示，0为否，1为是，默认为1',
  PRIMARY KEY (`nav_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='页面导航表';



DROP TABLE IF EXISTS `#__offpayarea`;
CREATE TABLE IF NOT EXISTS `#__offpayarea` (
  `store_id` int(8) unsigned NOT NULL COMMENT '商家ID',
  `area_id` text COMMENT '县ID组合',
  PRIMARY KEY (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='货到付款支持地区表';



DROP TABLE IF EXISTS `#__order`;
CREATE TABLE IF NOT EXISTS `#__order` (
  `order_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单自增id',
  `order_sn` varchar(20) NOT NULL COMMENT '订单编号',
  `pay_sn` varchar(20) NOT NULL COMMENT '支付单号',
  `store_id` int(11) unsigned NOT NULL COMMENT '卖家店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '卖家店铺名称',
  `buyer_id` int(11) unsigned NOT NULL COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家姓名',
  `buyer_email` varchar(80) DEFAULT NULL COMMENT '买家电子邮箱',
  `chain_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '门店ID',
  `add_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '订单生成时间',
  `payment_code` char(20) NOT NULL DEFAULT '' COMMENT '支付方式名称代码',
  `payment_time` int(10) unsigned DEFAULT '0' COMMENT '支付(付款)时间',
  `trade_no` varchar(35) DEFAULT NULL COMMENT '第三方平台交易号',
  `finnshed_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '订单完成时间',
  `goods_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '商品总价格',
  `order_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '订单总价格',
  `rcb_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '充值卡支付金额',
  `pd_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '预存款支付金额',
  `presell_deposit_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '定金金额',
  `presell_rcb_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '定金充值卡支付金额',
  `presell_pd_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '定金预存款支付金额',
  `presell_trade_no` varchar(35) DEFAULT NULL COMMENT '第三方平台交易号',
  `presell_payment_code` char(20) NOT NULL DEFAULT '' COMMENT '支付方式名称代码',
  `presell_end_time` int(10) unsigned DEFAULT '0' COMMENT '预售结束时间',
  `shipping_fee` decimal(10,2) unsigned DEFAULT '0.00' COMMENT '运费',
  `evaluation_state` tinyint(4) DEFAULT '0' COMMENT '评价状态 0：未评价 1：已评价 2:已过期未评价',
  `order_state` tinyint(4) NOT NULL DEFAULT '10' COMMENT '订单状态：0:已取消 10:未付款 14:待付定金 15:待付尾款 20:待发货 30:已发货 35:待自提 40:已收货',
  `refund_state` tinyint(1) unsigned DEFAULT '0' COMMENT '退款状态 0:无退款 1:部分退款 2:全部退款',
  `lock_state` tinyint(1) unsigned DEFAULT '0' COMMENT '锁定状态:0:正常,大于0:锁定',
  `delete_state` tinyint(4) NOT NULL DEFAULT '0' COMMENT '删除状态 0:未删除 1:放入回收站 2:彻底删除',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `delay_time` int(10) unsigned DEFAULT '0' COMMENT '延迟时间,默认为0',
  `order_from` tinyint(4) NOT NULL DEFAULT '1' COMMENT '订单来源，1:PC 2:手机',
  `shipping_code` varchar(50) DEFAULT '' COMMENT '订单物流单号',
  `order_type` tinyint(4) DEFAULT NULL COMMENT '订单类型',
  `ob_no` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '相关结算单号',
  PRIMARY KEY (`order_id`),
  KEY `store_id` (`store_id`),
  KEY `buyer_id` (`buyer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='订单表';



DROP TABLE IF EXISTS `#__orderbill`;
CREATE TABLE IF NOT EXISTS `#__orderbill` (
  `ob_no` int(11) NOT NULL AUTO_INCREMENT COMMENT '结算单编号(年月店铺ID)',
  `ob_startdate` int(11) NOT NULL COMMENT '开始日期',
  `ob_enddate` int(11) NOT NULL COMMENT '结束日期',
  `ob_order_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '结算订单金额',
  `ob_shipping_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '结算运费',
  `ob_order_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '结算退单金额',
  `ob_commis_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '结算佣金金额',
  `ob_commis_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '结算退还佣金',
  `ob_store_cost_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '店铺促销活动费用',
  `ob_mall_voucher_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '店铺平台代金券金额',
  `ob_vr_order_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟订单金额',
  `ob_vr_order_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟订单退款金额',
  `ob_vr_commis_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟佣金金额',
  `ob_vr_commis_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟退还佣金金额',
  `ob_vr_inviter_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟分销佣金金额',
  `ob_result_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '应结金额',
  `ob_createdate` int(11) DEFAULT '0' COMMENT '生成结算单日期',
  `ob_state` enum('1','2','3','4') DEFAULT '1' COMMENT '结算状态 1，默认2，店家已确认3，平台已审核4，结算完成',
  `ob_store_id` int(11) NOT NULL COMMENT '店铺ID',
  `ob_store_name` varchar(50) DEFAULT NULL COMMENT '店铺名',
  `ob_inviter_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '分销的佣金',
  `ob_seller_content` varchar(255) NOT NULL DEFAULT '' COMMENT '商家备注',
  `ob_admin_content` varchar(255) NOT NULL DEFAULT '' COMMENT '管理员备注',
  PRIMARY KEY (`ob_no`),
  KEY `ob_store_id` (`ob_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='结算表';



DROP TABLE IF EXISTS `#__ordercommon`;
CREATE TABLE IF NOT EXISTS `#__ordercommon` (
  `order_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `shipping_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '配送时间',
  `shipping_express_id` tinyint(1) NOT NULL DEFAULT '0' COMMENT '配送公司ID',
  `evaluation_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '评价时间',
  `evalseller_state` enum('0','1') NOT NULL DEFAULT '0' COMMENT '卖家是否已评价买家',
  `evalseller_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '卖家评价买家的时间',
  `order_message` varchar(300) DEFAULT NULL COMMENT '订单留言',
  `order_pointscount` int(11) NOT NULL DEFAULT '0' COMMENT '订单赠送积分',
  `voucher_price` int(11) DEFAULT NULL COMMENT '店铺代金券面额',
  `voucher_code` varchar(32) DEFAULT NULL COMMENT '店铺代金券编码',
  `mallvoucher_price` int(11) DEFAULT NULL COMMENT '平台代金券面额',
  `mallvoucher_code` varchar(32) DEFAULT NULL COMMENT '平台代金券编码',
  `deliver_explain` text COMMENT '订单发货备注',
  `daddress_id` mediumint(9) NOT NULL DEFAULT '0' COMMENT '发货地址ID',
  `reciver_name` varchar(50) NOT NULL COMMENT '收货人姓名',
  `reciver_info` varchar(500) NOT NULL COMMENT '收货人其它信息',
  `reciver_province_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '收货人省级ID',
  `reciver_city_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '收货人市级ID',
  `invoice_info` varchar(500) DEFAULT NULL COMMENT '订单发票信息',
  `promotion_info` varchar(500) DEFAULT NULL COMMENT '订单促销信息备注',
  PRIMARY KEY (`order_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='订单信息扩展表';



DROP TABLE IF EXISTS `#__ordergoods`;
CREATE TABLE IF NOT EXISTS `#__ordergoods` (
  `rec_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单商品表自增ID',
  `order_id` int(11) NOT NULL COMMENT '订单ID',
  `goods_id` int(11) NOT NULL COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `goods_num` smallint(5) unsigned NOT NULL DEFAULT '1' COMMENT '商品数量',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `goods_pay_price` decimal(10,2) unsigned NOT NULL COMMENT '商品实际成交价',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `buyer_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '买家ID',
  `goods_type` enum('1','2','3','4','5','6','7','8','9','10') NOT NULL DEFAULT '1' COMMENT '1默认2抢购商品3限时折扣商品4组合套装5赠品6拼团7会员等级折扣8砍价9批发10预售',
  `promotions_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '促销活动ID（抢购ID/限时折扣ID/优惠套装ID）与goods_type搭配使用',
  `commis_rate` smallint(5) unsigned NOT NULL DEFAULT '0' COMMENT '佣金比例',
  `gc_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '商品最底级分类ID',
  PRIMARY KEY (`rec_id`),
  KEY `order_id` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='订单商品表';



DROP TABLE IF EXISTS `#__orderinviter`;
CREATE TABLE IF NOT EXISTS `#__orderinviter` (
  `orderinviter_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '分销详情自增ID',
  `orderinviter_order_id` int(10) unsigned NOT NULL COMMENT '订单ID',
  `orderinviter_member_id` int(10) unsigned NOT NULL COMMENT '推荐人ID',
  `orderinviter_money` decimal(10,2) unsigned NOT NULL COMMENT '佣金',
  `orderinviter_remark` varchar(255) NOT NULL COMMENT '分销详情备注',
  `orderinviter_member_name` varchar(60) NOT NULL COMMENT '推荐人用户名',
  `orderinviter_order_sn` varchar(20) NOT NULL COMMENT '订单号',
  `orderinviter_goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共id',
  `orderinviter_goods_id` int(10) unsigned NOT NULL COMMENT '商品id',
  `orderinviter_level` int(10) unsigned NOT NULL COMMENT '分销级别',
  `orderinviter_ratio` decimal(4,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '分销比例',
  `orderinviter_goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `orderinviter_valid` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '0待结算1已结算2无效',
  `orderinviter_store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `orderinviter_order_type` tinyint(1) unsigned NOT NULL COMMENT '订单类型（0实物订单1虚拟订单）',
  `orderinviter_goods_quantity` int(10) unsigned NOT NULL COMMENT '商品数量',
  `orderinviter_goods_amount` decimal(10,2) unsigned NOT NULL COMMENT '商品金额',
  `orderinviter_store_name` varchar(60) NOT NULL COMMENT '店铺名',
  `orderinviter_addtime` int(10) unsigned NOT NULL COMMENT '添加时间',
  PRIMARY KEY (`orderinviter_id`),
  KEY `orderinviter_member_id` (`orderinviter_member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='分销详情表';



DROP TABLE IF EXISTS `#__orderlog`;
CREATE TABLE IF NOT EXISTS `#__orderlog` (
  `log_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单记录自增ID',
  `order_id` int(11) NOT NULL COMMENT '订单id',
  `log_msg` varchar(150) DEFAULT '' COMMENT '订单记录文字描述',
  `log_time` int(10) unsigned NOT NULL COMMENT '订单记录处理时间',
  `log_role` char(2) NOT NULL COMMENT '操作角色',
  `log_user` varchar(30) DEFAULT '' COMMENT '操作人',
  `log_orderstate` enum('0','10','14','15','20','30','35','40') DEFAULT NULL COMMENT '订单状态：0:已取消10:未付款;14:待付定金;15:待付尾款;20:已付款;30:已发货;35:待自提;40:已收货;',
  PRIMARY KEY (`log_id`),
  KEY `order_id` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='订单记录表';



DROP TABLE IF EXISTS `#__orderpay`;
CREATE TABLE IF NOT EXISTS `#__orderpay` (
  `pay_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '订单支付自增ID',
  `pay_sn` varchar(20) NOT NULL COMMENT '支付单号',
  `buyer_id` int(10) unsigned NOT NULL COMMENT '买家ID',
  `api_paystate` enum('0','1') DEFAULT '0' COMMENT '0默认未支付1已支付(只有第三方支付接口通知到时才会更改此状态)',
  PRIMARY KEY (`pay_id`),
  KEY `pay_sn` (`pay_sn`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='订单支付表';



DROP TABLE IF EXISTS `#__orderstatis`;
CREATE TABLE IF NOT EXISTS `#__orderstatis` (
  `os_month` mediumint(9) unsigned NOT NULL DEFAULT '0' COMMENT '统计编号(年月)',
  `os_order_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '订单金额',
  `os_shipping_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '运费',
  `os_order_returntotals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '退单金额',
  `os_commis_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '佣金金额',
  `os_commis_returntotals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '退还佣金',
  `os_store_costtotals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '店铺促销活动费用',
  `os_vr_order_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟订单金额',
  `os_vr_order_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟订单退款金额',
  `os_vr_commis_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟佣金金额',
  `os_vr_commis_return_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟退还佣金金额',
  `os_vr_inviter_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '虚拟分销佣金金额',
  `os_result_totals` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '本期应结',
  `os_createdate` int(11) DEFAULT NULL COMMENT '创建记录日期',
  `os_inviter_totals` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '分销佣金',
  PRIMARY KEY (`os_month`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='月销量统计表';



DROP TABLE IF EXISTS `#__payment`;
CREATE TABLE IF NOT EXISTS `#__payment` (
  `payment_code` char(20) NOT NULL COMMENT '支付代码',
  `payment_name` char(20) NOT NULL COMMENT '支付名称',
  `payment_config` text COMMENT '支付接口配置信息',
  `payment_platform` char(10) NOT NULL COMMENT '支付方式所适应平台 pc h5 app',
  `payment_state` enum('0','1') NOT NULL DEFAULT '0' COMMENT '接口状态0禁用1启用',
  PRIMARY KEY (`payment_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='支付方式表';



DROP TABLE IF EXISTS `#__pbargain`;
CREATE TABLE IF NOT EXISTS `#__pbargain` (
  `bargain_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '砍价活动自增ID',
  `member_id` int(11) unsigned NOT NULL COMMENT '卖家用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '卖家用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `bargain_name` varchar(50) NOT NULL COMMENT '砍价名称',
  `bargain_goods_id` int(11) unsigned NOT NULL COMMENT '商品ID',
  `bargain_goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `bargain_goods_image` varchar(100) DEFAULT '' COMMENT '商品图片',
  `bargain_goods_price` decimal(10,2) NOT NULL COMMENT '商品原价',
  `bargain_goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表ID',
  `bargain_limit` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '砍价限购数量',
  `bargain_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '砍价有效期/小时',
  `bargain_floorprice` decimal(10,2) NOT NULL COMMENT '商品底价',
  `bargain_total` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '共多少刀砍至底价',
  `bargain_max` decimal(10,2) NOT NULL COMMENT '每刀最多可砍金额',
  `bargain_remark` varchar(50) NOT NULL COMMENT '分享描述',
  `bargain_begintime` int(10) unsigned NOT NULL COMMENT '砍价开始时间',
  `bargain_endtime` int(10) unsigned NOT NULL COMMENT '砍价结束时间',
  `bargain_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态，0:已取消 1:未开始 2:进行中 3:已结束',
  PRIMARY KEY (`bargain_id`),
  KEY `member_id` (`member_id`),
  KEY `store_id` (`store_id`),
  KEY `bargain_goods_id` (`bargain_goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺砍价活动表';



DROP TABLE IF EXISTS `#__pbargainlog`;
CREATE TABLE IF NOT EXISTS `#__pbargainlog` (
  `pbargainlog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '砍价记录自增ID',
  `pbargainlog_member_id` int(11) unsigned NOT NULL COMMENT '帮砍价ID',
  `pbargainlog_member_name` varchar(50) NOT NULL COMMENT '帮砍价用户名',
  `pbargainlog_price` decimal(10,2) NOT NULL COMMENT '砍掉的价格',
  `pbargainlog_time` int(10) unsigned NOT NULL COMMENT '砍价时间',
  `bargain_id` int(10) unsigned NOT NULL COMMENT '砍价活动ID',
  `bargainorder_id` int(10) unsigned NOT NULL COMMENT '砍价订单ID',
  PRIMARY KEY (`pbargainlog_id`),
  KEY `pbargainlog_member_id` (`pbargainlog_member_id`,`bargainorder_id`),
  KEY `bargain_id` (`bargain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='砍价记录表';



DROP TABLE IF EXISTS `#__pbargainorder`;
CREATE TABLE IF NOT EXISTS `#__pbargainorder` (
  `bargainorder_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '砍价订单自增ID',
  `bargainorder_initiator_id` int(11) unsigned NOT NULL COMMENT '砍价订单发起人ID',
  `bargainorder_initiator_name` varchar(50) NOT NULL COMMENT '砍价订单发起人用户名',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `bargain_id` int(10) unsigned NOT NULL COMMENT '砍价活动ID',
  `bargain_name` varchar(50) NOT NULL COMMENT '砍价名称',
  `bargain_total` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '共多少刀砍至底价',
  `bargain_goods_id` int(11) unsigned NOT NULL COMMENT '商品ID',
  `bargain_goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `bargain_goods_price` decimal(10,2) NOT NULL COMMENT '商品原价',
  `bargain_goods_image` varchar(100) DEFAULT '' COMMENT '商品图片',
  `bargainorder_times` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '砍价次数',
  `bargainorder_current_price` decimal(10,2) NOT NULL COMMENT '砍价后价格',
  `bargainorder_begintime` int(10) unsigned NOT NULL COMMENT '开始时间',
  `bargainorder_endtime` int(10) unsigned NOT NULL COMMENT '结束时间',
  `bargainorder_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态，0:取消 1:正常 2:砍价成功 3:砍价失败',
  `order_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '订单ID',
  PRIMARY KEY (`bargainorder_id`),
  KEY `bargainorder_initiator_id` (`bargainorder_initiator_id`),
  KEY `store_id` (`store_id`),
  KEY `bargain_id` (`bargain_id`),
  KEY `bargain_goods_id` (`bargain_goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='砍价订单表';



DROP TABLE IF EXISTS `#__pbargainquota`;
CREATE TABLE IF NOT EXISTS `#__pbargainquota` (
  `bargainquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '砍价套餐ID',
  `member_id` int(11) unsigned NOT NULL COMMENT '卖家用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '卖家用户名',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `bargainquota_starttime` int(10) unsigned NOT NULL COMMENT '砍价套餐开始时间',
  `bargainquota_endtime` int(10) unsigned NOT NULL COMMENT '砍价套餐结束时间',
  PRIMARY KEY (`bargainquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='砍价套餐表';



DROP TABLE IF EXISTS `#__pboothgoods`;
CREATE TABLE IF NOT EXISTS `#__pboothgoods` (
  `boothgoods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '展位商品ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '展位店铺id',
  `goods_id` int(10) unsigned NOT NULL COMMENT '展位商品id',
  `gc_id` int(10) unsigned NOT NULL COMMENT '商品分类id',
  `boothgoods_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '展位商品状态 1开启 0关闭 默认1',
  PRIMARY KEY (`boothgoods_id`),
  KEY `store_id` (`store_id`),
  KEY `gc_id` (`gc_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='展位商品表';



DROP TABLE IF EXISTS `#__pboothquota`;
CREATE TABLE IF NOT EXISTS `#__pboothquota` (
  `boothquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '展位套餐自增ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `boothquota_starttime` int(10) unsigned NOT NULL COMMENT '展位开始时间',
  `boothquota_endtime` int(10) unsigned NOT NULL COMMENT '展位结束时间',
  `boothquota_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '套餐状态 1:开启 0:关闭',
  PRIMARY KEY (`boothquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='展位套餐表';



DROP TABLE IF EXISTS `#__pbundling`;
CREATE TABLE IF NOT EXISTS `#__pbundling` (
  `bl_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '组合ID',
  `store_id` int(11) NOT NULL COMMENT '店铺名称',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `bl_name` varchar(50) NOT NULL COMMENT '组合名称',
  `bl_discount_price` decimal(10,2) NOT NULL COMMENT '组合价格',
  `bl_freight_choose` tinyint(1) NOT NULL COMMENT '运费承担方式',
  `bl_freight` decimal(10,2) NOT NULL COMMENT '运费',
  `bl_state` tinyint(1) NOT NULL DEFAULT '1' COMMENT '组合状态 0:关闭 1:开启',
  PRIMARY KEY (`bl_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组合销售活动表';



DROP TABLE IF EXISTS `#__pbundlinggoods`;
CREATE TABLE IF NOT EXISTS `#__pbundlinggoods` (
  `blgoods_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '组合商品id',
  `blgoods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `blgoods_appoint` tinyint(3) unsigned NOT NULL COMMENT '指定商品 1是，0否',
  `bl_id` int(11) NOT NULL COMMENT '组合id',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品id',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_image` varchar(100) NOT NULL COMMENT '商品图片',
  PRIMARY KEY (`blgoods_id`),
  KEY `bl_id` (`bl_id`),
  KEY `goods_id` (`goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组合销售活动商品表';



DROP TABLE IF EXISTS `#__pbundlingquota`;
CREATE TABLE IF NOT EXISTS `#__pbundlingquota` (
  `blquota_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '组合套餐自增ID',
  `store_id` int(11) NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `member_id` int(11) NOT NULL COMMENT '会员ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `blquota_month` tinyint(3) unsigned NOT NULL COMMENT '组合套餐购买数量（单位月）',
  `blquota_starttime` varchar(10) NOT NULL COMMENT '组合套餐开始时间',
  `blquota_endtime` varchar(10) NOT NULL COMMENT '组合套餐结束时间',
  `blquota_state` tinyint(1) unsigned NOT NULL COMMENT '组合套餐状态：0关闭，1开启。默认为 1',
  PRIMARY KEY (`blquota_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组合销售套餐表';



DROP TABLE IF EXISTS `#__pdcash`;
CREATE TABLE IF NOT EXISTS `#__pdcash` (
  `pdc_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '提现记录自增ID',
  `pdc_sn` varchar(20) NOT NULL COMMENT '记录唯一标示',
  `pdc_member_id` int(11) NOT NULL COMMENT '会员ID',
  `pdc_member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `pdc_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '金额',
  `pdc_bank_type` varchar(10) NOT NULL DEFAULT 'bank' COMMENT 'bank银行 alipay 支付宝 weixin 微信收款',
  `pdc_bank_name` varchar(40) NOT NULL COMMENT '收款银行',
  `pdc_bank_no` varchar(30) DEFAULT NULL COMMENT '收款账号',
  `pdc_bank_user` varchar(10) DEFAULT NULL COMMENT '开户人姓名',
  `pdc_addtime` int(11) NOT NULL COMMENT '添加时间',
  `pdc_payment_time` int(11) DEFAULT NULL COMMENT '付款时间',
  `pdc_payment_state` enum('0','1') NOT NULL DEFAULT '0' COMMENT '提现支付状态 0:默认1:支付完成',
  `pdc_payment_admin` varchar(30) DEFAULT NULL COMMENT '支付管理员',
  `pdc_payment_code` varchar(20) DEFAULT '' COMMENT '支付方式',
  `pdc_trade_sn` varchar(50) DEFAULT '' COMMENT '第三方支付接口交易号',
  PRIMARY KEY (`pdc_id`),
  KEY `pdc_member_id` (`pdc_member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='预存款提现记录表';



DROP TABLE IF EXISTS `#__pdlog`;
CREATE TABLE IF NOT EXISTS `#__pdlog` (
  `lg_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '预存款变更日志自增ID',
  `lg_member_id` int(11) NOT NULL COMMENT '会员ID',
  `lg_member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `lg_admin_name` varchar(50) DEFAULT NULL COMMENT '管理员名称',
  `lg_type` varchar(50) NOT NULL DEFAULT '' COMMENT 'order_pay下单支付预存款,order_freeze下单冻结预存款,order_cancel取消订单解冻预存款,order_comb_pay下单支付被冻结的预存款,recharge充值,cash_apply申请提现冻结预存款,cash_pay提现成功,cash_del取消提现申请，解冻预存款,refund退款',
  `lg_av_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '可用金额变更0:未变更',
  `lg_freeze_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '冻结金额变更0:未变更',
  `lg_addtime` int(11) NOT NULL COMMENT '变更添加时间',
  `lg_desc` varchar(150) DEFAULT NULL COMMENT '变更描述',
  PRIMARY KEY (`lg_id`),
  KEY `lg_member_id` (`lg_member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='预存款变更日志表';



DROP TABLE IF EXISTS `#__pdrecharge`;
CREATE TABLE IF NOT EXISTS `#__pdrecharge` (
  `pdr_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '充值自增ID',
  `pdr_sn` varchar(20) NOT NULL COMMENT '记录唯一标示',
  `pdr_member_id` int(11) NOT NULL COMMENT '会员ID',
  `pdr_member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `pdr_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '充值金额',
  `pdr_payment_code` varchar(20) DEFAULT '' COMMENT '支付方式',
  `pdr_trade_sn` varchar(50) DEFAULT '' COMMENT '第三方支付接口交易号',
  `pdr_addtime` int(11) NOT NULL COMMENT '充值添加时间',
  `pdr_payment_state` enum('0','1') NOT NULL DEFAULT '0' COMMENT '支付状态 0未支付1支付',
  `pdr_paymenttime` int(11) NOT NULL DEFAULT '0' COMMENT '支付时间',
  `pdr_admin` varchar(30) DEFAULT '' COMMENT '管理员名',
  PRIMARY KEY (`pdr_id`),
  KEY `pdr_member_id` (`pdr_member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='预存款充值表';



DROP TABLE IF EXISTS `#__pmansong`;
CREATE TABLE IF NOT EXISTS `#__pmansong` (
  `mansong_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '满送活动编号',
  `mansong_name` varchar(50) NOT NULL COMMENT '活动名称',
  `mansongquota_id` int(10) unsigned NOT NULL COMMENT '套餐编号',
  `mansong_starttime` int(10) unsigned NOT NULL COMMENT '活动开始时间',
  `mansong_endtime` int(10) unsigned NOT NULL COMMENT '活动结束时间',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `mansong_state` tinyint(1) unsigned NOT NULL COMMENT '活动状态 1:未发布 2:正常 3:取消 4:失效 5:结束',
  `mansong_remark` varchar(200) NOT NULL COMMENT '满就送备注',
  PRIMARY KEY (`mansong_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='满就送活动表';



DROP TABLE IF EXISTS `#__pmansongquota`;
CREATE TABLE IF NOT EXISTS `#__pmansongquota` (
  `mansongquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '满就送套餐编号',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `mansongquota_apply_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '申请ID',
  `mansongquota_starttime` int(10) unsigned NOT NULL COMMENT '开始时间',
  `mansongquota_endtime` int(10) unsigned NOT NULL COMMENT '结束时间',
  `mansongquota_state` tinyint(1) unsigned DEFAULT NULL COMMENT '配额状态 1:可用 2:取消 3:结束',
  PRIMARY KEY (`mansongquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='满就送套餐表';



DROP TABLE IF EXISTS `#__pmansongrule`;
CREATE TABLE IF NOT EXISTS `#__pmansongrule` (
  `mansongrule_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '满就送规则ID',
  `mansong_id` int(10) unsigned NOT NULL COMMENT '满就送活动ID',
  `mansongrule_price` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '满就送级别价格',
  `mansongrule_discount` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '满就送减现金优惠金额',
  `mansong_goods_name` varchar(200) DEFAULT NULL COMMENT '满就送礼品名称',
  `goods_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '满就送商品ID',
  PRIMARY KEY (`mansongrule_id`),
  KEY `mansong_id` (`mansong_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='满就送活动规则表';



DROP TABLE IF EXISTS `#__pmgdiscountquota`;
CREATE TABLE IF NOT EXISTS `#__pmgdiscountquota` (
  `mgdiscountquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '会员等级折扣套餐ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `mgdiscountquota_starttime` int(10) unsigned NOT NULL COMMENT '会员等级折扣套餐开始时间',
  `mgdiscountquota_endtime` int(10) unsigned NOT NULL COMMENT '会员等级折扣套餐结束时间',
  PRIMARY KEY (`mgdiscountquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员等级折扣套餐表';



DROP TABLE IF EXISTS `#__pointscart`;
CREATE TABLE IF NOT EXISTS `#__pointscart` (
  `pcart_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '积分购物车自增ID',
  `pmember_id` int(11) NOT NULL COMMENT '会员ID',
  `pgoods_id` int(11) NOT NULL COMMENT '积分礼品序号',
  `pgoods_name` varchar(200) NOT NULL COMMENT '积分礼品名称',
  `pgoods_points` int(11) NOT NULL COMMENT '积分礼品兑换积分',
  `pgoods_choosenum` int(11) NOT NULL COMMENT '选择积分礼品数量',
  `pgoods_image` varchar(100) DEFAULT NULL COMMENT '积分礼品图片',
  PRIMARY KEY (`pcart_id`),
  KEY `pmember_id` (`pmember_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='积分礼品兑换购物车';



DROP TABLE IF EXISTS `#__pointsgoods`;
CREATE TABLE IF NOT EXISTS `#__pointsgoods` (
  `pgoods_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '积分礼品自增ID',
  `pgoods_name` varchar(200) NOT NULL COMMENT '积分礼品名称',
  `pgoods_price` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '积分礼品原价',
  `pgoods_points` int(11) NOT NULL COMMENT '积分礼品兑换积分',
  `pgoods_image` varchar(100) DEFAULT NULL COMMENT '积分礼品封面图片',
  `pgoods_tag` varchar(100) NOT NULL COMMENT '积分礼品标签',
  `pgoods_serial` varchar(50) NOT NULL COMMENT '积分礼品货号',
  `pgoods_storage` int(11) NOT NULL DEFAULT '0' COMMENT '积分礼品库存',
  `pgoods_show` tinyint(1) NOT NULL COMMENT '积分礼品上架 0:下架 1:上架',
  `pgoods_commend` tinyint(1) NOT NULL COMMENT '积分礼品是否推荐',
  `pgoods_addtime` int(11) NOT NULL COMMENT '积分礼品添加时间',
  `pgoods_keywords` varchar(100) DEFAULT NULL COMMENT '积分礼品关键字',
  `pgoods_description` varchar(200) DEFAULT NULL COMMENT '积分礼品描述',
  `pgoods_body` text COMMENT '积分礼品内容',
  `pgoods_state` tinyint(1) NOT NULL DEFAULT '0' COMMENT '积分礼品状态 0:开启 1:禁售',
  `pgoods_close_reason` varchar(255) DEFAULT NULL COMMENT '积分礼品禁售原因',
  `pgoods_salenum` int(11) NOT NULL DEFAULT '0' COMMENT '积分礼品售出数量',
  `pgoods_view` int(11) NOT NULL DEFAULT '0' COMMENT '积分商品浏览量',
  `pgoods_islimit` tinyint(1) NOT NULL COMMENT '是否限制兑换数量',
  `pgoods_limitnum` int(11) DEFAULT NULL COMMENT '限制兑换数量',
  `pgoods_islimittime` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否限制兑换时间 0:不限制 1:限制',
  `pgoods_limitmgrade` int(11) NOT NULL DEFAULT '0' COMMENT '限制参与兑换的会员级别',
  `pgoods_starttime` int(11) DEFAULT NULL COMMENT '积分兑换开始时间',
  `pgoods_endtime` int(11) DEFAULT NULL COMMENT '积分兑换结束时间',
  `pgoods_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '积分礼品排序',
  PRIMARY KEY (`pgoods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='积分礼品表';



DROP TABLE IF EXISTS `#__pointslog`;
CREATE TABLE IF NOT EXISTS `#__pointslog` (
  `pl_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '积分日志自增ID',
  `pl_memberid` int(11) NOT NULL COMMENT '会员ID',
  `pl_membername` varchar(100) NOT NULL COMMENT '会员名称',
  `pl_adminid` int(11) DEFAULT NULL COMMENT '管理员ID',
  `pl_adminname` varchar(100) DEFAULT NULL COMMENT '管理员名称',
  `pl_points` int(11) NOT NULL DEFAULT '0' COMMENT '积分数 负数为扣除',
  `pl_addtime` int(11) NOT NULL COMMENT '积分添加时间',
  `pl_desc` varchar(100) NOT NULL COMMENT '积分操作描述',
  `pl_stage` varchar(50) NOT NULL COMMENT '积分操作阶段',
  PRIMARY KEY (`pl_id`),
  KEY `pl_memberid` (`pl_memberid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员积分日志表';



DROP TABLE IF EXISTS `#__pointsorder`;
CREATE TABLE IF NOT EXISTS `#__pointsorder` (
  `point_orderid` int(11) NOT NULL AUTO_INCREMENT COMMENT '兑换订单自增ID',
  `point_ordersn` varchar(20) NOT NULL COMMENT '兑换订单编号',
  `point_buyerid` int(11) NOT NULL COMMENT '兑换会员ID',
  `point_buyername` varchar(50) NOT NULL COMMENT '兑换会员姓名',
  `point_buyeremail` varchar(100) DEFAULT NULL COMMENT '兑换会员email',
  `point_addtime` int(11) NOT NULL COMMENT '兑换订单添加时间',
  `point_shippingtime` int(11) DEFAULT NULL COMMENT '兑换配送时间',
  `point_shippingcode` varchar(50) DEFAULT NULL COMMENT '兑换物流单号',
  `point_shipping_ecode` varchar(30) DEFAULT NULL COMMENT '兑换物流公司编码',
  `point_finnshedtime` int(11) DEFAULT NULL COMMENT '兑换订单完成时间',
  `point_allpoint` int(11) NOT NULL DEFAULT '0' COMMENT '兑换总积分',
  `point_ordermessage` varchar(300) DEFAULT NULL COMMENT '兑换订单留言',
  `point_orderstate` int(11) NOT NULL DEFAULT '20' COMMENT '订单状态：20:已兑换并扣除积分;30:已发货;40:已收货;50:已完成;2:已取消',
  PRIMARY KEY (`point_orderid`),
  KEY `point_buyerid` (`point_buyerid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='兑换订单表';



DROP TABLE IF EXISTS `#__pointsorderaddress`;
CREATE TABLE IF NOT EXISTS `#__pointsorderaddress` (
  `pointoa_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '积分兑换地址自增ID',
  `pointoa_orderid` int(11) NOT NULL COMMENT '订单id',
  `pointoa_truename` varchar(50) NOT NULL COMMENT '收货人姓名',
  `pointoa_areaid` int(11) NOT NULL COMMENT '地区id',
  `pointoa_areainfo` varchar(100) NOT NULL COMMENT '地区内容',
  `pointoa_address` varchar(200) NOT NULL COMMENT '详细地址',
  `pointoa_zipcode` varchar(20) NOT NULL COMMENT '邮政编码',
  `pointoa_telphone` varchar(20) NOT NULL COMMENT '电话号码',
  `pointoa_mobphone` varchar(20) NOT NULL COMMENT '手机号码',
  PRIMARY KEY (`pointoa_id`),
  KEY `pointoa_orderid` (`pointoa_orderid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='积分兑换地址表';



DROP TABLE IF EXISTS `#__pointsordergoods`;
CREATE TABLE IF NOT EXISTS `#__pointsordergoods` (
  `pointog_recid` int(11) NOT NULL AUTO_INCREMENT COMMENT '积分订单商品自增ID',
  `pointog_orderid` int(11) NOT NULL COMMENT '订单ID',
  `pointog_goodsid` int(11) NOT NULL COMMENT '礼品ID',
  `pointog_goodsname` varchar(100) NOT NULL COMMENT '礼品名称',
  `pointog_goodspoints` int(11) NOT NULL COMMENT '礼品兑换积分',
  `pointog_goodsnum` int(11) NOT NULL COMMENT '礼品数量',
  `pointog_goodsimage` varchar(100) DEFAULT NULL COMMENT '礼品图片',
  PRIMARY KEY (`pointog_recid`),
  KEY `pointog_orderid` (`pointog_orderid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='兑换订单商品表';



DROP TABLE IF EXISTS `#__ppintuan`;
CREATE TABLE IF NOT EXISTS `#__ppintuan` (
  `pintuan_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '拼团自增ID',
  `member_id` int(11) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `pintuanquota_id` int(10) unsigned NOT NULL COMMENT '拼团套餐ID',
  `pintuan_name` varchar(50) NOT NULL COMMENT '拼团名称',
  `pintuan_goods_id` int(11) unsigned NOT NULL COMMENT '商品ID',
  `pintuan_goods_name` varchar(200) NOT NULL COMMENT '拼团名称',
  `pintuan_goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表ID',
  `pintuan_goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `pintuan_is_virtual` tinyint(3) DEFAULT '0' COMMENT '是否为虚拟商品 1:是 0:否',
  `pintuan_zhe` int(10) unsigned NOT NULL COMMENT '拼团折扣',
  `pintuan_image` varchar(50) DEFAULT NULL COMMENT '拼团图片',
  `pintuan_starttime` int(10) unsigned NOT NULL COMMENT '拼团开始时间',
  `pintuan_end_time` int(10) unsigned NOT NULL COMMENT '拼团结束时间',
  `pintuan_limit_number` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成团人数',
  `pintuan_limit_hour` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成团时限',
  `pintuan_limit_quantity` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成团数量限制',
  `pintuan_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '组团数量',
  `pintuan_ok_count` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成功组团数量',
  `pintuan_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:取消 1:正常',
  PRIMARY KEY (`pintuan_id`),
  KEY `store_id` (`store_id`),
  KEY `pintuan_goods_id` (`pintuan_goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺拼团表';



DROP TABLE IF EXISTS `#__ppintuangroup`;
CREATE TABLE IF NOT EXISTS `#__ppintuangroup` (
  `pintuangroup_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '拼团开团ID',
  `pintuan_id` int(10) unsigned NOT NULL COMMENT '拼团ID',
  `pintuangroup_goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `pintuangroup_is_virtual` tinyint(3) DEFAULT '0' COMMENT '是否为虚拟商品 1:是 0:否',
  `pintuangroup_limit_number` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成团人数',
  `pintuangroup_limit_hour` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '成团时限',
  `pintuangroup_joined` int(10) unsigned NOT NULL COMMENT '己参团人数',
  `pintuangroup_headid` int(10) unsigned NOT NULL COMMENT '团长用户编号',
  `pintuangroup_starttime` int(10) unsigned NOT NULL COMMENT '开团时间',
  `pintuangroup_endtime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '结束时间 成功或失败',
  `pintuangroup_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:取消 1:参团中 2:成功',
  PRIMARY KEY (`pintuangroup_id`),
  KEY `pintuan_id` (`pintuan_id`),
  KEY `pintuangroup_goods_id` (`pintuangroup_goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='拼团开团表';



DROP TABLE IF EXISTS `#__ppintuanorder`;
CREATE TABLE IF NOT EXISTS `#__ppintuanorder` (
  `pintuanorder_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '拼团开团ID',
  `pintuan_id` int(10) unsigned NOT NULL COMMENT '拼团ID',
  `pintuangroup_id` int(11) unsigned NOT NULL COMMENT '拼团开团ID',
  `order_id` int(11) NOT NULL COMMENT '订单ID',
  `order_sn` varchar(20) NOT NULL COMMENT '订单编号',
  `pintuanorder_isfirst` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '是否首团订单，0:否 1:是',
  `pintuanorder_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:取消 1:参团中 2:成功',
  `pintuanorder_type` tinyint(1) unsigned NOT NULL COMMENT '订单类型（0实物1虚拟）',
  PRIMARY KEY (`pintuanorder_id`),
  KEY `pintuan_id` (`pintuan_id`),
  KEY `pintuangroup_id` (`pintuangroup_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='拼团订单辅助表';



DROP TABLE IF EXISTS `#__ppintuanquota`;
CREATE TABLE IF NOT EXISTS `#__ppintuanquota` (
  `pintuanquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '拼团套餐ID',
  `member_id` int(11) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_id` int(11) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `pintuanquota_starttime` int(10) unsigned NOT NULL COMMENT '拼团套餐开始时间',
  `pintuanquota_endtime` int(10) unsigned NOT NULL COMMENT '拼团套餐结束时间',
  PRIMARY KEY (`pintuanquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='拼团套餐表';


DROP TABLE IF EXISTS `#__presell`;
CREATE TABLE IF NOT EXISTS `#__presell` (
  `presell_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '预售ID',
  `presell_type` tinyint(1) unsigned NOT NULL COMMENT '预售类型（1全款预售2定金预售）',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `presell_deposit_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '定金金额',
  `presell_price` decimal(10,2) unsigned NOT NULL COMMENT '预售价',
  `presell_start_time` int(10) unsigned NOT NULL COMMENT '活动开始时间',
  `presell_end_time` int(10) unsigned NOT NULL COMMENT '活动结束时间',
  `presell_shipping_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '预售发货时间',
  `presell_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:已取消 1:待开始 2:进行中 3:已结束',
  PRIMARY KEY (`presell_id`),
  KEY `store_id` (`store_id`),
  KEY `goods_id` (`goods_id`),
  KEY `goods_commonid` (`goods_commonid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='预售表' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__presellquota`;
CREATE TABLE IF NOT EXISTS `#__presellquota` (
  `presellquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '预售套餐ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名称',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `presellquota_starttime` int(10) unsigned NOT NULL COMMENT '开始时间',
  `presellquota_endtime` int(10) unsigned NOT NULL COMMENT '结束时间',
  PRIMARY KEY (`presellquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='预售套餐' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__pxianshi`;
CREATE TABLE IF NOT EXISTS `#__pxianshi` (
  `xianshi_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '限时折扣自增ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `xianshiquota_id` int(10) unsigned NOT NULL COMMENT '套餐ID',
  `xianshi_name` varchar(50) NOT NULL COMMENT '活动名称',
  `xianshi_title` varchar(10) DEFAULT NULL COMMENT '活动标题',
  `xianshi_explain` varchar(50) DEFAULT NULL COMMENT '活动说明',
  `xianshi_starttime` int(10) unsigned NOT NULL COMMENT '活动开始时间',
  `xianshi_end_time` int(10) unsigned NOT NULL COMMENT '活动结束时间',
  `xianshi_lower_limit` int(10) unsigned NOT NULL DEFAULT '1' COMMENT '购买下限，1:不限制',
  `xianshi_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:取消 1:正常',
  PRIMARY KEY (`xianshi_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='限时折扣活动表';



DROP TABLE IF EXISTS `#__pxianshigoods`;
CREATE TABLE IF NOT EXISTS `#__pxianshigoods` (
  `xianshigoods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '限时折扣商品表',
  `xianshi_id` int(10) unsigned NOT NULL COMMENT '限时折扣ID',
  `xianshi_name` varchar(50) NOT NULL COMMENT '限时折扣名称',
  `xianshi_title` varchar(10) DEFAULT NULL COMMENT '限时折扣标题',
  `xianshi_explain` varchar(50) DEFAULT NULL COMMENT '限时折扣说明',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_price` decimal(10,2) NOT NULL COMMENT '店铺价格',
  `goods_image` varchar(100) NOT NULL COMMENT '商品图片',
  `xianshigoods_price` decimal(10,2) NOT NULL COMMENT '限时折扣价格',
  `xianshigoods_starttime` int(10) unsigned NOT NULL COMMENT '限时折扣开始时间',
  `xianshigoods_end_time` int(10) unsigned NOT NULL COMMENT '限时折扣结束时间',
  `xianshigoods_lower_limit` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '购买下限，0为不限制',
  `xianshigoods_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '限时折扣状态，0-取消 1-正常',
  `xianshigoods_recommend` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '限时折扣推荐标志 0-未推荐 1-已推荐',
  `gc_id_1` mediumint(9) DEFAULT '0' COMMENT '商品分类一级ID',
  PRIMARY KEY (`xianshigoods_id`),
  KEY `store_id` (`store_id`),
  KEY `goods_id` (`goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='限时折扣商品表';



DROP TABLE IF EXISTS `#__pxianshiquota`;
CREATE TABLE IF NOT EXISTS `#__pxianshiquota` (
  `xianshiquota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '限时折扣套餐ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `xianshiquota_starttime` int(10) unsigned NOT NULL COMMENT '限时折扣套餐开始时间',
  `xianshiquota_endtime` int(10) unsigned NOT NULL COMMENT '限时折扣套餐结束时间',
  PRIMARY KEY (`xianshiquota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='限时折扣套餐表';



DROP TABLE IF EXISTS `#__rcblog`;
CREATE TABLE IF NOT EXISTS `#__rcblog` (
  `rcblog_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '余额变更日志自增ID',
  `member_id` int(11) NOT NULL COMMENT '会员ID',
  `member_name` varchar(50) NOT NULL COMMENT '会员名称',
  `rcblog_type` varchar(15) NOT NULL DEFAULT '' COMMENT 'order_pay:下单使用 order_freeze:下单冻结 order_cancel:取消订单解冻 order_comb_pay:下单扣除被冻结 recharge:平台充值卡充值 refund:确认退款 vr_refund:虚拟兑码退款',
  `rcblog_addtime` int(11) NOT NULL COMMENT '变更添加时间',
  `available_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '可用充值卡余额变更 0表示未变更',
  `freeze_amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '冻结充值卡余额变更 0表示未变更',
  `rcblog_description` varchar(150) DEFAULT NULL COMMENT '变更描述',
  PRIMARY KEY (`rcblog_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='充值卡余额变更日志表';



DROP TABLE IF EXISTS `#__rechargecard`;
CREATE TABLE IF NOT EXISTS `#__rechargecard` (
  `rc_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '充值卡自增ID',
  `rc_sn` varchar(50) NOT NULL COMMENT '充值卡卡号',
  `rc_denomination` decimal(10,2) NOT NULL COMMENT '充值卡面额',
  `rc_batchflag` varchar(20) NOT NULL COMMENT '充值卡批次标识',
  `rc_admin_name` varchar(50) DEFAULT NULL COMMENT '充值卡创建者名称',
  `rc_tscreated` int(10) unsigned NOT NULL COMMENT '充值卡创建时间',
  `rc_tsused` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '充值卡使用时间',
  `rc_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '充值卡状态 0可用 1已用 2已删',
  `member_id` int(11) NOT NULL DEFAULT '0' COMMENT '使用者会员ID',
  `member_name` varchar(50) DEFAULT NULL COMMENT '使用者会员名称',
  PRIMARY KEY (`rc_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='平台充值卡';



DROP TABLE IF EXISTS `#__refundreason`;
CREATE TABLE IF NOT EXISTS `#__refundreason` (
  `reason_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '原因自增ID',
  `reason_info` varchar(50) NOT NULL COMMENT '原因内容',
  `reason_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '退款退货原因排序',
  `reason_updatetime` int(10) unsigned NOT NULL COMMENT '退款退货原因更新时间',
  PRIMARY KEY (`reason_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='退款退货原因表';



DROP TABLE IF EXISTS `#__refundreturn`;
CREATE TABLE IF NOT EXISTS `#__refundreturn` (
  `refund_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '退款退货记录自增ID',
  `order_id` int(10) unsigned NOT NULL COMMENT '订单ID',
  `order_sn` varchar(20) NOT NULL COMMENT '订单编号',
  `refund_sn` varchar(50) NOT NULL COMMENT '申请编号',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(20) NOT NULL COMMENT '店铺名称',
  `buyer_id` int(10) unsigned NOT NULL COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家会员名',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID,0:全部退款',
  `order_goods_id` int(10) unsigned DEFAULT '0' COMMENT '订单商品ID,0:全部退款',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_num` int(10) unsigned DEFAULT '1' COMMENT '商品数量',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `order_goods_type` tinyint(1) unsigned DEFAULT '1' COMMENT '订单商品类型:1:默认2:抢购商品3:限时折扣商品4:组合套装 5:赠品6:拼团7:会员等级折扣8:砍价',
  `refund_type` tinyint(1) unsigned DEFAULT '1' COMMENT '申请类型:1:退款,2:退货',
  `seller_state` tinyint(1) unsigned DEFAULT '1' COMMENT '卖家处理状态:1:待审核,2:同意,3:不同意',
  `refund_state` tinyint(1) unsigned DEFAULT '1' COMMENT '申请状态:1:处理中,2:待管理员处理,3:已完成,4:已拒绝',
  `return_type` tinyint(1) unsigned DEFAULT '1' COMMENT '退货类型:1:不用退货,2:需要退货',
  `order_lock` tinyint(1) unsigned DEFAULT '1' COMMENT '订单锁定类型:1:不用锁定,2:需要锁定',
  `goods_state` tinyint(1) unsigned DEFAULT '1' COMMENT '物流状态:1:待发货,2:待收货,3:未收到,4:已收货',
  `add_time` int(10) unsigned NOT NULL COMMENT '添加时间',
  `seller_time` int(10) unsigned DEFAULT '0' COMMENT '卖家处理时间',
  `admin_time` int(10) unsigned DEFAULT '0' COMMENT '管理员处理时间',
  `reason_id` int(10) unsigned DEFAULT '0' COMMENT '原因ID:0:其它',
  `reason_info` varchar(300) DEFAULT '' COMMENT '原因内容',
  `pic_info` varchar(300) DEFAULT '' COMMENT '退款退货图片',
  `buyer_message` varchar(300) DEFAULT NULL COMMENT '退款退货申请原因',
  `seller_message` varchar(300) DEFAULT NULL COMMENT '卖家备注',
  `admin_message` varchar(300) DEFAULT NULL COMMENT '管理员备注',
  `express_id` tinyint(1) unsigned DEFAULT '0' COMMENT '物流公司编号',
  `invoice_no` varchar(50) DEFAULT NULL COMMENT '物流单号',
  `ship_time` int(10) unsigned DEFAULT '0' COMMENT '发货时间,默认为0',
  `delay_time` int(10) unsigned DEFAULT '0' COMMENT '收货延迟时间,默认为0',
  `receive_time` int(10) unsigned DEFAULT '0' COMMENT '收货时间,默认为0',
  `receive_message` varchar(300) DEFAULT NULL COMMENT '收货备注',
  `commis_rate` smallint(6) DEFAULT '0' COMMENT '佣金比例',
  PRIMARY KEY (`refund_id`),
  KEY `order_id` (`order_id`),
  KEY `store_id` (`store_id`),
  KEY `buyer_id` (`buyer_id`),
  KEY `order_goods_id` (`order_goods_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='退款退货表';



DROP TABLE IF EXISTS `#__seller`;
CREATE TABLE IF NOT EXISTS `#__seller` (
  `seller_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '卖家自增ID',
  `seller_name` varchar(50) NOT NULL COMMENT '卖家用户名',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `sellergroup_id` int(10) unsigned NOT NULL COMMENT '卖家组ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `is_admin` tinyint(3) unsigned NOT NULL COMMENT '是否管理员 0:不是 1:是',
  `last_logintime` int(10) unsigned DEFAULT NULL COMMENT '最后登录时间',
  PRIMARY KEY (`seller_id`),
  KEY `member_id` (`member_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='卖家用户表';



DROP TABLE IF EXISTS `#__sellergroup`;
CREATE TABLE IF NOT EXISTS `#__sellergroup` (
  `sellergroup_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '卖家组自增ID',
  `sellergroup_name` varchar(50) NOT NULL COMMENT '卖家组名称',
  `sellergroup_limits` text NOT NULL COMMENT '卖家组权限',
  `smt_limits` text NOT NULL COMMENT '消卖家组息权限范围',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  PRIMARY KEY (`sellergroup_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='卖家用户组表';



DROP TABLE IF EXISTS `#__sellerlog`;
CREATE TABLE IF NOT EXISTS `#__sellerlog` (
  `sellerlog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '卖家日志自增ID',
  `sellerlog_content` varchar(100) NOT NULL COMMENT '卖家日志内容',
  `sellerlog_time` int(10) unsigned NOT NULL COMMENT '卖家日志时间',
  `sellerlog_seller_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '卖家ID',
  `sellerlog_seller_name` varchar(50) NOT NULL COMMENT '卖家帐号',
  `sellerlog_store_id` int(10) unsigned NOT NULL COMMENT '店铺编号',
  `sellerlog_seller_ip` varchar(50) NOT NULL COMMENT '卖家ip',
  `sellerlog_url` varchar(100) NOT NULL COMMENT '卖家日志url',
  `sellerlog_state` tinyint(3) unsigned NOT NULL COMMENT '日志状态 0:失败 1:成功',
  PRIMARY KEY (`sellerlog_id`),
  KEY `sellerlog_seller_id` (`sellerlog_seller_id`),
  KEY `sellerlog_store_id` (`sellerlog_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='卖家日志表';



DROP TABLE IF EXISTS `#__seo`;
CREATE TABLE IF NOT EXISTS `#__seo` (
  `seo_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'SEO自增ID',
  `seo_title` varchar(255) NOT NULL COMMENT 'SEO标题',
  `seo_keywords` varchar(255) NOT NULL COMMENT 'SEO关键词',
  `seo_description` text NOT NULL COMMENT 'SEO描述',
  `seo_type` varchar(20) NOT NULL COMMENT 'SEO类型',
  PRIMARY KEY (`seo_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='SEO信息存放表';



DROP TABLE IF EXISTS `#__smslog`;
CREATE TABLE IF NOT EXISTS `#__smslog` (
  `smslog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '短信记录自增ID',
  `smslog_phone` char(11) NOT NULL COMMENT '短信手机号',
  `smslog_captcha` char(6) NOT NULL COMMENT '短信动态码',
  `smslog_ip` varchar(15) NOT NULL COMMENT '短信请求IP',
  `smslog_msg` text COMMENT '短信内容',
  `smslog_type` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '短信类型:1为注册,2为登录,3为找回密码,4绑定手机,5安全验证,默认为1',
  `smslog_smstime` int(10) unsigned NOT NULL COMMENT '短信添加时间',
  `member_id` int(10) unsigned DEFAULT '0' COMMENT '短信会员ID,注册为0',
  `member_name` varchar(50) DEFAULT '' COMMENT '短信会员名',
  `smslog_state` tinyint(1) unsigned DEFAULT '0' COMMENT '0待发送1发送成功2发送失败',
  PRIMARY KEY (`smslog_id`),
  KEY `smslog_phone` (`smslog_phone`),
  KEY `member_id` (`member_id`),
  KEY `smslog_state` (`smslog_state`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='手机短信记录表';



DROP TABLE IF EXISTS `#__snsalbumclass`;
CREATE TABLE IF NOT EXISTS `#__snsalbumclass` (
  `ac_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '相册自增ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `ac_name` varchar(100) NOT NULL COMMENT '相册名称',
  `ac_des` varchar(255) NOT NULL COMMENT '相册描述',
  `ac_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '相册排序',
  `ac_cover` varchar(255) DEFAULT NULL COMMENT '相册封面',
  `ac_uploadtime` int(10) unsigned NOT NULL COMMENT '图片上传时间',
  `ac_isdefault` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '是否为买家秀相册  1:是 0:否',
  PRIMARY KEY (`ac_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='相册表';



DROP TABLE IF EXISTS `#__snsalbumpic`;
CREATE TABLE IF NOT EXISTS `#__snsalbumpic` (
  `ap_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '相册图片自增ID',
  `ac_id` int(10) unsigned DEFAULT NULL COMMENT '相册ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '会员ID',
  `ap_name` varchar(100) NOT NULL COMMENT '图片名称',
  `ap_cover` varchar(255) NOT NULL COMMENT '图片路径',
  `ap_size` int(10) unsigned NOT NULL COMMENT '图片大小',
  `ap_spec` varchar(100) NOT NULL COMMENT '图片规格',
  `ap_uploadtime` int(10) unsigned NOT NULL COMMENT '图片上传时间',
  `ap_type` tinyint(4) NOT NULL DEFAULT '0' COMMENT '图片类型，0为无、1为买家秀',
  `item_id` tinyint(4) NOT NULL DEFAULT '0' COMMENT '信息ID',
  PRIMARY KEY (`ap_id`),
  KEY `member_id` (`member_id`),
  KEY `ac_id` (`ac_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='相册图片表';



DROP TABLE IF EXISTS `#__snsfriend`;
CREATE TABLE IF NOT EXISTS `#__snsfriend` (
  `friend_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '好友自增ID',
  `friend_frommid` int(11) NOT NULL COMMENT '会员ID',
  `friend_frommname` varchar(100) DEFAULT NULL COMMENT '会员名称',
  `friend_frommavatar` varchar(100) DEFAULT NULL COMMENT '会员头像',
  `friend_tomid` int(11) NOT NULL COMMENT '朋友ID',
  `friend_tomname` varchar(100) NOT NULL COMMENT '好友会员名称',
  `friend_tomavatar` varchar(100) DEFAULT NULL COMMENT '好友头像',
  `friend_addtime` int(11) NOT NULL COMMENT '好友添加时间',
  `friend_followstate` tinyint(1) NOT NULL DEFAULT '1' COMMENT '关注状态 1:单方关注 2:双方关注',
  PRIMARY KEY (`friend_id`),
  KEY `friend_frommid` (`friend_frommid`),
  KEY `friend_tomid` (`friend_tomid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='好友数据表';



DROP TABLE IF EXISTS `#__snsmembertag`;
CREATE TABLE IF NOT EXISTS `#__snsmembertag` (
  `mtag_id` int(10) NOT NULL AUTO_INCREMENT COMMENT '会员标签自增ID',
  `mtag_name` varchar(20) NOT NULL COMMENT '会员标签名称',
  `mtag_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '会员标签排序',
  `mtag_recommend` tinyint(4) NOT NULL DEFAULT '0' COMMENT '标签推荐 0:未推荐 1:已推荐',
  `mtag_desc` varchar(50) NOT NULL COMMENT '标签描述',
  `mtag_img` varchar(50) DEFAULT NULL COMMENT '标签图片',
  PRIMARY KEY (`mtag_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员标签表';



DROP TABLE IF EXISTS `#__snsmtagmember`;
CREATE TABLE IF NOT EXISTS `#__snsmtagmember` (
  `mtag_id` int(11) NOT NULL COMMENT '会员标签表ID',
  `member_id` int(11) NOT NULL COMMENT '会员ID',
  `recommend` tinyint(4) NOT NULL DEFAULT '0' COMMENT '推荐，默认为0',
  PRIMARY KEY (`mtag_id`,`member_id`),
  KEY `member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员标签会员对照表';



DROP TABLE IF EXISTS `#__spec`;
CREATE TABLE IF NOT EXISTS `#__spec` (
  `sp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '规格自增ID',
  `sp_name` varchar(100) NOT NULL COMMENT '规格名称',
  `sp_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '规格排序',
  `gc_id` int(10) unsigned DEFAULT '0' COMMENT '所属商品分类id',
  `gc_name` varchar(100) DEFAULT NULL COMMENT '所属商品分类名称',
  PRIMARY KEY (`sp_id`),
  KEY `gc_id` (`gc_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品规格表';



DROP TABLE IF EXISTS `#__specvalue`;
CREATE TABLE IF NOT EXISTS `#__specvalue` (
  `spvalue_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '规格值自增ID',
  `spvalue_name` varchar(100) NOT NULL COMMENT '规格值名称',
  `sp_id` int(10) unsigned NOT NULL COMMENT '所属规格ID',
  `gc_id` int(10) unsigned NOT NULL COMMENT '分类ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `spvalue_color` varchar(10) DEFAULT NULL COMMENT '规格颜色',
  `spvalue_sort` tinyint(1) unsigned NOT NULL COMMENT '规格排序',
  PRIMARY KEY (`spvalue_id`),
  KEY `store_id` (`store_id`),
  KEY `sp_id` (`sp_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品规格值表';



DROP TABLE IF EXISTS `#__statmember`;
CREATE TABLE IF NOT EXISTS `#__statmember` (
  `statm_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '统计自增ID',
  `statm_memberid` int(11) NOT NULL COMMENT '会员ID',
  `statm_membername` varchar(100) NOT NULL COMMENT '会员名称',
  `statm_time` int(11) NOT NULL COMMENT '统计时间',
  `statm_ordernum` int(11) NOT NULL DEFAULT '0' COMMENT '下单量',
  `statm_orderamount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '下单金额',
  `statm_goodsnum` int(11) NOT NULL DEFAULT '0' COMMENT '下单商品件数',
  `statm_predincrease` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '预存款增加额',
  `statm_predreduce` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '预存款减少额',
  `statm_pointsincrease` int(11) NOT NULL DEFAULT '0' COMMENT '积分增加额',
  `statm_pointsreduce` int(11) NOT NULL DEFAULT '0' COMMENT '积分减少额',
  `statm_updatetime` int(11) NOT NULL COMMENT '更新时间',
  PRIMARY KEY (`statm_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员相关数据统计';



DROP TABLE IF EXISTS `#__statorder`;
CREATE TABLE IF NOT EXISTS `#__statorder` (
  `order_id` int(11) NOT NULL COMMENT '订单id',
  `order_sn` varchar(20) NOT NULL COMMENT '订单编号',
  `order_add_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '订单生成时间',
  `payment_code` char(20) DEFAULT '' COMMENT '支付方式',
  `order_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '订单总价格',
  `shipping_fee` decimal(10,2) unsigned DEFAULT '0.00' COMMENT '运费',
  `evaluation_state` enum('0','1') DEFAULT '0' COMMENT '评价状态 0未评价，1已评价',
  `order_state` enum('0','10','14','15','20','30','35','40') NOT NULL DEFAULT '10' COMMENT '订单状态：0(已取消)10(默认):未付款 14:待付定金 15:待付尾款;20:已付款;30:已发货;35:待自提;40:已收货;',
  `refund_state` tinyint(1) unsigned DEFAULT '0' COMMENT '退款状态:0是无退款,1是部分退款,2是全部退款',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `order_from` enum('1','2') NOT NULL DEFAULT '1' COMMENT '订单来源，1:PC 2:手机',
  `order_isvalid` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否为计入统计的有效订单，0为无效 1为有效',
  `reciver_province_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '收货人省级ID',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '卖家店铺名称',
  `grade_id` int(11) NOT NULL COMMENT '店铺等级',
  `storeclass_id` int(11) NOT NULL COMMENT '店铺分类',
  `buyer_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家姓名',
  UNIQUE KEY `order_id` (`order_id`),
  KEY `order_add_time` (`order_add_time`),
  KEY `order_isvalid` (`order_isvalid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='统计功能订单缓存表';



DROP TABLE IF EXISTS `#__statordergoods`;
CREATE TABLE IF NOT EXISTS `#__statordergoods` (
  `rec_id` int(11) NOT NULL COMMENT '订单商品表索引ID',
  `stat_updatetime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '缓存生成时间',
  `order_id` int(11) NOT NULL COMMENT '订单id',
  `order_sn` varchar(20) NOT NULL COMMENT '订单编号',
  `order_add_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '订单生成时间',
  `payment_code` char(20) DEFAULT '' COMMENT '支付方式',
  `order_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '订单总价格',
  `shipping_fee` decimal(10,2) unsigned DEFAULT '0.00' COMMENT '运费',
  `evaluation_state` enum('0','1') DEFAULT '0' COMMENT '评价状态 0:未评价，1:已评价',
  `order_state` enum('0','10','14','15','20','30','35','40') NOT NULL DEFAULT '10' COMMENT '订单状态 0:已取消;10:未付款 14:待付定金 15:待付尾款;20:已付款;30:已发货;35:待自提;40:已收货;',
  `refund_state` tinyint(1) unsigned DEFAULT '0' COMMENT '退款状态:0:无退款,1:部分退款,2:全部退款',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `order_from` enum('1','2') NOT NULL DEFAULT '1' COMMENT '来源 1:PC 2:手机',
  `order_isvalid` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否为计入统计的有效订单，0为无效 1为有效',
  `reciver_province_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '收货人省级ID',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '卖家店铺名称',
  `grade_id` int(11) NOT NULL COMMENT '店铺等级',
  `storeclass_id` int(11) NOT NULL COMMENT '店铺分类',
  `buyer_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家姓名',
  `goods_id` int(11) NOT NULL COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称+规格',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '商品公共表id',
  `goods_commonname` varchar(50) NOT NULL COMMENT '商品公共表中商品名称',
  `gc_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '商品最底级分类ID',
  `gc_parentid_1` int(11) NOT NULL DEFAULT '0' COMMENT '一级父类ID',
  `gc_parentid_2` int(11) NOT NULL DEFAULT '0' COMMENT '二级父类ID',
  `gc_parentid_3` int(11) NOT NULL DEFAULT '0' COMMENT '三级父类ID',
  `brand_id` int(10) unsigned NOT NULL COMMENT '品牌id',
  `brand_name` varchar(100) NOT NULL COMMENT '品牌名称',
  `goods_serial` varchar(50) NOT NULL COMMENT '商家编号',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `goods_num` smallint(5) unsigned NOT NULL DEFAULT '1' COMMENT '商品数量',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `goods_pay_price` decimal(10,2) unsigned NOT NULL COMMENT '商品实际成交价',
  `goods_type` enum('1','2','3','4','5','6','7','8','9') NOT NULL DEFAULT '1' COMMENT '1:默认 2:抢购商品 3:限时折扣商品 4:优惠套装 5:赠品 6:拼团 7:会员等级折扣 8:砍价',
  `promotions_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '促销活动ID（抢购ID/限时折扣ID/优惠套装ID）与goods_type搭配使用',
  `commis_rate` smallint(5) unsigned NOT NULL DEFAULT '0' COMMENT '佣金比例',
  UNIQUE KEY `rec_id` (`rec_id`),
  KEY `order_id` (`order_id`),
  KEY `order_add_time` (`order_add_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='统计功能订单商品缓存表';



DROP TABLE IF EXISTS `#__store`;
CREATE TABLE IF NOT EXISTS `#__store` (
  `store_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '店铺自增ID',
  `store_name` varchar(100) NOT NULL COMMENT '店铺名称',
  `grade_id` int(11) DEFAULT '0' COMMENT '店铺等级ID',
  `member_id` int(11) NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `seller_name` varchar(50) NOT NULL COMMENT '店主卖家用户名',
  `storeclass_id` int(11) DEFAULT '0' COMMENT '店铺分类ID',
  `store_company_name` varchar(50) DEFAULT NULL COMMENT '店铺公司名称',
  `region_id` int(10) DEFAULT NULL COMMENT '地区ID',
  `area_info` varchar(100) DEFAULT NULL COMMENT '地区名称',
  `store_address` varchar(100) DEFAULT NULL COMMENT '店铺地址',
  `store_zip` varchar(10) DEFAULT NULL COMMENT '邮政编码',
  `store_state` tinyint(1) NOT NULL DEFAULT '2' COMMENT '店铺状态:0关闭，1开启，2审核中',
  `store_close_info` varchar(255) DEFAULT NULL COMMENT '店铺关闭原因',
  `store_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺排序',
  `store_addtime` int(11) NOT NULL DEFAULT '0' COMMENT '店铺时间',
  `store_endtime` int(11) NOT NULL DEFAULT '0' COMMENT '店铺关闭时间',
  `store_logo` varchar(255) DEFAULT NULL COMMENT '店铺LOGO',
  `store_banner` varchar(255) DEFAULT NULL COMMENT '店铺Banner',
  `store_avatar` varchar(255) DEFAULT NULL COMMENT '店铺头像',
  `store_keywords` varchar(255) DEFAULT NULL COMMENT '店铺SEO关键字',
  `store_description` varchar(255) DEFAULT NULL COMMENT '店铺SEO描述',
  `store_qq` varchar(50) DEFAULT NULL COMMENT '店铺QQ',
  `store_ww` varchar(50) DEFAULT NULL COMMENT '店铺WW',
  `store_phone` varchar(20) DEFAULT NULL COMMENT '商家电话',
  `store_mainbusiness` text COMMENT '主营商品',
  `store_recommend` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否推荐:0否 1是',
  `store_theme` varchar(50) NOT NULL DEFAULT 'default' COMMENT '店铺当前主题',
  `store_credit` int(11) NOT NULL DEFAULT '100' COMMENT '店铺信用',
  `store_desccredit` float unsigned NOT NULL DEFAULT '5' COMMENT '描述相符度分数',
  `store_servicecredit` float unsigned NOT NULL DEFAULT '5' COMMENT '服务态度分数',
  `store_deliverycredit` float unsigned NOT NULL DEFAULT '5' COMMENT '发货速度分数',
  `store_collect` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺收藏数量',
  `store_slide` text COMMENT '店铺幻灯片',
  `store_slide_url` text COMMENT '店铺幻灯片链接',
  `store_seal` varchar(255) DEFAULT NULL COMMENT '店铺印章',
  `store_printexplain` varchar(500) DEFAULT NULL COMMENT '打印订单页面下方说明文字',
  `store_sales` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺销量',
  `store_presales` text COMMENT '售前客服',
  `store_aftersales` text COMMENT '售后客服',
  `store_workingtime` varchar(100) DEFAULT NULL COMMENT '工作时间',
  `store_free_price` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '超出该金额免运费，大于0才表示该值有效',
  `store_decoration_switch` int(10) unsigned DEFAULT '0' COMMENT '店铺装修开关(0-关闭 装修编号-开启)',
  `store_decoration_only` tinyint(1) unsigned DEFAULT '0' COMMENT '开启店铺装修时，仅显示店铺装修(1-是 0-否',
  `store_decoration_image_count` int(10) unsigned DEFAULT '0' COMMENT '店铺装修相册图片数量',
  `is_platform_store` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否自营店铺 1是 0否',
  `bind_all_gc` tinyint(1) NOT NULL DEFAULT '0' COMMENT '自营店是否绑定全部分类 0否1是',
  `store_vrcode_prefix` char(3) DEFAULT NULL COMMENT '商家兑换码前缀',
  `store_baozh` tinyint(1) DEFAULT '0' COMMENT '保证服务开关',
  `store_qtian` tinyint(1) DEFAULT '0' COMMENT '7天退换',
  `store_zhping` tinyint(1) DEFAULT '0' COMMENT '正品保障',
  `store_erxiaoshi` tinyint(1) DEFAULT '0' COMMENT '两小时发货',
  `store_tuihuo` tinyint(1) DEFAULT '0' COMMENT '退货承诺',
  `store_shiyong` tinyint(1) DEFAULT '0' COMMENT '试用中心',
  `store_shiti` tinyint(1) DEFAULT '0' COMMENT '实体验证',
  `store_xiaoxie` tinyint(1) DEFAULT '0' COMMENT '消协保证',
  `store_huodaofk` tinyint(1) DEFAULT '0' COMMENT '货到付款',
  `store_free_time` varchar(10) DEFAULT NULL COMMENT '商家配送时间',
  `store_longitude` varchar(20) DEFAULT '' COMMENT '经度',
  `store_latitude` varchar(20) DEFAULT '' COMMENT '纬度',
  `mb_title_img` varchar(150) DEFAULT NULL COMMENT '手机店铺背景图',
  `mb_sliders` text COMMENT '手机店铺轮播图',
  `deliver_region` varchar(50) DEFAULT NULL COMMENT '店铺默认配送区域',
  `store_mgdiscount` text COMMENT '序列化会员等级折扣(店铺)',
  `store_mgdiscount_state` tinyint(1) DEFAULT '0' COMMENT '店铺是否开启序列化会员等级折扣',
  `store_bill_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上一期结算时间',
  `store_avaliable_deposit` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '店铺已缴保证金',
  `store_freeze_deposit` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '店铺审核保证金',
  `store_payable_deposit` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '店铺应缴保证金',
  `store_avaliable_money` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '店铺可用金额',
  `store_freeze_money` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '店铺冻结金额',
  `expresscf_kdn_if_open` tinyint(1) DEFAULT '0' COMMENT '快递鸟开启',
  `expresscf_kdn_id` varchar(20) DEFAULT NULL COMMENT '快递鸟-用户ID',
  `expresscf_kdn_key` varchar(100) DEFAULT NULL COMMENT '快递鸟-API key',
  `expresscf_kdn_printer` varchar(100) DEFAULT NULL COMMENT '快递鸟-打印机',
  PRIMARY KEY (`store_id`),
  KEY `seller_name` (`seller_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='店铺数据表';



DROP TABLE IF EXISTS `#__storebindclass`;
CREATE TABLE IF NOT EXISTS `#__storebindclass` (
  `storebindclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '类目自增ID',
  `store_id` int(11) unsigned DEFAULT '0' COMMENT '店铺ID',
  `commis_rate` tinyint(4) unsigned DEFAULT '0' COMMENT '佣金比例',
  `class_1` mediumint(9) unsigned DEFAULT '0' COMMENT '一级分类',
  `class_2` mediumint(9) unsigned DEFAULT '0' COMMENT '二级分类',
  `class_3` mediumint(9) unsigned DEFAULT '0' COMMENT '三级分类',
  `storebindclass_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态0:审核中1:已审核 2:平台自营店铺',
  PRIMARY KEY (`storebindclass_id`),
  KEY `store_id` (`store_id`),
  KEY `class_1` (`class_1`),
  KEY `class_2` (`class_2`),
  KEY `class_3` (`class_3`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺可发布商品类目表';



DROP TABLE IF EXISTS `#__storeclass`;
CREATE TABLE IF NOT EXISTS `#__storeclass` (
  `storeclass_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '店铺分类自增ID',
  `storeclass_name` varchar(50) NOT NULL COMMENT '店铺分类名称',
  `storeclass_bail` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '店铺分类保证金数额',
  `storeclass_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺分类排序',
  PRIMARY KEY (`storeclass_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='店铺分类表';



DROP TABLE IF EXISTS `#__storecost`;
CREATE TABLE IF NOT EXISTS `#__storecost` (
  `storecost_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '店铺消费自增ID',
  `storecost_store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `storecost_seller_id` int(10) unsigned NOT NULL COMMENT '卖家ID',
  `storecost_price` int(10) unsigned NOT NULL COMMENT '店铺消费价格',
  `storecost_remark` varchar(255) NOT NULL COMMENT '店铺消费备注',
  `storecost_state` tinyint(3) unsigned NOT NULL COMMENT '费用状态 0:未结算 1:已结算',
  `storecost_time` int(10) unsigned NOT NULL COMMENT '费用发生时间',
  PRIMARY KEY (`storecost_id`),
  KEY `storecost_store_id` (`storecost_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺消费表';



DROP TABLE IF EXISTS `#__storedepositlog`;
CREATE TABLE IF NOT EXISTS `#__storedepositlog` (
  `storedepositlog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '保证金日志id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(60) NOT NULL COMMENT '店铺名称',
  `store_avaliable_deposit` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '已缴保证金',
  `store_freeze_deposit` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '审核保证金',
  `store_payable_deposit` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '应缴保证金',
  `storedepositlog_state` tinyint(1) unsigned NOT NULL COMMENT '状态（0无效1有效2待审核3已同意4已拒绝5已缴纳6已取消）',
  `storedepositlog_type` smallint(5) unsigned NOT NULL COMMENT '日志类型',
  `storedepositlog_desc` varchar(255) NOT NULL COMMENT '日志详情',
  `storedepositlog_add_time` int(10) unsigned NOT NULL COMMENT '添加时间',
  PRIMARY KEY (`storedepositlog_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺保证金日志表';



DROP TABLE IF EXISTS `#__storeextend`;
CREATE TABLE IF NOT EXISTS `#__storeextend` (
  `store_id` mediumint(8) unsigned NOT NULL COMMENT '店铺ID',
  `express` text COMMENT '快递公司ID的组合',
  `pricerange` text COMMENT '店铺统计设置的商品价格区间',
  `orderpricerange` text COMMENT '店铺统计设置的订单价格区间',
  PRIMARY KEY (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺信息扩展表';



DROP TABLE IF EXISTS `#__storegoodsclass`;
CREATE TABLE IF NOT EXISTS `#__storegoodsclass` (
  `storegc_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '店铺商品分类ID',
  `store_id` int(11) NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `storegc_name` varchar(50) NOT NULL COMMENT '店铺商品分类名称',
  `storegc_parent_id` int(11) NOT NULL COMMENT '上级ID',
  `storegc_state` tinyint(1) NOT NULL DEFAULT '0' COMMENT '店铺商品分类状态',
  `storegc_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '商品分类排序',
  PRIMARY KEY (`storegc_id`),
  KEY `storegc_parent_id` (`storegc_parent_id`,`storegc_sort`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺商品分类表';



DROP TABLE IF EXISTS `#__storegrade`;
CREATE TABLE IF NOT EXISTS `#__storegrade` (
  `storegrade_id` int(10) NOT NULL AUTO_INCREMENT COMMENT '店铺等级自增ID',
  `storegrade_name` varchar(50) NOT NULL COMMENT '店铺等级名称',
  `storegrade_goods_limit` int(10) DEFAULT '0' COMMENT '允许发布商品数量',
  `storegrade_album_limit` int(10) DEFAULT '0' COMMENT '允许发布图片数量',
  `storegrade_space_limit` int(10) DEFAULT '0' COMMENT '允许上传空间大小,单位MB',
  `storegrade_template_number` tinyint(3) DEFAULT '0' COMMENT '店铺等级选择店铺模板套数',
  `storegrade_template` varchar(255) DEFAULT NULL COMMENT '店铺等级模板内容',
  `storegrade_price` int(10) DEFAULT '0' COMMENT '店铺等级费用',
  `storegrade_confirm` tinyint(1) DEFAULT '1' COMMENT '店铺等级审核,0为否 1为是',
  `storegrade_description` text COMMENT '店铺等级申请说明',
  `storegrade_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺等级排序',
  PRIMARY KEY (`storegrade_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='店铺等级表';



DROP TABLE IF EXISTS `#__storejoinin`;
CREATE TABLE IF NOT EXISTS `#__storejoinin` (
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) DEFAULT NULL COMMENT '店主用户名',
  `store_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '店铺类型:0公司，1个人',
  `company_name` varchar(50) DEFAULT NULL COMMENT '公司名称',
  `company_province_id` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '所在地省ID',
  `company_address` varchar(50) DEFAULT NULL COMMENT '公司地址',
  `company_address_detail` varchar(50) DEFAULT NULL COMMENT '公司详细地址',
  `company_registered_capital` int(10) unsigned DEFAULT NULL COMMENT '注册资金',
  `contacts_name` varchar(50) DEFAULT NULL COMMENT '联系人姓名',
  `contacts_phone` varchar(20) DEFAULT NULL COMMENT '联系人电话',
  `contacts_email` varchar(50) DEFAULT NULL COMMENT '联系人邮箱',
  `business_licence_number` varchar(50) DEFAULT NULL COMMENT '营业执照号',
  `business_licence_address` varchar(50) DEFAULT NULL COMMENT '营业执所在地',
  `business_licence_start` date DEFAULT NULL COMMENT '营业执照有效期开始',
  `business_licence_end` date DEFAULT NULL COMMENT '营业执照有效期结束',
  `business_sphere` varchar(1000) DEFAULT NULL COMMENT '法定经营范围',
  `business_licence_number_electronic` varchar(50) DEFAULT NULL COMMENT '营业执照电子版',
  `bank_account_name` varchar(50) DEFAULT NULL COMMENT '银行开户名',
  `bank_account_number` varchar(50) DEFAULT NULL COMMENT '公司银行账号',
  `bank_name` varchar(50) DEFAULT NULL COMMENT '开户银行支行名称',
  `bank_address` varchar(50) DEFAULT NULL COMMENT '开户银行所在地',
  `is_settlement_account` tinyint(1) DEFAULT NULL COMMENT '开户行账号是否为结算账号 1-开户行就是结算账号 2-独立的计算账号',
  `settlement_bank_account_name` varchar(50) DEFAULT NULL COMMENT '结算银行开户名',
  `settlement_bank_account_number` varchar(50) DEFAULT NULL COMMENT '结算公司银行账号',
  `settlement_bank_name` varchar(50) DEFAULT NULL COMMENT '结算开户银行支行名称',
  `settlement_bank_address` varchar(50) DEFAULT NULL COMMENT '结算开户银行所在地',
  `seller_name` varchar(50) DEFAULT NULL COMMENT '卖家帐号',
  `store_name` varchar(50) DEFAULT NULL COMMENT '店铺名称',
  `store_class_ids` varchar(1000) DEFAULT NULL COMMENT '店铺分类编号集合',
  `store_class_names` varchar(1000) DEFAULT NULL COMMENT '店铺分类名称集合',
  `store_longitude` varchar(20) DEFAULT '' COMMENT '经度',
  `store_latitude` varchar(20) DEFAULT '' COMMENT '纬度',
  `joinin_state` varchar(50) DEFAULT NULL COMMENT '申请状态 10-已提交申请 11-缴费完成  20-审核成功 30-审核失败 31-缴费审核失败 40-审核通过开店',
  `joinin_message` varchar(200) DEFAULT NULL COMMENT '管理员审核信息',
  `joinin_year` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '开店时长(年)',
  `storegrade_name` varchar(50) DEFAULT NULL COMMENT '店铺等级名称',
  `storegrade_id` int(10) unsigned DEFAULT NULL COMMENT '店铺等级编号',
  `sg_info` varchar(200) DEFAULT NULL COMMENT '店铺等级下的收费等信息',
  `storeclass_name` varchar(50) DEFAULT NULL COMMENT '店铺分类名称',
  `storeclass_id` int(10) unsigned DEFAULT NULL COMMENT '店铺分类编号',
  `storeclass_bail` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '店铺分类保证金',
  `store_class_commis_rates` varchar(200) DEFAULT NULL COMMENT '分类佣金比例',
  `paying_money_certificate` varchar(50) DEFAULT NULL COMMENT '付款凭证',
  `paying_money_certificate_explain` varchar(200) DEFAULT NULL COMMENT '付款凭证说明',
  `paying_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '付款金额',
  `pay_sn` varchar(20) NOT NULL DEFAULT '' COMMENT '支付单号',
  `payment_code` varchar(20) DEFAULT '' COMMENT '支付方式',
  `trade_sn` varchar(50) DEFAULT '' COMMENT '第三方支付接口交易号',
  `rcb_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '充值卡支付金额',
  `pd_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '预存款支付金额'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺入住表';



DROP TABLE IF EXISTS `#__storemoneylog`;
CREATE TABLE IF NOT EXISTS `#__storemoneylog` (
  `storemoneylog_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '金额日志id',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `store_name` varchar(60) NOT NULL COMMENT '店铺名称',
  `store_avaliable_money` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '变动可用金额',
  `store_freeze_money` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '变动冻结金额',
  `storemoneylog_type` smallint(5) unsigned NOT NULL COMMENT '日志类型',
  `storemoneylog_desc` varchar(255) NOT NULL COMMENT '日志详情',
  `storemoneylog_state` tinyint(1) unsigned NOT NULL COMMENT '状态（0无效1有效2待审核3已同意4已拒绝）',
  `storemoneylog_add_time` int(10) unsigned NOT NULL COMMENT '添加时间',
  `storemoneylog_payment_code` varchar(20) DEFAULT '' COMMENT '支付方式',
  `storemoneylog_trade_sn` varchar(50) DEFAULT '' COMMENT '第三方支付接口交易号',
  PRIMARY KEY (`storemoneylog_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺金额日志表';



DROP TABLE IF EXISTS `#__storemsg`;
CREATE TABLE IF NOT EXISTS `#__storemsg` (
  `storemsg_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '店铺消息自增ID',
  `storemt_code` varchar(100) NOT NULL COMMENT '模板编码',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `storemsg_content` varchar(255) NOT NULL COMMENT '消息内容',
  `storemsg_addtime` int(10) unsigned NOT NULL COMMENT '发送时间',
  `storemsg_readids` varchar(255) DEFAULT NULL COMMENT '已读卖家id',
  PRIMARY KEY (`storemsg_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺消息表';



DROP TABLE IF EXISTS `#__storemsgread`;
CREATE TABLE IF NOT EXISTS `#__storemsgread` (
  `storemsg_id` int(11) NOT NULL COMMENT '店铺消息ID',
  `seller_id` int(11) NOT NULL COMMENT '卖家ID',
  `storemsg_readtime` int(11) NOT NULL COMMENT '阅读时间',
  PRIMARY KEY (`storemsg_id`,`seller_id`),
  KEY `seller_id` (`seller_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺消息阅读表';



DROP TABLE IF EXISTS `#__storemsgsetting`;
CREATE TABLE IF NOT EXISTS `#__storemsgsetting` (
  `storemt_code` varchar(100) NOT NULL COMMENT '模板编码',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺id',
  `storems_message_switch` tinyint(3) unsigned NOT NULL COMMENT '站内信接收开关 0:关闭 1:开启',
  `storems_short_switch` tinyint(3) unsigned NOT NULL COMMENT '短消息接收开关 0:关闭 1:开启',
  `storems_mail_switch` tinyint(3) unsigned NOT NULL COMMENT '邮件接收开关 0:关闭 1:开启',
  `storems_weixin_switch` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '微信接收开关 0:关闭 1:开启',
  `storems_short_number` varchar(11) NOT NULL COMMENT '手机号码',
  `storems_mail_number` varchar(100) NOT NULL COMMENT '邮箱号码',
  PRIMARY KEY (`storemt_code`,`store_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺消息接收设置';



DROP TABLE IF EXISTS `#__storemsgtpl`;
CREATE TABLE IF NOT EXISTS `#__storemsgtpl` (
  `storemt_code` varchar(100) NOT NULL COMMENT '商家消息模板编码',
  `storemt_name` varchar(100) NOT NULL COMMENT '商家消息模板名称',
  `storemt_message_switch` tinyint(3) unsigned NOT NULL COMMENT '站内信默认开关 0:关 1:开',
  `storemt_message_content` varchar(255) NOT NULL COMMENT '站内信内容',
  `storemt_message_forced` tinyint(3) unsigned NOT NULL COMMENT '站内信强制接收 0:否 1:是',
  `storemt_short_switch` tinyint(3) unsigned NOT NULL COMMENT '短信默认开关 0:关 1:开',
  `storemt_short_content` varchar(255) NOT NULL COMMENT '短信内容',
  `smt_short_forced` tinyint(3) unsigned NOT NULL COMMENT '短信强制接收 0:否 1:是',
  `storemt_mail_switch` tinyint(3) unsigned NOT NULL COMMENT '邮件默认开 0:关 1:开',
  `storemt_mail_subject` varchar(255) NOT NULL COMMENT '邮件标题',
  `storemt_mail_content` text NOT NULL COMMENT '邮件内容',
  `storemt_mail_forced` tinyint(3) unsigned NOT NULL COMMENT '邮件强制接收 0:否 1:是',
  `storemt_weixin_switch` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '微信默认开关 0:关 1:开',
  `storemt_weixin_code` varchar(255) NOT NULL DEFAULT '' COMMENT '微信code',
  `storemt_weixin_forced` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '微信强制接收 0:否 1:是',
  `ali_template_code` varchar(255) DEFAULT NULL COMMENT '阿里云短信模板ID',
  `ten_template_code` varchar(255) DEFAULT NULL COMMENT '腾讯云短信模板ID',
  PRIMARY KEY (`storemt_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商家消息模板';



DROP TABLE IF EXISTS `#__storenavigation`;
CREATE TABLE IF NOT EXISTS `#__storenavigation` (
  `storenav_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '卖家店铺导航自增ID',
  `storenav_title` varchar(50) NOT NULL COMMENT '卖家店铺导航名称',
  `storenav_store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '卖家店铺ID',
  `storenav_content` text COMMENT '卖家店铺导航内容',
  `storenav_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '卖家店铺导航排序',
  `storenav_url` varchar(255) DEFAULT NULL COMMENT '店铺导航的外链URL',
  PRIMARY KEY (`storenav_id`),
  KEY `storenav_store_id` (`storenav_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='卖家店铺导航信息表';



DROP TABLE IF EXISTS `#__storeplate`;
CREATE TABLE IF NOT EXISTS `#__storeplate` (
  `storeplate_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '关联板式id',
  `storeplate_name` varchar(10) NOT NULL COMMENT '关联板式名称',
  `storeplate_position` tinyint(3) unsigned NOT NULL COMMENT '关联板式位置 1:顶部 0:底部',
  `storeplate_content` text NOT NULL COMMENT '关联板式内容',
  `store_id` int(10) unsigned NOT NULL COMMENT '所属店铺ID',
  PRIMARY KEY (`storeplate_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='关联板式表';



DROP TABLE IF EXISTS `#__storereopen`;
CREATE TABLE IF NOT EXISTS `#__storereopen` (
  `storereopen_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '续签自增ID',
  `storereopen_grade_id` smallint(5) unsigned NOT NULL DEFAULT '0' COMMENT '店铺等级ID',
  `storereopen_grade_name` varchar(30) DEFAULT NULL COMMENT '等级名称',
  `storereopen_grade_price` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '等级收费(元/年)',
  `storereopen_year` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '续签时长(年)',
  `storereopen_pay_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '应付总金额',
  `storereopen_store_name` varchar(50) DEFAULT NULL COMMENT '店铺名字',
  `storereopen_store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `storereopen_state` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态 0:未上传凭证 1:审核中 2:审核通过',
  `storereopen_pay_cert` varchar(50) DEFAULT NULL COMMENT '付款凭证',
  `storereopen_pay_cert_explain` varchar(200) DEFAULT NULL COMMENT '付款说明',
  PRIMARY KEY (`storereopen_id`),
  KEY `storereopen_store_id` (`storereopen_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='续签内容表';



DROP TABLE IF EXISTS `#__storesnscomment`;
CREATE TABLE IF NOT EXISTS `#__storesnscomment` (
  `storesnscomm_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '店铺动态评论自增ID',
  `stracelog_id` int(11) NOT NULL COMMENT '店铺动态ID',
  `storesnscomm_content` varchar(150) DEFAULT NULL COMMENT '评论内容',
  `storesnscomm_memberid` int(11) DEFAULT NULL COMMENT '会员ID',
  `storesnscomm_membername` varchar(45) DEFAULT NULL COMMENT '会员名称',
  `storesnscomm_memberavatar` varchar(50) DEFAULT NULL COMMENT '会员头像',
  `storesnscomm_time` varchar(11) DEFAULT NULL COMMENT '评论时间',
  `storesnscomm_state` tinyint(1) NOT NULL DEFAULT '1' COMMENT '评论状态 1:正常 0:屏蔽',
  PRIMARY KEY (`storesnscomm_id`),
  KEY `stracelog_id` (`stracelog_id`),
  KEY `storesnscomm_memberid` (`storesnscomm_memberid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺动态评论表';



DROP TABLE IF EXISTS `#__storesnssetting`;
CREATE TABLE IF NOT EXISTS `#__storesnssetting` (
  `storesnsset_storeid` int(11) NOT NULL COMMENT '店铺ID',
  `storesnsset_new` tinyint(4) NOT NULL DEFAULT '1' COMMENT '新品 0:关闭 1:开启',
  `storesnsset_newtitle` varchar(150) NOT NULL COMMENT '新品内容',
  `storesnsset_coupon` tinyint(4) NOT NULL DEFAULT '1' COMMENT '优惠券 0:关闭 1:开启',
  `storesnsset_coupontitle` varchar(150) NOT NULL COMMENT '优惠券内容',
  `storesnsset_xianshi` tinyint(4) NOT NULL DEFAULT '1' COMMENT '限时折扣 0:关闭 1:开启',
  `storesnsset_xianshititle` varchar(150) NOT NULL COMMENT '限时折扣内容',
  `storesnsset_mansong` tinyint(4) NOT NULL DEFAULT '1' COMMENT '满即送 0:关闭 1:开启',
  `storesnsset_mansongtitle` varchar(150) NOT NULL COMMENT '满即送内容',
  `storesnsset_bundling` tinyint(4) NOT NULL DEFAULT '1' COMMENT '组合销售 0:关闭 1:开启',
  `storesnsset_bundlingtitle` varchar(150) NOT NULL COMMENT '组合销售内容',
  `storesnsset_groupbuy` tinyint(4) NOT NULL DEFAULT '1' COMMENT '抢购,0:关闭 1:开启',
  `storesnsset_groupbuytitle` varchar(150) NOT NULL COMMENT '抢购内容',
  PRIMARY KEY (`storesnsset_storeid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺自动发布动态设置表';



DROP TABLE IF EXISTS `#__storesnstracelog`;
CREATE TABLE IF NOT EXISTS `#__storesnstracelog` (
  `stracelog_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '店铺动态自增ID',
  `stracelog_storeid` int(11) DEFAULT NULL COMMENT '店铺ID',
  `stracelog_storename` varchar(100) DEFAULT NULL COMMENT '店铺名称',
  `stracelog_storelogo` varchar(255) NOT NULL COMMENT '店标',
  `stracelog_title` varchar(150) DEFAULT NULL COMMENT '动态标题',
  `stracelog_content` text COMMENT '发表内容',
  `stracelog_time` varchar(11) DEFAULT NULL COMMENT '动态发表时间',
  `stracelog_cool` int(11) DEFAULT '0' COMMENT '动态赞数量',
  `stracelog_spread` int(11) DEFAULT '0' COMMENT '动态转播数量',
  `stracelog_comment` int(11) DEFAULT '0' COMMENT '动态评论数量',
  `stracelog_type` tinyint(4) DEFAULT '1' COMMENT '1:relay,2:normal,3:new,4:coupon,5:xianshi,6:mansong,7:bundling,8:groupbuy,9:recommend,10:hotsell',
  `stracelog_goodsdata` text COMMENT '商品信息',
  `stracelog_state` tinyint(1) NOT NULL DEFAULT '1' COMMENT '动态状态 1:正常 0:屏蔽',
  PRIMARY KEY (`stracelog_id`),
  KEY `stracelog_storeid` (`stracelog_storeid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺动态表';



DROP TABLE IF EXISTS `#__storewatermark`;
CREATE TABLE IF NOT EXISTS `#__storewatermark` (
  `swm_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '水印自增ID',
  `swm_quality` int(3) NOT NULL DEFAULT '90' COMMENT '水印图片质量',
  `swm_image_name` varchar(255) DEFAULT NULL COMMENT '水印文件名',
  `swm_image_pos` tinyint(1) NOT NULL DEFAULT '1' COMMENT '水印图片存放位置',
  `swm_image_transition` int(3) NOT NULL DEFAULT '20' COMMENT '水印图片融合度 ',
  `swm_text` text COMMENT '水印文字',
  `swm_text_size` int(3) NOT NULL DEFAULT '20' COMMENT '水印文字大小',
  `swm_text_angle` tinyint(1) NOT NULL DEFAULT '4' COMMENT '水印文字角度',
  `swm_text_pos` tinyint(1) NOT NULL DEFAULT '3' COMMENT '水印文字位置',
  `swm_text_font` varchar(50) DEFAULT NULL COMMENT '水印文字字体',
  `swm_text_color` varchar(7) NOT NULL DEFAULT '#CCCCCC' COMMENT '水印字体颜色值',
  `store_id` int(11) DEFAULT NULL COMMENT '店铺ID',
  PRIMARY KEY (`swm_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺水印图片表';


DROP TABLE IF EXISTS `#__store_service`;
CREATE TABLE IF NOT EXISTS `#__store_service` (
  `store_service_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '店铺服务ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_service_title` varchar(20) NOT NULL COMMENT '店铺服务标题',
  `store_service_desc` varchar(60) NOT NULL COMMENT '店铺服务描述',
  `store_service_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '店铺服务排序',
  PRIMARY KEY (`store_service_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='店铺服务' AUTO_INCREMENT=1 ;


DROP TABLE IF EXISTS `#__transport`;
CREATE TABLE IF NOT EXISTS `#__transport` (
  `transport_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '售卖区域自增ID',
  `transport_title` varchar(30) NOT NULL COMMENT '售卖区域名称',
  `send_tpl_id` mediumint(8) unsigned DEFAULT NULL COMMENT '发货地区模板ID',
  `store_id` mediumint(8) unsigned NOT NULL COMMENT '店铺ID',
  `transport_updatetime` int(10) unsigned DEFAULT '0' COMMENT '最后更新时间',
  `transport_is_limited` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否限制配送',
  `transport_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '计费方式（0件1重量）',
  PRIMARY KEY (`transport_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='售卖区域';



DROP TABLE IF EXISTS `#__transportextend`;
CREATE TABLE IF NOT EXISTS `#__transportextend` (
  `transportext_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '运费模板扩展ID',
  `transportext_area_id` text COMMENT '市级地区ID组成的串，以，隔开，两端也有，',
  `transportext_top_area_id` text COMMENT '省级地区ID组成的串，以，隔开，两端也有，',
  `transportext_area_name` text COMMENT '地区name组成的串，以，隔开',
  `transportext_sprice` decimal(10,2) DEFAULT '0.00' COMMENT '首件运费',
  `transport_id` mediumint(8) unsigned NOT NULL COMMENT '运费模板ID',
  `transport_title` varchar(60) DEFAULT NULL COMMENT '运费模板',
  `transportext_is_default` tinyint(2) NOT NULL DEFAULT '0',
  `transportext_snum` int(11) DEFAULT '1' COMMENT '起始件数',
  `transportext_xnum` int(11) DEFAULT NULL,
  `transportext_xprice` decimal(10,2) DEFAULT NULL,
  PRIMARY KEY (`transportext_id`),
  KEY `transport_id` (`transport_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='运费模板扩展表';



DROP TABLE IF EXISTS `#__type`;
CREATE TABLE IF NOT EXISTS `#__type` (
  `type_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '类型自增ID',
  `type_name` varchar(100) NOT NULL COMMENT '类型名称',
  `type_sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '类型排序',
  `class_id` int(10) unsigned DEFAULT '0' COMMENT '所属商品分类id',
  `class_name` varchar(100) NOT NULL COMMENT '所属商品分类名称',
  PRIMARY KEY (`type_id`),
  KEY `class_id` (`class_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='商品类型表';



DROP TABLE IF EXISTS `#__typebrand`;
CREATE TABLE IF NOT EXISTS `#__typebrand` (
  `type_id` int(10) unsigned NOT NULL COMMENT '类型ID',
  `brand_id` int(10) unsigned NOT NULL COMMENT '品牌ID'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品类型与品牌对应表';



DROP TABLE IF EXISTS `#__typespec`;
CREATE TABLE IF NOT EXISTS `#__typespec` (
  `type_id` int(10) unsigned NOT NULL COMMENT '类型ID',
  `sp_id` int(10) unsigned NOT NULL COMMENT '规格ID'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='商品类型与规格对应表';



DROP TABLE IF EXISTS `#__upload`;
CREATE TABLE IF NOT EXISTS `#__upload` (
  `upload_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '上传文件自增ID',
  `file_name` varchar(100) DEFAULT NULL COMMENT '上传文件名',
  `file_size` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上传文件大小',
  `upload_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '上传文件类别 0:无 1:后台文章图片 2:帮助内容图片 3:店铺幻灯片 4:会员协议图片 5:积分礼品切换图片 6:积分礼品内容图片 7:可视化编辑模块图片',
  `upload_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上传文件添加时间',
  `item_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '信息ID',
  PRIMARY KEY (`upload_id`),
  KEY `upload_type` (`upload_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='上传文件表';



DROP TABLE IF EXISTS `#__verify_code`;
CREATE TABLE IF NOT EXISTS `#__verify_code` (
  `verify_code_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '验证码id',
  `verify_code_type` tinyint(1) unsigned NOT NULL COMMENT '验证码类型（1登录2注册3修改密码4绑定手机5绑定邮箱6安全验证）',
  `verify_code` char(6) NOT NULL COMMENT '验证码',
  `verify_code_user_type` tinyint(1) unsigned NOT NULL COMMENT '发送验证码的用户类型（1会员2店长3配送员）',
  `verify_code_user_id` int(10) unsigned NOT NULL COMMENT '发送验证码的用户id',
  `verify_code_user_name` varchar(60) NOT NULL COMMENT '发送验证码的用户名',
  `verify_code_add_time` int(10) unsigned NOT NULL COMMENT '发送时间',
  `verify_code_ip` varchar(15) NOT NULL COMMENT 'ip地址',
  PRIMARY KEY (`verify_code_id`),
  KEY `verify_code_type` (`verify_code_type`,`verify_code_user_type`,`verify_code_user_id`,`verify_code`,`verify_code_add_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='验证码表';



DROP TABLE IF EXISTS `#__voucher`;
CREATE TABLE IF NOT EXISTS `#__voucher` (
  `voucher_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '代金券自增ID',
  `voucher_code` varchar(32) NOT NULL COMMENT '代金券编码',
  `vouchertemplate_id` int(11) NOT NULL COMMENT '代金券模版编号',
  `voucher_title` varchar(50) NOT NULL COMMENT '代金券标题',
  `voucher_desc` varchar(255) NOT NULL COMMENT '代金券描述',
  `voucher_startdate` int(11) NOT NULL COMMENT '代金券有效期开始时间',
  `voucher_enddate` int(11) NOT NULL COMMENT '代金券有效期结束时间',
  `voucher_price` int(11) NOT NULL COMMENT '代金券面额',
  `voucher_limit` decimal(10,2) NOT NULL COMMENT '代金券使用时的订单限额',
  `voucher_store_id` int(11) NOT NULL COMMENT '代金券的店铺id',
  `voucher_state` tinyint(4) NOT NULL COMMENT '代金券状态 1:未用 2:已用 3:过期 4:收回 ',
  `voucher_activedate` int(11) NOT NULL COMMENT '代金券发放日期',
  `voucher_type` tinyint(4) NOT NULL DEFAULT '0' COMMENT '代金券类别',
  `voucher_owner_id` int(11) NOT NULL COMMENT '代金券所有者ID',
  `voucher_owner_name` varchar(50) NOT NULL COMMENT '代金券所有者名称',
  `voucher_order_id` int(11) DEFAULT NULL COMMENT '使用该代金券的订单编号',
  PRIMARY KEY (`voucher_id`),
  KEY `voucher_store_id` (`voucher_store_id`),
  KEY `voucher_owner_id` (`voucher_owner_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='代金券表';



DROP TABLE IF EXISTS `#__voucherprice`;
CREATE TABLE IF NOT EXISTS `#__voucherprice` (
  `voucherprice_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '代金券面值自增ID',
  `voucherprice_describe` varchar(255) NOT NULL COMMENT '代金券描述',
  `voucherprice` int(11) NOT NULL COMMENT '代金券面值',
  `voucherprice_defaultpoints` int(11) NOT NULL DEFAULT '0' COMMENT '代金劵默认的兑换所需积分可以为0',
  PRIMARY KEY (`voucherprice_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='代金券面额表';



DROP TABLE IF EXISTS `#__voucherquota`;
CREATE TABLE IF NOT EXISTS `#__voucherquota` (
  `voucherquota_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '代金券套餐自增ID',
  `voucherquota_applyid` int(11) DEFAULT NULL COMMENT '代金券套餐申请编号',
  `voucherquota_memberid` int(11) NOT NULL COMMENT '会员ID',
  `voucherquota_membername` varchar(100) NOT NULL COMMENT '会员名称',
  `voucherquota_storeid` int(11) NOT NULL COMMENT '店铺ID',
  `voucherquota_storename` varchar(100) NOT NULL COMMENT '店铺名称',
  `voucherquota_starttime` int(11) NOT NULL COMMENT '代金券套餐开始时间',
  `voucherquota_endtime` int(11) NOT NULL COMMENT '代金券套餐结束时间',
  `voucherquota_state` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态 1:可用 2:取消 3:结束',
  PRIMARY KEY (`voucherquota_id`),
  KEY `voucherquota_storeid` (`voucherquota_storeid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='代金券套餐表';



DROP TABLE IF EXISTS `#__vouchertemplate`;
CREATE TABLE IF NOT EXISTS `#__vouchertemplate` (
  `vouchertemplate_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '代金券模版自增ID',
  `vouchertemplate_title` varchar(50) NOT NULL COMMENT '代金券模版名称',
  `vouchertemplate_desc` varchar(255) NOT NULL COMMENT '代金券模版描述',
  `vouchertemplate_startdate` int(11) NOT NULL COMMENT '代金券模版有效期开始时间',
  `vouchertemplate_enddate` int(11) NOT NULL COMMENT '代金券模版有效期结束时间',
  `vouchertemplate_price` int(11) NOT NULL COMMENT '代金券模版面额',
  `vouchertemplate_limit` decimal(10,2) NOT NULL COMMENT '代金券使用时的订单限额',
  `vouchertemplate_store_id` int(11) NOT NULL COMMENT '代金券模版的店铺ID',
  `vouchertemplate_storename` varchar(100) DEFAULT NULL COMMENT '店铺名称',
  `vouchertemplate_sc_id` int(11) NOT NULL DEFAULT '0' COMMENT '所属店铺分类ID',
  `vouchertemplate_creator_id` int(11) NOT NULL COMMENT '代金券模版的创建者ID',
  `vouchertemplate_state` tinyint(4) NOT NULL COMMENT '代金券模版状态 1:有效 2:失效',
  `vouchertemplate_total` int(11) NOT NULL COMMENT '模版可发放的代金券总数',
  `vouchertemplate_giveout` int(11) NOT NULL COMMENT '模版已发放的代金券数量',
  `vouchertemplate_used` int(11) NOT NULL COMMENT '模版已经使用过的代金券',
  `vouchertemplate_adddate` int(11) NOT NULL COMMENT '模版的创建时间',
  `vouchertemplate_quotaid` int(11) NOT NULL COMMENT '套餐编号',
  `vouchertemplate_points` int(11) NOT NULL DEFAULT '0' COMMENT '兑换所需积分',
  `vouchertemplate_eachlimit` int(11) NOT NULL DEFAULT '1' COMMENT '每人限领张数',
  `vouchertemplate_styleimg` varchar(200) DEFAULT NULL COMMENT '样式模版图片',
  `vouchertemplate_customimg` varchar(200) DEFAULT NULL COMMENT '自定义代金券模板图片',
  `vouchertemplate_recommend` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否推荐 0:不推荐 1:推荐',
  `vouchertemplate_gettype` tinyint(1) NOT NULL COMMENT '代金券类型',
  `vouchertemplate_if_private` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否私密 0:否 1:是',
  PRIMARY KEY (`vouchertemplate_id`),
  KEY `vouchertemplate_store_id` (`vouchertemplate_store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='代金券模版表';



DROP TABLE IF EXISTS `#__vrgroupbuyclass`;
CREATE TABLE IF NOT EXISTS `#__vrgroupbuyclass` (
  `vrgclass_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '虚拟抢购分类自增ID',
  `vrgclass_name` varchar(100) NOT NULL COMMENT '分类名称',
  `vrgclass_parent_id` int(11) NOT NULL COMMENT '上级分类ID',
  `vrgclass_sort` tinyint(3) unsigned DEFAULT '255' COMMENT '虚拟抢购分类排序',
  PRIMARY KEY (`vrgclass_id`),
  KEY `vrgclass_parent_id` (`vrgclass_parent_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='虚拟抢购分类表';



DROP TABLE IF EXISTS `#__vrorder`;
CREATE TABLE IF NOT EXISTS `#__vrorder` (
  `order_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '虚拟订单自增ID',
  `order_sn` varchar(20) NOT NULL COMMENT '虚拟订单编号',
  `store_id` int(11) unsigned NOT NULL COMMENT '卖家店铺ID',
  `store_name` varchar(50) NOT NULL COMMENT '卖家店铺名称',
  `buyer_id` int(11) unsigned NOT NULL COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家登录名',
  `buyer_phone` varchar(11) NOT NULL COMMENT '买家手机',
  `add_time` int(10) unsigned NOT NULL COMMENT '虚拟订单生成时间',
  `payment_code` char(20) NOT NULL DEFAULT '' COMMENT '虚拟订单支付方式名称代码',
  `payment_time` int(10) unsigned DEFAULT '0' COMMENT '虚拟订单支付(付款)时间',
  `trade_no` varchar(35) DEFAULT NULL COMMENT '第三方平台交易号',
  `close_time` int(10) unsigned DEFAULT '0' COMMENT '虚拟订单关闭时间',
  `close_reason` varchar(50) DEFAULT NULL COMMENT '虚拟订单关闭原因',
  `finnshed_time` int(11) DEFAULT NULL COMMENT '虚拟订单完成时间',
  `order_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '订单总价格(支付金额)',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `rcb_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '充值卡支付金额',
  `pd_amount` decimal(10,2) unsigned NOT NULL DEFAULT '0.00' COMMENT '预存款支付金额',
  `voucher_price` int(11) DEFAULT NULL COMMENT '店铺代金券面额',
  `voucher_code` varchar(32) DEFAULT NULL COMMENT '店铺代金券编码',
  `mallvoucher_price` int(11) DEFAULT NULL COMMENT '平台代金券面额',
  `mallvoucher_code` varchar(32) DEFAULT NULL COMMENT '平台代金券编码',
  `order_state` tinyint(4) NOT NULL DEFAULT '0' COMMENT '订单状态 0:已取消 10:未付款 20:已付款 40:已完成',
  `refund_state` tinyint(1) unsigned DEFAULT '0' COMMENT '退款状态 0:无退款 1:部分退款 2:全部退款',
  `buyer_msg` varchar(150) DEFAULT NULL COMMENT '虚拟订单买家留言',
  `delete_state` tinyint(4) NOT NULL DEFAULT '0' COMMENT '删除状态 0:未删除1:放入回收站2:彻底删除',
  `goods_id` int(11) NOT NULL COMMENT '商品ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_price` decimal(10,2) NOT NULL COMMENT '商品价格',
  `goods_num` smallint(5) unsigned NOT NULL DEFAULT '1' COMMENT '商品数量',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `virtual_type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '虚拟商品类型 0:核销商品 1:卡券商品 2:网盘商品 3:下载商品',
  `virtual_content` text COMMENT '虚拟商品内容',
  `commis_rate` smallint(5) unsigned NOT NULL DEFAULT '0' COMMENT '佣金比例',
  `gc_id` mediumint(9) DEFAULT '0' COMMENT '商品最底级分类ID',
  `vr_indate` int(11) DEFAULT NULL COMMENT '虚拟订单有效期',
  `vr_send_times` tinyint(4) NOT NULL DEFAULT '0' COMMENT '兑换码发送次数',
  `vr_invalid_refund` tinyint(4) NOT NULL DEFAULT '1' COMMENT '允许过期退款 1:是 0:否',
  `order_promotion_type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '订单参加的促销类型 0:无促销 1:抢购 2:拼团',
  `promotions_id` mediumint(9) DEFAULT '0' COMMENT '促销ID，与order_promotion_type配合使用',
  `order_from` tinyint(4) NOT NULL DEFAULT '1' COMMENT '订单来源 1:PC 2:手机',
  `evaluation_state` tinyint(4) NOT NULL DEFAULT '0' COMMENT '评价状态 0:默认 1:已评价 2:禁止评价',
  `evaluation_time` int(11) NOT NULL DEFAULT '0' COMMENT '评价时间',
  `use_state` tinyint(4) DEFAULT '0' COMMENT '使用状态 0:未使用 1:已使用',
  `ob_no` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '相关结算单号',
  PRIMARY KEY (`order_id`),
  KEY `store_id` (`store_id`),
  KEY `buyer_id` (`buyer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='虚拟订单表';



DROP TABLE IF EXISTS `#__vrordercode`;
CREATE TABLE IF NOT EXISTS `#__vrordercode` (
  `rec_id` int(11) NOT NULL AUTO_INCREMENT COMMENT '兑换码自增ID',
  `order_id` int(11) NOT NULL COMMENT '虚拟订单ID',
  `store_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '店铺ID',
  `buyer_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '买家ID',
  `vr_code` varchar(18) NOT NULL COMMENT '兑换码',
  `vr_state` tinyint(4) NOT NULL DEFAULT '0' COMMENT '使用状态 0:(默认)未使用1:已使用2:已过期',
  `vr_usetime` int(11) DEFAULT NULL COMMENT '使用时间',
  `pay_price` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '实际支付金额(结算)',
  `vr_indate` int(11) DEFAULT NULL COMMENT '过期时间',
  `commis_rate` smallint(6) NOT NULL DEFAULT '0' COMMENT '佣金比例',
  `refund_lock` tinyint(1) unsigned DEFAULT '0' COMMENT '退款锁定状态:0:正常,1:锁定,2:同意',
  `vr_invalid_refund` tinyint(4) NOT NULL DEFAULT '1' COMMENT '允许过期退款1:是0:否',
  PRIMARY KEY (`rec_id`),
  KEY `order_id` (`order_id`),
  KEY `store_id` (`store_id`),
  KEY `buyer_id` (`buyer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='兑换码表';



DROP TABLE IF EXISTS `#__vrrefund`;
CREATE TABLE IF NOT EXISTS `#__vrrefund` (
  `refund_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '虚拟退款记录自增ID',
  `order_id` int(10) unsigned NOT NULL COMMENT '虚拟订单ID',
  `order_sn` varchar(20) NOT NULL COMMENT '虚拟订单编号',
  `refund_sn` varchar(50) NOT NULL COMMENT '申请编号',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `store_name` varchar(20) NOT NULL COMMENT '店铺名称',
  `buyer_id` int(10) unsigned NOT NULL COMMENT '买家ID',
  `buyer_name` varchar(50) NOT NULL COMMENT '买家会员名',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_num` int(10) unsigned DEFAULT '1' COMMENT '退款商品数量',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_image` varchar(100) DEFAULT NULL COMMENT '商品图片',
  `redeemcode_sn` varchar(300) NOT NULL COMMENT '兑换码编号',
  `refund_amount` decimal(10,2) DEFAULT '0.00' COMMENT '退款金额',
  `admin_state` tinyint(1) unsigned DEFAULT '1' COMMENT '退款状态 1:待审核 2:同意 3:不同意',
  `add_time` int(10) unsigned NOT NULL COMMENT '虚拟退款添加时间',
  `admin_time` int(10) unsigned DEFAULT '0' COMMENT '管理员处理时间',
  `buyer_message` varchar(300) DEFAULT NULL COMMENT '虚拟退款申请原因',
  `admin_message` varchar(300) DEFAULT NULL COMMENT '管理员备注',
  `commis_rate` smallint(6) DEFAULT '0' COMMENT '佣金比例',
  PRIMARY KEY (`refund_id`),
  KEY `order_id` (`order_id`),
  KEY `store_id` (`store_id`),
  KEY `buyer_id` (`buyer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='虚拟退款表';

DROP TABLE IF EXISTS `#__wholesale`;
CREATE TABLE IF NOT EXISTS `#__wholesale` (
  `wholesale_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '批发ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `wholesalequota_id` int(10) unsigned NOT NULL COMMENT '批发套餐ID',
  `wholesale_starttime` int(10) unsigned NOT NULL COMMENT '活动开始时间',
  `wholesale_end_time` int(10) unsigned NOT NULL COMMENT '活动结束时间',
  `wholesale_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0:取消 1:正常',
  `wholesale_if_mix` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '是否混批',
  PRIMARY KEY (`wholesale_id`),
  KEY `store_id` (`store_id`),
  KEY `goods_commonid` (`goods_commonid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='批发表' AUTO_INCREMENT=1 ;


DROP TABLE IF EXISTS `#__wholesalegoods`;
CREATE TABLE IF NOT EXISTS `#__wholesalegoods` (
  `wholesalegoods_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '批发商品表',
  `wholesale_id` int(10) unsigned NOT NULL COMMENT '批发ID',
  `goods_id` int(10) unsigned NOT NULL COMMENT '商品ID',
  `goods_commonid` int(10) unsigned NOT NULL COMMENT '主商品公共ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `goods_name` varchar(200) NOT NULL COMMENT '商品名称',
  `goods_price` decimal(10,2) NOT NULL COMMENT '店铺价格',
  `goods_image` varchar(100) NOT NULL COMMENT '商品图片',
  `wholesalegoods_price` text NOT NULL COMMENT '批发价格',
  `wholesale_starttime` int(10) unsigned NOT NULL COMMENT '开始时间',
  `wholesale_end_time` int(10) unsigned NOT NULL COMMENT '结束时间',
  `wholesalegoods_state` tinyint(3) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0-取消 1-正常',
  PRIMARY KEY (`wholesalegoods_id`),
  KEY `store_id` (`store_id`),
  KEY `goods_id` (`goods_id`),
  KEY `goods_commonid` (`goods_commonid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='批发商品表' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__wholesalequota`;
CREATE TABLE IF NOT EXISTS `#__wholesalequota` (
  `wholesalequota_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '批发套餐ID',
  `member_id` int(10) unsigned NOT NULL COMMENT '用户ID',
  `store_id` int(10) unsigned NOT NULL COMMENT '店铺ID',
  `member_name` varchar(50) NOT NULL COMMENT '用户名称',
  `store_name` varchar(50) NOT NULL COMMENT '店铺名称',
  `wholesalequota_starttime` int(10) unsigned NOT NULL COMMENT '开始时间',
  `wholesalequota_endtime` int(10) unsigned NOT NULL COMMENT '结束时间',
  PRIMARY KEY (`wholesalequota_id`),
  KEY `store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='批发套餐' AUTO_INCREMENT=1 ;

DROP TABLE IF EXISTS `#__wxconfig`;
CREATE TABLE IF NOT EXISTS `#__wxconfig` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '微信配置自增ID',
  `wxname` varchar(60) NOT NULL DEFAULT '' COMMENT '公众号名称',
  `appid` varchar(50) NOT NULL DEFAULT '' COMMENT 'appid',
  `appsecret` varchar(50) NOT NULL DEFAULT '' COMMENT 'appsecret',
  `token` char(255) NOT NULL COMMENT 'token',
  `qrcode` varchar(200) NOT NULL DEFAULT '' COMMENT '公众号二维码',
  `access_token` varchar(250) DEFAULT NULL COMMENT '令牌',
  `expires_in` int(15) DEFAULT NULL COMMENT '过期时间',
  `xcx_appid` varchar(50) NOT NULL DEFAULT '' COMMENT '小程序appid',
  `xcx_appsecret` varchar(50) NOT NULL DEFAULT '' COMMENT '小程序appsecret',
  `xcx_access_token` varchar(250) DEFAULT NULL COMMENT '小程序令牌',
  `xcx_expires_in` int(15) DEFAULT NULL COMMENT '小程序过期时间',
  `ticket` varchar(250) DEFAULT NULL COMMENT 'ticket',
  `ticket_expires_in` int(15) DEFAULT NULL COMMENT 'ticket过期时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信配置表';



DROP TABLE IF EXISTS `#__wxkeyword`;
CREATE TABLE IF NOT EXISTS `#__wxkeyword` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '表id',
  `keyword` char(255) NOT NULL COMMENT '关键词',
  `pid` int(11) NOT NULL COMMENT '对应表ID',
  `type` varchar(30) DEFAULT 'TEXT' COMMENT '关键词操作类型',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信关键词表';



DROP TABLE IF EXISTS `#__wxmenu`;
CREATE TABLE IF NOT EXISTS `#__wxmenu` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '微信菜单id',
  `pid` int(11) NOT NULL DEFAULT '0' COMMENT '父菜单id',
  `name` varchar(32) NOT NULL COMMENT '微信菜单名称',
  `type` varchar(10) NOT NULL DEFAULT '' COMMENT '微信菜单类型',
  `value` text COMMENT '微信菜单值',
  `sort` tinyint(3) unsigned NOT NULL DEFAULT '255' COMMENT '排序',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信菜单表';



DROP TABLE IF EXISTS `#__wxmsg`;
CREATE TABLE IF NOT EXISTS `#__wxmsg` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '推送ID',
  `member_id` int(11) DEFAULT NULL COMMENT '为空则推送全体微信用户',
  `content` text NOT NULL COMMENT '推送内容',
  `createtime` int(15) NOT NULL COMMENT '创建时间',
  `issend` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0未发送1成功2失败',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信推送表';



DROP TABLE IF EXISTS `#__wxtext`;
CREATE TABLE IF NOT EXISTS `#__wxtext` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '表id',
  `keyword` char(255) NOT NULL COMMENT '关键词',
  `text` text NOT NULL COMMENT 'text',
  `createtime` varchar(13) NOT NULL DEFAULT '' COMMENT '创建时间',
  `updatetime` varchar(13) NOT NULL DEFAULT '' COMMENT '更新时间',
  `click` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '点击',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信文本回复表';

INSERT INTO `#__area` (`area_id`, `area_name`, `area_parent_id`, `area_sort`, `area_deep`, `area_region`, `area_initial`) VALUES
(1, '北京市', 0, 255, 1, '华北','B'),
(2, '天津市', 0, 255, 1, '华北','T'),
(3, '河北省', 0, 255, 1, '华北','H'),
(4, '山西省', 0, 255, 1, '华北','S'),
(5, '内蒙古自治区', 0, 255, 1, '华北','N'),
(6, '辽宁省', 0, 255, 1, '东北','L'),
(7, '吉林省', 0, 255, 1, '东北','J'),
(8, '黑龙江省', 0, 255, 1, '东北','H'),
(9, '上海市', 0, 255, 1, '华东','S'),
(10, '江苏省', 0, 255, 1, '华东','J'),
(11, '浙江省', 0, 255, 1, '华东','Z'),
(12, '安徽省', 0, 255, 1, '华东','A'),
(13, '福建省', 0, 255, 1, '华南','F'),
(14, '江西省', 0, 255, 1, '华东','J'),
(15, '山东省', 0, 255, 1, '华东','S'),
(16, '河南省', 0, 255, 1, '华中','H'),
(17, '湖北省', 0, 255, 1, '华中','H'),
(18, '湖南省', 0, 255, 1, '华中','H'),
(19, '广东省', 0, 255, 1, '华南','G'),
(20, '广西壮族自治区', 0, 255, 1, '华南','G'),
(21, '海南省', 0, 255, 1, '华南','H'),
(22, '重庆市', 0, 255, 1, '西南','C'),
(23, '四川省', 0, 255, 1, '西南','S'),
(24, '贵州省', 0, 255, 1, '西南','G'),
(25, '云南省', 0, 255, 1, '西南','Y'),
(26, '西藏自治区', 0, 255, 1, '西南','X'),
(27, '陕西省', 0, 255, 1, '西北','S'),
(28, '甘肃省', 0, 255, 1, '西北','G'),
(29, '青海省', 0, 255, 1, '西北','Q'),
(30, '宁夏回族自治区', 0, 255, 1, '西北','N'),
(31, '新疆维吾尔自治区', 0, 255, 1, '西北','X'),
(3661, '香港', 0, 255, 1, '港澳台','X'),
(3662, '澳门', 0, 255, 1, '港澳台','A'),
(3663, '台湾', 0, 255, 1, '港澳台','T'),
(3664, '海外', 0, 255, 1, '海外','H');
INSERT INTO `#__area` (`area_id`, `area_name`, `area_parent_id`, `area_sort`, `area_deep`, `area_region`) VALUES
(32, '市辖区', 1, 255, 2, NULL),
(33, '市辖区', 2, 255, 2, NULL),
(34, '石家庄市', 3, 255, 2, NULL),
(35, '唐山市', 3, 255, 2, NULL),
(36, '秦皇岛市', 3, 255, 2, NULL),
(37, '邯郸市', 3, 255, 2, NULL),
(38, '邢台市', 3, 255, 2, NULL),
(39, '保定市', 3, 255, 2, NULL),
(40, '张家口市', 3, 255, 2, NULL),
(41, '承德市', 3, 255, 2, NULL),
(42, '沧州市', 3, 255, 2, NULL),
(43, '廊坊市', 3, 255, 2, NULL),
(44, '衡水市', 3, 255, 2, NULL),
(45, '太原市', 4, 255, 2, NULL),
(46, '大同市', 4, 255, 2, NULL),
(47, '阳泉市', 4, 255, 2, NULL),
(48, '长治市', 4, 255, 2, NULL),
(49, '晋城市', 4, 255, 2, NULL),
(50, '朔州市', 4, 255, 2, NULL),
(51, '晋中市', 4, 255, 2, NULL),
(52, '运城市', 4, 255, 2, NULL),
(53, '忻州市', 4, 255, 2, NULL),
(54, '临汾市', 4, 255, 2, NULL),
(55, '吕梁市', 4, 255, 2, NULL),
(56, '呼和浩特市', 5, 255, 2, NULL),
(57, '包头市', 5, 255, 2, NULL),
(58, '乌海市', 5, 255, 2, NULL),
(59, '赤峰市', 5, 255, 2, NULL),
(60, '通辽市', 5, 255, 2, NULL),
(61, '鄂尔多斯市', 5, 255, 2, NULL),
(62, '呼伦贝尔市', 5, 255, 2, NULL),
(63, '巴彦淖尔市', 5, 255, 2, NULL),
(64, '乌兰察布市', 5, 255, 2, NULL),
(65, '兴安盟', 5, 255, 2, NULL),
(66, '锡林郭勒盟', 5, 255, 2, NULL),
(67, '阿拉善盟', 5, 255, 2, NULL),
(68, '沈阳市', 6, 255, 2, NULL),
(69, '大连市', 6, 255, 2, NULL),
(70, '鞍山市', 6, 255, 2, NULL),
(71, '抚顺市', 6, 255, 2, NULL),
(72, '本溪市', 6, 255, 2, NULL),
(73, '丹东市', 6, 255, 2, NULL),
(74, '锦州市', 6, 255, 2, NULL),
(75, '营口市', 6, 255, 2, NULL),
(76, '阜新市', 6, 255, 2, NULL),
(77, '辽阳市', 6, 255, 2, NULL),
(78, '盘锦市', 6, 255, 2, NULL),
(79, '铁岭市', 6, 255, 2, NULL),
(80, '朝阳市', 6, 255, 2, NULL),
(81, '葫芦岛市', 6, 255, 2, NULL),
(82, '长春市', 7, 255, 2, NULL),
(83, '吉林市', 7, 255, 2, NULL),
(84, '四平市', 7, 255, 2, NULL),
(85, '辽源市', 7, 255, 2, NULL),
(86, '通化市', 7, 255, 2, NULL),
(87, '白山市', 7, 255, 2, NULL),
(88, '松原市', 7, 255, 2, NULL),
(89, '白城市', 7, 255, 2, NULL),
(90, '延边朝鲜族自治州', 7, 255, 2, NULL),
(91, '哈尔滨市', 8, 255, 2, NULL),
(92, '齐齐哈尔市', 8, 255, 2, NULL),
(93, '鸡西市', 8, 255, 2, NULL),
(94, '鹤岗市', 8, 255, 2, NULL),
(95, '双鸭山市', 8, 255, 2, NULL),
(96, '大庆市', 8, 255, 2, NULL),
(97, '伊春市', 8, 255, 2, NULL),
(98, '佳木斯市', 8, 255, 2, NULL),
(99, '七台河市', 8, 255, 2, NULL),
(100, '牡丹江市', 8, 255, 2, NULL),
(101, '黑河市', 8, 255, 2, NULL),
(102, '绥化市', 8, 255, 2, NULL),
(103, '大兴安岭地区', 8, 255, 2, NULL),
(104, '市辖区', 9, 255, 2, NULL),
(105, '南京市', 10, 255, 2, NULL),
(106, '无锡市', 10, 255, 2, NULL),
(107, '徐州市', 10, 255, 2, NULL),
(108, '常州市', 10, 255, 2, NULL),
(109, '苏州市', 10, 255, 2, NULL),
(110, '南通市', 10, 255, 2, NULL),
(111, '连云港市', 10, 255, 2, NULL),
(112, '淮安市', 10, 255, 2, NULL),
(113, '盐城市', 10, 255, 2, NULL),
(114, '扬州市', 10, 255, 2, NULL),
(115, '镇江市', 10, 255, 2, NULL),
(116, '泰州市', 10, 255, 2, NULL),
(117, '宿迁市', 10, 255, 2, NULL),
(118, '杭州市', 11, 255, 2, NULL),
(119, '宁波市', 11, 255, 2, NULL),
(120, '温州市', 11, 255, 2, NULL),
(121, '嘉兴市', 11, 255, 2, NULL),
(122, '湖州市', 11, 255, 2, NULL),
(123, '绍兴市', 11, 255, 2, NULL),
(124, '金华市', 11, 255, 2, NULL),
(125, '衢州市', 11, 255, 2, NULL),
(126, '舟山市', 11, 255, 2, NULL),
(127, '台州市', 11, 255, 2, NULL),
(128, '丽水市', 11, 255, 2, NULL),
(129, '合肥市', 12, 255, 2, NULL),
(130, '芜湖市', 12, 255, 2, NULL),
(131, '蚌埠市', 12, 255, 2, NULL),
(132, '淮南市', 12, 255, 2, NULL),
(133, '马鞍山市', 12, 255, 2, NULL),
(134, '淮北市', 12, 255, 2, NULL),
(135, '铜陵市', 12, 255, 2, NULL),
(136, '安庆市', 12, 255, 2, NULL),
(137, '黄山市', 12, 255, 2, NULL),
(138, '滁州市', 12, 255, 2, NULL),
(139, '阜阳市', 12, 255, 2, NULL),
(140, '宿州市', 12, 255, 2, NULL),
(141, '六安市', 12, 255, 2, NULL),
(142, '亳州市', 12, 255, 2, NULL),
(143, '池州市', 12, 255, 2, NULL),
(144, '宣城市', 12, 255, 2, NULL),
(145, '福州市', 13, 255, 2, NULL),
(146, '厦门市', 13, 255, 2, NULL),
(147, '莆田市', 13, 255, 2, NULL),
(148, '三明市', 13, 255, 2, NULL),
(149, '泉州市', 13, 255, 2, NULL),
(150, '漳州市', 13, 255, 2, NULL),
(151, '南平市', 13, 255, 2, NULL),
(152, '龙岩市', 13, 255, 2, NULL),
(153, '宁德市', 13, 255, 2, NULL),
(154, '南昌市', 14, 255, 2, NULL),
(155, '景德镇市', 14, 255, 2, NULL),
(156, '萍乡市', 14, 255, 2, NULL),
(157, '九江市', 14, 255, 2, NULL),
(158, '新余市', 14, 255, 2, NULL),
(159, '鹰潭市', 14, 255, 2, NULL),
(160, '赣州市', 14, 255, 2, NULL),
(161, '吉安市', 14, 255, 2, NULL),
(162, '宜春市', 14, 255, 2, NULL),
(163, '抚州市', 14, 255, 2, NULL),
(164, '上饶市', 14, 255, 2, NULL),
(165, '济南市', 15, 255, 2, NULL),
(166, '青岛市', 15, 255, 2, NULL),
(167, '淄博市', 15, 255, 2, NULL),
(168, '枣庄市', 15, 255, 2, NULL),
(169, '东营市', 15, 255, 2, NULL),
(170, '烟台市', 15, 255, 2, NULL),
(171, '潍坊市', 15, 255, 2, NULL),
(172, '济宁市', 15, 255, 2, NULL),
(173, '泰安市', 15, 255, 2, NULL),
(174, '威海市', 15, 255, 2, NULL),
(175, '日照市', 15, 255, 2, NULL),
(176, '临沂市', 15, 255, 2, NULL),
(177, '德州市', 15, 255, 2, NULL),
(178, '聊城市', 15, 255, 2, NULL),
(179, '滨州市', 15, 255, 2, NULL),
(180, '菏泽市', 15, 255, 2, NULL),
(181, '郑州市', 16, 255, 2, NULL),
(182, '开封市', 16, 255, 2, NULL),
(183, '洛阳市', 16, 255, 2, NULL),
(184, '平顶山市', 16, 255, 2, NULL),
(185, '安阳市', 16, 255, 2, NULL),
(186, '鹤壁市', 16, 255, 2, NULL),
(187, '新乡市', 16, 255, 2, NULL),
(188, '焦作市', 16, 255, 2, NULL),
(189, '濮阳市', 16, 255, 2, NULL),
(190, '许昌市', 16, 255, 2, NULL),
(191, '漯河市', 16, 255, 2, NULL),
(192, '三门峡市', 16, 255, 2, NULL),
(193, '南阳市', 16, 255, 2, NULL),
(194, '商丘市', 16, 255, 2, NULL),
(195, '信阳市', 16, 255, 2, NULL),
(196, '周口市', 16, 255, 2, NULL),
(197, '驻马店市', 16, 255, 2, NULL),
(198, '省直辖县级行政区划', 16, 255, 2, NULL),
(199, '武汉市', 17, 255, 2, NULL),
(200, '黄石市', 17, 255, 2, NULL),
(201, '十堰市', 17, 255, 2, NULL),
(202, '宜昌市', 17, 255, 2, NULL),
(203, '襄阳市', 17, 255, 2, NULL),
(204, '鄂州市', 17, 255, 2, NULL),
(205, '荆门市', 17, 255, 2, NULL),
(206, '孝感市', 17, 255, 2, NULL),
(207, '荆州市', 17, 255, 2, NULL),
(208, '黄冈市', 17, 255, 2, NULL),
(209, '咸宁市', 17, 255, 2, NULL),
(210, '随州市', 17, 255, 2, NULL),
(211, '恩施土家族苗族自治州', 17, 255, 2, NULL),
(212, '省直辖县级行政区划', 17, 255, 2, NULL),
(213, '长沙市', 18, 255, 2, NULL),
(214, '株洲市', 18, 255, 2, NULL),
(215, '湘潭市', 18, 255, 2, NULL),
(216, '衡阳市', 18, 255, 2, NULL),
(217, '邵阳市', 18, 255, 2, NULL),
(218, '岳阳市', 18, 255, 2, NULL),
(219, '常德市', 18, 255, 2, NULL),
(220, '张家界市', 18, 255, 2, NULL),
(221, '益阳市', 18, 255, 2, NULL),
(222, '郴州市', 18, 255, 2, NULL),
(223, '永州市', 18, 255, 2, NULL),
(224, '怀化市', 18, 255, 2, NULL),
(225, '娄底市', 18, 255, 2, NULL),
(226, '湘西土家族苗族自治州', 18, 255, 2, NULL),
(227, '广州市', 19, 255, 2, NULL),
(228, '韶关市', 19, 255, 2, NULL),
(229, '深圳市', 19, 255, 2, NULL),
(230, '珠海市', 19, 255, 2, NULL),
(231, '汕头市', 19, 255, 2, NULL),
(232, '佛山市', 19, 255, 2, NULL),
(233, '江门市', 19, 255, 2, NULL),
(234, '湛江市', 19, 255, 2, NULL),
(235, '茂名市', 19, 255, 2, NULL),
(236, '肇庆市', 19, 255, 2, NULL),
(237, '惠州市', 19, 255, 2, NULL),
(238, '梅州市', 19, 255, 2, NULL),
(239, '汕尾市', 19, 255, 2, NULL),
(240, '河源市', 19, 255, 2, NULL),
(241, '阳江市', 19, 255, 2, NULL),
(242, '清远市', 19, 255, 2, NULL),
(243, '东莞市', 19, 255, 2, NULL),
(244, '中山市', 19, 255, 2, NULL),
(245, '潮州市', 19, 255, 2, NULL),
(246, '揭阳市', 19, 255, 2, NULL),
(247, '云浮市', 19, 255, 2, NULL),
(248, '南宁市', 20, 255, 2, NULL),
(249, '柳州市', 20, 255, 2, NULL),
(250, '桂林市', 20, 255, 2, NULL),
(251, '梧州市', 20, 255, 2, NULL),
(252, '北海市', 20, 255, 2, NULL),
(253, '防城港市', 20, 255, 2, NULL),
(254, '钦州市', 20, 255, 2, NULL),
(255, '贵港市', 20, 255, 2, NULL),
(256, '玉林市', 20, 255, 2, NULL),
(257, '百色市', 20, 255, 2, NULL),
(258, '贺州市', 20, 255, 2, NULL),
(259, '河池市', 20, 255, 2, NULL),
(260, '来宾市', 20, 255, 2, NULL),
(261, '崇左市', 20, 255, 2, NULL),
(262, '海口市', 21, 255, 2, NULL),
(263, '三亚市', 21, 255, 2, NULL),
(264, '三沙市', 21, 255, 2, NULL),
(265, '儋州市', 21, 255, 2, NULL),
(266, '省直辖县级行政区划', 21, 255, 2, NULL),
(267, '市辖区', 22, 255, 2, NULL),
(268, '县', 22, 255, 2, NULL),
(269, '成都市', 23, 255, 2, NULL),
(270, '自贡市', 23, 255, 2, NULL),
(271, '攀枝花市', 23, 255, 2, NULL),
(272, '泸州市', 23, 255, 2, NULL),
(273, '德阳市', 23, 255, 2, NULL),
(274, '绵阳市', 23, 255, 2, NULL),
(275, '广元市', 23, 255, 2, NULL),
(276, '遂宁市', 23, 255, 2, NULL),
(277, '内江市', 23, 255, 2, NULL),
(278, '乐山市', 23, 255, 2, NULL),
(279, '南充市', 23, 255, 2, NULL),
(280, '眉山市', 23, 255, 2, NULL),
(281, '宜宾市', 23, 255, 2, NULL),
(282, '广安市', 23, 255, 2, NULL),
(283, '达州市', 23, 255, 2, NULL),
(284, '雅安市', 23, 255, 2, NULL),
(285, '巴中市', 23, 255, 2, NULL),
(286, '资阳市', 23, 255, 2, NULL),
(287, '阿坝藏族羌族自治州', 23, 255, 2, NULL),
(288, '甘孜藏族自治州', 23, 255, 2, NULL),
(289, '凉山彝族自治州', 23, 255, 2, NULL),
(290, '贵阳市', 24, 255, 2, NULL),
(291, '六盘水市', 24, 255, 2, NULL),
(292, '遵义市', 24, 255, 2, NULL),
(293, '安顺市', 24, 255, 2, NULL),
(294, '毕节市', 24, 255, 2, NULL),
(295, '铜仁市', 24, 255, 2, NULL),
(296, '黔西南布依族苗族自治州', 24, 255, 2, NULL),
(297, '黔东南苗族侗族自治州', 24, 255, 2, NULL),
(298, '黔南布依族苗族自治州', 24, 255, 2, NULL),
(299, '昆明市', 25, 255, 2, NULL),
(300, '曲靖市', 25, 255, 2, NULL),
(301, '玉溪市', 25, 255, 2, NULL),
(302, '保山市', 25, 255, 2, NULL),
(303, '昭通市', 25, 255, 2, NULL),
(304, '丽江市', 25, 255, 2, NULL),
(305, '普洱市', 25, 255, 2, NULL),
(306, '临沧市', 25, 255, 2, NULL),
(307, '楚雄彝族自治州', 25, 255, 2, NULL),
(308, '红河哈尼族彝族自治州', 25, 255, 2, NULL),
(309, '文山壮族苗族自治州', 25, 255, 2, NULL),
(310, '西双版纳傣族自治州', 25, 255, 2, NULL),
(311, '大理白族自治州', 25, 255, 2, NULL),
(312, '德宏傣族景颇族自治州', 25, 255, 2, NULL),
(313, '怒江傈僳族自治州', 25, 255, 2, NULL),
(314, '迪庆藏族自治州', 25, 255, 2, NULL),
(315, '拉萨市', 26, 255, 2, NULL),
(316, '日喀则市', 26, 255, 2, NULL),
(317, '昌都市', 26, 255, 2, NULL),
(318, '林芝市', 26, 255, 2, NULL),
(319, '山南市', 26, 255, 2, NULL),
(320, '那曲市', 26, 255, 2, NULL),
(321, '阿里地区', 26, 255, 2, NULL),
(322, '西安市', 27, 255, 2, NULL),
(323, '铜川市', 27, 255, 2, NULL),
(324, '宝鸡市', 27, 255, 2, NULL),
(325, '咸阳市', 27, 255, 2, NULL),
(326, '渭南市', 27, 255, 2, NULL),
(327, '延安市', 27, 255, 2, NULL),
(328, '汉中市', 27, 255, 2, NULL),
(329, '榆林市', 27, 255, 2, NULL),
(330, '安康市', 27, 255, 2, NULL),
(331, '商洛市', 27, 255, 2, NULL),
(332, '兰州市', 28, 255, 2, NULL),
(333, '嘉峪关市', 28, 255, 2, NULL),
(334, '金昌市', 28, 255, 2, NULL),
(335, '白银市', 28, 255, 2, NULL),
(336, '天水市', 28, 255, 2, NULL),
(337, '武威市', 28, 255, 2, NULL),
(338, '张掖市', 28, 255, 2, NULL),
(339, '平凉市', 28, 255, 2, NULL),
(340, '酒泉市', 28, 255, 2, NULL),
(341, '庆阳市', 28, 255, 2, NULL),
(342, '定西市', 28, 255, 2, NULL),
(343, '陇南市', 28, 255, 2, NULL),
(344, '临夏回族自治州', 28, 255, 2, NULL),
(345, '甘南藏族自治州', 28, 255, 2, NULL),
(346, '西宁市', 29, 255, 2, NULL),
(347, '海东市', 29, 255, 2, NULL),
(348, '海北藏族自治州', 29, 255, 2, NULL),
(349, '黄南藏族自治州', 29, 255, 2, NULL),
(350, '海南藏族自治州', 29, 255, 2, NULL),
(351, '果洛藏族自治州', 29, 255, 2, NULL),
(352, '玉树藏族自治州', 29, 255, 2, NULL),
(353, '海西蒙古族藏族自治州', 29, 255, 2, NULL),
(354, '银川市', 30, 255, 2, NULL),
(355, '石嘴山市', 30, 255, 2, NULL),
(356, '吴忠市', 30, 255, 2, NULL),
(357, '固原市', 30, 255, 2, NULL),
(358, '中卫市', 30, 255, 2, NULL),
(359, '乌鲁木齐市', 31, 255, 2, NULL),
(360, '克拉玛依市', 31, 255, 2, NULL),
(361, '吐鲁番市', 31, 255, 2, NULL),
(362, '哈密市', 31, 255, 2, NULL),
(363, '昌吉回族自治州', 31, 255, 2, NULL),
(364, '博尔塔拉蒙古自治州', 31, 255, 2, NULL),
(365, '巴音郭楞蒙古自治州', 31, 255, 2, NULL),
(366, '阿克苏地区', 31, 255, 2, NULL),
(367, '克孜勒苏柯尔克孜自治州', 31, 255, 2, NULL),
(368, '喀什地区', 31, 255, 2, NULL),
(369, '和田地区', 31, 255, 2, NULL),
(370, '伊犁哈萨克自治州', 31, 255, 2, NULL),
(371, '塔城地区', 31, 255, 2, NULL),
(372, '阿勒泰地区', 31, 255, 2, NULL),
(373, '自治区直辖县级行政区划', 31, 255, 2, NULL),
(374, '东城区', 32, 255, 3, NULL),
(375, '西城区', 32, 255, 3, NULL),
(376, '朝阳区', 32, 255, 3, NULL),
(377, '丰台区', 32, 255, 3, NULL),
(378, '石景山区', 32, 255, 3, NULL),
(379, '海淀区', 32, 255, 3, NULL),
(380, '门头沟区', 32, 255, 3, NULL),
(381, '房山区', 32, 255, 3, NULL),
(382, '通州区', 32, 255, 3, NULL),
(383, '顺义区', 32, 255, 3, NULL),
(384, '昌平区', 32, 255, 3, NULL),
(385, '大兴区', 32, 255, 3, NULL),
(386, '怀柔区', 32, 255, 3, NULL),
(387, '平谷区', 32, 255, 3, NULL),
(388, '密云区', 32, 255, 3, NULL),
(389, '延庆区', 32, 255, 3, NULL),
(390, '和平区', 33, 255, 3, NULL),
(391, '河东区', 33, 255, 3, NULL),
(392, '河西区', 33, 255, 3, NULL),
(393, '南开区', 33, 255, 3, NULL),
(394, '河北区', 33, 255, 3, NULL),
(395, '红桥区', 33, 255, 3, NULL),
(396, '东丽区', 33, 255, 3, NULL),
(397, '西青区', 33, 255, 3, NULL),
(398, '津南区', 33, 255, 3, NULL),
(399, '北辰区', 33, 255, 3, NULL),
(400, '武清区', 33, 255, 3, NULL),
(401, '宝坻区', 33, 255, 3, NULL),
(402, '滨海新区', 33, 255, 3, NULL),
(403, '宁河区', 33, 255, 3, NULL),
(404, '静海区', 33, 255, 3, NULL),
(405, '蓟州区', 33, 255, 3, NULL),
(406, '和平区', 33, 255, 3, NULL),
(407, '河东区', 33, 255, 3, NULL),
(408, '河西区', 33, 255, 3, NULL),
(409, '南开区', 33, 255, 3, NULL),
(410, '河北区', 33, 255, 3, NULL),
(411, '红桥区', 33, 255, 3, NULL),
(412, '东丽区', 33, 255, 3, NULL),
(413, '西青区', 33, 255, 3, NULL),
(414, '津南区', 33, 255, 3, NULL),
(415, '北辰区', 33, 255, 3, NULL),
(416, '武清区', 33, 255, 3, NULL),
(417, '宝坻区', 33, 255, 3, NULL),
(418, '滨海新区', 33, 255, 3, NULL),
(419, '宁河区', 33, 255, 3, NULL),
(420, '静海区', 33, 255, 3, NULL),
(421, '蓟州区', 33, 255, 3, NULL),
(422, '市辖区', 34, 255, 3, NULL),
(423, '长安区', 34, 255, 3, NULL),
(424, '桥西区', 34, 255, 3, NULL),
(425, '新华区', 34, 255, 3, NULL),
(426, '井陉矿区', 34, 255, 3, NULL),
(427, '裕华区', 34, 255, 3, NULL),
(428, '藁城区', 34, 255, 3, NULL),
(429, '鹿泉区', 34, 255, 3, NULL),
(430, '栾城区', 34, 255, 3, NULL),
(431, '井陉县', 34, 255, 3, NULL),
(432, '正定县', 34, 255, 3, NULL),
(433, '行唐县', 34, 255, 3, NULL),
(434, '灵寿县', 34, 255, 3, NULL),
(435, '高邑县', 34, 255, 3, NULL),
(436, '深泽县', 34, 255, 3, NULL),
(437, '赞皇县', 34, 255, 3, NULL),
(438, '无极县', 34, 255, 3, NULL),
(439, '平山县', 34, 255, 3, NULL),
(440, '元氏县', 34, 255, 3, NULL),
(441, '赵县', 34, 255, 3, NULL),
(442, '石家庄高新技术产业开发区', 34, 255, 3, NULL),
(443, '石家庄循环化工园区', 34, 255, 3, NULL),
(444, '辛集市', 34, 255, 3, NULL),
(445, '晋州市', 34, 255, 3, NULL),
(446, '新乐市', 34, 255, 3, NULL),
(447, '市辖区', 35, 255, 3, NULL),
(448, '路南区', 35, 255, 3, NULL),
(449, '路北区', 35, 255, 3, NULL),
(450, '古冶区', 35, 255, 3, NULL),
(451, '开平区', 35, 255, 3, NULL),
(452, '丰南区', 35, 255, 3, NULL),
(453, '丰润区', 35, 255, 3, NULL),
(454, '曹妃甸区', 35, 255, 3, NULL),
(455, '滦南县', 35, 255, 3, NULL),
(456, '乐亭县', 35, 255, 3, NULL),
(457, '迁西县', 35, 255, 3, NULL),
(458, '玉田县', 35, 255, 3, NULL),
(459, '河北唐山芦台经济开发区', 35, 255, 3, NULL),
(460, '唐山市汉沽管理区', 35, 255, 3, NULL),
(461, '唐山高新技术产业开发区', 35, 255, 3, NULL),
(462, '河北唐山海港经济开发区', 35, 255, 3, NULL),
(463, '遵化市', 35, 255, 3, NULL),
(464, '迁安市', 35, 255, 3, NULL),
(465, '滦州市', 35, 255, 3, NULL),
(466, '市辖区', 36, 255, 3, NULL),
(467, '海港区', 36, 255, 3, NULL),
(468, '山海关区', 36, 255, 3, NULL),
(469, '北戴河区', 36, 255, 3, NULL),
(470, '抚宁区', 36, 255, 3, NULL),
(471, '青龙满族自治县', 36, 255, 3, NULL),
(472, '昌黎县', 36, 255, 3, NULL),
(473, '卢龙县', 36, 255, 3, NULL),
(474, '秦皇岛市经济技术开发区', 36, 255, 3, NULL),
(475, '北戴河新区', 36, 255, 3, NULL),
(476, '市辖区', 37, 255, 3, NULL),
(477, '邯山区', 37, 255, 3, NULL),
(478, '丛台区', 37, 255, 3, NULL),
(479, '复兴区', 37, 255, 3, NULL),
(480, '峰峰矿区', 37, 255, 3, NULL),
(481, '肥乡区', 37, 255, 3, NULL),
(482, '永年区', 37, 255, 3, NULL),
(483, '临漳县', 37, 255, 3, NULL),
(484, '成安县', 37, 255, 3, NULL),
(485, '大名县', 37, 255, 3, NULL),
(486, '涉县', 37, 255, 3, NULL),
(487, '磁县', 37, 255, 3, NULL),
(488, '邱县', 37, 255, 3, NULL),
(489, '鸡泽县', 37, 255, 3, NULL),
(490, '广平县', 37, 255, 3, NULL),
(491, '馆陶县', 37, 255, 3, NULL),
(492, '魏县', 37, 255, 3, NULL),
(493, '曲周县', 37, 255, 3, NULL),
(494, '邯郸经济技术开发区', 37, 255, 3, NULL),
(495, '邯郸冀南新区', 37, 255, 3, NULL),
(496, '武安市', 37, 255, 3, NULL),
(497, '市辖区', 38, 255, 3, NULL),
(498, '襄都区', 38, 255, 3, NULL),
(499, '信都区', 38, 255, 3, NULL),
(500, '任泽区', 38, 255, 3, NULL),
(501, '南和区', 38, 255, 3, NULL),
(502, '临城县', 38, 255, 3, NULL),
(503, '内丘县', 38, 255, 3, NULL),
(504, '柏乡县', 38, 255, 3, NULL),
(505, '隆尧县', 38, 255, 3, NULL),
(506, '宁晋县', 38, 255, 3, NULL),
(507, '巨鹿县', 38, 255, 3, NULL),
(508, '新河县', 38, 255, 3, NULL),
(509, '广宗县', 38, 255, 3, NULL),
(510, '平乡县', 38, 255, 3, NULL),
(511, '威县', 38, 255, 3, NULL),
(512, '清河县', 38, 255, 3, NULL),
(513, '临西县', 38, 255, 3, NULL),
(514, '河北邢台经济开发区', 38, 255, 3, NULL),
(515, '南宫市', 38, 255, 3, NULL),
(516, '沙河市', 38, 255, 3, NULL),
(517, '市辖区', 39, 255, 3, NULL),
(518, '竞秀区', 39, 255, 3, NULL),
(519, '莲池区', 39, 255, 3, NULL),
(520, '满城区', 39, 255, 3, NULL),
(521, '清苑区', 39, 255, 3, NULL),
(522, '徐水区', 39, 255, 3, NULL),
(523, '涞水县', 39, 255, 3, NULL),
(524, '阜平县', 39, 255, 3, NULL),
(525, '定兴县', 39, 255, 3, NULL),
(526, '唐县', 39, 255, 3, NULL),
(527, '高阳县', 39, 255, 3, NULL),
(528, '容城县', 39, 255, 3, NULL),
(529, '涞源县', 39, 255, 3, NULL),
(530, '望都县', 39, 255, 3, NULL),
(531, '安新县', 39, 255, 3, NULL),
(532, '易县', 39, 255, 3, NULL),
(533, '曲阳县', 39, 255, 3, NULL),
(534, '蠡县', 39, 255, 3, NULL),
(535, '顺平县', 39, 255, 3, NULL),
(536, '博野县', 39, 255, 3, NULL),
(537, '雄县', 39, 255, 3, NULL),
(538, '保定高新技术产业开发区', 39, 255, 3, NULL),
(539, '保定白沟新城', 39, 255, 3, NULL),
(540, '涿州市', 39, 255, 3, NULL),
(541, '定州市', 39, 255, 3, NULL),
(542, '安国市', 39, 255, 3, NULL),
(543, '高碑店市', 39, 255, 3, NULL),
(544, '市辖区', 40, 255, 3, NULL),
(545, '桥东区', 40, 255, 3, NULL),
(546, '桥西区', 40, 255, 3, NULL),
(547, '宣化区', 40, 255, 3, NULL),
(548, '下花园区', 40, 255, 3, NULL),
(549, '万全区', 40, 255, 3, NULL),
(550, '崇礼区', 40, 255, 3, NULL),
(551, '张北县', 40, 255, 3, NULL),
(552, '康保县', 40, 255, 3, NULL),
(553, '沽源县', 40, 255, 3, NULL),
(554, '尚义县', 40, 255, 3, NULL),
(555, '蔚县', 40, 255, 3, NULL),
(556, '阳原县', 40, 255, 3, NULL),
(557, '怀安县', 40, 255, 3, NULL),
(558, '怀来县', 40, 255, 3, NULL),
(559, '涿鹿县', 40, 255, 3, NULL),
(560, '赤城县', 40, 255, 3, NULL),
(561, '张家口经济开发区', 40, 255, 3, NULL),
(562, '张家口市察北管理区', 40, 255, 3, NULL),
(563, '张家口市塞北管理区', 40, 255, 3, NULL),
(564, '市辖区', 41, 255, 3, NULL),
(565, '双桥区', 41, 255, 3, NULL),
(566, '双滦区', 41, 255, 3, NULL),
(567, '鹰手营子矿区', 41, 255, 3, NULL),
(568, '承德县', 41, 255, 3, NULL),
(569, '兴隆县', 41, 255, 3, NULL),
(570, '滦平县', 41, 255, 3, NULL),
(571, '隆化县', 41, 255, 3, NULL),
(572, '丰宁满族自治县', 41, 255, 3, NULL),
(573, '宽城满族自治县', 41, 255, 3, NULL),
(574, '围场满族蒙古族自治县', 41, 255, 3, NULL),
(575, '承德高新技术产业开发区', 41, 255, 3, NULL),
(576, '平泉市', 41, 255, 3, NULL),
(577, '市辖区', 42, 255, 3, NULL),
(578, '新华区', 42, 255, 3, NULL),
(579, '运河区', 42, 255, 3, NULL),
(580, '沧县', 42, 255, 3, NULL),
(581, '青县', 42, 255, 3, NULL),
(582, '东光县', 42, 255, 3, NULL),
(583, '海兴县', 42, 255, 3, NULL),
(584, '盐山县', 42, 255, 3, NULL),
(585, '肃宁县', 42, 255, 3, NULL),
(586, '南皮县', 42, 255, 3, NULL),
(587, '吴桥县', 42, 255, 3, NULL),
(588, '献县', 42, 255, 3, NULL),
(589, '孟村回族自治县', 42, 255, 3, NULL),
(590, '河北沧州经济开发区', 42, 255, 3, NULL),
(591, '沧州高新技术产业开发区', 42, 255, 3, NULL),
(592, '沧州渤海新区', 42, 255, 3, NULL),
(593, '泊头市', 42, 255, 3, NULL),
(594, '任丘市', 42, 255, 3, NULL),
(595, '黄骅市', 42, 255, 3, NULL),
(596, '河间市', 42, 255, 3, NULL),
(597, '市辖区', 43, 255, 3, NULL),
(598, '安次区', 43, 255, 3, NULL),
(599, '广阳区', 43, 255, 3, NULL),
(600, '固安县', 43, 255, 3, NULL),
(601, '永清县', 43, 255, 3, NULL),
(602, '香河县', 43, 255, 3, NULL),
(603, '大城县', 43, 255, 3, NULL),
(604, '文安县', 43, 255, 3, NULL),
(605, '大厂回族自治县', 43, 255, 3, NULL),
(606, '廊坊经济技术开发区', 43, 255, 3, NULL),
(607, '霸州市', 43, 255, 3, NULL),
(608, '三河市', 43, 255, 3, NULL),
(609, '市辖区', 44, 255, 3, NULL),
(610, '桃城区', 44, 255, 3, NULL),
(611, '冀州区', 44, 255, 3, NULL),
(612, '枣强县', 44, 255, 3, NULL),
(613, '武邑县', 44, 255, 3, NULL),
(614, '武强县', 44, 255, 3, NULL),
(615, '饶阳县', 44, 255, 3, NULL),
(616, '安平县', 44, 255, 3, NULL),
(617, '故城县', 44, 255, 3, NULL),
(618, '景县', 44, 255, 3, NULL),
(619, '阜城县', 44, 255, 3, NULL),
(620, '河北衡水高新技术产业开发区', 44, 255, 3, NULL),
(621, '衡水滨湖新区', 44, 255, 3, NULL),
(622, '深州市', 44, 255, 3, NULL),
(623, '市辖区', 45, 255, 3, NULL),
(624, '小店区', 45, 255, 3, NULL),
(625, '迎泽区', 45, 255, 3, NULL),
(626, '杏花岭区', 45, 255, 3, NULL),
(627, '尖草坪区', 45, 255, 3, NULL),
(628, '万柏林区', 45, 255, 3, NULL),
(629, '晋源区', 45, 255, 3, NULL),
(630, '清徐县', 45, 255, 3, NULL),
(631, '阳曲县', 45, 255, 3, NULL),
(632, '娄烦县', 45, 255, 3, NULL),
(633, '山西转型综合改革示范区', 45, 255, 3, NULL),
(634, '古交市', 45, 255, 3, NULL),
(635, '市辖区', 46, 255, 3, NULL),
(636, '新荣区', 46, 255, 3, NULL),
(637, '平城区', 46, 255, 3, NULL),
(638, '云冈区', 46, 255, 3, NULL),
(639, '云州区', 46, 255, 3, NULL),
(640, '阳高县', 46, 255, 3, NULL),
(641, '天镇县', 46, 255, 3, NULL),
(642, '广灵县', 46, 255, 3, NULL),
(643, '灵丘县', 46, 255, 3, NULL),
(644, '浑源县', 46, 255, 3, NULL),
(645, '左云县', 46, 255, 3, NULL),
(646, '山西大同经济开发区', 46, 255, 3, NULL),
(647, '市辖区', 47, 255, 3, NULL),
(648, '城区', 47, 255, 3, NULL),
(649, '矿区', 47, 255, 3, NULL),
(650, '郊区', 47, 255, 3, NULL),
(651, '平定县', 47, 255, 3, NULL),
(652, '盂县', 47, 255, 3, NULL),
(653, '市辖区', 48, 255, 3, NULL),
(654, '潞州区', 48, 255, 3, NULL),
(655, '上党区', 48, 255, 3, NULL),
(656, '屯留区', 48, 255, 3, NULL),
(657, '潞城区', 48, 255, 3, NULL),
(658, '襄垣县', 48, 255, 3, NULL),
(659, '平顺县', 48, 255, 3, NULL),
(660, '黎城县', 48, 255, 3, NULL),
(661, '壶关县', 48, 255, 3, NULL),
(662, '长子县', 48, 255, 3, NULL),
(663, '武乡县', 48, 255, 3, NULL),
(664, '沁县', 48, 255, 3, NULL),
(665, '沁源县', 48, 255, 3, NULL),
(666, '山西长治高新技术产业园区', 48, 255, 3, NULL),
(667, '市辖区', 49, 255, 3, NULL),
(668, '城区', 49, 255, 3, NULL),
(669, '沁水县', 49, 255, 3, NULL),
(670, '阳城县', 49, 255, 3, NULL),
(671, '陵川县', 49, 255, 3, NULL),
(672, '泽州县', 49, 255, 3, NULL),
(673, '高平市', 49, 255, 3, NULL),
(674, '市辖区', 50, 255, 3, NULL),
(675, '朔城区', 50, 255, 3, NULL),
(676, '平鲁区', 50, 255, 3, NULL),
(677, '山阴县', 50, 255, 3, NULL),
(678, '应县', 50, 255, 3, NULL),
(679, '右玉县', 50, 255, 3, NULL),
(680, '山西朔州经济开发区', 50, 255, 3, NULL),
(681, '怀仁市', 50, 255, 3, NULL),
(682, '市辖区', 51, 255, 3, NULL),
(683, '榆次区', 51, 255, 3, NULL),
(684, '太谷区', 51, 255, 3, NULL),
(685, '榆社县', 51, 255, 3, NULL),
(686, '左权县', 51, 255, 3, NULL),
(687, '和顺县', 51, 255, 3, NULL),
(688, '昔阳县', 51, 255, 3, NULL),
(689, '寿阳县', 51, 255, 3, NULL),
(690, '祁县', 51, 255, 3, NULL),
(691, '平遥县', 51, 255, 3, NULL),
(692, '灵石县', 51, 255, 3, NULL),
(693, '介休市', 51, 255, 3, NULL),
(694, '市辖区', 52, 255, 3, NULL),
(695, '盐湖区', 52, 255, 3, NULL),
(696, '临猗县', 52, 255, 3, NULL),
(697, '万荣县', 52, 255, 3, NULL),
(698, '闻喜县', 52, 255, 3, NULL),
(699, '稷山县', 52, 255, 3, NULL),
(700, '新绛县', 52, 255, 3, NULL),
(701, '绛县', 52, 255, 3, NULL),
(702, '垣曲县', 52, 255, 3, NULL),
(703, '夏县', 52, 255, 3, NULL),
(704, '平陆县', 52, 255, 3, NULL),
(705, '芮城县', 52, 255, 3, NULL),
(706, '永济市', 52, 255, 3, NULL),
(707, '河津市', 52, 255, 3, NULL),
(708, '市辖区', 53, 255, 3, NULL),
(709, '忻府区', 53, 255, 3, NULL),
(710, '定襄县', 53, 255, 3, NULL),
(711, '五台县', 53, 255, 3, NULL),
(712, '代县', 53, 255, 3, NULL),
(713, '繁峙县', 53, 255, 3, NULL),
(714, '宁武县', 53, 255, 3, NULL),
(715, '静乐县', 53, 255, 3, NULL),
(716, '神池县', 53, 255, 3, NULL),
(717, '五寨县', 53, 255, 3, NULL),
(718, '岢岚县', 53, 255, 3, NULL),
(719, '河曲县', 53, 255, 3, NULL),
(720, '保德县', 53, 255, 3, NULL),
(721, '偏关县', 53, 255, 3, NULL),
(722, '五台山风景名胜区', 53, 255, 3, NULL),
(723, '原平市', 53, 255, 3, NULL),
(724, '市辖区', 54, 255, 3, NULL),
(725, '尧都区', 54, 255, 3, NULL),
(726, '曲沃县', 54, 255, 3, NULL),
(727, '翼城县', 54, 255, 3, NULL),
(728, '襄汾县', 54, 255, 3, NULL),
(729, '洪洞县', 54, 255, 3, NULL),
(730, '古县', 54, 255, 3, NULL),
(731, '安泽县', 54, 255, 3, NULL),
(732, '浮山县', 54, 255, 3, NULL),
(733, '吉县', 54, 255, 3, NULL),
(734, '乡宁县', 54, 255, 3, NULL),
(735, '大宁县', 54, 255, 3, NULL),
(736, '隰县', 54, 255, 3, NULL),
(737, '永和县', 54, 255, 3, NULL),
(738, '蒲县', 54, 255, 3, NULL),
(739, '汾西县', 54, 255, 3, NULL),
(740, '侯马市', 54, 255, 3, NULL),
(741, '霍州市', 54, 255, 3, NULL),
(742, '市辖区', 55, 255, 3, NULL),
(743, '离石区', 55, 255, 3, NULL),
(744, '文水县', 55, 255, 3, NULL),
(745, '交城县', 55, 255, 3, NULL),
(746, '兴县', 55, 255, 3, NULL),
(747, '临县', 55, 255, 3, NULL),
(748, '柳林县', 55, 255, 3, NULL),
(749, '石楼县', 55, 255, 3, NULL),
(750, '岚县', 55, 255, 3, NULL),
(751, '方山县', 55, 255, 3, NULL),
(752, '中阳县', 55, 255, 3, NULL),
(753, '交口县', 55, 255, 3, NULL),
(754, '孝义市', 55, 255, 3, NULL),
(755, '汾阳市', 55, 255, 3, NULL),
(756, '市辖区', 56, 255, 3, NULL),
(757, '新城区', 56, 255, 3, NULL),
(758, '回民区', 56, 255, 3, NULL),
(759, '玉泉区', 56, 255, 3, NULL),
(760, '赛罕区', 56, 255, 3, NULL),
(761, '土默特左旗', 56, 255, 3, NULL),
(762, '托克托县', 56, 255, 3, NULL),
(763, '和林格尔县', 56, 255, 3, NULL),
(764, '清水河县', 56, 255, 3, NULL),
(765, '武川县', 56, 255, 3, NULL),
(766, '呼和浩特经济技术开发区', 56, 255, 3, NULL),
(767, '市辖区', 57, 255, 3, NULL),
(768, '东河区', 57, 255, 3, NULL),
(769, '昆都仑区', 57, 255, 3, NULL),
(770, '青山区', 57, 255, 3, NULL),
(771, '石拐区', 57, 255, 3, NULL),
(772, '白云鄂博矿区', 57, 255, 3, NULL),
(773, '九原区', 57, 255, 3, NULL),
(774, '土默特右旗', 57, 255, 3, NULL),
(775, '固阳县', 57, 255, 3, NULL),
(776, '达尔罕茂明安联合旗', 57, 255, 3, NULL),
(777, '包头稀土高新技术产业开发区', 57, 255, 3, NULL),
(778, '市辖区', 58, 255, 3, NULL),
(779, '海勃湾区', 58, 255, 3, NULL),
(780, '海南区', 58, 255, 3, NULL),
(781, '乌达区', 58, 255, 3, NULL),
(782, '市辖区', 59, 255, 3, NULL),
(783, '红山区', 59, 255, 3, NULL),
(784, '元宝山区', 59, 255, 3, NULL),
(785, '松山区', 59, 255, 3, NULL),
(786, '阿鲁科尔沁旗', 59, 255, 3, NULL),
(787, '巴林左旗', 59, 255, 3, NULL),
(788, '巴林右旗', 59, 255, 3, NULL),
(789, '林西县', 59, 255, 3, NULL),
(790, '克什克腾旗', 59, 255, 3, NULL),
(791, '翁牛特旗', 59, 255, 3, NULL),
(792, '喀喇沁旗', 59, 255, 3, NULL),
(793, '宁城县', 59, 255, 3, NULL),
(794, '敖汉旗', 59, 255, 3, NULL),
(795, '市辖区', 60, 255, 3, NULL),
(796, '科尔沁区', 60, 255, 3, NULL),
(797, '科尔沁左翼中旗', 60, 255, 3, NULL),
(798, '科尔沁左翼后旗', 60, 255, 3, NULL),
(799, '开鲁县', 60, 255, 3, NULL),
(800, '库伦旗', 60, 255, 3, NULL),
(801, '奈曼旗', 60, 255, 3, NULL),
(802, '扎鲁特旗', 60, 255, 3, NULL),
(803, '通辽经济技术开发区', 60, 255, 3, NULL),
(804, '霍林郭勒市', 60, 255, 3, NULL),
(805, '市辖区', 61, 255, 3, NULL),
(806, '东胜区', 61, 255, 3, NULL),
(807, '康巴什区', 61, 255, 3, NULL),
(808, '达拉特旗', 61, 255, 3, NULL),
(809, '准格尔旗', 61, 255, 3, NULL),
(810, '鄂托克前旗', 61, 255, 3, NULL),
(811, '鄂托克旗', 61, 255, 3, NULL),
(812, '杭锦旗', 61, 255, 3, NULL),
(813, '乌审旗', 61, 255, 3, NULL),
(814, '伊金霍洛旗', 61, 255, 3, NULL),
(815, '市辖区', 62, 255, 3, NULL),
(816, '海拉尔区', 62, 255, 3, NULL),
(817, '扎赉诺尔区', 62, 255, 3, NULL),
(818, '阿荣旗', 62, 255, 3, NULL),
(819, '莫力达瓦达斡尔族自治旗', 62, 255, 3, NULL),
(820, '鄂伦春自治旗', 62, 255, 3, NULL),
(821, '鄂温克族自治旗', 62, 255, 3, NULL),
(822, '陈巴尔虎旗', 62, 255, 3, NULL),
(823, '新巴尔虎左旗', 62, 255, 3, NULL),
(824, '新巴尔虎右旗', 62, 255, 3, NULL),
(825, '满洲里市', 62, 255, 3, NULL),
(826, '牙克石市', 62, 255, 3, NULL),
(827, '扎兰屯市', 62, 255, 3, NULL),
(828, '额尔古纳市', 62, 255, 3, NULL),
(829, '根河市', 62, 255, 3, NULL),
(830, '市辖区', 63, 255, 3, NULL),
(831, '临河区', 63, 255, 3, NULL),
(832, '五原县', 63, 255, 3, NULL),
(833, '磴口县', 63, 255, 3, NULL),
(834, '乌拉特前旗', 63, 255, 3, NULL),
(835, '乌拉特中旗', 63, 255, 3, NULL),
(836, '乌拉特后旗', 63, 255, 3, NULL),
(837, '杭锦后旗', 63, 255, 3, NULL),
(838, '市辖区', 64, 255, 3, NULL),
(839, '集宁区', 64, 255, 3, NULL),
(840, '卓资县', 64, 255, 3, NULL),
(841, '化德县', 64, 255, 3, NULL),
(842, '商都县', 64, 255, 3, NULL),
(843, '兴和县', 64, 255, 3, NULL),
(844, '凉城县', 64, 255, 3, NULL),
(845, '察哈尔右翼前旗', 64, 255, 3, NULL),
(846, '察哈尔右翼中旗', 64, 255, 3, NULL),
(847, '察哈尔右翼后旗', 64, 255, 3, NULL),
(848, '四子王旗', 64, 255, 3, NULL),
(849, '丰镇市', 64, 255, 3, NULL),
(850, '乌兰浩特市', 65, 255, 3, NULL),
(851, '阿尔山市', 65, 255, 3, NULL),
(852, '科尔沁右翼前旗', 65, 255, 3, NULL),
(853, '科尔沁右翼中旗', 65, 255, 3, NULL),
(854, '扎赉特旗', 65, 255, 3, NULL),
(855, '突泉县', 65, 255, 3, NULL),
(856, '二连浩特市', 66, 255, 3, NULL),
(857, '锡林浩特市', 66, 255, 3, NULL),
(858, '阿巴嘎旗', 66, 255, 3, NULL),
(859, '苏尼特左旗', 66, 255, 3, NULL),
(860, '苏尼特右旗', 66, 255, 3, NULL),
(861, '东乌珠穆沁旗', 66, 255, 3, NULL),
(862, '西乌珠穆沁旗', 66, 255, 3, NULL),
(863, '太仆寺旗', 66, 255, 3, NULL),
(864, '镶黄旗', 66, 255, 3, NULL),
(865, '正镶白旗', 66, 255, 3, NULL),
(866, '正蓝旗', 66, 255, 3, NULL),
(867, '多伦县', 66, 255, 3, NULL),
(868, '乌拉盖管委会', 66, 255, 3, NULL),
(869, '阿拉善左旗', 67, 255, 3, NULL),
(870, '阿拉善右旗', 67, 255, 3, NULL),
(871, '额济纳旗', 67, 255, 3, NULL),
(872, '内蒙古阿拉善经济开发区', 67, 255, 3, NULL),
(873, '市辖区', 68, 255, 3, NULL),
(874, '和平区', 68, 255, 3, NULL),
(875, '沈河区', 68, 255, 3, NULL),
(876, '大东区', 68, 255, 3, NULL),
(877, '皇姑区', 68, 255, 3, NULL),
(878, '铁西区', 68, 255, 3, NULL),
(879, '苏家屯区', 68, 255, 3, NULL),
(880, '浑南区', 68, 255, 3, NULL),
(881, '沈北新区', 68, 255, 3, NULL),
(882, '于洪区', 68, 255, 3, NULL),
(883, '辽中区', 68, 255, 3, NULL),
(884, '康平县', 68, 255, 3, NULL),
(885, '法库县', 68, 255, 3, NULL),
(886, '新民市', 68, 255, 3, NULL),
(887, '市辖区', 69, 255, 3, NULL),
(888, '中山区', 69, 255, 3, NULL),
(889, '西岗区', 69, 255, 3, NULL),
(890, '沙河口区', 69, 255, 3, NULL),
(891, '甘井子区', 69, 255, 3, NULL),
(892, '旅顺口区', 69, 255, 3, NULL),
(893, '金州区', 69, 255, 3, NULL),
(894, '普兰店区', 69, 255, 3, NULL),
(895, '长海县', 69, 255, 3, NULL),
(896, '瓦房店市', 69, 255, 3, NULL),
(897, '庄河市', 69, 255, 3, NULL),
(898, '市辖区', 70, 255, 3, NULL),
(899, '铁东区', 70, 255, 3, NULL),
(900, '铁西区', 70, 255, 3, NULL),
(901, '立山区', 70, 255, 3, NULL),
(902, '千山区', 70, 255, 3, NULL),
(903, '台安县', 70, 255, 3, NULL),
(904, '岫岩满族自治县', 70, 255, 3, NULL),
(905, '海城市', 70, 255, 3, NULL),
(906, '市辖区', 71, 255, 3, NULL),
(907, '新抚区', 71, 255, 3, NULL),
(908, '东洲区', 71, 255, 3, NULL),
(909, '望花区', 71, 255, 3, NULL),
(910, '顺城区', 71, 255, 3, NULL),
(911, '抚顺县', 71, 255, 3, NULL),
(912, '新宾满族自治县', 71, 255, 3, NULL),
(913, '清原满族自治县', 71, 255, 3, NULL),
(914, '市辖区', 72, 255, 3, NULL),
(915, '平山区', 72, 255, 3, NULL),
(916, '溪湖区', 72, 255, 3, NULL),
(917, '明山区', 72, 255, 3, NULL),
(918, '南芬区', 72, 255, 3, NULL),
(919, '本溪满族自治县', 72, 255, 3, NULL),
(920, '桓仁满族自治县', 72, 255, 3, NULL),
(921, '市辖区', 73, 255, 3, NULL),
(922, '元宝区', 73, 255, 3, NULL),
(923, '振兴区', 73, 255, 3, NULL),
(924, '振安区', 73, 255, 3, NULL),
(925, '宽甸满族自治县', 73, 255, 3, NULL),
(926, '东港市', 73, 255, 3, NULL),
(927, '凤城市', 73, 255, 3, NULL),
(928, '市辖区', 74, 255, 3, NULL),
(929, '古塔区', 74, 255, 3, NULL),
(930, '凌河区', 74, 255, 3, NULL),
(931, '太和区', 74, 255, 3, NULL),
(932, '黑山县', 74, 255, 3, NULL),
(933, '义县', 74, 255, 3, NULL),
(934, '凌海市', 74, 255, 3, NULL),
(935, '北镇市', 74, 255, 3, NULL),
(936, '市辖区', 75, 255, 3, NULL),
(937, '站前区', 75, 255, 3, NULL),
(938, '西市区', 75, 255, 3, NULL),
(939, '鲅鱼圈区', 75, 255, 3, NULL),
(940, '老边区', 75, 255, 3, NULL),
(941, '盖州市', 75, 255, 3, NULL),
(942, '大石桥市', 75, 255, 3, NULL),
(943, '市辖区', 76, 255, 3, NULL),
(944, '海州区', 76, 255, 3, NULL),
(945, '新邱区', 76, 255, 3, NULL),
(946, '太平区', 76, 255, 3, NULL),
(947, '清河门区', 76, 255, 3, NULL),
(948, '细河区', 76, 255, 3, NULL),
(949, '阜新蒙古族自治县', 76, 255, 3, NULL),
(950, '彰武县', 76, 255, 3, NULL),
(951, '市辖区', 77, 255, 3, NULL),
(952, '白塔区', 77, 255, 3, NULL),
(953, '文圣区', 77, 255, 3, NULL),
(954, '宏伟区', 77, 255, 3, NULL),
(955, '弓长岭区', 77, 255, 3, NULL),
(956, '太子河区', 77, 255, 3, NULL),
(957, '辽阳县', 77, 255, 3, NULL),
(958, '灯塔市', 77, 255, 3, NULL),
(959, '市辖区', 78, 255, 3, NULL),
(960, '双台子区', 78, 255, 3, NULL),
(961, '兴隆台区', 78, 255, 3, NULL),
(962, '大洼区', 78, 255, 3, NULL),
(963, '盘山县', 78, 255, 3, NULL),
(964, '市辖区', 79, 255, 3, NULL),
(965, '银州区', 79, 255, 3, NULL),
(966, '清河区', 79, 255, 3, NULL),
(967, '铁岭县', 79, 255, 3, NULL),
(968, '西丰县', 79, 255, 3, NULL),
(969, '昌图县', 79, 255, 3, NULL),
(970, '调兵山市', 79, 255, 3, NULL),
(971, '开原市', 79, 255, 3, NULL),
(972, '市辖区', 80, 255, 3, NULL),
(973, '双塔区', 80, 255, 3, NULL),
(974, '龙城区', 80, 255, 3, NULL),
(975, '朝阳县', 80, 255, 3, NULL),
(976, '建平县', 80, 255, 3, NULL),
(977, '喀喇沁左翼蒙古族自治县', 80, 255, 3, NULL),
(978, '北票市', 80, 255, 3, NULL),
(979, '凌源市', 80, 255, 3, NULL),
(980, '市辖区', 81, 255, 3, NULL),
(981, '连山区', 81, 255, 3, NULL),
(982, '龙港区', 81, 255, 3, NULL),
(983, '南票区', 81, 255, 3, NULL),
(984, '绥中县', 81, 255, 3, NULL),
(985, '建昌县', 81, 255, 3, NULL),
(986, '兴城市', 81, 255, 3, NULL),
(987, '市辖区', 82, 255, 3, NULL),
(988, '南关区', 82, 255, 3, NULL),
(989, '宽城区', 82, 255, 3, NULL),
(990, '朝阳区', 82, 255, 3, NULL),
(991, '二道区', 82, 255, 3, NULL),
(992, '绿园区', 82, 255, 3, NULL),
(993, '双阳区', 82, 255, 3, NULL),
(994, '九台区', 82, 255, 3, NULL),
(995, '农安县', 82, 255, 3, NULL),
(996, '长春经济技术开发区', 82, 255, 3, NULL),
(997, '长春净月高新技术产业开发区', 82, 255, 3, NULL),
(998, '长春高新技术产业开发区', 82, 255, 3, NULL),
(999, '长春汽车经济技术开发区', 82, 255, 3, NULL),
(1000, '榆树市', 82, 255, 3, NULL),
(1001, '德惠市', 82, 255, 3, NULL),
(1002, '公主岭市', 82, 255, 3, NULL),
(1003, '市辖区', 83, 255, 3, NULL),
(1004, '昌邑区', 83, 255, 3, NULL),
(1005, '龙潭区', 83, 255, 3, NULL),
(1006, '船营区', 83, 255, 3, NULL),
(1007, '丰满区', 83, 255, 3, NULL),
(1008, '永吉县', 83, 255, 3, NULL),
(1009, '吉林经济开发区', 83, 255, 3, NULL),
(1010, '吉林高新技术产业开发区', 83, 255, 3, NULL),
(1011, '吉林中国新加坡食品区', 83, 255, 3, NULL),
(1012, '蛟河市', 83, 255, 3, NULL),
(1013, '桦甸市', 83, 255, 3, NULL),
(1014, '舒兰市', 83, 255, 3, NULL),
(1015, '磐石市', 83, 255, 3, NULL),
(1016, '市辖区', 84, 255, 3, NULL),
(1017, '铁西区', 84, 255, 3, NULL),
(1018, '铁东区', 84, 255, 3, NULL),
(1019, '梨树县', 84, 255, 3, NULL),
(1020, '伊通满族自治县', 84, 255, 3, NULL),
(1021, '双辽市', 84, 255, 3, NULL),
(1022, '市辖区', 85, 255, 3, NULL),
(1023, '龙山区', 85, 255, 3, NULL),
(1024, '西安区', 85, 255, 3, NULL),
(1025, '东丰县', 85, 255, 3, NULL),
(1026, '东辽县', 85, 255, 3, NULL),
(1027, '市辖区', 86, 255, 3, NULL),
(1028, '东昌区', 86, 255, 3, NULL),
(1029, '二道江区', 86, 255, 3, NULL),
(1030, '通化县', 86, 255, 3, NULL),
(1031, '辉南县', 86, 255, 3, NULL),
(1032, '柳河县', 86, 255, 3, NULL),
(1033, '梅河口市', 86, 255, 3, NULL),
(1034, '集安市', 86, 255, 3, NULL),
(1035, '市辖区', 87, 255, 3, NULL),
(1036, '浑江区', 87, 255, 3, NULL),
(1037, '江源区', 87, 255, 3, NULL),
(1038, '抚松县', 87, 255, 3, NULL),
(1039, '靖宇县', 87, 255, 3, NULL),
(1040, '长白朝鲜族自治县', 87, 255, 3, NULL),
(1041, '临江市', 87, 255, 3, NULL),
(1042, '市辖区', 88, 255, 3, NULL),
(1043, '宁江区', 88, 255, 3, NULL),
(1044, '前郭尔罗斯蒙古族自治县', 88, 255, 3, NULL),
(1045, '长岭县', 88, 255, 3, NULL),
(1046, '乾安县', 88, 255, 3, NULL),
(1047, '吉林松原经济开发区', 88, 255, 3, NULL),
(1048, '扶余市', 88, 255, 3, NULL),
(1049, '市辖区', 89, 255, 3, NULL),
(1050, '洮北区', 89, 255, 3, NULL),
(1051, '镇赉县', 89, 255, 3, NULL),
(1052, '通榆县', 89, 255, 3, NULL),
(1053, '吉林白城经济开发区', 89, 255, 3, NULL),
(1054, '洮南市', 89, 255, 3, NULL),
(1055, '大安市', 89, 255, 3, NULL),
(1056, '延吉市', 90, 255, 3, NULL),
(1057, '图们市', 90, 255, 3, NULL),
(1058, '敦化市', 90, 255, 3, NULL),
(1059, '珲春市', 90, 255, 3, NULL),
(1060, '龙井市', 90, 255, 3, NULL),
(1061, '和龙市', 90, 255, 3, NULL),
(1062, '汪清县', 90, 255, 3, NULL),
(1063, '安图县', 90, 255, 3, NULL),
(1064, '市辖区', 91, 255, 3, NULL),
(1065, '道里区', 91, 255, 3, NULL),
(1066, '南岗区', 91, 255, 3, NULL),
(1067, '道外区', 91, 255, 3, NULL),
(1068, '平房区', 91, 255, 3, NULL),
(1069, '松北区', 91, 255, 3, NULL),
(1070, '香坊区', 91, 255, 3, NULL),
(1071, '呼兰区', 91, 255, 3, NULL),
(1072, '阿城区', 91, 255, 3, NULL),
(1073, '双城区', 91, 255, 3, NULL),
(1074, '依兰县', 91, 255, 3, NULL),
(1075, '方正县', 91, 255, 3, NULL),
(1076, '宾县', 91, 255, 3, NULL),
(1077, '巴彦县', 91, 255, 3, NULL),
(1078, '木兰县', 91, 255, 3, NULL),
(1079, '通河县', 91, 255, 3, NULL),
(1080, '延寿县', 91, 255, 3, NULL),
(1081, '尚志市', 91, 255, 3, NULL),
(1082, '五常市', 91, 255, 3, NULL),
(1083, '市辖区', 92, 255, 3, NULL),
(1084, '龙沙区', 92, 255, 3, NULL),
(1085, '建华区', 92, 255, 3, NULL),
(1086, '铁锋区', 92, 255, 3, NULL),
(1087, '昂昂溪区', 92, 255, 3, NULL),
(1088, '富拉尔基区', 92, 255, 3, NULL),
(1089, '碾子山区', 92, 255, 3, NULL),
(1090, '梅里斯达斡尔族区', 92, 255, 3, NULL),
(1091, '龙江县', 92, 255, 3, NULL),
(1092, '依安县', 92, 255, 3, NULL),
(1093, '泰来县', 92, 255, 3, NULL),
(1094, '甘南县', 92, 255, 3, NULL),
(1095, '富裕县', 92, 255, 3, NULL),
(1096, '克山县', 92, 255, 3, NULL),
(1097, '克东县', 92, 255, 3, NULL),
(1098, '拜泉县', 92, 255, 3, NULL),
(1099, '讷河市', 92, 255, 3, NULL),
(1100, '市辖区', 93, 255, 3, NULL),
(1101, '鸡冠区', 93, 255, 3, NULL),
(1102, '恒山区', 93, 255, 3, NULL),
(1103, '滴道区', 93, 255, 3, NULL),
(1104, '梨树区', 93, 255, 3, NULL),
(1105, '城子河区', 93, 255, 3, NULL),
(1106, '麻山区', 93, 255, 3, NULL),
(1107, '鸡东县', 93, 255, 3, NULL),
(1108, '虎林市', 93, 255, 3, NULL),
(1109, '密山市', 93, 255, 3, NULL),
(1110, '市辖区', 94, 255, 3, NULL),
(1111, '向阳区', 94, 255, 3, NULL),
(1112, '工农区', 94, 255, 3, NULL),
(1113, '南山区', 94, 255, 3, NULL),
(1114, '兴安区', 94, 255, 3, NULL),
(1115, '东山区', 94, 255, 3, NULL),
(1116, '兴山区', 94, 255, 3, NULL),
(1117, '萝北县', 94, 255, 3, NULL),
(1118, '绥滨县', 94, 255, 3, NULL),
(1119, '市辖区', 95, 255, 3, NULL),
(1120, '尖山区', 95, 255, 3, NULL),
(1121, '岭东区', 95, 255, 3, NULL),
(1122, '四方台区', 95, 255, 3, NULL),
(1123, '宝山区', 95, 255, 3, NULL),
(1124, '集贤县', 95, 255, 3, NULL),
(1125, '友谊县', 95, 255, 3, NULL),
(1126, '宝清县', 95, 255, 3, NULL),
(1127, '饶河县', 95, 255, 3, NULL),
(1128, '市辖区', 96, 255, 3, NULL),
(1129, '萨尔图区', 96, 255, 3, NULL),
(1130, '龙凤区', 96, 255, 3, NULL),
(1131, '让胡路区', 96, 255, 3, NULL),
(1132, '红岗区', 96, 255, 3, NULL),
(1133, '大同区', 96, 255, 3, NULL),
(1134, '肇州县', 96, 255, 3, NULL),
(1135, '肇源县', 96, 255, 3, NULL),
(1136, '林甸县', 96, 255, 3, NULL),
(1137, '杜尔伯特蒙古族自治县', 96, 255, 3, NULL),
(1138, '大庆高新技术产业开发区', 96, 255, 3, NULL),
(1139, '市辖区', 97, 255, 3, NULL),
(1140, '伊美区', 97, 255, 3, NULL),
(1141, '乌翠区', 97, 255, 3, NULL),
(1142, '友好区', 97, 255, 3, NULL),
(1143, '嘉荫县', 97, 255, 3, NULL),
(1144, '汤旺县', 97, 255, 3, NULL),
(1145, '丰林县', 97, 255, 3, NULL),
(1146, '大箐山县', 97, 255, 3, NULL),
(1147, '南岔县', 97, 255, 3, NULL),
(1148, '金林区', 97, 255, 3, NULL),
(1149, '铁力市', 97, 255, 3, NULL),
(1150, '市辖区', 98, 255, 3, NULL),
(1151, '向阳区', 98, 255, 3, NULL),
(1152, '前进区', 98, 255, 3, NULL),
(1153, '东风区', 98, 255, 3, NULL),
(1154, '郊区', 98, 255, 3, NULL),
(1155, '桦南县', 98, 255, 3, NULL),
(1156, '桦川县', 98, 255, 3, NULL),
(1157, '汤原县', 98, 255, 3, NULL),
(1158, '同江市', 98, 255, 3, NULL),
(1159, '富锦市', 98, 255, 3, NULL),
(1160, '抚远市', 98, 255, 3, NULL),
(1161, '市辖区', 99, 255, 3, NULL),
(1162, '新兴区', 99, 255, 3, NULL),
(1163, '桃山区', 99, 255, 3, NULL),
(1164, '茄子河区', 99, 255, 3, NULL),
(1165, '勃利县', 99, 255, 3, NULL),
(1166, '市辖区', 100, 255, 3, NULL),
(1167, '东安区', 100, 255, 3, NULL),
(1168, '阳明区', 100, 255, 3, NULL),
(1169, '爱民区', 100, 255, 3, NULL),
(1170, '西安区', 100, 255, 3, NULL),
(1171, '林口县', 100, 255, 3, NULL),
(1172, '牡丹江经济技术开发区', 100, 255, 3, NULL),
(1173, '绥芬河市', 100, 255, 3, NULL),
(1174, '海林市', 100, 255, 3, NULL),
(1175, '宁安市', 100, 255, 3, NULL),
(1176, '穆棱市', 100, 255, 3, NULL),
(1177, '东宁市', 100, 255, 3, NULL),
(1178, '市辖区', 101, 255, 3, NULL),
(1179, '爱辉区', 101, 255, 3, NULL),
(1180, '逊克县', 101, 255, 3, NULL),
(1181, '孙吴县', 101, 255, 3, NULL),
(1182, '北安市', 101, 255, 3, NULL),
(1183, '五大连池市', 101, 255, 3, NULL),
(1184, '嫩江市', 101, 255, 3, NULL),
(1185, '市辖区', 102, 255, 3, NULL),
(1186, '北林区', 102, 255, 3, NULL),
(1187, '望奎县', 102, 255, 3, NULL),
(1188, '兰西县', 102, 255, 3, NULL),
(1189, '青冈县', 102, 255, 3, NULL),
(1190, '庆安县', 102, 255, 3, NULL),
(1191, '明水县', 102, 255, 3, NULL),
(1192, '绥棱县', 102, 255, 3, NULL),
(1193, '安达市', 102, 255, 3, NULL),
(1194, '肇东市', 102, 255, 3, NULL),
(1195, '海伦市', 102, 255, 3, NULL),
(1196, '漠河市', 103, 255, 3, NULL),
(1197, '呼玛县', 103, 255, 3, NULL),
(1198, '塔河县', 103, 255, 3, NULL),
(1199, '加格达奇区', 103, 255, 3, NULL),
(1200, '松岭区', 103, 255, 3, NULL),
(1201, '新林区', 103, 255, 3, NULL),
(1202, '呼中区', 103, 255, 3, NULL),
(1203, '黄浦区', 104, 255, 3, NULL),
(1204, '徐汇区', 104, 255, 3, NULL),
(1205, '长宁区', 104, 255, 3, NULL),
(1206, '静安区', 104, 255, 3, NULL),
(1207, '普陀区', 104, 255, 3, NULL),
(1208, '虹口区', 104, 255, 3, NULL),
(1209, '杨浦区', 104, 255, 3, NULL),
(1210, '闵行区', 104, 255, 3, NULL),
(1211, '宝山区', 104, 255, 3, NULL),
(1212, '嘉定区', 104, 255, 3, NULL),
(1213, '浦东新区', 104, 255, 3, NULL),
(1214, '金山区', 104, 255, 3, NULL),
(1215, '松江区', 104, 255, 3, NULL),
(1216, '青浦区', 104, 255, 3, NULL),
(1217, '奉贤区', 104, 255, 3, NULL),
(1218, '崇明区', 104, 255, 3, NULL),
(1219, '市辖区', 105, 255, 3, NULL),
(1220, '玄武区', 105, 255, 3, NULL),
(1221, '秦淮区', 105, 255, 3, NULL),
(1222, '建邺区', 105, 255, 3, NULL),
(1223, '鼓楼区', 105, 255, 3, NULL),
(1224, '浦口区', 105, 255, 3, NULL),
(1225, '栖霞区', 105, 255, 3, NULL),
(1226, '雨花台区', 105, 255, 3, NULL),
(1227, '江宁区', 105, 255, 3, NULL),
(1228, '六合区', 105, 255, 3, NULL),
(1229, '溧水区', 105, 255, 3, NULL),
(1230, '高淳区', 105, 255, 3, NULL),
(1231, '市辖区', 106, 255, 3, NULL),
(1232, '锡山区', 106, 255, 3, NULL),
(1233, '惠山区', 106, 255, 3, NULL),
(1234, '滨湖区', 106, 255, 3, NULL),
(1235, '梁溪区', 106, 255, 3, NULL),
(1236, '新吴区', 106, 255, 3, NULL),
(1237, '江阴市', 106, 255, 3, NULL),
(1238, '宜兴市', 106, 255, 3, NULL),
(1239, '市辖区', 107, 255, 3, NULL),
(1240, '鼓楼区', 107, 255, 3, NULL),
(1241, '云龙区', 107, 255, 3, NULL),
(1242, '贾汪区', 107, 255, 3, NULL),
(1243, '泉山区', 107, 255, 3, NULL),
(1244, '铜山区', 107, 255, 3, NULL),
(1245, '丰县', 107, 255, 3, NULL),
(1246, '沛县', 107, 255, 3, NULL),
(1247, '睢宁县', 107, 255, 3, NULL),
(1248, '徐州经济技术开发区', 107, 255, 3, NULL),
(1249, '新沂市', 107, 255, 3, NULL),
(1250, '邳州市', 107, 255, 3, NULL),
(1251, '市辖区', 108, 255, 3, NULL),
(1252, '天宁区', 108, 255, 3, NULL),
(1253, '钟楼区', 108, 255, 3, NULL),
(1254, '新北区', 108, 255, 3, NULL),
(1255, '武进区', 108, 255, 3, NULL),
(1256, '金坛区', 108, 255, 3, NULL),
(1257, '溧阳市', 108, 255, 3, NULL),
(1258, '市辖区', 109, 255, 3, NULL),
(1259, '虎丘区', 109, 255, 3, NULL),
(1260, '吴中区', 109, 255, 3, NULL),
(1261, '相城区', 109, 255, 3, NULL),
(1262, '姑苏区', 109, 255, 3, NULL),
(1263, '吴江区', 109, 255, 3, NULL),
(1264, '苏州工业园区', 109, 255, 3, NULL),
(1265, '常熟市', 109, 255, 3, NULL),
(1266, '张家港市', 109, 255, 3, NULL),
(1267, '昆山市', 109, 255, 3, NULL),
(1268, '太仓市', 109, 255, 3, NULL),
(1269, '市辖区', 110, 255, 3, NULL),
(1270, '崇川区', 110, 255, 3, NULL),
(1271, '港闸区', 110, 255, 3, NULL),
(1272, '通州区', 110, 255, 3, NULL),
(1273, '如东县', 110, 255, 3, NULL),
(1274, '南通经济技术开发区', 110, 255, 3, NULL),
(1275, '启东市', 110, 255, 3, NULL),
(1276, '如皋市', 110, 255, 3, NULL),
(1277, '海门市', 110, 255, 3, NULL),
(1278, '海安市', 110, 255, 3, NULL),
(1279, '市辖区', 111, 255, 3, NULL),
(1280, '连云区', 111, 255, 3, NULL),
(1281, '海州区', 111, 255, 3, NULL),
(1282, '赣榆区', 111, 255, 3, NULL),
(1283, '东海县', 111, 255, 3, NULL),
(1284, '灌云县', 111, 255, 3, NULL),
(1285, '灌南县', 111, 255, 3, NULL),
(1286, '连云港经济技术开发区', 111, 255, 3, NULL),
(1287, '连云港高新技术产业开发区', 111, 255, 3, NULL),
(1288, '市辖区', 112, 255, 3, NULL),
(1289, '淮安区', 112, 255, 3, NULL),
(1290, '淮阴区', 112, 255, 3, NULL),
(1291, '清江浦区', 112, 255, 3, NULL),
(1292, '洪泽区', 112, 255, 3, NULL),
(1293, '涟水县', 112, 255, 3, NULL),
(1294, '盱眙县', 112, 255, 3, NULL),
(1295, '金湖县', 112, 255, 3, NULL),
(1296, '淮安经济技术开发区', 112, 255, 3, NULL),
(1297, '市辖区', 113, 255, 3, NULL),
(1298, '亭湖区', 113, 255, 3, NULL),
(1299, '盐都区', 113, 255, 3, NULL),
(1300, '大丰区', 113, 255, 3, NULL),
(1301, '响水县', 113, 255, 3, NULL),
(1302, '滨海县', 113, 255, 3, NULL),
(1303, '阜宁县', 113, 255, 3, NULL),
(1304, '射阳县', 113, 255, 3, NULL),
(1305, '建湖县', 113, 255, 3, NULL),
(1306, '盐城经济技术开发区', 113, 255, 3, NULL);
INSERT INTO `#__area` (`area_id`, `area_name`, `area_parent_id`, `area_sort`, `area_deep`, `area_region`) VALUES
(1307, '东台市', 113, 255, 3, NULL),
(1308, '市辖区', 114, 255, 3, NULL),
(1309, '广陵区', 114, 255, 3, NULL),
(1310, '邗江区', 114, 255, 3, NULL),
(1311, '江都区', 114, 255, 3, NULL),
(1312, '宝应县', 114, 255, 3, NULL),
(1313, '扬州经济技术开发区', 114, 255, 3, NULL),
(1314, '仪征市', 114, 255, 3, NULL),
(1315, '高邮市', 114, 255, 3, NULL),
(1316, '市辖区', 115, 255, 3, NULL),
(1317, '京口区', 115, 255, 3, NULL),
(1318, '润州区', 115, 255, 3, NULL),
(1319, '丹徒区', 115, 255, 3, NULL),
(1320, '镇江新区', 115, 255, 3, NULL),
(1321, '丹阳市', 115, 255, 3, NULL),
(1322, '扬中市', 115, 255, 3, NULL),
(1323, '句容市', 115, 255, 3, NULL),
(1324, '市辖区', 116, 255, 3, NULL),
(1325, '海陵区', 116, 255, 3, NULL),
(1326, '高港区', 116, 255, 3, NULL),
(1327, '姜堰区', 116, 255, 3, NULL),
(1328, '泰州医药高新技术产业开发区', 116, 255, 3, NULL),
(1329, '兴化市', 116, 255, 3, NULL),
(1330, '靖江市', 116, 255, 3, NULL),
(1331, '泰兴市', 116, 255, 3, NULL),
(1332, '市辖区', 117, 255, 3, NULL),
(1333, '宿城区', 117, 255, 3, NULL),
(1334, '宿豫区', 117, 255, 3, NULL),
(1335, '沭阳县', 117, 255, 3, NULL),
(1336, '泗阳县', 117, 255, 3, NULL),
(1337, '泗洪县', 117, 255, 3, NULL),
(1338, '宿迁经济技术开发区', 117, 255, 3, NULL),
(1339, '市辖区', 118, 255, 3, NULL),
(1340, '上城区', 118, 255, 3, NULL),
(1341, '下城区', 118, 255, 3, NULL),
(1342, '江干区', 118, 255, 3, NULL),
(1343, '拱墅区', 118, 255, 3, NULL),
(1344, '西湖区', 118, 255, 3, NULL),
(1345, '滨江区', 118, 255, 3, NULL),
(1346, '萧山区', 118, 255, 3, NULL),
(1347, '余杭区', 118, 255, 3, NULL),
(1348, '富阳区', 118, 255, 3, NULL),
(1349, '临安区', 118, 255, 3, NULL),
(1350, '桐庐县', 118, 255, 3, NULL),
(1351, '淳安县', 118, 255, 3, NULL),
(1352, '建德市', 118, 255, 3, NULL),
(1353, '市辖区', 119, 255, 3, NULL),
(1354, '海曙区', 119, 255, 3, NULL),
(1355, '江北区', 119, 255, 3, NULL),
(1356, '北仑区', 119, 255, 3, NULL),
(1357, '镇海区', 119, 255, 3, NULL),
(1358, '鄞州区', 119, 255, 3, NULL),
(1359, '奉化区', 119, 255, 3, NULL),
(1360, '象山县', 119, 255, 3, NULL),
(1361, '宁海县', 119, 255, 3, NULL),
(1362, '余姚市', 119, 255, 3, NULL),
(1363, '慈溪市', 119, 255, 3, NULL),
(1364, '市辖区', 120, 255, 3, NULL),
(1365, '鹿城区', 120, 255, 3, NULL),
(1366, '龙湾区', 120, 255, 3, NULL),
(1367, '瓯海区', 120, 255, 3, NULL),
(1368, '洞头区', 120, 255, 3, NULL),
(1369, '永嘉县', 120, 255, 3, NULL),
(1370, '平阳县', 120, 255, 3, NULL),
(1371, '苍南县', 120, 255, 3, NULL),
(1372, '文成县', 120, 255, 3, NULL),
(1373, '泰顺县', 120, 255, 3, NULL),
(1374, '温州经济技术开发区', 120, 255, 3, NULL),
(1375, '瑞安市', 120, 255, 3, NULL),
(1376, '乐清市', 120, 255, 3, NULL),
(1377, '龙港市', 120, 255, 3, NULL),
(1378, '市辖区', 121, 255, 3, NULL),
(1379, '南湖区', 121, 255, 3, NULL),
(1380, '秀洲区', 121, 255, 3, NULL),
(1381, '嘉善县', 121, 255, 3, NULL),
(1382, '海盐县', 121, 255, 3, NULL),
(1383, '海宁市', 121, 255, 3, NULL),
(1384, '平湖市', 121, 255, 3, NULL),
(1385, '桐乡市', 121, 255, 3, NULL),
(1386, '市辖区', 122, 255, 3, NULL),
(1387, '吴兴区', 122, 255, 3, NULL),
(1388, '南浔区', 122, 255, 3, NULL),
(1389, '德清县', 122, 255, 3, NULL),
(1390, '长兴县', 122, 255, 3, NULL),
(1391, '安吉县', 122, 255, 3, NULL),
(1392, '市辖区', 123, 255, 3, NULL),
(1393, '越城区', 123, 255, 3, NULL),
(1394, '柯桥区', 123, 255, 3, NULL),
(1395, '上虞区', 123, 255, 3, NULL),
(1396, '新昌县', 123, 255, 3, NULL),
(1397, '诸暨市', 123, 255, 3, NULL),
(1398, '嵊州市', 123, 255, 3, NULL),
(1399, '市辖区', 124, 255, 3, NULL),
(1400, '婺城区', 124, 255, 3, NULL),
(1401, '金东区', 124, 255, 3, NULL),
(1402, '武义县', 124, 255, 3, NULL),
(1403, '浦江县', 124, 255, 3, NULL),
(1404, '磐安县', 124, 255, 3, NULL),
(1405, '兰溪市', 124, 255, 3, NULL),
(1406, '义乌市', 124, 255, 3, NULL),
(1407, '东阳市', 124, 255, 3, NULL),
(1408, '永康市', 124, 255, 3, NULL),
(1409, '市辖区', 125, 255, 3, NULL),
(1410, '柯城区', 125, 255, 3, NULL),
(1411, '衢江区', 125, 255, 3, NULL),
(1412, '常山县', 125, 255, 3, NULL),
(1413, '开化县', 125, 255, 3, NULL),
(1414, '龙游县', 125, 255, 3, NULL),
(1415, '江山市', 125, 255, 3, NULL),
(1416, '市辖区', 126, 255, 3, NULL),
(1417, '定海区', 126, 255, 3, NULL),
(1418, '普陀区', 126, 255, 3, NULL),
(1419, '岱山县', 126, 255, 3, NULL),
(1420, '嵊泗县', 126, 255, 3, NULL),
(1421, '市辖区', 127, 255, 3, NULL),
(1422, '椒江区', 127, 255, 3, NULL),
(1423, '黄岩区', 127, 255, 3, NULL),
(1424, '路桥区', 127, 255, 3, NULL),
(1425, '三门县', 127, 255, 3, NULL),
(1426, '天台县', 127, 255, 3, NULL),
(1427, '仙居县', 127, 255, 3, NULL),
(1428, '温岭市', 127, 255, 3, NULL),
(1429, '临海市', 127, 255, 3, NULL),
(1430, '玉环市', 127, 255, 3, NULL),
(1431, '市辖区', 128, 255, 3, NULL),
(1432, '莲都区', 128, 255, 3, NULL),
(1433, '青田县', 128, 255, 3, NULL),
(1434, '缙云县', 128, 255, 3, NULL),
(1435, '遂昌县', 128, 255, 3, NULL),
(1436, '松阳县', 128, 255, 3, NULL),
(1437, '云和县', 128, 255, 3, NULL),
(1438, '庆元县', 128, 255, 3, NULL),
(1439, '景宁畲族自治县', 128, 255, 3, NULL),
(1440, '龙泉市', 128, 255, 3, NULL),
(1441, '市辖区', 129, 255, 3, NULL),
(1442, '瑶海区', 129, 255, 3, NULL),
(1443, '庐阳区', 129, 255, 3, NULL),
(1444, '蜀山区', 129, 255, 3, NULL),
(1445, '包河区', 129, 255, 3, NULL),
(1446, '长丰县', 129, 255, 3, NULL),
(1447, '肥东县', 129, 255, 3, NULL),
(1448, '肥西县', 129, 255, 3, NULL),
(1449, '庐江县', 129, 255, 3, NULL),
(1450, '合肥高新技术产业开发区', 129, 255, 3, NULL),
(1451, '合肥经济技术开发区', 129, 255, 3, NULL),
(1452, '合肥新站高新技术产业开发区', 129, 255, 3, NULL),
(1453, '巢湖市', 129, 255, 3, NULL),
(1454, '市辖区', 130, 255, 3, NULL),
(1455, '镜湖区', 130, 255, 3, NULL),
(1456, '弋江区', 130, 255, 3, NULL),
(1457, '鸠江区', 130, 255, 3, NULL),
(1458, '三山区', 130, 255, 3, NULL),
(1459, '芜湖县', 130, 255, 3, NULL),
(1460, '繁昌县', 130, 255, 3, NULL),
(1461, '南陵县', 130, 255, 3, NULL),
(1462, '芜湖经济技术开发区', 130, 255, 3, NULL),
(1463, '安徽芜湖长江大桥经济开发区', 130, 255, 3, NULL),
(1464, '无为市', 130, 255, 3, NULL),
(1465, '市辖区', 131, 255, 3, NULL),
(1466, '龙子湖区', 131, 255, 3, NULL),
(1467, '蚌山区', 131, 255, 3, NULL),
(1468, '禹会区', 131, 255, 3, NULL),
(1469, '淮上区', 131, 255, 3, NULL),
(1470, '怀远县', 131, 255, 3, NULL),
(1471, '五河县', 131, 255, 3, NULL),
(1472, '固镇县', 131, 255, 3, NULL),
(1473, '蚌埠市高新技术开发区', 131, 255, 3, NULL),
(1474, '蚌埠市经济开发区', 131, 255, 3, NULL),
(1475, '市辖区', 132, 255, 3, NULL),
(1476, '大通区', 132, 255, 3, NULL),
(1477, '田家庵区', 132, 255, 3, NULL),
(1478, '谢家集区', 132, 255, 3, NULL),
(1479, '八公山区', 132, 255, 3, NULL),
(1480, '潘集区', 132, 255, 3, NULL),
(1481, '凤台县', 132, 255, 3, NULL),
(1482, '寿县', 132, 255, 3, NULL),
(1483, '市辖区', 133, 255, 3, NULL),
(1484, '花山区', 133, 255, 3, NULL),
(1485, '雨山区', 133, 255, 3, NULL),
(1486, '博望区', 133, 255, 3, NULL),
(1487, '当涂县', 133, 255, 3, NULL),
(1488, '含山县', 133, 255, 3, NULL),
(1489, '和县', 133, 255, 3, NULL),
(1490, '市辖区', 134, 255, 3, NULL),
(1491, '杜集区', 134, 255, 3, NULL),
(1492, '相山区', 134, 255, 3, NULL),
(1493, '烈山区', 134, 255, 3, NULL),
(1494, '濉溪县', 134, 255, 3, NULL),
(1495, '市辖区', 135, 255, 3, NULL),
(1496, '铜官区', 135, 255, 3, NULL),
(1497, '义安区', 135, 255, 3, NULL),
(1498, '郊区', 135, 255, 3, NULL),
(1499, '枞阳县', 135, 255, 3, NULL),
(1500, '市辖区', 136, 255, 3, NULL),
(1501, '迎江区', 136, 255, 3, NULL),
(1502, '大观区', 136, 255, 3, NULL),
(1503, '宜秀区', 136, 255, 3, NULL),
(1504, '怀宁县', 136, 255, 3, NULL),
(1505, '太湖县', 136, 255, 3, NULL),
(1506, '宿松县', 136, 255, 3, NULL),
(1507, '望江县', 136, 255, 3, NULL),
(1508, '岳西县', 136, 255, 3, NULL),
(1509, '安徽安庆经济开发区', 136, 255, 3, NULL),
(1510, '桐城市', 136, 255, 3, NULL),
(1511, '潜山市', 136, 255, 3, NULL),
(1512, '市辖区', 137, 255, 3, NULL),
(1513, '屯溪区', 137, 255, 3, NULL),
(1514, '黄山区', 137, 255, 3, NULL),
(1515, '徽州区', 137, 255, 3, NULL),
(1516, '歙县', 137, 255, 3, NULL),
(1517, '休宁县', 137, 255, 3, NULL),
(1518, '黟县', 137, 255, 3, NULL),
(1519, '祁门县', 137, 255, 3, NULL),
(1520, '市辖区', 138, 255, 3, NULL),
(1521, '琅琊区', 138, 255, 3, NULL),
(1522, '南谯区', 138, 255, 3, NULL),
(1523, '来安县', 138, 255, 3, NULL),
(1524, '全椒县', 138, 255, 3, NULL),
(1525, '定远县', 138, 255, 3, NULL),
(1526, '凤阳县', 138, 255, 3, NULL),
(1527, '苏滁现代产业园', 138, 255, 3, NULL),
(1528, '滁州经济技术开发区', 138, 255, 3, NULL),
(1529, '天长市', 138, 255, 3, NULL),
(1530, '明光市', 138, 255, 3, NULL),
(1531, '市辖区', 139, 255, 3, NULL),
(1532, '颍州区', 139, 255, 3, NULL),
(1533, '颍东区', 139, 255, 3, NULL),
(1534, '颍泉区', 139, 255, 3, NULL),
(1535, '临泉县', 139, 255, 3, NULL),
(1536, '太和县', 139, 255, 3, NULL),
(1537, '阜南县', 139, 255, 3, NULL),
(1538, '颍上县', 139, 255, 3, NULL),
(1539, '阜阳合肥现代产业园区', 139, 255, 3, NULL),
(1540, '阜阳经济技术开发区', 139, 255, 3, NULL),
(1541, '界首市', 139, 255, 3, NULL),
(1542, '市辖区', 140, 255, 3, NULL),
(1543, '埇桥区', 140, 255, 3, NULL),
(1544, '砀山县', 140, 255, 3, NULL),
(1545, '萧县', 140, 255, 3, NULL),
(1546, '灵璧县', 140, 255, 3, NULL),
(1547, '泗县', 140, 255, 3, NULL),
(1548, '宿州马鞍山现代产业园区', 140, 255, 3, NULL),
(1549, '宿州经济技术开发区', 140, 255, 3, NULL),
(1550, '市辖区', 141, 255, 3, NULL),
(1551, '金安区', 141, 255, 3, NULL),
(1552, '裕安区', 141, 255, 3, NULL),
(1553, '叶集区', 141, 255, 3, NULL),
(1554, '霍邱县', 141, 255, 3, NULL),
(1555, '舒城县', 141, 255, 3, NULL),
(1556, '金寨县', 141, 255, 3, NULL),
(1557, '霍山县', 141, 255, 3, NULL),
(1558, '市辖区', 142, 255, 3, NULL),
(1559, '谯城区', 142, 255, 3, NULL),
(1560, '涡阳县', 142, 255, 3, NULL),
(1561, '蒙城县', 142, 255, 3, NULL),
(1562, '利辛县', 142, 255, 3, NULL),
(1563, '市辖区', 143, 255, 3, NULL),
(1564, '贵池区', 143, 255, 3, NULL),
(1565, '东至县', 143, 255, 3, NULL),
(1566, '石台县', 143, 255, 3, NULL),
(1567, '青阳县', 143, 255, 3, NULL),
(1568, '市辖区', 144, 255, 3, NULL),
(1569, '宣州区', 144, 255, 3, NULL),
(1570, '郎溪县', 144, 255, 3, NULL),
(1571, '泾县', 144, 255, 3, NULL),
(1572, '绩溪县', 144, 255, 3, NULL),
(1573, '旌德县', 144, 255, 3, NULL),
(1574, '宣城市经济开发区', 144, 255, 3, NULL),
(1575, '宁国市', 144, 255, 3, NULL),
(1576, '广德市', 144, 255, 3, NULL),
(1577, '市辖区', 145, 255, 3, NULL),
(1578, '鼓楼区', 145, 255, 3, NULL),
(1579, '台江区', 145, 255, 3, NULL),
(1580, '仓山区', 145, 255, 3, NULL),
(1581, '马尾区', 145, 255, 3, NULL),
(1582, '晋安区', 145, 255, 3, NULL),
(1583, '长乐区', 145, 255, 3, NULL),
(1584, '闽侯县', 145, 255, 3, NULL),
(1585, '连江县', 145, 255, 3, NULL),
(1586, '罗源县', 145, 255, 3, NULL),
(1587, '闽清县', 145, 255, 3, NULL),
(1588, '永泰县', 145, 255, 3, NULL),
(1589, '平潭县', 145, 255, 3, NULL),
(1590, '福清市', 145, 255, 3, NULL),
(1591, '市辖区', 146, 255, 3, NULL),
(1592, '思明区', 146, 255, 3, NULL),
(1593, '海沧区', 146, 255, 3, NULL),
(1594, '湖里区', 146, 255, 3, NULL),
(1595, '集美区', 146, 255, 3, NULL),
(1596, '同安区', 146, 255, 3, NULL),
(1597, '翔安区', 146, 255, 3, NULL),
(1598, '市辖区', 147, 255, 3, NULL),
(1599, '城厢区', 147, 255, 3, NULL),
(1600, '涵江区', 147, 255, 3, NULL),
(1601, '荔城区', 147, 255, 3, NULL),
(1602, '秀屿区', 147, 255, 3, NULL),
(1603, '仙游县', 147, 255, 3, NULL),
(1604, '市辖区', 148, 255, 3, NULL),
(1605, '梅列区', 148, 255, 3, NULL),
(1606, '三元区', 148, 255, 3, NULL),
(1607, '明溪县', 148, 255, 3, NULL),
(1608, '清流县', 148, 255, 3, NULL),
(1609, '宁化县', 148, 255, 3, NULL),
(1610, '大田县', 148, 255, 3, NULL),
(1611, '尤溪县', 148, 255, 3, NULL),
(1612, '沙县', 148, 255, 3, NULL),
(1613, '将乐县', 148, 255, 3, NULL),
(1614, '泰宁县', 148, 255, 3, NULL),
(1615, '建宁县', 148, 255, 3, NULL),
(1616, '永安市', 148, 255, 3, NULL),
(1617, '市辖区', 149, 255, 3, NULL),
(1618, '鲤城区', 149, 255, 3, NULL),
(1619, '丰泽区', 149, 255, 3, NULL),
(1620, '洛江区', 149, 255, 3, NULL),
(1621, '泉港区', 149, 255, 3, NULL),
(1622, '惠安县', 149, 255, 3, NULL),
(1623, '安溪县', 149, 255, 3, NULL),
(1624, '永春县', 149, 255, 3, NULL),
(1625, '德化县', 149, 255, 3, NULL),
(1626, '金门县', 149, 255, 3, NULL),
(1627, '石狮市', 149, 255, 3, NULL),
(1628, '晋江市', 149, 255, 3, NULL),
(1629, '南安市', 149, 255, 3, NULL),
(1630, '市辖区', 150, 255, 3, NULL),
(1631, '芗城区', 150, 255, 3, NULL),
(1632, '龙文区', 150, 255, 3, NULL),
(1633, '云霄县', 150, 255, 3, NULL),
(1634, '漳浦县', 150, 255, 3, NULL),
(1635, '诏安县', 150, 255, 3, NULL),
(1636, '长泰县', 150, 255, 3, NULL),
(1637, '东山县', 150, 255, 3, NULL),
(1638, '南靖县', 150, 255, 3, NULL),
(1639, '平和县', 150, 255, 3, NULL),
(1640, '华安县', 150, 255, 3, NULL),
(1641, '龙海市', 150, 255, 3, NULL),
(1642, '市辖区', 151, 255, 3, NULL),
(1643, '延平区', 151, 255, 3, NULL),
(1644, '建阳区', 151, 255, 3, NULL),
(1645, '顺昌县', 151, 255, 3, NULL),
(1646, '浦城县', 151, 255, 3, NULL),
(1647, '光泽县', 151, 255, 3, NULL),
(1648, '松溪县', 151, 255, 3, NULL),
(1649, '政和县', 151, 255, 3, NULL),
(1650, '邵武市', 151, 255, 3, NULL),
(1651, '武夷山市', 151, 255, 3, NULL),
(1652, '建瓯市', 151, 255, 3, NULL),
(1653, '市辖区', 152, 255, 3, NULL),
(1654, '新罗区', 152, 255, 3, NULL),
(1655, '永定区', 152, 255, 3, NULL),
(1656, '长汀县', 152, 255, 3, NULL),
(1657, '上杭县', 152, 255, 3, NULL),
(1658, '武平县', 152, 255, 3, NULL),
(1659, '连城县', 152, 255, 3, NULL),
(1660, '漳平市', 152, 255, 3, NULL),
(1661, '市辖区', 153, 255, 3, NULL),
(1662, '蕉城区', 153, 255, 3, NULL),
(1663, '霞浦县', 153, 255, 3, NULL),
(1664, '古田县', 153, 255, 3, NULL),
(1665, '屏南县', 153, 255, 3, NULL),
(1666, '寿宁县', 153, 255, 3, NULL),
(1667, '周宁县', 153, 255, 3, NULL),
(1668, '柘荣县', 153, 255, 3, NULL),
(1669, '福安市', 153, 255, 3, NULL),
(1670, '福鼎市', 153, 255, 3, NULL),
(1671, '市辖区', 154, 255, 3, NULL),
(1672, '东湖区', 154, 255, 3, NULL),
(1673, '西湖区', 154, 255, 3, NULL),
(1674, '青云谱区', 154, 255, 3, NULL),
(1675, '青山湖区', 154, 255, 3, NULL),
(1676, '新建区', 154, 255, 3, NULL),
(1677, '红谷滩区', 154, 255, 3, NULL),
(1678, '南昌县', 154, 255, 3, NULL),
(1679, '安义县', 154, 255, 3, NULL),
(1680, '进贤县', 154, 255, 3, NULL),
(1681, '市辖区', 155, 255, 3, NULL),
(1682, '昌江区', 155, 255, 3, NULL),
(1683, '珠山区', 155, 255, 3, NULL),
(1684, '浮梁县', 155, 255, 3, NULL),
(1685, '乐平市', 155, 255, 3, NULL),
(1686, '市辖区', 156, 255, 3, NULL),
(1687, '安源区', 156, 255, 3, NULL),
(1688, '湘东区', 156, 255, 3, NULL),
(1689, '莲花县', 156, 255, 3, NULL),
(1690, '上栗县', 156, 255, 3, NULL),
(1691, '芦溪县', 156, 255, 3, NULL),
(1692, '市辖区', 157, 255, 3, NULL),
(1693, '濂溪区', 157, 255, 3, NULL),
(1694, '浔阳区', 157, 255, 3, NULL),
(1695, '柴桑区', 157, 255, 3, NULL),
(1696, '武宁县', 157, 255, 3, NULL),
(1697, '修水县', 157, 255, 3, NULL),
(1698, '永修县', 157, 255, 3, NULL),
(1699, '德安县', 157, 255, 3, NULL),
(1700, '都昌县', 157, 255, 3, NULL),
(1701, '湖口县', 157, 255, 3, NULL),
(1702, '彭泽县', 157, 255, 3, NULL),
(1703, '瑞昌市', 157, 255, 3, NULL),
(1704, '共青城市', 157, 255, 3, NULL),
(1705, '庐山市', 157, 255, 3, NULL),
(1706, '市辖区', 158, 255, 3, NULL),
(1707, '渝水区', 158, 255, 3, NULL),
(1708, '分宜县', 158, 255, 3, NULL),
(1709, '市辖区', 159, 255, 3, NULL),
(1710, '月湖区', 159, 255, 3, NULL),
(1711, '余江区', 159, 255, 3, NULL),
(1712, '贵溪市', 159, 255, 3, NULL),
(1713, '市辖区', 160, 255, 3, NULL),
(1714, '章贡区', 160, 255, 3, NULL),
(1715, '南康区', 160, 255, 3, NULL),
(1716, '赣县区', 160, 255, 3, NULL),
(1717, '信丰县', 160, 255, 3, NULL),
(1718, '大余县', 160, 255, 3, NULL),
(1719, '上犹县', 160, 255, 3, NULL),
(1720, '崇义县', 160, 255, 3, NULL),
(1721, '安远县', 160, 255, 3, NULL),
(1722, '定南县', 160, 255, 3, NULL),
(1723, '全南县', 160, 255, 3, NULL),
(1724, '宁都县', 160, 255, 3, NULL),
(1725, '于都县', 160, 255, 3, NULL),
(1726, '兴国县', 160, 255, 3, NULL),
(1727, '会昌县', 160, 255, 3, NULL),
(1728, '寻乌县', 160, 255, 3, NULL),
(1729, '石城县', 160, 255, 3, NULL),
(1730, '瑞金市', 160, 255, 3, NULL),
(1731, '龙南市', 160, 255, 3, NULL),
(1732, '市辖区', 161, 255, 3, NULL),
(1733, '吉州区', 161, 255, 3, NULL),
(1734, '青原区', 161, 255, 3, NULL),
(1735, '吉安县', 161, 255, 3, NULL),
(1736, '吉水县', 161, 255, 3, NULL),
(1737, '峡江县', 161, 255, 3, NULL),
(1738, '新干县', 161, 255, 3, NULL),
(1739, '永丰县', 161, 255, 3, NULL),
(1740, '泰和县', 161, 255, 3, NULL),
(1741, '遂川县', 161, 255, 3, NULL),
(1742, '万安县', 161, 255, 3, NULL),
(1743, '安福县', 161, 255, 3, NULL),
(1744, '永新县', 161, 255, 3, NULL),
(1745, '井冈山市', 161, 255, 3, NULL),
(1746, '市辖区', 162, 255, 3, NULL),
(1747, '袁州区', 162, 255, 3, NULL),
(1748, '奉新县', 162, 255, 3, NULL),
(1749, '万载县', 162, 255, 3, NULL),
(1750, '上高县', 162, 255, 3, NULL),
(1751, '宜丰县', 162, 255, 3, NULL),
(1752, '靖安县', 162, 255, 3, NULL),
(1753, '铜鼓县', 162, 255, 3, NULL),
(1754, '丰城市', 162, 255, 3, NULL),
(1755, '樟树市', 162, 255, 3, NULL),
(1756, '高安市', 162, 255, 3, NULL),
(1757, '市辖区', 163, 255, 3, NULL),
(1758, '临川区', 163, 255, 3, NULL),
(1759, '东乡区', 163, 255, 3, NULL),
(1760, '南城县', 163, 255, 3, NULL),
(1761, '黎川县', 163, 255, 3, NULL),
(1762, '南丰县', 163, 255, 3, NULL),
(1763, '崇仁县', 163, 255, 3, NULL),
(1764, '乐安县', 163, 255, 3, NULL),
(1765, '宜黄县', 163, 255, 3, NULL),
(1766, '金溪县', 163, 255, 3, NULL),
(1767, '资溪县', 163, 255, 3, NULL),
(1768, '广昌县', 163, 255, 3, NULL),
(1769, '市辖区', 164, 255, 3, NULL),
(1770, '信州区', 164, 255, 3, NULL),
(1771, '广丰区', 164, 255, 3, NULL),
(1772, '广信区', 164, 255, 3, NULL),
(1773, '玉山县', 164, 255, 3, NULL),
(1774, '铅山县', 164, 255, 3, NULL),
(1775, '横峰县', 164, 255, 3, NULL),
(1776, '弋阳县', 164, 255, 3, NULL),
(1777, '余干县', 164, 255, 3, NULL),
(1778, '鄱阳县', 164, 255, 3, NULL),
(1779, '万年县', 164, 255, 3, NULL),
(1780, '婺源县', 164, 255, 3, NULL),
(1781, '德兴市', 164, 255, 3, NULL),
(1782, '市辖区', 165, 255, 3, NULL),
(1783, '历下区', 165, 255, 3, NULL),
(1784, '市中区', 165, 255, 3, NULL),
(1785, '槐荫区', 165, 255, 3, NULL),
(1786, '天桥区', 165, 255, 3, NULL),
(1787, '历城区', 165, 255, 3, NULL),
(1788, '长清区', 165, 255, 3, NULL),
(1789, '章丘区', 165, 255, 3, NULL),
(1790, '济阳区', 165, 255, 3, NULL),
(1791, '莱芜区', 165, 255, 3, NULL),
(1792, '钢城区', 165, 255, 3, NULL),
(1793, '平阴县', 165, 255, 3, NULL),
(1794, '商河县', 165, 255, 3, NULL),
(1795, '济南高新技术产业开发区', 165, 255, 3, NULL),
(1796, '市辖区', 166, 255, 3, NULL),
(1797, '市南区', 166, 255, 3, NULL),
(1798, '市北区', 166, 255, 3, NULL),
(1799, '黄岛区', 166, 255, 3, NULL),
(1800, '崂山区', 166, 255, 3, NULL),
(1801, '李沧区', 166, 255, 3, NULL),
(1802, '城阳区', 166, 255, 3, NULL),
(1803, '即墨区', 166, 255, 3, NULL),
(1804, '青岛高新技术产业开发区', 166, 255, 3, NULL),
(1805, '胶州市', 166, 255, 3, NULL),
(1806, '平度市', 166, 255, 3, NULL),
(1807, '莱西市', 166, 255, 3, NULL),
(1808, '市辖区', 167, 255, 3, NULL),
(1809, '淄川区', 167, 255, 3, NULL),
(1810, '张店区', 167, 255, 3, NULL),
(1811, '博山区', 167, 255, 3, NULL),
(1812, '临淄区', 167, 255, 3, NULL),
(1813, '周村区', 167, 255, 3, NULL),
(1814, '桓台县', 167, 255, 3, NULL),
(1815, '高青县', 167, 255, 3, NULL),
(1816, '沂源县', 167, 255, 3, NULL),
(1817, '市辖区', 168, 255, 3, NULL),
(1818, '市中区', 168, 255, 3, NULL),
(1819, '薛城区', 168, 255, 3, NULL),
(1820, '峄城区', 168, 255, 3, NULL),
(1821, '台儿庄区', 168, 255, 3, NULL),
(1822, '山亭区', 168, 255, 3, NULL),
(1823, '滕州市', 168, 255, 3, NULL),
(1824, '市辖区', 169, 255, 3, NULL),
(1825, '东营区', 169, 255, 3, NULL),
(1826, '河口区', 169, 255, 3, NULL),
(1827, '垦利区', 169, 255, 3, NULL),
(1828, '利津县', 169, 255, 3, NULL),
(1829, '广饶县', 169, 255, 3, NULL),
(1830, '东营经济技术开发区', 169, 255, 3, NULL),
(1831, '东营港经济开发区', 169, 255, 3, NULL),
(1832, '市辖区', 170, 255, 3, NULL),
(1833, '芝罘区', 170, 255, 3, NULL),
(1834, '福山区', 170, 255, 3, NULL),
(1835, '牟平区', 170, 255, 3, NULL),
(1836, '莱山区', 170, 255, 3, NULL),
(1837, '蓬莱区', 170, 255, 3, NULL),
(1838, '烟台高新技术产业开发区', 170, 255, 3, NULL),
(1839, '烟台经济技术开发区', 170, 255, 3, NULL),
(1840, '龙口市', 170, 255, 3, NULL),
(1841, '莱阳市', 170, 255, 3, NULL),
(1842, '莱州市', 170, 255, 3, NULL),
(1843, '招远市', 170, 255, 3, NULL),
(1844, '栖霞市', 170, 255, 3, NULL),
(1845, '海阳市', 170, 255, 3, NULL),
(1846, '市辖区', 171, 255, 3, NULL),
(1847, '潍城区', 171, 255, 3, NULL),
(1848, '寒亭区', 171, 255, 3, NULL),
(1849, '坊子区', 171, 255, 3, NULL),
(1850, '奎文区', 171, 255, 3, NULL),
(1851, '临朐县', 171, 255, 3, NULL),
(1852, '昌乐县', 171, 255, 3, NULL),
(1853, '潍坊滨海经济技术开发区', 171, 255, 3, NULL),
(1854, '青州市', 171, 255, 3, NULL),
(1855, '诸城市', 171, 255, 3, NULL),
(1856, '寿光市', 171, 255, 3, NULL),
(1857, '安丘市', 171, 255, 3, NULL),
(1858, '高密市', 171, 255, 3, NULL),
(1859, '昌邑市', 171, 255, 3, NULL),
(1860, '市辖区', 172, 255, 3, NULL),
(1861, '任城区', 172, 255, 3, NULL),
(1862, '兖州区', 172, 255, 3, NULL),
(1863, '微山县', 172, 255, 3, NULL),
(1864, '鱼台县', 172, 255, 3, NULL),
(1865, '金乡县', 172, 255, 3, NULL),
(1866, '嘉祥县', 172, 255, 3, NULL),
(1867, '汶上县', 172, 255, 3, NULL),
(1868, '泗水县', 172, 255, 3, NULL),
(1869, '梁山县', 172, 255, 3, NULL),
(1870, '济宁高新技术产业开发区', 172, 255, 3, NULL),
(1871, '曲阜市', 172, 255, 3, NULL),
(1872, '邹城市', 172, 255, 3, NULL),
(1873, '市辖区', 173, 255, 3, NULL),
(1874, '泰山区', 173, 255, 3, NULL),
(1875, '岱岳区', 173, 255, 3, NULL),
(1876, '宁阳县', 173, 255, 3, NULL),
(1877, '东平县', 173, 255, 3, NULL),
(1878, '新泰市', 173, 255, 3, NULL),
(1879, '肥城市', 173, 255, 3, NULL),
(1880, '市辖区', 174, 255, 3, NULL),
(1881, '环翠区', 174, 255, 3, NULL),
(1882, '文登区', 174, 255, 3, NULL),
(1883, '威海火炬高技术产业开发区', 174, 255, 3, NULL),
(1884, '威海经济技术开发区', 174, 255, 3, NULL),
(1885, '威海临港经济技术开发区', 174, 255, 3, NULL),
(1886, '荣成市', 174, 255, 3, NULL),
(1887, '乳山市', 174, 255, 3, NULL),
(1888, '市辖区', 175, 255, 3, NULL),
(1889, '东港区', 175, 255, 3, NULL),
(1890, '岚山区', 175, 255, 3, NULL),
(1891, '五莲县', 175, 255, 3, NULL),
(1892, '莒县', 175, 255, 3, NULL),
(1893, '日照经济技术开发区', 175, 255, 3, NULL),
(1894, '市辖区', 176, 255, 3, NULL),
(1895, '兰山区', 176, 255, 3, NULL),
(1896, '罗庄区', 176, 255, 3, NULL),
(1897, '河东区', 176, 255, 3, NULL),
(1898, '沂南县', 176, 255, 3, NULL),
(1899, '郯城县', 176, 255, 3, NULL),
(1900, '沂水县', 176, 255, 3, NULL),
(1901, '兰陵县', 176, 255, 3, NULL),
(1902, '费县', 176, 255, 3, NULL),
(1903, '平邑县', 176, 255, 3, NULL),
(1904, '莒南县', 176, 255, 3, NULL),
(1905, '蒙阴县', 176, 255, 3, NULL),
(1906, '临沭县', 176, 255, 3, NULL),
(1907, '临沂高新技术产业开发区', 176, 255, 3, NULL),
(1908, '市辖区', 177, 255, 3, NULL),
(1909, '德城区', 177, 255, 3, NULL),
(1910, '陵城区', 177, 255, 3, NULL),
(1911, '宁津县', 177, 255, 3, NULL),
(1912, '庆云县', 177, 255, 3, NULL),
(1913, '临邑县', 177, 255, 3, NULL),
(1914, '齐河县', 177, 255, 3, NULL),
(1915, '平原县', 177, 255, 3, NULL),
(1916, '夏津县', 177, 255, 3, NULL),
(1917, '武城县', 177, 255, 3, NULL),
(1918, '德州经济技术开发区', 177, 255, 3, NULL),
(1919, '德州运河经济开发区', 177, 255, 3, NULL),
(1920, '乐陵市', 177, 255, 3, NULL),
(1921, '禹城市', 177, 255, 3, NULL),
(1922, '市辖区', 178, 255, 3, NULL),
(1923, '东昌府区', 178, 255, 3, NULL),
(1924, '茌平区', 178, 255, 3, NULL),
(1925, '阳谷县', 178, 255, 3, NULL),
(1926, '莘县', 178, 255, 3, NULL),
(1927, '东阿县', 178, 255, 3, NULL),
(1928, '冠县', 178, 255, 3, NULL),
(1929, '高唐县', 178, 255, 3, NULL),
(1930, '临清市', 178, 255, 3, NULL),
(1931, '市辖区', 179, 255, 3, NULL),
(1932, '滨城区', 179, 255, 3, NULL),
(1933, '沾化区', 179, 255, 3, NULL),
(1934, '惠民县', 179, 255, 3, NULL),
(1935, '阳信县', 179, 255, 3, NULL),
(1936, '无棣县', 179, 255, 3, NULL),
(1937, '博兴县', 179, 255, 3, NULL),
(1938, '邹平市', 179, 255, 3, NULL),
(1939, '市辖区', 180, 255, 3, NULL),
(1940, '牡丹区', 180, 255, 3, NULL),
(1941, '定陶区', 180, 255, 3, NULL),
(1942, '曹县', 180, 255, 3, NULL),
(1943, '单县', 180, 255, 3, NULL),
(1944, '成武县', 180, 255, 3, NULL),
(1945, '巨野县', 180, 255, 3, NULL),
(1946, '郓城县', 180, 255, 3, NULL),
(1947, '鄄城县', 180, 255, 3, NULL),
(1948, '东明县', 180, 255, 3, NULL),
(1949, '菏泽经济技术开发区', 180, 255, 3, NULL),
(1950, '菏泽高新技术开发区', 180, 255, 3, NULL),
(1951, '市辖区', 181, 255, 3, NULL),
(1952, '中原区', 181, 255, 3, NULL),
(1953, '二七区', 181, 255, 3, NULL),
(1954, '管城回族区', 181, 255, 3, NULL),
(1955, '金水区', 181, 255, 3, NULL),
(1956, '上街区', 181, 255, 3, NULL),
(1957, '惠济区', 181, 255, 3, NULL),
(1958, '中牟县', 181, 255, 3, NULL),
(1959, '郑州经济技术开发区', 181, 255, 3, NULL),
(1960, '郑州高新技术产业开发区', 181, 255, 3, NULL),
(1961, '郑州航空港经济综合实验区', 181, 255, 3, NULL),
(1962, '巩义市', 181, 255, 3, NULL),
(1963, '荥阳市', 181, 255, 3, NULL),
(1964, '新密市', 181, 255, 3, NULL),
(1965, '新郑市', 181, 255, 3, NULL),
(1966, '登封市', 181, 255, 3, NULL),
(1967, '市辖区', 182, 255, 3, NULL),
(1968, '龙亭区', 182, 255, 3, NULL),
(1969, '顺河回族区', 182, 255, 3, NULL),
(1970, '鼓楼区', 182, 255, 3, NULL),
(1971, '禹王台区', 182, 255, 3, NULL),
(1972, '祥符区', 182, 255, 3, NULL),
(1973, '杞县', 182, 255, 3, NULL),
(1974, '通许县', 182, 255, 3, NULL),
(1975, '尉氏县', 182, 255, 3, NULL),
(1976, '兰考县', 182, 255, 3, NULL),
(1977, '市辖区', 183, 255, 3, NULL),
(1978, '老城区', 183, 255, 3, NULL),
(1979, '西工区', 183, 255, 3, NULL),
(1980, '瀍河回族区', 183, 255, 3, NULL),
(1981, '涧西区', 183, 255, 3, NULL),
(1982, '吉利区', 183, 255, 3, NULL),
(1983, '洛龙区', 183, 255, 3, NULL),
(1984, '孟津县', 183, 255, 3, NULL),
(1985, '新安县', 183, 255, 3, NULL),
(1986, '栾川县', 183, 255, 3, NULL),
(1987, '嵩县', 183, 255, 3, NULL),
(1988, '汝阳县', 183, 255, 3, NULL),
(1989, '宜阳县', 183, 255, 3, NULL),
(1990, '洛宁县', 183, 255, 3, NULL),
(1991, '伊川县', 183, 255, 3, NULL),
(1992, '洛阳高新技术产业开发区', 183, 255, 3, NULL),
(1993, '偃师市', 183, 255, 3, NULL),
(1994, '市辖区', 184, 255, 3, NULL),
(1995, '新华区', 184, 255, 3, NULL),
(1996, '卫东区', 184, 255, 3, NULL),
(1997, '石龙区', 184, 255, 3, NULL),
(1998, '湛河区', 184, 255, 3, NULL),
(1999, '宝丰县', 184, 255, 3, NULL),
(2000, '叶县', 184, 255, 3, NULL),
(2001, '鲁山县', 184, 255, 3, NULL),
(2002, '郏县', 184, 255, 3, NULL),
(2003, '平顶山高新技术产业开发区', 184, 255, 3, NULL),
(2004, '平顶山市城乡一体化示范区', 184, 255, 3, NULL),
(2005, '舞钢市', 184, 255, 3, NULL),
(2006, '汝州市', 184, 255, 3, NULL),
(2007, '市辖区', 185, 255, 3, NULL),
(2008, '文峰区', 185, 255, 3, NULL),
(2009, '北关区', 185, 255, 3, NULL),
(2010, '殷都区', 185, 255, 3, NULL),
(2011, '龙安区', 185, 255, 3, NULL),
(2012, '安阳县', 185, 255, 3, NULL),
(2013, '汤阴县', 185, 255, 3, NULL),
(2014, '滑县', 185, 255, 3, NULL),
(2015, '内黄县', 185, 255, 3, NULL),
(2016, '安阳高新技术产业开发区', 185, 255, 3, NULL),
(2017, '林州市', 185, 255, 3, NULL),
(2018, '市辖区', 186, 255, 3, NULL),
(2019, '鹤山区', 186, 255, 3, NULL),
(2020, '山城区', 186, 255, 3, NULL),
(2021, '淇滨区', 186, 255, 3, NULL),
(2022, '浚县', 186, 255, 3, NULL),
(2023, '淇县', 186, 255, 3, NULL),
(2024, '鹤壁经济技术开发区', 186, 255, 3, NULL),
(2025, '市辖区', 187, 255, 3, NULL),
(2026, '红旗区', 187, 255, 3, NULL),
(2027, '卫滨区', 187, 255, 3, NULL),
(2028, '凤泉区', 187, 255, 3, NULL),
(2029, '牧野区', 187, 255, 3, NULL),
(2030, '新乡县', 187, 255, 3, NULL),
(2031, '获嘉县', 187, 255, 3, NULL),
(2032, '原阳县', 187, 255, 3, NULL),
(2033, '延津县', 187, 255, 3, NULL),
(2034, '封丘县', 187, 255, 3, NULL),
(2035, '新乡高新技术产业开发区', 187, 255, 3, NULL),
(2036, '新乡经济技术开发区', 187, 255, 3, NULL),
(2037, '新乡市平原城乡一体化示范区', 187, 255, 3, NULL),
(2038, '卫辉市', 187, 255, 3, NULL),
(2039, '辉县市', 187, 255, 3, NULL),
(2040, '长垣市', 187, 255, 3, NULL),
(2041, '市辖区', 188, 255, 3, NULL),
(2042, '解放区', 188, 255, 3, NULL),
(2043, '中站区', 188, 255, 3, NULL),
(2044, '马村区', 188, 255, 3, NULL),
(2045, '山阳区', 188, 255, 3, NULL),
(2046, '修武县', 188, 255, 3, NULL),
(2047, '博爱县', 188, 255, 3, NULL),
(2048, '武陟县', 188, 255, 3, NULL),
(2049, '温县', 188, 255, 3, NULL),
(2050, '焦作城乡一体化示范区', 188, 255, 3, NULL),
(2051, '沁阳市', 188, 255, 3, NULL),
(2052, '孟州市', 188, 255, 3, NULL),
(2053, '市辖区', 189, 255, 3, NULL),
(2054, '华龙区', 189, 255, 3, NULL),
(2055, '清丰县', 189, 255, 3, NULL),
(2056, '南乐县', 189, 255, 3, NULL),
(2057, '范县', 189, 255, 3, NULL),
(2058, '台前县', 189, 255, 3, NULL),
(2059, '濮阳县', 189, 255, 3, NULL),
(2060, '河南濮阳工业园区', 189, 255, 3, NULL),
(2061, '濮阳经济技术开发区', 189, 255, 3, NULL),
(2062, '市辖区', 190, 255, 3, NULL),
(2063, '魏都区', 190, 255, 3, NULL),
(2064, '建安区', 190, 255, 3, NULL),
(2065, '鄢陵县', 190, 255, 3, NULL),
(2066, '襄城县', 190, 255, 3, NULL),
(2067, '许昌经济技术开发区', 190, 255, 3, NULL),
(2068, '禹州市', 190, 255, 3, NULL),
(2069, '长葛市', 190, 255, 3, NULL),
(2070, '市辖区', 191, 255, 3, NULL),
(2071, '源汇区', 191, 255, 3, NULL),
(2072, '郾城区', 191, 255, 3, NULL),
(2073, '召陵区', 191, 255, 3, NULL),
(2074, '舞阳县', 191, 255, 3, NULL),
(2075, '临颍县', 191, 255, 3, NULL),
(2076, '漯河经济技术开发区', 191, 255, 3, NULL),
(2077, '市辖区', 192, 255, 3, NULL),
(2078, '湖滨区', 192, 255, 3, NULL),
(2079, '陕州区', 192, 255, 3, NULL),
(2080, '渑池县', 192, 255, 3, NULL),
(2081, '卢氏县', 192, 255, 3, NULL),
(2082, '河南三门峡经济开发区', 192, 255, 3, NULL),
(2083, '义马市', 192, 255, 3, NULL),
(2084, '灵宝市', 192, 255, 3, NULL),
(2085, '市辖区', 193, 255, 3, NULL),
(2086, '宛城区', 193, 255, 3, NULL),
(2087, '卧龙区', 193, 255, 3, NULL),
(2088, '南召县', 193, 255, 3, NULL),
(2089, '方城县', 193, 255, 3, NULL),
(2090, '西峡县', 193, 255, 3, NULL),
(2091, '镇平县', 193, 255, 3, NULL),
(2092, '内乡县', 193, 255, 3, NULL),
(2093, '淅川县', 193, 255, 3, NULL),
(2094, '社旗县', 193, 255, 3, NULL),
(2095, '唐河县', 193, 255, 3, NULL),
(2096, '新野县', 193, 255, 3, NULL),
(2097, '桐柏县', 193, 255, 3, NULL),
(2098, '南阳高新技术产业开发区', 193, 255, 3, NULL),
(2099, '南阳市城乡一体化示范区', 193, 255, 3, NULL),
(2100, '邓州市', 193, 255, 3, NULL),
(2101, '市辖区', 194, 255, 3, NULL),
(2102, '梁园区', 194, 255, 3, NULL),
(2103, '睢阳区', 194, 255, 3, NULL),
(2104, '民权县', 194, 255, 3, NULL),
(2105, '睢县', 194, 255, 3, NULL),
(2106, '宁陵县', 194, 255, 3, NULL),
(2107, '柘城县', 194, 255, 3, NULL),
(2108, '虞城县', 194, 255, 3, NULL),
(2109, '夏邑县', 194, 255, 3, NULL),
(2110, '豫东综合物流产业聚集区', 194, 255, 3, NULL),
(2111, '河南商丘经济开发区', 194, 255, 3, NULL),
(2112, '永城市', 194, 255, 3, NULL),
(2113, '市辖区', 195, 255, 3, NULL),
(2114, '浉河区', 195, 255, 3, NULL),
(2115, '平桥区', 195, 255, 3, NULL),
(2116, '罗山县', 195, 255, 3, NULL),
(2117, '光山县', 195, 255, 3, NULL),
(2118, '新县', 195, 255, 3, NULL),
(2119, '商城县', 195, 255, 3, NULL),
(2120, '固始县', 195, 255, 3, NULL),
(2121, '潢川县', 195, 255, 3, NULL),
(2122, '淮滨县', 195, 255, 3, NULL),
(2123, '息县', 195, 255, 3, NULL),
(2124, '信阳高新技术产业开发区', 195, 255, 3, NULL),
(2125, '市辖区', 196, 255, 3, NULL),
(2126, '川汇区', 196, 255, 3, NULL),
(2127, '淮阳区', 196, 255, 3, NULL),
(2128, '扶沟县', 196, 255, 3, NULL),
(2129, '西华县', 196, 255, 3, NULL),
(2130, '商水县', 196, 255, 3, NULL),
(2131, '沈丘县', 196, 255, 3, NULL),
(2132, '郸城县', 196, 255, 3, NULL),
(2133, '太康县', 196, 255, 3, NULL),
(2134, '鹿邑县', 196, 255, 3, NULL),
(2135, '河南周口经济开发区', 196, 255, 3, NULL),
(2136, '项城市', 196, 255, 3, NULL),
(2137, '市辖区', 197, 255, 3, NULL),
(2138, '驿城区', 197, 255, 3, NULL),
(2139, '西平县', 197, 255, 3, NULL),
(2140, '上蔡县', 197, 255, 3, NULL),
(2141, '平舆县', 197, 255, 3, NULL),
(2142, '正阳县', 197, 255, 3, NULL),
(2143, '确山县', 197, 255, 3, NULL),
(2144, '泌阳县', 197, 255, 3, NULL),
(2145, '汝南县', 197, 255, 3, NULL),
(2146, '遂平县', 197, 255, 3, NULL),
(2147, '新蔡县', 197, 255, 3, NULL),
(2148, '河南驻马店经济开发区', 197, 255, 3, NULL),
(2149, '济源市', 198, 255, 3, NULL),
(2150, '市辖区', 199, 255, 3, NULL),
(2151, '江岸区', 199, 255, 3, NULL),
(2152, '江汉区', 199, 255, 3, NULL),
(2153, '硚口区', 199, 255, 3, NULL),
(2154, '汉阳区', 199, 255, 3, NULL),
(2155, '武昌区', 199, 255, 3, NULL),
(2156, '青山区', 199, 255, 3, NULL),
(2157, '洪山区', 199, 255, 3, NULL),
(2158, '东西湖区', 199, 255, 3, NULL),
(2159, '汉南区', 199, 255, 3, NULL),
(2160, '蔡甸区', 199, 255, 3, NULL),
(2161, '江夏区', 199, 255, 3, NULL),
(2162, '黄陂区', 199, 255, 3, NULL),
(2163, '新洲区', 199, 255, 3, NULL),
(2164, '市辖区', 200, 255, 3, NULL),
(2165, '黄石港区', 200, 255, 3, NULL),
(2166, '西塞山区', 200, 255, 3, NULL),
(2167, '下陆区', 200, 255, 3, NULL),
(2168, '铁山区', 200, 255, 3, NULL),
(2169, '阳新县', 200, 255, 3, NULL),
(2170, '大冶市', 200, 255, 3, NULL),
(2171, '市辖区', 201, 255, 3, NULL),
(2172, '茅箭区', 201, 255, 3, NULL),
(2173, '张湾区', 201, 255, 3, NULL),
(2174, '郧阳区', 201, 255, 3, NULL),
(2175, '郧西县', 201, 255, 3, NULL),
(2176, '竹山县', 201, 255, 3, NULL),
(2177, '竹溪县', 201, 255, 3, NULL),
(2178, '房县', 201, 255, 3, NULL),
(2179, '丹江口市', 201, 255, 3, NULL),
(2180, '市辖区', 202, 255, 3, NULL),
(2181, '西陵区', 202, 255, 3, NULL),
(2182, '伍家岗区', 202, 255, 3, NULL),
(2183, '点军区', 202, 255, 3, NULL),
(2184, '猇亭区', 202, 255, 3, NULL),
(2185, '夷陵区', 202, 255, 3, NULL),
(2186, '远安县', 202, 255, 3, NULL),
(2187, '兴山县', 202, 255, 3, NULL),
(2188, '秭归县', 202, 255, 3, NULL),
(2189, '长阳土家族自治县', 202, 255, 3, NULL),
(2190, '五峰土家族自治县', 202, 255, 3, NULL),
(2191, '宜都市', 202, 255, 3, NULL),
(2192, '当阳市', 202, 255, 3, NULL),
(2193, '枝江市', 202, 255, 3, NULL),
(2194, '市辖区', 203, 255, 3, NULL),
(2195, '襄城区', 203, 255, 3, NULL),
(2196, '樊城区', 203, 255, 3, NULL),
(2197, '襄州区', 203, 255, 3, NULL),
(2198, '南漳县', 203, 255, 3, NULL),
(2199, '谷城县', 203, 255, 3, NULL),
(2200, '保康县', 203, 255, 3, NULL),
(2201, '老河口市', 203, 255, 3, NULL),
(2202, '枣阳市', 203, 255, 3, NULL),
(2203, '宜城市', 203, 255, 3, NULL),
(2204, '市辖区', 204, 255, 3, NULL),
(2205, '梁子湖区', 204, 255, 3, NULL),
(2206, '华容区', 204, 255, 3, NULL),
(2207, '鄂城区', 204, 255, 3, NULL),
(2208, '市辖区', 205, 255, 3, NULL),
(2209, '东宝区', 205, 255, 3, NULL),
(2210, '掇刀区', 205, 255, 3, NULL),
(2211, '沙洋县', 205, 255, 3, NULL),
(2212, '钟祥市', 205, 255, 3, NULL),
(2213, '京山市', 205, 255, 3, NULL),
(2214, '市辖区', 206, 255, 3, NULL),
(2215, '孝南区', 206, 255, 3, NULL),
(2216, '孝昌县', 206, 255, 3, NULL),
(2217, '大悟县', 206, 255, 3, NULL),
(2218, '云梦县', 206, 255, 3, NULL),
(2219, '应城市', 206, 255, 3, NULL),
(2220, '安陆市', 206, 255, 3, NULL),
(2221, '汉川市', 206, 255, 3, NULL),
(2222, '市辖区', 207, 255, 3, NULL),
(2223, '沙市区', 207, 255, 3, NULL),
(2224, '荆州区', 207, 255, 3, NULL),
(2225, '公安县', 207, 255, 3, NULL),
(2226, '监利县', 207, 255, 3, NULL),
(2227, '江陵县', 207, 255, 3, NULL),
(2228, '荆州经济技术开发区', 207, 255, 3, NULL),
(2229, '石首市', 207, 255, 3, NULL),
(2230, '洪湖市', 207, 255, 3, NULL),
(2231, '松滋市', 207, 255, 3, NULL),
(2232, '市辖区', 208, 255, 3, NULL),
(2233, '黄州区', 208, 255, 3, NULL),
(2234, '团风县', 208, 255, 3, NULL),
(2235, '红安县', 208, 255, 3, NULL),
(2236, '罗田县', 208, 255, 3, NULL),
(2237, '英山县', 208, 255, 3, NULL),
(2238, '浠水县', 208, 255, 3, NULL),
(2239, '蕲春县', 208, 255, 3, NULL),
(2240, '黄梅县', 208, 255, 3, NULL),
(2241, '龙感湖管理区', 208, 255, 3, NULL),
(2242, '麻城市', 208, 255, 3, NULL),
(2243, '武穴市', 208, 255, 3, NULL),
(2244, '市辖区', 209, 255, 3, NULL),
(2245, '咸安区', 209, 255, 3, NULL),
(2246, '嘉鱼县', 209, 255, 3, NULL),
(2247, '通城县', 209, 255, 3, NULL),
(2248, '崇阳县', 209, 255, 3, NULL),
(2249, '通山县', 209, 255, 3, NULL),
(2250, '赤壁市', 209, 255, 3, NULL),
(2251, '市辖区', 210, 255, 3, NULL),
(2252, '曾都区', 210, 255, 3, NULL),
(2253, '随县', 210, 255, 3, NULL),
(2254, '广水市', 210, 255, 3, NULL),
(2255, '恩施市', 211, 255, 3, NULL),
(2256, '利川市', 211, 255, 3, NULL),
(2257, '建始县', 211, 255, 3, NULL),
(2258, '巴东县', 211, 255, 3, NULL),
(2259, '宣恩县', 211, 255, 3, NULL),
(2260, '咸丰县', 211, 255, 3, NULL),
(2261, '来凤县', 211, 255, 3, NULL),
(2262, '鹤峰县', 211, 255, 3, NULL),
(2263, '仙桃市', 212, 255, 3, NULL),
(2264, '潜江市', 212, 255, 3, NULL),
(2265, '天门市', 212, 255, 3, NULL),
(2266, '神农架林区', 212, 255, 3, NULL),
(2267, '市辖区', 213, 255, 3, NULL),
(2268, '芙蓉区', 213, 255, 3, NULL),
(2269, '天心区', 213, 255, 3, NULL),
(2270, '岳麓区', 213, 255, 3, NULL),
(2271, '开福区', 213, 255, 3, NULL),
(2272, '雨花区', 213, 255, 3, NULL),
(2273, '望城区', 213, 255, 3, NULL),
(2274, '长沙县', 213, 255, 3, NULL),
(2275, '浏阳市', 213, 255, 3, NULL),
(2276, '宁乡市', 213, 255, 3, NULL),
(2277, '市辖区', 214, 255, 3, NULL),
(2278, '荷塘区', 214, 255, 3, NULL),
(2279, '芦淞区', 214, 255, 3, NULL),
(2280, '石峰区', 214, 255, 3, NULL),
(2281, '天元区', 214, 255, 3, NULL),
(2282, '渌口区', 214, 255, 3, NULL),
(2283, '攸县', 214, 255, 3, NULL),
(2284, '茶陵县', 214, 255, 3, NULL),
(2285, '炎陵县', 214, 255, 3, NULL),
(2286, '云龙示范区', 214, 255, 3, NULL),
(2287, '醴陵市', 214, 255, 3, NULL),
(2288, '市辖区', 215, 255, 3, NULL),
(2289, '雨湖区', 215, 255, 3, NULL),
(2290, '岳塘区', 215, 255, 3, NULL),
(2291, '湘潭县', 215, 255, 3, NULL),
(2292, '湖南湘潭高新技术产业园区', 215, 255, 3, NULL),
(2293, '湘潭昭山示范区', 215, 255, 3, NULL),
(2294, '湘潭九华示范区', 215, 255, 3, NULL),
(2295, '湘乡市', 215, 255, 3, NULL),
(2296, '韶山市', 215, 255, 3, NULL),
(2297, '市辖区', 216, 255, 3, NULL),
(2298, '珠晖区', 216, 255, 3, NULL),
(2299, '雁峰区', 216, 255, 3, NULL),
(2300, '石鼓区', 216, 255, 3, NULL),
(2301, '蒸湘区', 216, 255, 3, NULL),
(2302, '南岳区', 216, 255, 3, NULL),
(2303, '衡阳县', 216, 255, 3, NULL),
(2304, '衡南县', 216, 255, 3, NULL),
(2305, '衡山县', 216, 255, 3, NULL),
(2306, '衡东县', 216, 255, 3, NULL),
(2307, '祁东县', 216, 255, 3, NULL),
(2308, '衡阳综合保税区', 216, 255, 3, NULL),
(2309, '湖南衡阳高新技术产业园区', 216, 255, 3, NULL),
(2310, '湖南衡阳松木经济开发区', 216, 255, 3, NULL),
(2311, '耒阳市', 216, 255, 3, NULL),
(2312, '常宁市', 216, 255, 3, NULL),
(2313, '市辖区', 217, 255, 3, NULL),
(2314, '双清区', 217, 255, 3, NULL),
(2315, '大祥区', 217, 255, 3, NULL),
(2316, '北塔区', 217, 255, 3, NULL),
(2317, '新邵县', 217, 255, 3, NULL),
(2318, '邵阳县', 217, 255, 3, NULL),
(2319, '隆回县', 217, 255, 3, NULL),
(2320, '洞口县', 217, 255, 3, NULL),
(2321, '绥宁县', 217, 255, 3, NULL),
(2322, '新宁县', 217, 255, 3, NULL),
(2323, '城步苗族自治县', 217, 255, 3, NULL),
(2324, '武冈市', 217, 255, 3, NULL),
(2325, '邵东市', 217, 255, 3, NULL),
(2326, '市辖区', 218, 255, 3, NULL),
(2327, '岳阳楼区', 218, 255, 3, NULL),
(2328, '云溪区', 218, 255, 3, NULL),
(2329, '君山区', 218, 255, 3, NULL),
(2330, '岳阳县', 218, 255, 3, NULL),
(2331, '华容县', 218, 255, 3, NULL),
(2332, '湘阴县', 218, 255, 3, NULL),
(2333, '平江县', 218, 255, 3, NULL),
(2334, '岳阳市屈原管理区', 218, 255, 3, NULL),
(2335, '汨罗市', 218, 255, 3, NULL),
(2336, '临湘市', 218, 255, 3, NULL),
(2337, '市辖区', 219, 255, 3, NULL),
(2338, '武陵区', 219, 255, 3, NULL),
(2339, '鼎城区', 219, 255, 3, NULL),
(2340, '安乡县', 219, 255, 3, NULL),
(2341, '汉寿县', 219, 255, 3, NULL),
(2342, '澧县', 219, 255, 3, NULL),
(2343, '临澧县', 219, 255, 3, NULL),
(2344, '桃源县', 219, 255, 3, NULL),
(2345, '石门县', 219, 255, 3, NULL),
(2346, '常德市西洞庭管理区', 219, 255, 3, NULL),
(2347, '津市市', 219, 255, 3, NULL),
(2348, '市辖区', 220, 255, 3, NULL),
(2349, '永定区', 220, 255, 3, NULL),
(2350, '武陵源区', 220, 255, 3, NULL),
(2351, '慈利县', 220, 255, 3, NULL),
(2352, '桑植县', 220, 255, 3, NULL),
(2353, '市辖区', 221, 255, 3, NULL),
(2354, '资阳区', 221, 255, 3, NULL),
(2355, '赫山区', 221, 255, 3, NULL),
(2356, '南县', 221, 255, 3, NULL),
(2357, '桃江县', 221, 255, 3, NULL),
(2358, '安化县', 221, 255, 3, NULL),
(2359, '益阳市大通湖管理区', 221, 255, 3, NULL),
(2360, '湖南益阳高新技术产业园区', 221, 255, 3, NULL),
(2361, '沅江市', 221, 255, 3, NULL),
(2362, '市辖区', 222, 255, 3, NULL),
(2363, '北湖区', 222, 255, 3, NULL),
(2364, '苏仙区', 222, 255, 3, NULL),
(2365, '桂阳县', 222, 255, 3, NULL),
(2366, '宜章县', 222, 255, 3, NULL),
(2367, '永兴县', 222, 255, 3, NULL),
(2368, '嘉禾县', 222, 255, 3, NULL),
(2369, '临武县', 222, 255, 3, NULL),
(2370, '汝城县', 222, 255, 3, NULL),
(2371, '桂东县', 222, 255, 3, NULL),
(2372, '安仁县', 222, 255, 3, NULL),
(2373, '资兴市', 222, 255, 3, NULL),
(2374, '市辖区', 223, 255, 3, NULL),
(2375, '零陵区', 223, 255, 3, NULL),
(2376, '冷水滩区', 223, 255, 3, NULL),
(2377, '祁阳县', 223, 255, 3, NULL),
(2378, '东安县', 223, 255, 3, NULL),
(2379, '双牌县', 223, 255, 3, NULL),
(2380, '道县', 223, 255, 3, NULL),
(2381, '江永县', 223, 255, 3, NULL),
(2382, '宁远县', 223, 255, 3, NULL),
(2383, '蓝山县', 223, 255, 3, NULL),
(2384, '新田县', 223, 255, 3, NULL),
(2385, '江华瑶族自治县', 223, 255, 3, NULL),
(2386, '永州经济技术开发区', 223, 255, 3, NULL),
(2387, '永州市金洞管理区', 223, 255, 3, NULL),
(2388, '永州市回龙圩管理区', 223, 255, 3, NULL),
(2389, '市辖区', 224, 255, 3, NULL),
(2390, '鹤城区', 224, 255, 3, NULL),
(2391, '中方县', 224, 255, 3, NULL),
(2392, '沅陵县', 224, 255, 3, NULL),
(2393, '辰溪县', 224, 255, 3, NULL),
(2394, '溆浦县', 224, 255, 3, NULL),
(2395, '会同县', 224, 255, 3, NULL),
(2396, '麻阳苗族自治县', 224, 255, 3, NULL),
(2397, '新晃侗族自治县', 224, 255, 3, NULL),
(2398, '芷江侗族自治县', 224, 255, 3, NULL),
(2399, '靖州苗族侗族自治县', 224, 255, 3, NULL),
(2400, '通道侗族自治县', 224, 255, 3, NULL),
(2401, '怀化市洪江管理区', 224, 255, 3, NULL),
(2402, '洪江市', 224, 255, 3, NULL),
(2403, '市辖区', 225, 255, 3, NULL),
(2404, '娄星区', 225, 255, 3, NULL),
(2405, '双峰县', 225, 255, 3, NULL),
(2406, '新化县', 225, 255, 3, NULL),
(2407, '冷水江市', 225, 255, 3, NULL),
(2408, '涟源市', 225, 255, 3, NULL),
(2409, '吉首市', 226, 255, 3, NULL),
(2410, '泸溪县', 226, 255, 3, NULL),
(2411, '凤凰县', 226, 255, 3, NULL),
(2412, '花垣县', 226, 255, 3, NULL),
(2413, '保靖县', 226, 255, 3, NULL),
(2414, '古丈县', 226, 255, 3, NULL),
(2415, '永顺县', 226, 255, 3, NULL),
(2416, '龙山县', 226, 255, 3, NULL),
(2417, '市辖区', 227, 255, 3, NULL),
(2418, '荔湾区', 227, 255, 3, NULL),
(2419, '越秀区', 227, 255, 3, NULL),
(2420, '海珠区', 227, 255, 3, NULL),
(2421, '天河区', 227, 255, 3, NULL),
(2422, '白云区', 227, 255, 3, NULL),
(2423, '黄埔区', 227, 255, 3, NULL),
(2424, '番禺区', 227, 255, 3, NULL),
(2425, '花都区', 227, 255, 3, NULL),
(2426, '南沙区', 227, 255, 3, NULL),
(2427, '从化区', 227, 255, 3, NULL),
(2428, '增城区', 227, 255, 3, NULL),
(2429, '市辖区', 228, 255, 3, NULL),
(2430, '武江区', 228, 255, 3, NULL),
(2431, '浈江区', 228, 255, 3, NULL),
(2432, '曲江区', 228, 255, 3, NULL),
(2433, '始兴县', 228, 255, 3, NULL),
(2434, '仁化县', 228, 255, 3, NULL),
(2435, '翁源县', 228, 255, 3, NULL),
(2436, '乳源瑶族自治县', 228, 255, 3, NULL),
(2437, '新丰县', 228, 255, 3, NULL),
(2438, '乐昌市', 228, 255, 3, NULL),
(2439, '南雄市', 228, 255, 3, NULL),
(2440, '市辖区', 229, 255, 3, NULL),
(2441, '罗湖区', 229, 255, 3, NULL),
(2442, '福田区', 229, 255, 3, NULL),
(2443, '南山区', 229, 255, 3, NULL),
(2444, '宝安区', 229, 255, 3, NULL),
(2445, '龙岗区', 229, 255, 3, NULL),
(2446, '盐田区', 229, 255, 3, NULL),
(2447, '龙华区', 229, 255, 3, NULL),
(2448, '坪山区', 229, 255, 3, NULL),
(2449, '光明区', 229, 255, 3, NULL),
(2450, '市辖区', 230, 255, 3, NULL),
(2451, '香洲区', 230, 255, 3, NULL),
(2452, '斗门区', 230, 255, 3, NULL),
(2453, '金湾区', 230, 255, 3, NULL),
(2454, '市辖区', 231, 255, 3, NULL),
(2455, '龙湖区', 231, 255, 3, NULL),
(2456, '金平区', 231, 255, 3, NULL),
(2457, '濠江区', 231, 255, 3, NULL),
(2458, '潮阳区', 231, 255, 3, NULL),
(2459, '潮南区', 231, 255, 3, NULL),
(2460, '澄海区', 231, 255, 3, NULL),
(2461, '南澳县', 231, 255, 3, NULL),
(2462, '市辖区', 232, 255, 3, NULL),
(2463, '禅城区', 232, 255, 3, NULL),
(2464, '南海区', 232, 255, 3, NULL),
(2465, '顺德区', 232, 255, 3, NULL),
(2466, '三水区', 232, 255, 3, NULL),
(2467, '高明区', 232, 255, 3, NULL),
(2468, '市辖区', 233, 255, 3, NULL),
(2469, '蓬江区', 233, 255, 3, NULL),
(2470, '江海区', 233, 255, 3, NULL),
(2471, '新会区', 233, 255, 3, NULL),
(2472, '台山市', 233, 255, 3, NULL),
(2473, '开平市', 233, 255, 3, NULL),
(2474, '鹤山市', 233, 255, 3, NULL),
(2475, '恩平市', 233, 255, 3, NULL),
(2476, '市辖区', 234, 255, 3, NULL),
(2477, '赤坎区', 234, 255, 3, NULL),
(2478, '霞山区', 234, 255, 3, NULL),
(2479, '坡头区', 234, 255, 3, NULL),
(2480, '麻章区', 234, 255, 3, NULL),
(2481, '遂溪县', 234, 255, 3, NULL),
(2482, '徐闻县', 234, 255, 3, NULL),
(2483, '廉江市', 234, 255, 3, NULL),
(2484, '雷州市', 234, 255, 3, NULL),
(2485, '吴川市', 234, 255, 3, NULL),
(2486, '市辖区', 235, 255, 3, NULL),
(2487, '茂南区', 235, 255, 3, NULL),
(2488, '电白区', 235, 255, 3, NULL),
(2489, '高州市', 235, 255, 3, NULL),
(2490, '化州市', 235, 255, 3, NULL),
(2491, '信宜市', 235, 255, 3, NULL),
(2492, '市辖区', 236, 255, 3, NULL),
(2493, '端州区', 236, 255, 3, NULL),
(2494, '鼎湖区', 236, 255, 3, NULL),
(2495, '高要区', 236, 255, 3, NULL),
(2496, '广宁县', 236, 255, 3, NULL),
(2497, '怀集县', 236, 255, 3, NULL),
(2498, '封开县', 236, 255, 3, NULL),
(2499, '德庆县', 236, 255, 3, NULL),
(2500, '四会市', 236, 255, 3, NULL),
(2501, '市辖区', 237, 255, 3, NULL),
(2502, '惠城区', 237, 255, 3, NULL),
(2503, '惠阳区', 237, 255, 3, NULL),
(2504, '博罗县', 237, 255, 3, NULL),
(2505, '惠东县', 237, 255, 3, NULL),
(2506, '龙门县', 237, 255, 3, NULL),
(2507, '市辖区', 238, 255, 3, NULL),
(2508, '梅江区', 238, 255, 3, NULL),
(2509, '梅县区', 238, 255, 3, NULL),
(2510, '大埔县', 238, 255, 3, NULL),
(2511, '丰顺县', 238, 255, 3, NULL),
(2512, '五华县', 238, 255, 3, NULL),
(2513, '平远县', 238, 255, 3, NULL),
(2514, '蕉岭县', 238, 255, 3, NULL),
(2515, '兴宁市', 238, 255, 3, NULL),
(2516, '市辖区', 239, 255, 3, NULL),
(2517, '城区', 239, 255, 3, NULL),
(2518, '海丰县', 239, 255, 3, NULL),
(2519, '陆河县', 239, 255, 3, NULL),
(2520, '陆丰市', 239, 255, 3, NULL),
(2521, '市辖区', 240, 255, 3, NULL),
(2522, '源城区', 240, 255, 3, NULL),
(2523, '紫金县', 240, 255, 3, NULL),
(2524, '龙川县', 240, 255, 3, NULL),
(2525, '连平县', 240, 255, 3, NULL),
(2526, '和平县', 240, 255, 3, NULL),
(2527, '东源县', 240, 255, 3, NULL),
(2528, '市辖区', 241, 255, 3, NULL),
(2529, '江城区', 241, 255, 3, NULL),
(2530, '阳东区', 241, 255, 3, NULL),
(2531, '阳西县', 241, 255, 3, NULL),
(2532, '阳春市', 241, 255, 3, NULL),
(2533, '市辖区', 242, 255, 3, NULL),
(2534, '清城区', 242, 255, 3, NULL),
(2535, '清新区', 242, 255, 3, NULL),
(2536, '佛冈县', 242, 255, 3, NULL),
(2537, '阳山县', 242, 255, 3, NULL),
(2538, '连山壮族瑶族自治县', 242, 255, 3, NULL),
(2539, '连南瑶族自治县', 242, 255, 3, NULL),
(2540, '英德市', 242, 255, 3, NULL),
(2541, '连州市', 242, 255, 3, NULL),
(2542, '市辖区', 245, 255, 3, NULL),
(2543, '湘桥区', 245, 255, 3, NULL),
(2544, '潮安区', 245, 255, 3, NULL),
(2545, '饶平县', 245, 255, 3, NULL),
(2546, '市辖区', 246, 255, 3, NULL),
(2547, '榕城区', 246, 255, 3, NULL),
(2548, '揭东区', 246, 255, 3, NULL),
(2549, '揭西县', 246, 255, 3, NULL),
(2550, '惠来县', 246, 255, 3, NULL),
(2551, '普宁市', 246, 255, 3, NULL),
(2552, '市辖区', 247, 255, 3, NULL),
(2553, '云城区', 247, 255, 3, NULL),
(2554, '云安区', 247, 255, 3, NULL),
(2555, '新兴县', 247, 255, 3, NULL),
(2556, '郁南县', 247, 255, 3, NULL),
(2557, '罗定市', 247, 255, 3, NULL),
(2558, '市辖区', 248, 255, 3, NULL),
(2559, '兴宁区', 248, 255, 3, NULL),
(2560, '青秀区', 248, 255, 3, NULL),
(2561, '江南区', 248, 255, 3, NULL),
(2562, '西乡塘区', 248, 255, 3, NULL),
(2563, '良庆区', 248, 255, 3, NULL),
(2564, '邕宁区', 248, 255, 3, NULL),
(2565, '武鸣区', 248, 255, 3, NULL),
(2566, '隆安县', 248, 255, 3, NULL),
(2567, '马山县', 248, 255, 3, NULL),
(2568, '上林县', 248, 255, 3, NULL),
(2569, '宾阳县', 248, 255, 3, NULL),
(2570, '横县', 248, 255, 3, NULL),
(2571, '市辖区', 249, 255, 3, NULL),
(2572, '城中区', 249, 255, 3, NULL),
(2573, '鱼峰区', 249, 255, 3, NULL);
INSERT INTO `#__area` (`area_id`, `area_name`, `area_parent_id`, `area_sort`, `area_deep`, `area_region`) VALUES
(2574, '柳南区', 249, 255, 3, NULL),
(2575, '柳北区', 249, 255, 3, NULL),
(2576, '柳江区', 249, 255, 3, NULL),
(2577, '柳城县', 249, 255, 3, NULL),
(2578, '鹿寨县', 249, 255, 3, NULL),
(2579, '融安县', 249, 255, 3, NULL),
(2580, '融水苗族自治县', 249, 255, 3, NULL),
(2581, '三江侗族自治县', 249, 255, 3, NULL),
(2582, '市辖区', 250, 255, 3, NULL),
(2583, '秀峰区', 250, 255, 3, NULL),
(2584, '叠彩区', 250, 255, 3, NULL),
(2585, '象山区', 250, 255, 3, NULL),
(2586, '七星区', 250, 255, 3, NULL),
(2587, '雁山区', 250, 255, 3, NULL),
(2588, '临桂区', 250, 255, 3, NULL),
(2589, '阳朔县', 250, 255, 3, NULL),
(2590, '灵川县', 250, 255, 3, NULL),
(2591, '全州县', 250, 255, 3, NULL),
(2592, '兴安县', 250, 255, 3, NULL),
(2593, '永福县', 250, 255, 3, NULL),
(2594, '灌阳县', 250, 255, 3, NULL),
(2595, '龙胜各族自治县', 250, 255, 3, NULL),
(2596, '资源县', 250, 255, 3, NULL),
(2597, '平乐县', 250, 255, 3, NULL),
(2598, '恭城瑶族自治县', 250, 255, 3, NULL),
(2599, '荔浦市', 250, 255, 3, NULL),
(2600, '市辖区', 251, 255, 3, NULL),
(2601, '万秀区', 251, 255, 3, NULL),
(2602, '长洲区', 251, 255, 3, NULL),
(2603, '龙圩区', 251, 255, 3, NULL),
(2604, '苍梧县', 251, 255, 3, NULL),
(2605, '藤县', 251, 255, 3, NULL),
(2606, '蒙山县', 251, 255, 3, NULL),
(2607, '岑溪市', 251, 255, 3, NULL),
(2608, '市辖区', 252, 255, 3, NULL),
(2609, '海城区', 252, 255, 3, NULL),
(2610, '银海区', 252, 255, 3, NULL),
(2611, '铁山港区', 252, 255, 3, NULL),
(2612, '合浦县', 252, 255, 3, NULL),
(2613, '市辖区', 253, 255, 3, NULL),
(2614, '港口区', 253, 255, 3, NULL),
(2615, '防城区', 253, 255, 3, NULL),
(2616, '上思县', 253, 255, 3, NULL),
(2617, '东兴市', 253, 255, 3, NULL),
(2618, '市辖区', 254, 255, 3, NULL),
(2619, '钦南区', 254, 255, 3, NULL),
(2620, '钦北区', 254, 255, 3, NULL),
(2621, '灵山县', 254, 255, 3, NULL),
(2622, '浦北县', 254, 255, 3, NULL),
(2623, '市辖区', 255, 255, 3, NULL),
(2624, '港北区', 255, 255, 3, NULL),
(2625, '港南区', 255, 255, 3, NULL),
(2626, '覃塘区', 255, 255, 3, NULL),
(2627, '平南县', 255, 255, 3, NULL),
(2628, '桂平市', 255, 255, 3, NULL),
(2629, '市辖区', 256, 255, 3, NULL),
(2630, '玉州区', 256, 255, 3, NULL),
(2631, '福绵区', 256, 255, 3, NULL),
(2632, '容县', 256, 255, 3, NULL),
(2633, '陆川县', 256, 255, 3, NULL),
(2634, '博白县', 256, 255, 3, NULL),
(2635, '兴业县', 256, 255, 3, NULL),
(2636, '北流市', 256, 255, 3, NULL),
(2637, '市辖区', 257, 255, 3, NULL),
(2638, '右江区', 257, 255, 3, NULL),
(2639, '田阳区', 257, 255, 3, NULL),
(2640, '田东县', 257, 255, 3, NULL),
(2641, '德保县', 257, 255, 3, NULL),
(2642, '那坡县', 257, 255, 3, NULL),
(2643, '凌云县', 257, 255, 3, NULL),
(2644, '乐业县', 257, 255, 3, NULL),
(2645, '田林县', 257, 255, 3, NULL),
(2646, '西林县', 257, 255, 3, NULL),
(2647, '隆林各族自治县', 257, 255, 3, NULL),
(2648, '靖西市', 257, 255, 3, NULL),
(2649, '平果市', 257, 255, 3, NULL),
(2650, '市辖区', 258, 255, 3, NULL),
(2651, '八步区', 258, 255, 3, NULL),
(2652, '平桂区', 258, 255, 3, NULL),
(2653, '昭平县', 258, 255, 3, NULL),
(2654, '钟山县', 258, 255, 3, NULL),
(2655, '富川瑶族自治县', 258, 255, 3, NULL),
(2656, '市辖区', 259, 255, 3, NULL),
(2657, '金城江区', 259, 255, 3, NULL),
(2658, '宜州区', 259, 255, 3, NULL),
(2659, '南丹县', 259, 255, 3, NULL),
(2660, '天峨县', 259, 255, 3, NULL),
(2661, '凤山县', 259, 255, 3, NULL),
(2662, '东兰县', 259, 255, 3, NULL),
(2663, '罗城仫佬族自治县', 259, 255, 3, NULL),
(2664, '环江毛南族自治县', 259, 255, 3, NULL),
(2665, '巴马瑶族自治县', 259, 255, 3, NULL),
(2666, '都安瑶族自治县', 259, 255, 3, NULL),
(2667, '大化瑶族自治县', 259, 255, 3, NULL),
(2668, '市辖区', 260, 255, 3, NULL),
(2669, '兴宾区', 260, 255, 3, NULL),
(2670, '忻城县', 260, 255, 3, NULL),
(2671, '象州县', 260, 255, 3, NULL),
(2672, '武宣县', 260, 255, 3, NULL),
(2673, '金秀瑶族自治县', 260, 255, 3, NULL),
(2674, '合山市', 260, 255, 3, NULL),
(2675, '市辖区', 261, 255, 3, NULL),
(2676, '江州区', 261, 255, 3, NULL),
(2677, '扶绥县', 261, 255, 3, NULL),
(2678, '宁明县', 261, 255, 3, NULL),
(2679, '龙州县', 261, 255, 3, NULL),
(2680, '大新县', 261, 255, 3, NULL),
(2681, '天等县', 261, 255, 3, NULL),
(2682, '凭祥市', 261, 255, 3, NULL),
(2683, '市辖区', 262, 255, 3, NULL),
(2684, '秀英区', 262, 255, 3, NULL),
(2685, '龙华区', 262, 255, 3, NULL),
(2686, '琼山区', 262, 255, 3, NULL),
(2687, '美兰区', 262, 255, 3, NULL),
(2688, '市辖区', 263, 255, 3, NULL),
(2689, '海棠区', 263, 255, 3, NULL),
(2690, '吉阳区', 263, 255, 3, NULL),
(2691, '天涯区', 263, 255, 3, NULL),
(2692, '崖州区', 263, 255, 3, NULL),
(2693, '西沙群岛', 264, 255, 3, NULL),
(2694, '南沙群岛', 264, 255, 3, NULL),
(2695, '中沙群岛的岛礁及其海域', 264, 255, 3, NULL),
(2696, '五指山市', 266, 255, 3, NULL),
(2697, '琼海市', 266, 255, 3, NULL),
(2698, '文昌市', 266, 255, 3, NULL),
(2699, '万宁市', 266, 255, 3, NULL),
(2700, '东方市', 266, 255, 3, NULL),
(2701, '定安县', 266, 255, 3, NULL),
(2702, '屯昌县', 266, 255, 3, NULL),
(2703, '澄迈县', 266, 255, 3, NULL),
(2704, '临高县', 266, 255, 3, NULL),
(2705, '白沙黎族自治县', 266, 255, 3, NULL),
(2706, '昌江黎族自治县', 266, 255, 3, NULL),
(2707, '乐东黎族自治县', 266, 255, 3, NULL),
(2708, '陵水黎族自治县', 266, 255, 3, NULL),
(2709, '保亭黎族苗族自治县', 266, 255, 3, NULL),
(2710, '琼中黎族苗族自治县', 266, 255, 3, NULL),
(2711, '万州区', 267, 255, 3, NULL),
(2712, '涪陵区', 267, 255, 3, NULL),
(2713, '渝中区', 267, 255, 3, NULL),
(2714, '大渡口区', 267, 255, 3, NULL),
(2715, '江北区', 267, 255, 3, NULL),
(2716, '沙坪坝区', 267, 255, 3, NULL),
(2717, '九龙坡区', 267, 255, 3, NULL),
(2718, '南岸区', 267, 255, 3, NULL),
(2719, '北碚区', 267, 255, 3, NULL),
(2720, '綦江区', 267, 255, 3, NULL),
(2721, '大足区', 267, 255, 3, NULL),
(2722, '渝北区', 267, 255, 3, NULL),
(2723, '巴南区', 267, 255, 3, NULL),
(2724, '黔江区', 267, 255, 3, NULL),
(2725, '长寿区', 267, 255, 3, NULL),
(2726, '江津区', 267, 255, 3, NULL),
(2727, '合川区', 267, 255, 3, NULL),
(2728, '永川区', 267, 255, 3, NULL),
(2729, '南川区', 267, 255, 3, NULL),
(2730, '璧山区', 267, 255, 3, NULL),
(2731, '铜梁区', 267, 255, 3, NULL),
(2732, '潼南区', 267, 255, 3, NULL),
(2733, '荣昌区', 267, 255, 3, NULL),
(2734, '开州区', 267, 255, 3, NULL),
(2735, '梁平区', 267, 255, 3, NULL),
(2736, '武隆区', 267, 255, 3, NULL),
(2737, '城口县', 268, 255, 3, NULL),
(2738, '丰都县', 268, 255, 3, NULL),
(2739, '垫江县', 268, 255, 3, NULL),
(2740, '忠县', 268, 255, 3, NULL),
(2741, '云阳县', 268, 255, 3, NULL),
(2742, '奉节县', 268, 255, 3, NULL),
(2743, '巫山县', 268, 255, 3, NULL),
(2744, '巫溪县', 268, 255, 3, NULL),
(2745, '石柱土家族自治县', 268, 255, 3, NULL),
(2746, '秀山土家族苗族自治县', 268, 255, 3, NULL),
(2747, '酉阳土家族苗族自治县', 268, 255, 3, NULL),
(2748, '彭水苗族土家族自治县', 268, 255, 3, NULL),
(2749, '市辖区', 269, 255, 3, NULL),
(2750, '锦江区', 269, 255, 3, NULL),
(2751, '青羊区', 269, 255, 3, NULL),
(2752, '金牛区', 269, 255, 3, NULL),
(2753, '武侯区', 269, 255, 3, NULL),
(2754, '成华区', 269, 255, 3, NULL),
(2755, '龙泉驿区', 269, 255, 3, NULL),
(2756, '青白江区', 269, 255, 3, NULL),
(2757, '新都区', 269, 255, 3, NULL),
(2758, '温江区', 269, 255, 3, NULL),
(2759, '双流区', 269, 255, 3, NULL),
(2760, '郫都区', 269, 255, 3, NULL),
(2761, '新津区', 269, 255, 3, NULL),
(2762, '金堂县', 269, 255, 3, NULL),
(2763, '大邑县', 269, 255, 3, NULL),
(2764, '蒲江县', 269, 255, 3, NULL),
(2765, '都江堰市', 269, 255, 3, NULL),
(2766, '彭州市', 269, 255, 3, NULL),
(2767, '邛崃市', 269, 255, 3, NULL),
(2768, '崇州市', 269, 255, 3, NULL),
(2769, '简阳市', 269, 255, 3, NULL),
(2770, '市辖区', 270, 255, 3, NULL),
(2771, '自流井区', 270, 255, 3, NULL),
(2772, '贡井区', 270, 255, 3, NULL),
(2773, '大安区', 270, 255, 3, NULL),
(2774, '沿滩区', 270, 255, 3, NULL),
(2775, '荣县', 270, 255, 3, NULL),
(2776, '富顺县', 270, 255, 3, NULL),
(2777, '市辖区', 271, 255, 3, NULL),
(2778, '东区', 271, 255, 3, NULL),
(2779, '西区', 271, 255, 3, NULL),
(2780, '仁和区', 271, 255, 3, NULL),
(2781, '米易县', 271, 255, 3, NULL),
(2782, '盐边县', 271, 255, 3, NULL),
(2783, '市辖区', 272, 255, 3, NULL),
(2784, '江阳区', 272, 255, 3, NULL),
(2785, '纳溪区', 272, 255, 3, NULL),
(2786, '龙马潭区', 272, 255, 3, NULL),
(2787, '泸县', 272, 255, 3, NULL),
(2788, '合江县', 272, 255, 3, NULL),
(2789, '叙永县', 272, 255, 3, NULL),
(2790, '古蔺县', 272, 255, 3, NULL),
(2791, '市辖区', 273, 255, 3, NULL),
(2792, '旌阳区', 273, 255, 3, NULL),
(2793, '罗江区', 273, 255, 3, NULL),
(2794, '中江县', 273, 255, 3, NULL),
(2795, '广汉市', 273, 255, 3, NULL),
(2796, '什邡市', 273, 255, 3, NULL),
(2797, '绵竹市', 273, 255, 3, NULL),
(2798, '市辖区', 274, 255, 3, NULL),
(2799, '涪城区', 274, 255, 3, NULL),
(2800, '游仙区', 274, 255, 3, NULL),
(2801, '安州区', 274, 255, 3, NULL),
(2802, '三台县', 274, 255, 3, NULL),
(2803, '盐亭县', 274, 255, 3, NULL),
(2804, '梓潼县', 274, 255, 3, NULL),
(2805, '北川羌族自治县', 274, 255, 3, NULL),
(2806, '平武县', 274, 255, 3, NULL),
(2807, '江油市', 274, 255, 3, NULL),
(2808, '市辖区', 275, 255, 3, NULL),
(2809, '利州区', 275, 255, 3, NULL),
(2810, '昭化区', 275, 255, 3, NULL),
(2811, '朝天区', 275, 255, 3, NULL),
(2812, '旺苍县', 275, 255, 3, NULL),
(2813, '青川县', 275, 255, 3, NULL),
(2814, '剑阁县', 275, 255, 3, NULL),
(2815, '苍溪县', 275, 255, 3, NULL),
(2816, '市辖区', 276, 255, 3, NULL),
(2817, '船山区', 276, 255, 3, NULL),
(2818, '安居区', 276, 255, 3, NULL),
(2819, '蓬溪县', 276, 255, 3, NULL),
(2820, '大英县', 276, 255, 3, NULL),
(2821, '射洪市', 276, 255, 3, NULL),
(2822, '市辖区', 277, 255, 3, NULL),
(2823, '市中区', 277, 255, 3, NULL),
(2824, '东兴区', 277, 255, 3, NULL),
(2825, '威远县', 277, 255, 3, NULL),
(2826, '资中县', 277, 255, 3, NULL),
(2827, '内江经济开发区', 277, 255, 3, NULL),
(2828, '隆昌市', 277, 255, 3, NULL),
(2829, '市辖区', 278, 255, 3, NULL),
(2830, '市中区', 278, 255, 3, NULL),
(2831, '沙湾区', 278, 255, 3, NULL),
(2832, '五通桥区', 278, 255, 3, NULL),
(2833, '金口河区', 278, 255, 3, NULL),
(2834, '犍为县', 278, 255, 3, NULL),
(2835, '井研县', 278, 255, 3, NULL),
(2836, '夹江县', 278, 255, 3, NULL),
(2837, '沐川县', 278, 255, 3, NULL),
(2838, '峨边彝族自治县', 278, 255, 3, NULL),
(2839, '马边彝族自治县', 278, 255, 3, NULL),
(2840, '峨眉山市', 278, 255, 3, NULL),
(2841, '市辖区', 279, 255, 3, NULL),
(2842, '顺庆区', 279, 255, 3, NULL),
(2843, '高坪区', 279, 255, 3, NULL),
(2844, '嘉陵区', 279, 255, 3, NULL),
(2845, '南部县', 279, 255, 3, NULL),
(2846, '营山县', 279, 255, 3, NULL),
(2847, '蓬安县', 279, 255, 3, NULL),
(2848, '仪陇县', 279, 255, 3, NULL),
(2849, '西充县', 279, 255, 3, NULL),
(2850, '阆中市', 279, 255, 3, NULL),
(2851, '市辖区', 280, 255, 3, NULL),
(2852, '东坡区', 280, 255, 3, NULL),
(2853, '彭山区', 280, 255, 3, NULL),
(2854, '仁寿县', 280, 255, 3, NULL),
(2855, '洪雅县', 280, 255, 3, NULL),
(2856, '丹棱县', 280, 255, 3, NULL),
(2857, '青神县', 280, 255, 3, NULL),
(2858, '市辖区', 281, 255, 3, NULL),
(2859, '翠屏区', 281, 255, 3, NULL),
(2860, '南溪区', 281, 255, 3, NULL),
(2861, '叙州区', 281, 255, 3, NULL),
(2862, '江安县', 281, 255, 3, NULL),
(2863, '长宁县', 281, 255, 3, NULL),
(2864, '高县', 281, 255, 3, NULL),
(2865, '珙县', 281, 255, 3, NULL),
(2866, '筠连县', 281, 255, 3, NULL),
(2867, '兴文县', 281, 255, 3, NULL),
(2868, '屏山县', 281, 255, 3, NULL),
(2869, '市辖区', 282, 255, 3, NULL),
(2870, '广安区', 282, 255, 3, NULL),
(2871, '前锋区', 282, 255, 3, NULL),
(2872, '岳池县', 282, 255, 3, NULL),
(2873, '武胜县', 282, 255, 3, NULL),
(2874, '邻水县', 282, 255, 3, NULL),
(2875, '华蓥市', 282, 255, 3, NULL),
(2876, '市辖区', 283, 255, 3, NULL),
(2877, '通川区', 283, 255, 3, NULL),
(2878, '达川区', 283, 255, 3, NULL),
(2879, '宣汉县', 283, 255, 3, NULL),
(2880, '开江县', 283, 255, 3, NULL),
(2881, '大竹县', 283, 255, 3, NULL),
(2882, '渠县', 283, 255, 3, NULL),
(2883, '达州经济开发区', 283, 255, 3, NULL),
(2884, '万源市', 283, 255, 3, NULL),
(2885, '市辖区', 284, 255, 3, NULL),
(2886, '雨城区', 284, 255, 3, NULL),
(2887, '名山区', 284, 255, 3, NULL),
(2888, '荥经县', 284, 255, 3, NULL),
(2889, '汉源县', 284, 255, 3, NULL),
(2890, '石棉县', 284, 255, 3, NULL),
(2891, '天全县', 284, 255, 3, NULL),
(2892, '芦山县', 284, 255, 3, NULL),
(2893, '宝兴县', 284, 255, 3, NULL),
(2894, '市辖区', 285, 255, 3, NULL),
(2895, '巴州区', 285, 255, 3, NULL),
(2896, '恩阳区', 285, 255, 3, NULL),
(2897, '通江县', 285, 255, 3, NULL),
(2898, '南江县', 285, 255, 3, NULL),
(2899, '平昌县', 285, 255, 3, NULL),
(2900, '巴中经济开发区', 285, 255, 3, NULL),
(2901, '市辖区', 286, 255, 3, NULL),
(2902, '雁江区', 286, 255, 3, NULL),
(2903, '安岳县', 286, 255, 3, NULL),
(2904, '乐至县', 286, 255, 3, NULL),
(2905, '马尔康市', 287, 255, 3, NULL),
(2906, '汶川县', 287, 255, 3, NULL),
(2907, '理县', 287, 255, 3, NULL),
(2908, '茂县', 287, 255, 3, NULL),
(2909, '松潘县', 287, 255, 3, NULL),
(2910, '九寨沟县', 287, 255, 3, NULL),
(2911, '金川县', 287, 255, 3, NULL),
(2912, '小金县', 287, 255, 3, NULL),
(2913, '黑水县', 287, 255, 3, NULL),
(2914, '壤塘县', 287, 255, 3, NULL),
(2915, '阿坝县', 287, 255, 3, NULL),
(2916, '若尔盖县', 287, 255, 3, NULL),
(2917, '红原县', 287, 255, 3, NULL),
(2918, '康定市', 288, 255, 3, NULL),
(2919, '泸定县', 288, 255, 3, NULL),
(2920, '丹巴县', 288, 255, 3, NULL),
(2921, '九龙县', 288, 255, 3, NULL),
(2922, '雅江县', 288, 255, 3, NULL),
(2923, '道孚县', 288, 255, 3, NULL),
(2924, '炉霍县', 288, 255, 3, NULL),
(2925, '甘孜县', 288, 255, 3, NULL),
(2926, '新龙县', 288, 255, 3, NULL),
(2927, '德格县', 288, 255, 3, NULL),
(2928, '白玉县', 288, 255, 3, NULL),
(2929, '石渠县', 288, 255, 3, NULL),
(2930, '色达县', 288, 255, 3, NULL),
(2931, '理塘县', 288, 255, 3, NULL),
(2932, '巴塘县', 288, 255, 3, NULL),
(2933, '乡城县', 288, 255, 3, NULL),
(2934, '稻城县', 288, 255, 3, NULL),
(2935, '得荣县', 288, 255, 3, NULL),
(2936, '西昌市', 289, 255, 3, NULL),
(2937, '木里藏族自治县', 289, 255, 3, NULL),
(2938, '盐源县', 289, 255, 3, NULL),
(2939, '德昌县', 289, 255, 3, NULL),
(2940, '会理县', 289, 255, 3, NULL),
(2941, '会东县', 289, 255, 3, NULL),
(2942, '宁南县', 289, 255, 3, NULL),
(2943, '普格县', 289, 255, 3, NULL),
(2944, '布拖县', 289, 255, 3, NULL),
(2945, '金阳县', 289, 255, 3, NULL),
(2946, '昭觉县', 289, 255, 3, NULL),
(2947, '喜德县', 289, 255, 3, NULL),
(2948, '冕宁县', 289, 255, 3, NULL),
(2949, '越西县', 289, 255, 3, NULL),
(2950, '甘洛县', 289, 255, 3, NULL),
(2951, '美姑县', 289, 255, 3, NULL),
(2952, '雷波县', 289, 255, 3, NULL),
(2953, '市辖区', 290, 255, 3, NULL),
(2954, '南明区', 290, 255, 3, NULL),
(2955, '云岩区', 290, 255, 3, NULL),
(2956, '花溪区', 290, 255, 3, NULL),
(2957, '乌当区', 290, 255, 3, NULL),
(2958, '白云区', 290, 255, 3, NULL),
(2959, '观山湖区', 290, 255, 3, NULL),
(2960, '开阳县', 290, 255, 3, NULL),
(2961, '息烽县', 290, 255, 3, NULL),
(2962, '修文县', 290, 255, 3, NULL),
(2963, '清镇市', 290, 255, 3, NULL),
(2964, '钟山区', 291, 255, 3, NULL),
(2965, '六枝特区', 291, 255, 3, NULL),
(2966, '水城县', 291, 255, 3, NULL),
(2967, '盘州市', 291, 255, 3, NULL),
(2968, '市辖区', 292, 255, 3, NULL),
(2969, '红花岗区', 292, 255, 3, NULL),
(2970, '汇川区', 292, 255, 3, NULL),
(2971, '播州区', 292, 255, 3, NULL),
(2972, '桐梓县', 292, 255, 3, NULL),
(2973, '绥阳县', 292, 255, 3, NULL),
(2974, '正安县', 292, 255, 3, NULL),
(2975, '道真仡佬族苗族自治县', 292, 255, 3, NULL),
(2976, '务川仡佬族苗族自治县', 292, 255, 3, NULL),
(2977, '凤冈县', 292, 255, 3, NULL),
(2978, '湄潭县', 292, 255, 3, NULL),
(2979, '余庆县', 292, 255, 3, NULL),
(2980, '习水县', 292, 255, 3, NULL),
(2981, '赤水市', 292, 255, 3, NULL),
(2982, '仁怀市', 292, 255, 3, NULL),
(2983, '市辖区', 293, 255, 3, NULL),
(2984, '西秀区', 293, 255, 3, NULL),
(2985, '平坝区', 293, 255, 3, NULL),
(2986, '普定县', 293, 255, 3, NULL),
(2987, '镇宁布依族苗族自治县', 293, 255, 3, NULL),
(2988, '关岭布依族苗族自治县', 293, 255, 3, NULL),
(2989, '紫云苗族布依族自治县', 293, 255, 3, NULL),
(2990, '市辖区', 294, 255, 3, NULL),
(2991, '七星关区', 294, 255, 3, NULL),
(2992, '大方县', 294, 255, 3, NULL),
(2993, '黔西县', 294, 255, 3, NULL),
(2994, '金沙县', 294, 255, 3, NULL),
(2995, '织金县', 294, 255, 3, NULL),
(2996, '纳雍县', 294, 255, 3, NULL),
(2997, '威宁彝族回族苗族自治县', 294, 255, 3, NULL),
(2998, '赫章县', 294, 255, 3, NULL),
(2999, '市辖区', 295, 255, 3, NULL),
(3000, '碧江区', 295, 255, 3, NULL),
(3001, '万山区', 295, 255, 3, NULL),
(3002, '江口县', 295, 255, 3, NULL),
(3003, '玉屏侗族自治县', 295, 255, 3, NULL),
(3004, '石阡县', 295, 255, 3, NULL),
(3005, '思南县', 295, 255, 3, NULL),
(3006, '印江土家族苗族自治县', 295, 255, 3, NULL),
(3007, '德江县', 295, 255, 3, NULL),
(3008, '沿河土家族自治县', 295, 255, 3, NULL),
(3009, '松桃苗族自治县', 295, 255, 3, NULL),
(3010, '兴义市', 296, 255, 3, NULL),
(3011, '兴仁市', 296, 255, 3, NULL),
(3012, '普安县', 296, 255, 3, NULL),
(3013, '晴隆县', 296, 255, 3, NULL),
(3014, '贞丰县', 296, 255, 3, NULL),
(3015, '望谟县', 296, 255, 3, NULL),
(3016, '册亨县', 296, 255, 3, NULL),
(3017, '安龙县', 296, 255, 3, NULL),
(3018, '凯里市', 297, 255, 3, NULL),
(3019, '黄平县', 297, 255, 3, NULL),
(3020, '施秉县', 297, 255, 3, NULL),
(3021, '三穗县', 297, 255, 3, NULL),
(3022, '镇远县', 297, 255, 3, NULL),
(3023, '岑巩县', 297, 255, 3, NULL),
(3024, '天柱县', 297, 255, 3, NULL),
(3025, '锦屏县', 297, 255, 3, NULL),
(3026, '剑河县', 297, 255, 3, NULL),
(3027, '台江县', 297, 255, 3, NULL),
(3028, '黎平县', 297, 255, 3, NULL),
(3029, '榕江县', 297, 255, 3, NULL),
(3030, '从江县', 297, 255, 3, NULL),
(3031, '雷山县', 297, 255, 3, NULL),
(3032, '麻江县', 297, 255, 3, NULL),
(3033, '丹寨县', 297, 255, 3, NULL),
(3034, '都匀市', 298, 255, 3, NULL),
(3035, '福泉市', 298, 255, 3, NULL),
(3036, '荔波县', 298, 255, 3, NULL),
(3037, '贵定县', 298, 255, 3, NULL),
(3038, '瓮安县', 298, 255, 3, NULL),
(3039, '独山县', 298, 255, 3, NULL),
(3040, '平塘县', 298, 255, 3, NULL),
(3041, '罗甸县', 298, 255, 3, NULL),
(3042, '长顺县', 298, 255, 3, NULL),
(3043, '龙里县', 298, 255, 3, NULL),
(3044, '惠水县', 298, 255, 3, NULL),
(3045, '三都水族自治县', 298, 255, 3, NULL),
(3046, '市辖区', 299, 255, 3, NULL),
(3047, '五华区', 299, 255, 3, NULL),
(3048, '盘龙区', 299, 255, 3, NULL),
(3049, '官渡区', 299, 255, 3, NULL),
(3050, '西山区', 299, 255, 3, NULL),
(3051, '东川区', 299, 255, 3, NULL),
(3052, '呈贡区', 299, 255, 3, NULL),
(3053, '晋宁区', 299, 255, 3, NULL),
(3054, '富民县', 299, 255, 3, NULL),
(3055, '宜良县', 299, 255, 3, NULL),
(3056, '石林彝族自治县', 299, 255, 3, NULL),
(3057, '嵩明县', 299, 255, 3, NULL),
(3058, '禄劝彝族苗族自治县', 299, 255, 3, NULL),
(3059, '寻甸回族彝族自治县', 299, 255, 3, NULL),
(3060, '安宁市', 299, 255, 3, NULL),
(3061, '市辖区', 300, 255, 3, NULL),
(3062, '麒麟区', 300, 255, 3, NULL),
(3063, '沾益区', 300, 255, 3, NULL),
(3064, '马龙区', 300, 255, 3, NULL),
(3065, '陆良县', 300, 255, 3, NULL),
(3066, '师宗县', 300, 255, 3, NULL),
(3067, '罗平县', 300, 255, 3, NULL),
(3068, '富源县', 300, 255, 3, NULL),
(3069, '会泽县', 300, 255, 3, NULL),
(3070, '宣威市', 300, 255, 3, NULL),
(3071, '市辖区', 301, 255, 3, NULL),
(3072, '红塔区', 301, 255, 3, NULL),
(3073, '江川区', 301, 255, 3, NULL),
(3074, '通海县', 301, 255, 3, NULL),
(3075, '华宁县', 301, 255, 3, NULL),
(3076, '易门县', 301, 255, 3, NULL),
(3077, '峨山彝族自治县', 301, 255, 3, NULL),
(3078, '新平彝族傣族自治县', 301, 255, 3, NULL),
(3079, '元江哈尼族彝族傣族自治县', 301, 255, 3, NULL),
(3080, '澄江市', 301, 255, 3, NULL),
(3081, '市辖区', 302, 255, 3, NULL),
(3082, '隆阳区', 302, 255, 3, NULL),
(3083, '施甸县', 302, 255, 3, NULL),
(3084, '龙陵县', 302, 255, 3, NULL),
(3085, '昌宁县', 302, 255, 3, NULL),
(3086, '腾冲市', 302, 255, 3, NULL),
(3087, '市辖区', 303, 255, 3, NULL),
(3088, '昭阳区', 303, 255, 3, NULL),
(3089, '鲁甸县', 303, 255, 3, NULL),
(3090, '巧家县', 303, 255, 3, NULL),
(3091, '盐津县', 303, 255, 3, NULL),
(3092, '大关县', 303, 255, 3, NULL),
(3093, '永善县', 303, 255, 3, NULL),
(3094, '绥江县', 303, 255, 3, NULL),
(3095, '镇雄县', 303, 255, 3, NULL),
(3096, '彝良县', 303, 255, 3, NULL),
(3097, '威信县', 303, 255, 3, NULL),
(3098, '水富市', 303, 255, 3, NULL),
(3099, '市辖区', 304, 255, 3, NULL),
(3100, '古城区', 304, 255, 3, NULL),
(3101, '玉龙纳西族自治县', 304, 255, 3, NULL),
(3102, '永胜县', 304, 255, 3, NULL),
(3103, '华坪县', 304, 255, 3, NULL),
(3104, '宁蒗彝族自治县', 304, 255, 3, NULL),
(3105, '市辖区', 305, 255, 3, NULL),
(3106, '思茅区', 305, 255, 3, NULL),
(3107, '宁洱哈尼族彝族自治县', 305, 255, 3, NULL),
(3108, '墨江哈尼族自治县', 305, 255, 3, NULL),
(3109, '景东彝族自治县', 305, 255, 3, NULL),
(3110, '景谷傣族彝族自治县', 305, 255, 3, NULL),
(3111, '镇沅彝族哈尼族拉祜族自治县', 305, 255, 3, NULL),
(3112, '江城哈尼族彝族自治县', 305, 255, 3, NULL),
(3113, '孟连傣族拉祜族佤族自治县', 305, 255, 3, NULL),
(3114, '澜沧拉祜族自治县', 305, 255, 3, NULL),
(3115, '西盟佤族自治县', 305, 255, 3, NULL),
(3116, '市辖区', 306, 255, 3, NULL),
(3117, '临翔区', 306, 255, 3, NULL),
(3118, '凤庆县', 306, 255, 3, NULL),
(3119, '云县', 306, 255, 3, NULL),
(3120, '永德县', 306, 255, 3, NULL),
(3121, '镇康县', 306, 255, 3, NULL),
(3122, '双江拉祜族佤族布朗族傣族自治县', 306, 255, 3, NULL),
(3123, '耿马傣族佤族自治县', 306, 255, 3, NULL),
(3124, '沧源佤族自治县', 306, 255, 3, NULL),
(3125, '楚雄市', 307, 255, 3, NULL),
(3126, '双柏县', 307, 255, 3, NULL),
(3127, '牟定县', 307, 255, 3, NULL),
(3128, '南华县', 307, 255, 3, NULL),
(3129, '姚安县', 307, 255, 3, NULL),
(3130, '大姚县', 307, 255, 3, NULL),
(3131, '永仁县', 307, 255, 3, NULL),
(3132, '元谋县', 307, 255, 3, NULL),
(3133, '武定县', 307, 255, 3, NULL),
(3134, '禄丰县', 307, 255, 3, NULL),
(3135, '个旧市', 308, 255, 3, NULL),
(3136, '开远市', 308, 255, 3, NULL),
(3137, '蒙自市', 308, 255, 3, NULL),
(3138, '弥勒市', 308, 255, 3, NULL),
(3139, '屏边苗族自治县', 308, 255, 3, NULL),
(3140, '建水县', 308, 255, 3, NULL),
(3141, '石屏县', 308, 255, 3, NULL),
(3142, '泸西县', 308, 255, 3, NULL),
(3143, '元阳县', 308, 255, 3, NULL),
(3144, '红河县', 308, 255, 3, NULL),
(3145, '金平苗族瑶族傣族自治县', 308, 255, 3, NULL),
(3146, '绿春县', 308, 255, 3, NULL),
(3147, '河口瑶族自治县', 308, 255, 3, NULL),
(3148, '文山市', 309, 255, 3, NULL),
(3149, '砚山县', 309, 255, 3, NULL),
(3150, '西畴县', 309, 255, 3, NULL),
(3151, '麻栗坡县', 309, 255, 3, NULL),
(3152, '马关县', 309, 255, 3, NULL),
(3153, '丘北县', 309, 255, 3, NULL),
(3154, '广南县', 309, 255, 3, NULL),
(3155, '富宁县', 309, 255, 3, NULL),
(3156, '景洪市', 310, 255, 3, NULL),
(3157, '勐海县', 310, 255, 3, NULL),
(3158, '勐腊县', 310, 255, 3, NULL),
(3159, '大理市', 311, 255, 3, NULL),
(3160, '漾濞彝族自治县', 311, 255, 3, NULL),
(3161, '祥云县', 311, 255, 3, NULL),
(3162, '宾川县', 311, 255, 3, NULL),
(3163, '弥渡县', 311, 255, 3, NULL),
(3164, '南涧彝族自治县', 311, 255, 3, NULL),
(3165, '巍山彝族回族自治县', 311, 255, 3, NULL),
(3166, '永平县', 311, 255, 3, NULL),
(3167, '云龙县', 311, 255, 3, NULL),
(3168, '洱源县', 311, 255, 3, NULL),
(3169, '剑川县', 311, 255, 3, NULL),
(3170, '鹤庆县', 311, 255, 3, NULL),
(3171, '瑞丽市', 312, 255, 3, NULL),
(3172, '芒市', 312, 255, 3, NULL),
(3173, '梁河县', 312, 255, 3, NULL),
(3174, '盈江县', 312, 255, 3, NULL),
(3175, '陇川县', 312, 255, 3, NULL),
(3176, '泸水市', 313, 255, 3, NULL),
(3177, '福贡县', 313, 255, 3, NULL),
(3178, '贡山独龙族怒族自治县', 313, 255, 3, NULL),
(3179, '兰坪白族普米族自治县', 313, 255, 3, NULL),
(3180, '香格里拉市', 314, 255, 3, NULL),
(3181, '德钦县', 314, 255, 3, NULL),
(3182, '维西傈僳族自治县', 314, 255, 3, NULL),
(3183, '市辖区', 315, 255, 3, NULL),
(3184, '城关区', 315, 255, 3, NULL),
(3185, '堆龙德庆区', 315, 255, 3, NULL),
(3186, '达孜区', 315, 255, 3, NULL),
(3187, '林周县', 315, 255, 3, NULL),
(3188, '当雄县', 315, 255, 3, NULL),
(3189, '尼木县', 315, 255, 3, NULL),
(3190, '曲水县', 315, 255, 3, NULL),
(3191, '墨竹工卡县', 315, 255, 3, NULL),
(3192, '格尔木藏青工业园区', 315, 255, 3, NULL),
(3193, '拉萨经济技术开发区', 315, 255, 3, NULL),
(3194, '西藏文化旅游创意园区', 315, 255, 3, NULL),
(3195, '达孜工业园区', 315, 255, 3, NULL),
(3196, '桑珠孜区', 316, 255, 3, NULL),
(3197, '南木林县', 316, 255, 3, NULL),
(3198, '江孜县', 316, 255, 3, NULL),
(3199, '定日县', 316, 255, 3, NULL),
(3200, '萨迦县', 316, 255, 3, NULL),
(3201, '拉孜县', 316, 255, 3, NULL),
(3202, '昂仁县', 316, 255, 3, NULL),
(3203, '谢通门县', 316, 255, 3, NULL),
(3204, '白朗县', 316, 255, 3, NULL),
(3205, '仁布县', 316, 255, 3, NULL),
(3206, '康马县', 316, 255, 3, NULL),
(3207, '定结县', 316, 255, 3, NULL),
(3208, '仲巴县', 316, 255, 3, NULL),
(3209, '亚东县', 316, 255, 3, NULL),
(3210, '吉隆县', 316, 255, 3, NULL),
(3211, '聂拉木县', 316, 255, 3, NULL),
(3212, '萨嘎县', 316, 255, 3, NULL),
(3213, '岗巴县', 316, 255, 3, NULL),
(3214, '卡若区', 317, 255, 3, NULL),
(3215, '江达县', 317, 255, 3, NULL),
(3216, '贡觉县', 317, 255, 3, NULL),
(3217, '类乌齐县', 317, 255, 3, NULL),
(3218, '丁青县', 317, 255, 3, NULL),
(3219, '察雅县', 317, 255, 3, NULL),
(3220, '八宿县', 317, 255, 3, NULL),
(3221, '左贡县', 317, 255, 3, NULL),
(3222, '芒康县', 317, 255, 3, NULL),
(3223, '洛隆县', 317, 255, 3, NULL),
(3224, '边坝县', 317, 255, 3, NULL),
(3225, '巴宜区', 318, 255, 3, NULL),
(3226, '工布江达县', 318, 255, 3, NULL),
(3227, '米林县', 318, 255, 3, NULL),
(3228, '墨脱县', 318, 255, 3, NULL),
(3229, '波密县', 318, 255, 3, NULL),
(3230, '察隅县', 318, 255, 3, NULL),
(3231, '朗县', 318, 255, 3, NULL),
(3232, '市辖区', 319, 255, 3, NULL),
(3233, '乃东区', 319, 255, 3, NULL),
(3234, '扎囊县', 319, 255, 3, NULL),
(3235, '贡嘎县', 319, 255, 3, NULL),
(3236, '桑日县', 319, 255, 3, NULL),
(3237, '琼结县', 319, 255, 3, NULL),
(3238, '曲松县', 319, 255, 3, NULL),
(3239, '措美县', 319, 255, 3, NULL),
(3240, '洛扎县', 319, 255, 3, NULL),
(3241, '加查县', 319, 255, 3, NULL),
(3242, '隆子县', 319, 255, 3, NULL),
(3243, '错那县', 319, 255, 3, NULL),
(3244, '浪卡子县', 319, 255, 3, NULL),
(3245, '色尼区', 320, 255, 3, NULL),
(3246, '嘉黎县', 320, 255, 3, NULL),
(3247, '比如县', 320, 255, 3, NULL),
(3248, '聂荣县', 320, 255, 3, NULL),
(3249, '安多县', 320, 255, 3, NULL),
(3250, '申扎县', 320, 255, 3, NULL),
(3251, '索县', 320, 255, 3, NULL),
(3252, '班戈县', 320, 255, 3, NULL),
(3253, '巴青县', 320, 255, 3, NULL),
(3254, '尼玛县', 320, 255, 3, NULL),
(3255, '双湖县', 320, 255, 3, NULL),
(3256, '普兰县', 321, 255, 3, NULL),
(3257, '札达县', 321, 255, 3, NULL),
(3258, '噶尔县', 321, 255, 3, NULL),
(3259, '日土县', 321, 255, 3, NULL),
(3260, '革吉县', 321, 255, 3, NULL),
(3261, '改则县', 321, 255, 3, NULL),
(3262, '措勤县', 321, 255, 3, NULL),
(3263, '市辖区', 322, 255, 3, NULL),
(3264, '新城区', 322, 255, 3, NULL),
(3265, '碑林区', 322, 255, 3, NULL),
(3266, '莲湖区', 322, 255, 3, NULL),
(3267, '灞桥区', 322, 255, 3, NULL),
(3268, '未央区', 322, 255, 3, NULL),
(3269, '雁塔区', 322, 255, 3, NULL),
(3270, '阎良区', 322, 255, 3, NULL),
(3271, '临潼区', 322, 255, 3, NULL),
(3272, '长安区', 322, 255, 3, NULL),
(3273, '高陵区', 322, 255, 3, NULL),
(3274, '鄠邑区', 322, 255, 3, NULL),
(3275, '蓝田县', 322, 255, 3, NULL),
(3276, '周至县', 322, 255, 3, NULL),
(3277, '市辖区', 323, 255, 3, NULL),
(3278, '王益区', 323, 255, 3, NULL),
(3279, '印台区', 323, 255, 3, NULL),
(3280, '耀州区', 323, 255, 3, NULL),
(3281, '宜君县', 323, 255, 3, NULL),
(3282, '市辖区', 324, 255, 3, NULL),
(3283, '渭滨区', 324, 255, 3, NULL),
(3284, '金台区', 324, 255, 3, NULL),
(3285, '陈仓区', 324, 255, 3, NULL),
(3286, '凤翔县', 324, 255, 3, NULL),
(3287, '岐山县', 324, 255, 3, NULL),
(3288, '扶风县', 324, 255, 3, NULL),
(3289, '眉县', 324, 255, 3, NULL),
(3290, '陇县', 324, 255, 3, NULL),
(3291, '千阳县', 324, 255, 3, NULL),
(3292, '麟游县', 324, 255, 3, NULL),
(3293, '凤县', 324, 255, 3, NULL),
(3294, '太白县', 324, 255, 3, NULL),
(3295, '市辖区', 325, 255, 3, NULL),
(3296, '秦都区', 325, 255, 3, NULL),
(3297, '杨陵区', 325, 255, 3, NULL),
(3298, '渭城区', 325, 255, 3, NULL),
(3299, '三原县', 325, 255, 3, NULL),
(3300, '泾阳县', 325, 255, 3, NULL),
(3301, '乾县', 325, 255, 3, NULL),
(3302, '礼泉县', 325, 255, 3, NULL),
(3303, '永寿县', 325, 255, 3, NULL),
(3304, '长武县', 325, 255, 3, NULL),
(3305, '旬邑县', 325, 255, 3, NULL),
(3306, '淳化县', 325, 255, 3, NULL),
(3307, '武功县', 325, 255, 3, NULL),
(3308, '兴平市', 325, 255, 3, NULL),
(3309, '彬州市', 325, 255, 3, NULL),
(3310, '市辖区', 326, 255, 3, NULL),
(3311, '临渭区', 326, 255, 3, NULL),
(3312, '华州区', 326, 255, 3, NULL),
(3313, '潼关县', 326, 255, 3, NULL),
(3314, '大荔县', 326, 255, 3, NULL),
(3315, '合阳县', 326, 255, 3, NULL),
(3316, '澄城县', 326, 255, 3, NULL),
(3317, '蒲城县', 326, 255, 3, NULL),
(3318, '白水县', 326, 255, 3, NULL),
(3319, '富平县', 326, 255, 3, NULL),
(3320, '韩城市', 326, 255, 3, NULL),
(3321, '华阴市', 326, 255, 3, NULL),
(3322, '市辖区', 327, 255, 3, NULL),
(3323, '宝塔区', 327, 255, 3, NULL),
(3324, '安塞区', 327, 255, 3, NULL),
(3325, '延长县', 327, 255, 3, NULL),
(3326, '延川县', 327, 255, 3, NULL),
(3327, '志丹县', 327, 255, 3, NULL),
(3328, '吴起县', 327, 255, 3, NULL),
(3329, '甘泉县', 327, 255, 3, NULL),
(3330, '富县', 327, 255, 3, NULL),
(3331, '洛川县', 327, 255, 3, NULL),
(3332, '宜川县', 327, 255, 3, NULL),
(3333, '黄龙县', 327, 255, 3, NULL),
(3334, '黄陵县', 327, 255, 3, NULL),
(3335, '子长市', 327, 255, 3, NULL),
(3336, '市辖区', 328, 255, 3, NULL),
(3337, '汉台区', 328, 255, 3, NULL),
(3338, '南郑区', 328, 255, 3, NULL),
(3339, '城固县', 328, 255, 3, NULL),
(3340, '洋县', 328, 255, 3, NULL),
(3341, '西乡县', 328, 255, 3, NULL),
(3342, '勉县', 328, 255, 3, NULL),
(3343, '宁强县', 328, 255, 3, NULL),
(3344, '略阳县', 328, 255, 3, NULL),
(3345, '镇巴县', 328, 255, 3, NULL),
(3346, '留坝县', 328, 255, 3, NULL),
(3347, '佛坪县', 328, 255, 3, NULL),
(3348, '市辖区', 329, 255, 3, NULL),
(3349, '榆阳区', 329, 255, 3, NULL),
(3350, '横山区', 329, 255, 3, NULL),
(3351, '府谷县', 329, 255, 3, NULL),
(3352, '靖边县', 329, 255, 3, NULL),
(3353, '定边县', 329, 255, 3, NULL),
(3354, '绥德县', 329, 255, 3, NULL),
(3355, '米脂县', 329, 255, 3, NULL),
(3356, '佳县', 329, 255, 3, NULL),
(3357, '吴堡县', 329, 255, 3, NULL),
(3358, '清涧县', 329, 255, 3, NULL),
(3359, '子洲县', 329, 255, 3, NULL),
(3360, '神木市', 329, 255, 3, NULL),
(3361, '市辖区', 330, 255, 3, NULL),
(3362, '汉滨区', 330, 255, 3, NULL),
(3363, '汉阴县', 330, 255, 3, NULL),
(3364, '石泉县', 330, 255, 3, NULL),
(3365, '宁陕县', 330, 255, 3, NULL),
(3366, '紫阳县', 330, 255, 3, NULL),
(3367, '岚皋县', 330, 255, 3, NULL),
(3368, '平利县', 330, 255, 3, NULL),
(3369, '镇坪县', 330, 255, 3, NULL),
(3370, '旬阳县', 330, 255, 3, NULL),
(3371, '白河县', 330, 255, 3, NULL),
(3372, '市辖区', 331, 255, 3, NULL),
(3373, '商州区', 331, 255, 3, NULL),
(3374, '洛南县', 331, 255, 3, NULL),
(3375, '丹凤县', 331, 255, 3, NULL),
(3376, '商南县', 331, 255, 3, NULL),
(3377, '山阳县', 331, 255, 3, NULL),
(3378, '镇安县', 331, 255, 3, NULL),
(3379, '柞水县', 331, 255, 3, NULL),
(3380, '市辖区', 332, 255, 3, NULL),
(3381, '城关区', 332, 255, 3, NULL),
(3382, '七里河区', 332, 255, 3, NULL),
(3383, '西固区', 332, 255, 3, NULL),
(3384, '安宁区', 332, 255, 3, NULL),
(3385, '红古区', 332, 255, 3, NULL),
(3386, '永登县', 332, 255, 3, NULL),
(3387, '皋兰县', 332, 255, 3, NULL),
(3388, '榆中县', 332, 255, 3, NULL),
(3389, '兰州新区', 332, 255, 3, NULL),
(3390, '市辖区', 333, 255, 3, NULL),
(3391, '市辖区', 334, 255, 3, NULL),
(3392, '金川区', 334, 255, 3, NULL),
(3393, '永昌县', 334, 255, 3, NULL),
(3394, '市辖区', 335, 255, 3, NULL),
(3395, '白银区', 335, 255, 3, NULL),
(3396, '平川区', 335, 255, 3, NULL),
(3397, '靖远县', 335, 255, 3, NULL),
(3398, '会宁县', 335, 255, 3, NULL),
(3399, '景泰县', 335, 255, 3, NULL),
(3400, '市辖区', 336, 255, 3, NULL),
(3401, '秦州区', 336, 255, 3, NULL),
(3402, '麦积区', 336, 255, 3, NULL),
(3403, '清水县', 336, 255, 3, NULL),
(3404, '秦安县', 336, 255, 3, NULL),
(3405, '甘谷县', 336, 255, 3, NULL),
(3406, '武山县', 336, 255, 3, NULL),
(3407, '张家川回族自治县', 336, 255, 3, NULL),
(3408, '市辖区', 337, 255, 3, NULL),
(3409, '凉州区', 337, 255, 3, NULL),
(3410, '民勤县', 337, 255, 3, NULL),
(3411, '古浪县', 337, 255, 3, NULL),
(3412, '天祝藏族自治县', 337, 255, 3, NULL),
(3413, '市辖区', 338, 255, 3, NULL),
(3414, '甘州区', 338, 255, 3, NULL),
(3415, '肃南裕固族自治县', 338, 255, 3, NULL),
(3416, '民乐县', 338, 255, 3, NULL),
(3417, '临泽县', 338, 255, 3, NULL),
(3418, '高台县', 338, 255, 3, NULL),
(3419, '山丹县', 338, 255, 3, NULL),
(3420, '市辖区', 339, 255, 3, NULL),
(3421, '崆峒区', 339, 255, 3, NULL),
(3422, '泾川县', 339, 255, 3, NULL),
(3423, '灵台县', 339, 255, 3, NULL),
(3424, '崇信县', 339, 255, 3, NULL),
(3425, '庄浪县', 339, 255, 3, NULL),
(3426, '静宁县', 339, 255, 3, NULL),
(3427, '华亭市', 339, 255, 3, NULL),
(3428, '市辖区', 340, 255, 3, NULL),
(3429, '肃州区', 340, 255, 3, NULL),
(3430, '金塔县', 340, 255, 3, NULL),
(3431, '瓜州县', 340, 255, 3, NULL),
(3432, '肃北蒙古族自治县', 340, 255, 3, NULL),
(3433, '阿克塞哈萨克族自治县', 340, 255, 3, NULL),
(3434, '玉门市', 340, 255, 3, NULL),
(3435, '敦煌市', 340, 255, 3, NULL),
(3436, '市辖区', 341, 255, 3, NULL),
(3437, '西峰区', 341, 255, 3, NULL),
(3438, '庆城县', 341, 255, 3, NULL),
(3439, '环县', 341, 255, 3, NULL),
(3440, '华池县', 341, 255, 3, NULL),
(3441, '合水县', 341, 255, 3, NULL),
(3442, '正宁县', 341, 255, 3, NULL),
(3443, '宁县', 341, 255, 3, NULL),
(3444, '镇原县', 341, 255, 3, NULL),
(3445, '市辖区', 342, 255, 3, NULL),
(3446, '安定区', 342, 255, 3, NULL),
(3447, '通渭县', 342, 255, 3, NULL),
(3448, '陇西县', 342, 255, 3, NULL),
(3449, '渭源县', 342, 255, 3, NULL),
(3450, '临洮县', 342, 255, 3, NULL),
(3451, '漳县', 342, 255, 3, NULL),
(3452, '岷县', 342, 255, 3, NULL),
(3453, '市辖区', 343, 255, 3, NULL),
(3454, '武都区', 343, 255, 3, NULL),
(3455, '成县', 343, 255, 3, NULL),
(3456, '文县', 343, 255, 3, NULL),
(3457, '宕昌县', 343, 255, 3, NULL),
(3458, '康县', 343, 255, 3, NULL),
(3459, '西和县', 343, 255, 3, NULL),
(3460, '礼县', 343, 255, 3, NULL),
(3461, '徽县', 343, 255, 3, NULL),
(3462, '两当县', 343, 255, 3, NULL),
(3463, '临夏市', 344, 255, 3, NULL),
(3464, '临夏县', 344, 255, 3, NULL),
(3465, '康乐县', 344, 255, 3, NULL),
(3466, '永靖县', 344, 255, 3, NULL),
(3467, '广河县', 344, 255, 3, NULL),
(3468, '和政县', 344, 255, 3, NULL),
(3469, '东乡族自治县', 344, 255, 3, NULL),
(3470, '积石山保安族东乡族撒拉族自治县', 344, 255, 3, NULL),
(3471, '合作市', 345, 255, 3, NULL),
(3472, '临潭县', 345, 255, 3, NULL),
(3473, '卓尼县', 345, 255, 3, NULL),
(3474, '舟曲县', 345, 255, 3, NULL),
(3475, '迭部县', 345, 255, 3, NULL),
(3476, '玛曲县', 345, 255, 3, NULL),
(3477, '碌曲县', 345, 255, 3, NULL),
(3478, '夏河县', 345, 255, 3, NULL),
(3479, '市辖区', 346, 255, 3, NULL),
(3480, '城东区', 346, 255, 3, NULL),
(3481, '城中区', 346, 255, 3, NULL),
(3482, '城西区', 346, 255, 3, NULL),
(3483, '城北区', 346, 255, 3, NULL),
(3484, '湟中区', 346, 255, 3, NULL),
(3485, '大通回族土族自治县', 346, 255, 3, NULL),
(3486, '湟源县', 346, 255, 3, NULL),
(3487, '乐都区', 347, 255, 3, NULL),
(3488, '平安区', 347, 255, 3, NULL),
(3489, '民和回族土族自治县', 347, 255, 3, NULL),
(3490, '互助土族自治县', 347, 255, 3, NULL),
(3491, '化隆回族自治县', 347, 255, 3, NULL),
(3492, '循化撒拉族自治县', 347, 255, 3, NULL),
(3493, '门源回族自治县', 348, 255, 3, NULL),
(3494, '祁连县', 348, 255, 3, NULL),
(3495, '海晏县', 348, 255, 3, NULL),
(3496, '刚察县', 348, 255, 3, NULL),
(3497, '同仁县', 349, 255, 3, NULL),
(3498, '尖扎县', 349, 255, 3, NULL),
(3499, '泽库县', 349, 255, 3, NULL),
(3500, '河南蒙古族自治县', 349, 255, 3, NULL),
(3501, '共和县', 350, 255, 3, NULL),
(3502, '同德县', 350, 255, 3, NULL),
(3503, '贵德县', 350, 255, 3, NULL),
(3504, '兴海县', 350, 255, 3, NULL),
(3505, '贵南县', 350, 255, 3, NULL),
(3506, '玛沁县', 351, 255, 3, NULL),
(3507, '班玛县', 351, 255, 3, NULL),
(3508, '甘德县', 351, 255, 3, NULL),
(3509, '达日县', 351, 255, 3, NULL),
(3510, '久治县', 351, 255, 3, NULL),
(3511, '玛多县', 351, 255, 3, NULL),
(3512, '玉树市', 352, 255, 3, NULL),
(3513, '杂多县', 352, 255, 3, NULL),
(3514, '称多县', 352, 255, 3, NULL),
(3515, '治多县', 352, 255, 3, NULL),
(3516, '囊谦县', 352, 255, 3, NULL),
(3517, '曲麻莱县', 352, 255, 3, NULL),
(3518, '格尔木市', 353, 255, 3, NULL),
(3519, '德令哈市', 353, 255, 3, NULL),
(3520, '茫崖市', 353, 255, 3, NULL),
(3521, '乌兰县', 353, 255, 3, NULL),
(3522, '都兰县', 353, 255, 3, NULL),
(3523, '天峻县', 353, 255, 3, NULL),
(3524, '大柴旦行政委员会', 353, 255, 3, NULL),
(3525, '市辖区', 354, 255, 3, NULL),
(3526, '兴庆区', 354, 255, 3, NULL),
(3527, '西夏区', 354, 255, 3, NULL),
(3528, '金凤区', 354, 255, 3, NULL),
(3529, '永宁县', 354, 255, 3, NULL),
(3530, '贺兰县', 354, 255, 3, NULL),
(3531, '灵武市', 354, 255, 3, NULL),
(3532, '市辖区', 355, 255, 3, NULL),
(3533, '大武口区', 355, 255, 3, NULL),
(3534, '惠农区', 355, 255, 3, NULL),
(3535, '平罗县', 355, 255, 3, NULL),
(3536, '市辖区', 356, 255, 3, NULL),
(3537, '利通区', 356, 255, 3, NULL),
(3538, '红寺堡区', 356, 255, 3, NULL),
(3539, '盐池县', 356, 255, 3, NULL),
(3540, '同心县', 356, 255, 3, NULL),
(3541, '青铜峡市', 356, 255, 3, NULL),
(3542, '市辖区', 357, 255, 3, NULL),
(3543, '原州区', 357, 255, 3, NULL),
(3544, '西吉县', 357, 255, 3, NULL),
(3545, '隆德县', 357, 255, 3, NULL),
(3546, '泾源县', 357, 255, 3, NULL),
(3547, '彭阳县', 357, 255, 3, NULL),
(3548, '市辖区', 358, 255, 3, NULL),
(3549, '沙坡头区', 358, 255, 3, NULL),
(3550, '中宁县', 358, 255, 3, NULL),
(3551, '海原县', 358, 255, 3, NULL),
(3552, '市辖区', 359, 255, 3, NULL),
(3553, '天山区', 359, 255, 3, NULL),
(3554, '沙依巴克区', 359, 255, 3, NULL),
(3555, '新市区', 359, 255, 3, NULL),
(3556, '水磨沟区', 359, 255, 3, NULL),
(3557, '头屯河区', 359, 255, 3, NULL),
(3558, '达坂城区', 359, 255, 3, NULL),
(3559, '米东区', 359, 255, 3, NULL),
(3560, '乌鲁木齐县', 359, 255, 3, NULL),
(3561, '市辖区', 360, 255, 3, NULL),
(3562, '独山子区', 360, 255, 3, NULL),
(3563, '克拉玛依区', 360, 255, 3, NULL),
(3564, '白碱滩区', 360, 255, 3, NULL),
(3565, '乌尔禾区', 360, 255, 3, NULL),
(3566, '高昌区', 361, 255, 3, NULL),
(3567, '鄯善县', 361, 255, 3, NULL),
(3568, '托克逊县', 361, 255, 3, NULL),
(3569, '伊州区', 362, 255, 3, NULL),
(3570, '巴里坤哈萨克自治县', 362, 255, 3, NULL),
(3571, '伊吾县', 362, 255, 3, NULL),
(3572, '昌吉市', 363, 255, 3, NULL),
(3573, '阜康市', 363, 255, 3, NULL),
(3574, '呼图壁县', 363, 255, 3, NULL),
(3575, '玛纳斯县', 363, 255, 3, NULL),
(3576, '奇台县', 363, 255, 3, NULL),
(3577, '吉木萨尔县', 363, 255, 3, NULL),
(3578, '木垒哈萨克自治县', 363, 255, 3, NULL),
(3579, '博乐市', 364, 255, 3, NULL),
(3580, '阿拉山口市', 364, 255, 3, NULL),
(3581, '精河县', 364, 255, 3, NULL),
(3582, '温泉县', 364, 255, 3, NULL),
(3583, '库尔勒市', 365, 255, 3, NULL),
(3584, '轮台县', 365, 255, 3, NULL),
(3585, '尉犁县', 365, 255, 3, NULL),
(3586, '若羌县', 365, 255, 3, NULL),
(3587, '且末县', 365, 255, 3, NULL),
(3588, '焉耆回族自治县', 365, 255, 3, NULL),
(3589, '和静县', 365, 255, 3, NULL),
(3590, '和硕县', 365, 255, 3, NULL),
(3591, '博湖县', 365, 255, 3, NULL),
(3592, '库尔勒经济技术开发区', 365, 255, 3, NULL),
(3593, '阿克苏市', 366, 255, 3, NULL),
(3594, '库车市', 366, 255, 3, NULL),
(3595, '温宿县', 366, 255, 3, NULL),
(3596, '沙雅县', 366, 255, 3, NULL),
(3597, '新和县', 366, 255, 3, NULL),
(3598, '拜城县', 366, 255, 3, NULL),
(3599, '乌什县', 366, 255, 3, NULL),
(3600, '阿瓦提县', 366, 255, 3, NULL),
(3601, '柯坪县', 366, 255, 3, NULL),
(3602, '阿图什市', 367, 255, 3, NULL),
(3603, '阿克陶县', 367, 255, 3, NULL),
(3604, '阿合奇县', 367, 255, 3, NULL),
(3605, '乌恰县', 367, 255, 3, NULL),
(3606, '喀什市', 368, 255, 3, NULL),
(3607, '疏附县', 368, 255, 3, NULL),
(3608, '疏勒县', 368, 255, 3, NULL),
(3609, '英吉沙县', 368, 255, 3, NULL),
(3610, '泽普县', 368, 255, 3, NULL),
(3611, '莎车县', 368, 255, 3, NULL),
(3612, '叶城县', 368, 255, 3, NULL),
(3613, '麦盖提县', 368, 255, 3, NULL),
(3614, '岳普湖县', 368, 255, 3, NULL),
(3615, '伽师县', 368, 255, 3, NULL),
(3616, '巴楚县', 368, 255, 3, NULL),
(3617, '塔什库尔干塔吉克自治县', 368, 255, 3, NULL),
(3618, '和田市', 369, 255, 3, NULL),
(3619, '和田县', 369, 255, 3, NULL),
(3620, '墨玉县', 369, 255, 3, NULL),
(3621, '皮山县', 369, 255, 3, NULL),
(3622, '洛浦县', 369, 255, 3, NULL),
(3623, '策勒县', 369, 255, 3, NULL),
(3624, '于田县', 369, 255, 3, NULL),
(3625, '民丰县', 369, 255, 3, NULL),
(3626, '伊宁市', 370, 255, 3, NULL),
(3627, '奎屯市', 370, 255, 3, NULL),
(3628, '霍尔果斯市', 370, 255, 3, NULL),
(3629, '伊宁县', 370, 255, 3, NULL),
(3630, '察布查尔锡伯自治县', 370, 255, 3, NULL),
(3631, '霍城县', 370, 255, 3, NULL),
(3632, '巩留县', 370, 255, 3, NULL),
(3633, '新源县', 370, 255, 3, NULL),
(3634, '昭苏县', 370, 255, 3, NULL),
(3635, '特克斯县', 370, 255, 3, NULL),
(3636, '尼勒克县', 370, 255, 3, NULL),
(3637, '塔城市', 371, 255, 3, NULL),
(3638, '乌苏市', 371, 255, 3, NULL),
(3639, '额敏县', 371, 255, 3, NULL),
(3640, '沙湾县', 371, 255, 3, NULL),
(3641, '托里县', 371, 255, 3, NULL),
(3642, '裕民县', 371, 255, 3, NULL),
(3643, '和布克赛尔蒙古自治县', 371, 255, 3, NULL),
(3644, '阿勒泰市', 372, 255, 3, NULL),
(3645, '布尔津县', 372, 255, 3, NULL),
(3646, '富蕴县', 372, 255, 3, NULL),
(3647, '福海县', 372, 255, 3, NULL),
(3648, '哈巴河县', 372, 255, 3, NULL),
(3649, '青河县', 372, 255, 3, NULL),
(3650, '吉木乃县', 372, 255, 3, NULL),
(3651, '石河子市', 373, 255, 3, NULL),
(3652, '阿拉尔市', 373, 255, 3, NULL),
(3653, '图木舒克市', 373, 255, 3, NULL),
(3654, '五家渠市', 373, 255, 3, NULL),
(3655, '北屯市', 373, 255, 3, NULL),
(3656, '铁门关市', 373, 255, 3, NULL),
(3657, '双河市', 373, 255, 3, NULL),
(3658, '可克达拉市', 373, 255, 3, NULL),
(3659, '昆玉市', 373, 255, 3, NULL),
(3660, '胡杨河市', 373, 255, 3, NULL),
(3665, '香港岛', 3661, 255, 2, NULL),
(3666, '九龙', 3661, 255, 2, NULL),
(3667, '新界', 3661, 255, 2, NULL),
(3668, '中西区', 3665, 255, 3, NULL),
(3669, '湾仔', 3665, 255, 3, NULL),
(3670, '东区', 3665, 255, 3, NULL),
(3671, '南区', 3665, 255, 3, NULL),
(3672, '九龙城区', 3666, 255, 3, NULL),
(3673, '油尖旺区', 3666, 255, 3, NULL),
(3674, '深水埗区', 3666, 255, 3, NULL),
(3675, '黄大仙区', 3666, 255, 3, NULL),
(3676, '观塘区', 3666, 255, 3, NULL),
(3677, '北区', 3667, 255, 3, NULL),
(3678, '大埔区', 3667, 255, 3, NULL),
(3679, '沙田区', 3667, 255, 3, NULL),
(3680, '西贡区', 3667, 255, 3, NULL),
(3681, '元朗区', 3667, 255, 3, NULL),
(3682, '屯门区', 3667, 255, 3, NULL),
(3683, '荃湾区', 3667, 255, 3, NULL),
(3684, '葵青区', 3667, 255, 3, NULL),
(3685, '离岛区', 3667, 255, 3, NULL),
(3686, '澳门半岛', 3662, 255, 2, NULL),
(3687, '离岛', 3662, 255, 2, NULL),
(3688, '台北市', 3663, 255, 2, NULL),
(3689, '高雄市', 3663, 255, 2, NULL),
(3690, '台南市', 3663, 255, 2, NULL),
(3691, '台中市', 3663, 255, 2, NULL),
(3692, '金门县', 3663, 255, 2, NULL),
(3693, '南投县', 3663, 255, 2, NULL),
(3694, '基隆市', 3663, 255, 2, NULL),
(3695, '新竹市', 3663, 255, 2, NULL),
(3696, '嘉义市', 3663, 255, 2, NULL),
(3697, '新北市', 3663, 255, 2, NULL),
(3698, '宜兰县', 3663, 255, 2, NULL),
(3699, '新竹县', 3663, 255, 2, NULL),
(3700, '桃园县', 3663, 255, 2, NULL),
(3701, '苗栗县', 3663, 255, 2, NULL),
(3702, '彰化县', 3663, 255, 2, NULL),
(3703, '嘉义县', 3663, 255, 2, NULL),
(3704, '云林县', 3663, 255, 2, NULL),
(3705, '屏东县', 3663, 255, 2, NULL),
(3706, '台东县', 3663, 255, 2, NULL),
(3707, '花莲县', 3663, 255, 2, NULL),
(3708, '澎湖县', 3663, 255, 2, NULL),
(3709, '中正区', 3688, 255, 3, NULL),
(3710, '大同区', 3688, 255, 3, NULL),
(3711, '中山区', 3688, 255, 3, NULL),
(3712, '松山区', 3688, 255, 3, NULL),
(3713, '大安区', 3688, 255, 3, NULL),
(3714, '万华区', 3688, 255, 3, NULL),
(3715, '信义区', 3688, 255, 3, NULL),
(3716, '士林区', 3688, 255, 3, NULL),
(3717, '北投区', 3688, 255, 3, NULL),
(3718, '内湖区', 3688, 255, 3, NULL),
(3719, '南港区', 3688, 255, 3, NULL),
(3720, '文山区', 3688, 255, 3, NULL),
(3721, '其它区', 3688, 255, 3, NULL),
(3722, '新兴区', 3689, 255, 3, NULL),
(3723, '前金区', 3689, 255, 3, NULL),
(3724, '芩雅区', 3689, 255, 3, NULL),
(3725, '盐埕区', 3689, 255, 3, NULL),
(3726, '鼓山区', 3689, 255, 3, NULL),
(3727, '旗津区', 3689, 255, 3, NULL),
(3728, '前镇区', 3689, 255, 3, NULL),
(3729, '三民区', 3689, 255, 3, NULL),
(3730, '左营区', 3689, 255, 3, NULL),
(3731, '楠梓区', 3689, 255, 3, NULL),
(3732, '小港区', 3689, 255, 3, NULL),
(3733, '其它区', 3689, 255, 3, NULL),
(3734, '中西区', 3690, 255, 3, NULL),
(3735, '东区', 3690, 255, 3, NULL),
(3736, '南区', 3690, 255, 3, NULL),
(3737, '北区', 3690, 255, 3, NULL),
(3738, '安平区', 3690, 255, 3, NULL),
(3739, '安南区', 3690, 255, 3, NULL),
(3740, '其它区', 3690, 255, 3, NULL),
(3741, '中区', 3691, 255, 3, NULL),
(3742, '东区', 3691, 255, 3, NULL),
(3743, '南区', 3691, 255, 3, NULL),
(3744, '西区', 3691, 255, 3, NULL),
(3745, '北区', 3691, 255, 3, NULL),
(3746, '北屯区', 3691, 255, 3, NULL),
(3747, '西屯区', 3691, 255, 3, NULL),
(3748, '南屯区', 3691, 255, 3, NULL),
(3749, '其它区', 3691, 255, 3, NULL),
(3750, '仁爱区', 3694, 255, 3, NULL),
(3751, '信义区', 3694, 255, 3, NULL),
(3752, '中正区', 3694, 255, 3, NULL),
(3753, '中山区', 3694, 255, 3, NULL),
(3754, '安乐区', 3694, 255, 3, NULL),
(3755, '暖暖区', 3694, 255, 3, NULL),
(3756, '七堵区', 3694, 255, 3, NULL),
(3757, '其它区', 3694, 255, 3, NULL),
(3758, '东区', 3695, 255, 3, NULL),
(3759, '北区', 3695, 255, 3, NULL),
(3760, '香山区', 3695, 255, 3, NULL),
(3761, '其它区', 3695, 255, 3, NULL),
(3762, '东区', 3696, 255, 3, NULL),
(3763, '西区', 3696, 255, 3, NULL),
(3764, '其它区', 3696, 255, 3, NULL),
(3765, '美国', 3664, 0, 3, NULL),
(3766, '加拿大', 3664, 0, 3, NULL),
(3767, '澳大利亚', 3664, 0, 3, NULL),
(3768, '新西兰', 3664, 0, 3, NULL),
(3769, '英国', 3664, 0, 3, NULL),
(3770, '法国', 3664, 0, 3, NULL),
(3771, '德国', 3664, 0, 3, NULL),
(3772, '捷克', 3664, 0, 3, NULL),
(3773, '荷兰', 3664, 0, 3, NULL),
(3774, '瑞士', 3664, 0, 3, NULL),
(3775, '希腊', 3664, 0, 3, NULL),
(3776, '挪威', 3664, 0, 3, NULL),
(3777, '瑞典', 3664, 0, 3, NULL),
(3778, '丹麦', 3664, 0, 3, NULL),
(3779, '芬兰', 3664, 0, 3, NULL),
(3780, '爱尔兰', 3664, 0, 3, NULL),
(3781, '奥地利', 3664, 0, 3, NULL),
(3782, '意大利', 3664, 0, 3, NULL),
(3783, '乌克兰', 3664, 0, 3, NULL),
(3784, '俄罗斯', 3664, 0, 3, NULL),
(3785, '西班牙', 3664, 0, 3, NULL),
(3786, '韩国', 3664, 0, 3, NULL),
(3787, '新加坡', 3664, 0, 3, NULL),
(3788, '马来西亚', 3664, 0, 3, NULL),
(3789, '印度', 3664, 0, 3, NULL),
(3790, '泰国', 3664, 0, 3, NULL),
(3791, '日本', 3664, 0, 3, NULL),
(3792, '巴西', 3664, 0, 3, NULL),
(3793, '阿根廷', 3664, 0, 3, NULL),
(3794, '南非', 3664, 0, 3, NULL),
(3795, '埃及', 3664, 0, 3, NULL);

INSERT INTO `#__config` (`id`, `code`, `value`, `remark`) VALUES
(1, 'site_name', '德尚商城', '商城名称'),
(2, 'site_phone', '3', '商城客服服务电话'),
(3, 'site_state', '1', '商城状态'),
(4, 'site_logo', 'site_logo.png', '商城logo图'),
(5, 'member_logo', 'member_logo.png', '默认会员图'),
(6, 'seller_center_logo', 'seller_center_logo.jpg', '默认卖家中心logo'),
(7, 'site_mobile_logo', 'site_mobile_logo.png', '默认商城手机端logo'),
(8, 'site_logowx', 'site_logowx.jpg', '微信商城二维码'),
(9, 'icp_number', '2', 'ICP备案号'),
(10, 'site_tel400', '40002541852', '解释,备注'),
(11, 'site_email', '858761000@qq.com', '电子邮件'),
(12, 'flow_static_code', 'Copyright © 2013-2019 惠利玛开源系统 版权所有 保留一切权利', '底部版权信息'),
(13, 'closed_reason', '商城暂时关闭', '商城关闭原因'),
(14, 'guest_comment', '1', '是否允许游客咨询'),
(15, 'captcha_status_login', '1', '会员登录是否需要验证码'),
(16, 'captcha_status_register', '1', '会员注册是否验证码'),
(17, 'captcha_status_goodsqa', '1', '商品咨询是否验证码'),
(18, 'captcha_status_storelogin', '1', '店铺登录是否验证码'),
(19, 'cache_open', '0', '是否开启缓存'),
(21, 'default_goods_image', 'default_goods_image.jpg', '默认商品图'),
(22, 'default_store_logo', 'default_store_logo.jpg', '默认店铺图'),
(23, 'default_store_avatar', 'default_store_avatar.png', '默认店铺图像'),
(24, 'default_user_portrait', 'default_user_portrait.png', '默认会员图像'),
(25, 'fixed_suspension_state', '1', '是否开启首次访问悬浮'),
(26, 'fixed_suspension_img', 'fixed_suspension_img.png', '首次访问悬浮图像'),
(27, 'fixed_suspension_url', '#', '悬浮图像跳转地址'),
(28, 'admin_logo', 'logo.png', '后台登录中心Logo'),
(29, 'admin_backlogo', 'backlogo.png', '后台管理中心Logo'),
(31, 'store_joinin_pic', 'a:2:{s:3:"pic";a:3:{i:1;s:18:"store_joinin_1.jpg";i:2;s:18:"store_joinin_2.jpg";i:3;s:18:"store_joinin_3.jpg";}s:8:"show_txt";s:6:"测试";}', '解释,备注'),
(32, 'store_joinin_open', '1', '店铺入驻开启（0不开启1全部开启2仅企业3仅个人）'),
(40, 'smscf_wj_username', '', '短信平台账号'),
(41, 'smscf_wj_key', '', '短信平台密钥'),
(42, 'smscf_sign', '', '短信签名'),
(43, 'smscf_type', 'wj', '短信服务商'),
(44, 'smscf_ali_id', '', '阿里云短信AccessKeyId'),
(45, 'smscf_ali_secret', '', '阿里云短信AccessKeySecret'),
(46, 'smscf_ten_id', '', '腾讯云短信AccessKeyId'),
(47, 'smscf_ten_secret', '', '腾讯云短信AccessKeySecret'),
(51, 'email_host', 'smtp.126.com', '邮箱地址'),
(52, 'email_port', '25', '邮箱端口'),
(53, 'email_addr', '', '邮箱发件人地址'),
(54, 'email_id', '', '身份验证用户名'),
(55, 'email_pass', '', '用户名密码'),
(56, 'email_secure', '', '邮箱发送协议'),
(60, 'setup_date', '2015-01-01 00:00:00', '安装时间'),
(61, 'upload_type', 'local', '图片上传保存方式'),
(62, 'alioss_accessid', NULL, 'accessid'),
(63, 'alioss_accesssecret', NULL, 'oss_accesssecret'),
(64, 'alioss_bucket', NULL, 'oss_bucket'),
(65, 'alioss_endpoint', NULL, 'oss_endpoint'),
(66, 'aliendpoint_type', '0', 'aliendpoint_type'),
(80, 'flea_site_title', '', ''),
(81, 'flea_site_description', '', ''),
(82, 'flea_site_keywords', '', ''),
(83, 'flea_loginpic', '', ''),
(91, 'order_auto_receive_day', '7', '自动确认收货的天数'),
(92, 'order_auto_cancel_day', '3', '自动取消订单的天数'),
(93, 'code_invalid_refund', '7', '兑换码过期自动退款的天数'),
(101, 'qq_isuse', '1', '是否使用QQ互联'),
(102, 'qq_appid', '', 'qq互联id'),
(103, 'qq_appkey', '', 'qq秘钥'),
(111, 'sina_isuse', '1', '是的使用微博登录'),
(112, 'sina_wb_akey', '', '新浪id'),
(113, 'sina_wb_skey', '', '新浪秘钥'),
(121, 'sms_register', '0', '是否手机注册'),
(122, 'sms_login', '0', '是否手机登录'),
(123, 'sms_password', '0', '是否手机找回密码'),
(131, 'weixin_isuse', NULL, '是否微信登录'),
(132, 'weixin_appid', NULL, '微信appid'),
(133, 'weixin_secret', NULL, '微信appserite'),
(135, 'complain_time_limit', '864000', '商品详情页咨询文字提示'),
(136, 'malbum_max_sum', '10', '个人相册数量'),
(137, 'hot_search', '', '热门搜索关键字'),
(138, 'image_allow_ext', 'gif,jpg,jpeg,bmp,png,swf', '允许后缀'),
(139, 'image_max_filesize', '1024', '允许上传最大值'),
(140, 'expresscf_kdn_id', '', '快递鸟-用户ID'),
(141, 'expresscf_kdn_key', '', '快递鸟-API key'),
(142, 'expresscf_kdn_type', '', '快递鸟-API类型'),
(150, 'vod_tencent_secret_id', '', '腾讯Secret_id'),
(151, 'vod_tencent_secret_key', '', '腾讯Secret_key'),
(201, 'flea_isuse', '0', '闲置市场'),
(202, 'promotion_allow', '1', '商品促销'),
(203, 'groupbuy_allow', '1', '抢购'),
(204, 'points_isuse', '1', '开启积分机制'),
(205, 'pointshop_isuse', '1', '积分中心'),
(206, 'pointprod_isuse', '1', '积分兑换'),
(207, 'voucher_allow', '1', '代金券'),
(208, 'mgdiscount_allow', '1', '会员等级折扣'),
(209, 'mgdiscount_price', '1', '会员等级折扣价格'),
(230, 'points_reg', '5', '注册赠送积分数'),
(231, 'points_login', '10', '登录赠送积分数'),
(232, 'points_comments', '10', '评论赠送积分数'),
(233, 'points_signin', '10', '会员签到赠送积分'),
(234, 'points_invite', '10', '邀请注册积分'),
(235, 'points_rebate', '1', '返佣比例'),
(236, 'points_orderrate', '4', '消费额与赠送积分比例'),
(237, 'points_ordermax', '4', '每单最多赠送积分'),
(238, 'points_signin_isuse', '1', '开启签到送积分'),
(239, 'points_signin_cycle', '7', '签到持续周期'),
(240, 'points_signin_reward', '7', '签到持续周期额外奖励'),
(241, 'groupbuy_price', '20', '抢购价格'),
(242, 'groupbuy_review_day', '3', '抢购审核期'),
(350, 'live_pic1', '', '抢购默认幻灯片'),
(351, 'live_link1', '', '抢购幻灯片跳转地址'),
(352, 'live_pic2', '', '抢购默认幻灯片'),
(353, 'live_link2', '', '抢购幻灯片跳转地址'),
(354, 'live_pic3', '', '抢购默认幻灯片'),
(355, 'live_link3', '', '抢购幻灯片跳转地址'),
(356, 'live_pic4', '', '抢购默认幻灯片'),
(357, 'live_link4', '', '抢购幻灯片跳转地址'),
(358, 'promotion_presell_price', '10', '预售价格'),
(359, 'promotion_wholesale_price', '10', '批发价格'),
(360, 'promotion_xianshi_price', '10', '限时促销价格'),
(361, 'promotion_mansong_price', '16', '满送活动价格'),
(362, 'promotion_bundling_price', '15', '优惠活动价格'),
(363, 'promotion_bundling_sum', '10', '允许活动数量'),
(364, 'promotion_bundling_goods_sum', '3', '活动最大商品发布数量'),
(365, 'promotion_booth_price', '10', '推荐展位价格'),
(366, 'promotion_booth_goods_sum', '10', '允许设置最大推荐商品数量'),
(367, 'promotion_voucher_price', '10', '代金券价格'),
(368, 'promotion_pintuan_price', '10', '拼团套餐价格'),
(369, 'promotion_bargain_price', '10', '砍价套餐价格'),
(370, 'voucher_storetimes_limit', '20', '代金券活动数'),
(371, 'voucher_buyertimes_limit', '20', '卖家最大领取数'),
(380, 'chain_isuse', '1', '代收是否开启'),
(390, 'goods_verify', '0', '商品审核'),
(401, 'stat_pricerange', 'a:3:{i:0;a:2:{s:1:"s";s:1:"5";s:1:"e";s:2:"10";}i:1;a:2:{s:1:"s";s:2:"11";s:1:"e";s:2:"20";}i:2;a:2:{s:1:"s";s:2:"21";s:1:"e";s:2:"25";}}', '统计商品价格区间'),
(402, 'stat_orderpricerange', 'a:1:{i:0;a:2:{s:1:"s";s:2:"21";s:1:"e";s:2:"30";}}', '订单金额区间'),
(501, 'expset', 'a:4:{s:9:"login_exp";s:3:"151";s:11:"comment_exp";s:1:"1";s:7:"buy_exp";s:1:"1";s:11:"buy_exp_max";s:2:"50";}', '解释,备注'),
(502, 'exppoints_rule', 'a:4:{s:9:"exp_login";s:2:"20";s:12:"exp_comments";s:2:"10";s:13:"exp_orderrate";s:2:"10";s:12:"exp_ordermax";s:2:"10";}', '解释,备注'),
(601, 'member_grade', 'a:4:{i:1;a:3:{s:5:"level";i:1;s:10:"level_name";s:12:"青铜会员";s:9:"exppoints";i:0;}i:2;a:3:{s:5:"level";i:2;s:10:"level_name";s:12:"白银会员";s:9:"exppoints";i:150;}i:3;a:3:{s:5:"level";i:3;s:10:"level_name";s:12:"黄金会员";s:9:"exppoints";i:200;}i:4;a:3:{s:5:"level";i:4;s:10:"level_name";s:12:"白金会员";s:9:"exppoints";i:500;}}', '解释,备注'),
(701, 'inviter_back', 'inviter_back.png', '会员推广背景图片'),
(702, 'inviter_ratio_1', '30', '会员一级推广佣金比例'),
(703, 'inviter_ratio_2', '25', '会员二级推广佣金比例'),
(704, 'inviter_ratio_3', '15', '会员三级推广佣金比例'),
(705, 'baidu_ak', '22bb7221fc279a484895afcc6a0bb33a', '百度地图AK密钥'),
(706 ,  'inviter_open',  '1',  '推广开关'), 
(707 ,  'inviter_level',  '3',  '推广级别'), 
(708 ,  'inviter_show',  '1',  '详情页显示推广佣金'), 
(709 ,  'inviter_return',  '1',  '推广员返佣'), 
(710 ,  'inviter_view',  '0',  '推广员审核'),
(711 ,  'inviter_condition',  '0',  '推广员条件'), 
(712 ,  'inviter_condition_amount',  '0',  '成为推广员的消费门槛'),
(713 ,  'store_bill_cycle',  '7',  '店铺结算周期（天）'),
(714 ,  'store_withdraw_cycle',  '1',  '店铺提现周期（天）'), 
(715 ,  'store_withdraw_min',  '100',  '店铺最小提现金额（元）'),
(716 ,  'store_withdraw_max',  '10000',  '店铺最大提现金额（元）'),
(717 ,  'auto_register',  '0',  '自动注册'),
(718 ,  'business_licence',  '',  '营业执照'),
(719 ,  'member_auth',  '0',  '实名认证'),
(728 ,  'h5_chain_site_url',  'https://uniapp.chain.dsmall.csdeshang.com',  '手机端门店地址'),
(729 ,  'h5_store_site_url',  'https://uniapp.store.dsmall.csdeshang.com',  '手机端店铺地址'),
(730 ,  'h5_site_url',  'https://uniapp.dsmall.csdeshang.com',  '手机端地址'),
(731 ,  'h5_force_redirect',  '0',  '强制跳转到手机端'),
(740 ,  'member_withdraw_cycle',  '1',  '用户提现周期（天）'), 
(741 ,  'member_withdraw_min',  '100',  '用户最小提现金额（元）'),
(742 ,  'member_withdraw_max',  '10000',  '用户最大提现金额（元）'),
(752 ,  'instant_message_open',  '0',  '开启聊天'),
(753 ,  'instant_message_gateway_url',  '',  '聊天gateway地址'),
(754 ,  'instant_message_register_url',  '',  '聊天register地址'),
(755 ,  'live_push_domain',  '',  '推流域名'),
(756 ,  'live_push_key',  '',  '推流key'),
(757 ,  'live_play_domain',  '',  '拉流域名'),
(758 ,  'vod_tencent_appid',  '',  '腾讯云appid'),
(759 ,  'vod_tencent_play_domain',  '',  '点播域名'),
(760 ,  'vod_tencent_play_key',  '',  '点播key'),
(761 ,  'video_type',  'tencent',  '视频类型'),
(762 ,  'aliyun_user_id',  '',  '阿里云账号ID'),
(763 ,  'aliyun_access_key_id',  '',  '阿里云账号AccessKeyID'),
(764 ,  'aliyun_access_key_secret',  '',  '阿里云账号AccessKeySecret'),
(765 ,  'aliyun_live_push_key',  '',  '阿里云推流鉴权key'),
(766 ,  'aliyun_live_push_domain',  '',  '阿里云推流域名'),
(767 ,  'aliyun_live_play_domain',  '',  '阿里云播流域名'),
(768 ,  'aliyun_live_play_key',  '',  '阿里云播流鉴权key'),
(769 ,  'live_type',  '0',  '直播类型（0小程序原生直播1小程序组件直播）'),
(770 ,  'wab_number',  '',  '网安备'),
(771 ,  'word_filter_open',  '0',  '是否开启敏感词过滤'),
(772 ,  'word_filter_appid',  '',  '百度应用appid'),
(773 ,  'word_filter_secret',  '',  '百度应用secret'),
(774 ,  'word_filter_access_token',  '',  '百度应用access_token'),
(775 ,  'word_filter_access_token_expire',  '',  '百度应用access_token过期时间'),
(780 ,  'member_normal_register',  '1',  '用户普通注册（0关闭1开启）'),
(781 ,  'mapak_type',  '1',  '地图类型，1：高德地图，2：百度地图'),
(782 ,  'gaode_ak',  '',  '高德地图key'),
(783 ,  'gaode_jscode',  '',  '高德地图安全密钥'),
(784 ,  'baiduservice_ak',  '',  '百度地图服务端密钥');

INSERT INTO `#__articleclass` (`ac_id`, `ac_code`, `ac_name`, `ac_parent_id`, `ac_sort`) VALUES
  (1, 'notice', '商城公告', 0, 255),
  (2, 'member', '帮助中心', 0, 255),
  (3, 'store', '店主之家', 0, 255),
  (4, 'payment', '支付方式', 0, 255),
  (5, 'sold', '售后服务', 0, 255),
  (6, 'service', '客服中心', 0, 255),
  (7, 'about', '关于我们', 0, 255);


INSERT INTO `#__article` (`article_id`, `ac_id`, `article_url`, `article_show`, `article_sort`, `article_title`, `article_content`, `article_time`) VALUES (6, 2, '', 1, 255, '如何注册成为会员', '如何注册成为会员', 1435672310),
(7, 2, '', 1, 255, '如何搜索', '如何搜索', 1435672310),
(8, 2, '', 1, 255, '忘记密码', '忘记密码', 1435672310),
(9, 2, '', 1, 255, '我要买', '我要买', 1435672310),
(10, 2, '', 1, 255, '查看已购买商品', '查看已购买商品', 1435672310),
(11, 3, '', 1, 255, '如何管理店铺', '如何管理店铺', 1435672310),
(12, 3, '', 1, 255, '查看售出商品', '查看售出商品', 1435672310),
(13, 3, '', 1, 255, '如何发货', '如何发货', 1435672310),
(14, 3, '', 1, 255, '商城商品推荐', '商城商品推荐', 1435672310),
(15, 3, '', 1, 255, '如何申请开店', '如何申请开店', 1435672310),
(16, 4, '', 1, 255, '如何注册支付宝', '如何注册支付宝', 1435672310),
(17, 4, '', 1, 255, '在线支付', '在线支付', 1435672310),
(18, 6, '', 1, 255, '会员修改密码', '会员修改密码', 1435672310),
(19, 6, '', 1, 255, '会员修改个人资料', '会员修改个人资料', 1435672310),
(20, 6, '', 1, 255, '商品发布', '商品发布', 1435672310),
(21, 6, '', 1, 255, '修改收货地址', '修改收货地址', 1435672310),
(22, 7, '', 1, 255, '关于我们', '关于我们', 1435672310),
(23, 7, '', 1, 255, '联系我们', '联系我们', 1435672310),
(24, 7, '', 1, 255, '招聘英才', '招聘英才', 1435672310),
(25, 7, '', 1, 255, '合作及洽谈', '合作及洽谈', 1435672310),
(26, 5, '', 1, 255, '联系卖家', '联系卖家', 1435672310),
(28, 4, '', 1, 255, '分期付款', '分期付款<br />', 1435672310),
(29, 4, '', 1, 255, '邮局汇款', '邮局汇款<br />', 1435672310),
(30, 4, '', 1, 255, '公司转账', '公司转账<br />', 1435672310),
(31, 5, '', 1, 255, '退换货政策', '退换货政策', 1435672310),
(32, 5, '', 1, 255, '退换货流程', '退换货流程', 1435672310),
(33, 5, '', 1, 255, '返修/退换货', '返修/退换货', 1435672310),
(34, 5, '', 1, 255, '退款申请', '退款申请', 1435672310),
(35, 1, 'https://www.valimart.net//', 1, 1, '火爆销售中', '火爆销售中<br />', 1435672310),
(36, 1, '', 1, 255, '管理功能说明', '管理功能说明', 1435672310),
(37, 1, '', 1, 255, '如何扩充水印字体库', '如何扩充水印字体库', 1435672310),
(38, 1, '', 1, 255, '提示信息', '提示信息', 1435672310),
(39, 2, '', 1, 255, '积分细则', '积分细则积分细则', 1435672310),
(40, 2, '', 1, 255, '积分兑换说明', '积分兑换说明', 1435672310),
(41, 1, '', 1, 255, '功能使用说明', '功能使用说明', 1435672310);

INSERT INTO `#__complainsubject` (`complainsubject_id`, `complainsubject_content`, `complainsubject_desc`, `complainsubject_state`) VALUES (1, '商家不同意退款', '买家申请退款被拒绝。', 2),
(2, '未收到货', '交易成功，未收到货，钱已经付给商家，可进行维权。', 1),
(3, '售后保障服务', '交易完成后30天内，在使用商品过程中，发现商品有质量问题或无法正常使用，可进行维权。', 1);

INSERT INTO `#__consulttype` (`consulttype_id`, `consulttype_name`, `consulttype_introduce`, `consulttype_sort`) VALUES
(1, '商品咨询', '后台->交易->咨询管理->咨询类型->编辑', 1),
(2, '支付问题', '后台->交易->咨询管理->咨询类型->编辑', 2),
(3, '发票及保修', '后台->交易->咨询管理->咨询类型->编辑', 3),
(4, '促销及赠品', '后台->交易->咨询管理->咨询类型->编辑', 4);

INSERT INTO `#__document` (`document_id`, `document_code`, `document_title`, `document_content`, `document_time`) VALUES (1, 'agreement', '用户服务协议', '&lt;p&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;本协议是您与网站所有者（以下简称为&amp;quot;商城&amp;quot;）之间就商城网站服务等相关事宜所订立的契约，请您仔细阅读本注册协议，您点击&amp;quot;同意并继续&amp;quot;按钮后，本协议即构成对双方有约束力的法律文件。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第1条 本站服务条款的确认和接纳&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;1.1本站的各项电子服务的所有权和运作权归商城所有。用户同意所有注册协议条款并完成注册程序，才能成为本站的正式用户。用户确认：本协议条款是处理双方权利义务的契约，始终有效，法律另有强制性规定或双方另有特别约定的，依其规定。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;1.2用户点击同意本协议的，即视为用户确认自己具有享受本站服务、下单购物等相应的权利能力和行为能力，能够独立承担法律责任。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;1.3如果您在18周岁以下，您只能在父母或监护人的监护参与下才能使用本站。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;1.4商城保留在中华人民共和国大陆地区法施行之法律允许的范围内独自决定拒绝服务、关闭用户账户、清除或编辑内容或取消订单的权利。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第2条 本站服务&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;2.1商城通过互联网依法为用户提供互联网信息等服务，用户在完全同意本协议及本站规定的情况下，方有权使用本站的相关服务。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;2.2用户必须自行准备如下设备和承担如下开支：（1）上网设备，包括并不限于电脑或者其他上网终端、调制解调器及其他必备的上网装置；（2）上网开支，包括并不限于网络接入费、上网设备租用费、手机流量费等。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第3条 用户信息&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.1用户应自行诚信向本站提供注册资料，用户同意其提供的注册资料真实、准确、完整、合法有效，用户注册资料如有变动的，应及时更新其注册资料。如果用户提供的注册资料不合法、不真实、不准确、不详尽的，用户需承担因此引起的相应责任及后果，并且商城保留终止用户使用商城各项服务的权利。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.2用户在本站进行浏览、下单购物等活动时，涉及用户真实姓名/名称、通信地址、联系电话、电子邮箱等隐私信息的，本站将予以严格保密，除非得到用户的授权或法律另有规定，本站不会向外界披露用户隐私信息。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.3用户注册成功后，将产生用户名和密码等账户信息，您可以根据本站规定改变您的密码。用户应谨慎合理的保存、使用其用户名和密码。用户若发现任何非法使用用户账号或存在安全漏洞的情况，请立即通知本站并向公安机关报案。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.4用户同意，商城拥有通过邮件、短信电话等形式，向在本站注册、购物用户、收货人发送订单信息、促销活动等告知信息的权利。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.5用户不得将在本站注册获得的账户借给他人使用，否则用户应承担由此产生的全部责任，并与实际使用人承担连带责任。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;3.6用户同意，商城有权使用用户的注册信息、用户名、密码等信息，登录进入用户的注册账户，进行证据保全，包括但不限于公证、见证等。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第4条 用户依法言行义务&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;本协议依据国家相关法律法规规章制定，用户同意严格遵守以下义务：&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（1）不得传输或发表：煽动抗拒、破坏宪法和法律、行政法规实施的言论，煽动颠覆国家政权，推翻社会主义制度的言论，煽动分裂国家、破坏国家统一的的言论，煽动民族仇恨、民族歧视、破坏民族团结的言论；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（2）从中国大陆向境外传输资料信息时必须符合中国有关法规；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（3）不得利用本站从事洗钱、窃取商业秘密、窃取个人信息等违法犯罪活动；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（4）不得干扰本站的正常运转，不得侵入本站及国家计算机信息系统；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（5）不得传输或发表任何违法犯罪的、骚扰性的、中伤他人的、辱骂性的、恐吓性的、伤害性的、庸俗的，淫秽的、不文明的等信息资料；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（6）不得传输或发表损害国家社会公共利益和涉及国家安全的信息资料或言论；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（7）不得教唆他人从事本条所禁止的行为；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（8）不得利用在本站注册的账户进行牟利性经营活动；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（9）不得发布任何侵犯他人著作权、商标权等知识产权或合法权利的内容；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;用户应不时关注并遵守本站不时公布或修改的各类合法规则规定。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;本站保有删除站内各类不符合法律政策或不真实的信息内容而无须通知用户的权利。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;若用户未遵守以上规定的，本站有权作出独立判断并采取暂停或关闭用户帐号等措施。用户须对自己在网上的言论和行为承担法律责任。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第5条 商品信息&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;本站上的商品价格、数量、是否有货等商品信息随时都有可能发生变动，本站不作特别通知。由于网站上商品信息的数量极其庞大，虽然本站会尽最大努力保证您所浏览商品信息的准确性，但由于众所周知的互联网技术因素等客观原因存在，本站网页显示的信息可能会有一定的滞后性或差错，对此情形您知悉并理解；商城欢迎纠错，并会视情况给予纠错者一定的奖励。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;为表述便利，商品和服务简称为&amp;quot;商品&amp;quot;或&amp;quot;货物&amp;quot;。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第6条 订单&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;6.1在您下订单时，请您仔细确认所购商品的名称、价格、数量、型号、规格、尺寸、联系地址、电话、收货人等信息。收货人与用户本人不一致的，收货人的行为和意思表示视为用户的行为和意思表示，用户应对收货人的行为及意思表示的法律后果承担连带责任。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;6.2除法律另有强制性规定外，双方约定如下：本站上销售方展示的商品和价格等信息仅仅是交易信息的发布，您下单时须填写您希望购买的商品数量、价款及支付方式、收货人、联系方式、收货地址等内容；系统生成的订单信息是计算机信息系统根据您填写的内容自动生成的数据，仅是您向销售方发出的交易诉求；销售方收到您的订单信息后，只有在销售方将您在订单中订购的商品从仓库实际直接向您发出时（ 以商品出库为标志），方视为您与销售方之间就实际直接向您发出的商品建立了交易关系；如果您在一份订单里订购了多种商品并且销售方只给您发出了部分商品时，您与销售方之间仅就实际直接向您发出的商品建立了交易关系；只有在销售方实际直接向您发出了订单中订购的其他商品时，您和销售方之间就订单中该其他已实际直接向您发出的商品才成立交易关系。您可以随时登录您在本站注册的账户，查询您的订单状态。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;6.3由于市场变化及各种以合理商业努力难以控制的因素的影响，本站无法保证您提交的订单信息中希望购买的商品都会有货；如您拟购买的商品，发生缺货，您有权取消订单。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第7条 配送&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;7.1销售方将会把商品（货物）送到您所指定的收货地址，所有在本站上列出的送货时间为参考时间，参考时间的计算是根据库存状况、正常的处理过程和送货时间、送货地点的基础上估计得出的。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;7.2因如下情况造成订单延迟或无法配送等，销售方不承担延迟配送的责任：&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（1）用户提供的信息错误、地址不详细等原因导致的；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（2）货物送达后无人签收，导致无法配送或延迟配送的；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（3）情势变更因素导致的；&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;（4）不可抗力因素导致的，例如：自然灾害、交通戒严、突发战争等。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第8条 所有权及知识产权条款&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.1用户一旦接受本协议，即表明该用户主动将其在任何时间段在本站发表的任何形式的信息内容（包括但不限于客户评价、客户咨询、各类话题文章等信息内容）的财产性权利等任何可转让的权利，如著作权财产权（包括并不限于：复制权、发行权、出租权、展览权、表演权、放映权、广播权、信息网络传播权、摄制权、改编权、翻译权、汇编权以及应当由著作权人享有的其他可转让权利），全部独家且不可撤销地转让给商城所有，用户同意商城有权就任何主体侵权而单独提起诉讼。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.2本协议已经构成《中华人民共和国著作权法》第二十五条（条文序号依照2011年版著作权法确定）及相关法律规定的著作财产权等权利转让书面协议，其效力及于用户在商城网站上发布的任何受著作权法保护的作品内容，无论该等内容形成于本协议订立前还是本协议订立后。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.3用户同意并已充分了解本协议的条款，承诺不将已发表于本站的信息，以任何形式发布或授权其它主体以任何方式使用（包括但不限于在各类网站、媒体上使用）。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.4商城是本站的制作者,拥有此网站内容及资源的著作权等合法权利,受国家法律保护,有权不时地对本协议及本站的内容进行修改，并在本站张贴，无须另行通知用户。在法律允许的最大限度范围内，商城对本协议及本站内容拥有解释权。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.5除法律另有强制性规定外，未经商城明确的特别书面许可,任何单位或个人不得以任何方式非法地全部或部分复制、转载、引用、链接、抓取或以其他方式使用本站的信息内容，否则，商城有权追究其法律责任。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;8.6本站所刊登的资料信息（诸如文字、图表、标识、按钮图标、图像、声音文件片段、数字下载、数据编辑和软件），均是商城或其内容提供者的财产，受中国和国际版权法的保护。本站上所有内容的汇编是商城的排他财产，受中国和国际版权法的保护。本站上所有软件都是商城或其关联公司或其软件供应商的财产，受中国和国际版权法的保护。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第9条 责任限制及不承诺担保&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;除非另有明确的书面说明,本站及其所包含的或以其它方式通过本站提供给您的全部信息、内容、材料、产品（包括软件）和服务，均是在&amp;quot;按现状&amp;quot;和&amp;quot;按现有&amp;quot;的基础上提供的。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;除非另有明确的书面说明,商城不对本站的运营及其包含在本网站上的信息、内容、材料、产品（包括软件）或服务作任何形式的、明示或默示的声明或担保（根据中华人民共和国法律另有规定的以外）。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;商城不担保本站所包含的或以其它方式通过本站提供给您的全部信息、内容、材料、产品（包括软件）和服务、其服务器或从本站发出的电子信件、信息没有病毒或其他有害成分。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;如因不可抗力或其它本站无法控制的原因使本站销售系统崩溃或无法正常使用导致网上交易无法完成或丢失有关的信息、记录等，商城会合理地尽力协助处理善后事宜。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第10条 协议更新及用户关注义务&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;根据国家法律法规变化及网站运营需要，商城有权对本协议条款不时地进行修改，修改后的协议一旦被张贴在本站上即生效，并代替原来的协议。用户可随时登录查阅最新协议；用户有义务不时关注并阅读最新版的协议及网站公告。如用户不同意更新后的协议，可以且应立即停止接受商城网站依据本协议提供的服务；如用户继续使用本网站提供的服务的，即视为同意更新后的协议。商城建议您在使用本站之前阅读本协议及本站的公告。 如果本协议中任何一条被视为废止、无效或因任何理由不可执行，该条应视为可分的且并不影响任何其余条款的有效性和可执行性。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第11条 法律管辖和适用&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;本协议的订立、执行和解释及争议的解决均应适用在中华人民共和国大陆地区适用之有效法律（但不包括其冲突法规则）。 如发生本协议与适用之法律相抵触时，则这些条款将完全按法律规定重新解释，而其它有效条款继续有效。 如缔约方就本协议内容或其执行发生任何争议，双方应尽力友好协商解决；协商不成时，任何一方均可向有管辖权的中华人民共和国大陆地区法院提起诉讼。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;第12条 其他&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;12.1商城网站所有者是指在政府部门依法许可或备案的商城网站经营主体。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;12.2商城尊重用户和消费者的合法权利，本协议及本网站上发布的各类规则、声明等其他内容，均是为了更好的、更加便利的为用户和消费者提供服务。本站欢迎用户和社会各界提出意见和建议，商城将虚心接受并适时修改本协议及本站上的各类规则。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;12.3本协议内容中以黑体、加粗、下划线、斜体等方式显著标识的条款，请用户着重阅读。&lt;/span&gt;&lt;br/&gt;&lt;br/&gt;&lt;span style=&quot;color: rgb(102, 102, 102); font-size: 12px; background-color: rgb(255, 255, 255);&quot;&gt;12.4您点击本协议下方的&amp;quot;同意并继续&amp;quot;按钮即视为您完全接受本协议，在点击之前请您再次确认已知悉并完全理解本协议的全部内容。&lt;/span&gt;&lt;/span&gt;&lt;/p&gt;', 1435672310),
(4, 'open_store', '开店协议', '&lt;h2 style=&quot;padding: 0px; margin: 0px; font-size: 16px; font-weight: normal; color: rgb(51, 51, 51); line-height: 30px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;1.本协议的订立&lt;/span&gt;&lt;/h2&gt;&lt;p class=&quot;cont&quot; style=&quot;padding: 0px; margin-top: 0px; margin-bottom: 0px; line-height: 28px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;在本网站（&lt;/span&gt;&lt;a target=&quot;_blank&quot; href=&quot;http://www.ecmoban.com/&quot; class=&quot;link&quot; style=&quot;padding: 0px; margin: 0px; text-decoration: underline; color: rgb(85, 85, 85); font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;dsmall.csdeshang.com&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;）依据《德尚商城网站用户注册协议》登记注册，且符合本网站 商家入驻标准的用户（以下简称&amp;quot;商 家&amp;quot;），在同意本协议全部条款后，方有资格使用&amp;quot;德尚商城商家在线入驻系统&amp;quot;（以 下简称&amp;quot;入驻系统&amp;quot;）申请入驻。一经商家点击&amp;quot;同意以上协议，下一步&amp;quot;按键， 即意味着商家同意与本网站签订本协议并同意受本协议约束。&lt;/span&gt;&lt;/p&gt;&lt;h2 style=&quot;padding: 0px; margin: 0px; font-size: 16px; font-weight: normal; color: rgb(51, 51, 51); line-height: 30px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;2.入驻系统使用说明&lt;/span&gt;&lt;/h2&gt;&lt;p class=&quot;cont&quot; style=&quot;padding: 0px; margin-top: 0px; margin-bottom: 0px; line-height: 28px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;2.1 商家通过入驻系统提出入驻申请，并按照要求填写商家信息、提供商家资质资料后，由 本网站审核并与有合作意向的商家联系协商合作相关事宜，经双方协商一致线下签订书面《开放平台 供应商合作运营协议》（以下简称&amp;quot;运营协议&amp;quot;），且商家按照&amp;quot;运营协议&amp;quot;约定 支付相应平台使用费及保证金等必要费用后，商家正式入驻本网站。本网站将为入驻商家开通商家后 台系统，商家可通过商家后台系统在本网站运营 自己的入驻店铺。&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;cont&quot; style=&quot;padding: 0px; margin-top: 0px; margin-bottom: 0px; line-height: 28px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;2.2 商家以及本网站通过入驻系统做出的申请、资料提交及确认等各类沟通，仅为双方合作 的意向以及本网站对商家资格审核的必备程序，除遵守本协议各项约定外，对双方不产生法律约束力 。双方间最终合作事宜及运营规则均以&amp;quot;运营协议&amp;quot;的约定及商家后台系统公示的各项规则 为准。&lt;/span&gt;&lt;/p&gt;&lt;h2 style=&quot;padding: 0px; margin: 0px; font-size: 16px; font-weight: normal; color: rgb(51, 51, 51); line-height: 30px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;3.商家权利义务&lt;/span&gt;&lt;/h2&gt;&lt;p style=&quot;padding: 0px; margin-top: 0px; margin-bottom: 0px; line-height: 28px;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun; font-size: 12px;&quot;&gt;用户使用&amp;quot;德尚商城商家在线入驻系统&amp;quot;前请认真阅读并理解本协议内容，本协议 内容中以加粗方式显著标识的条款，请用户着重阅读、慎重考虑。&lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;', 1435672310),
(5, 'groupbuy', '抢购活动协议', '&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;在您报名参加随缘客平台推广活动之前，请您仔细阅读本协议的全部内容。如果您对本协议的条款有疑问，请通过随缘客客服渠道进行询问，我们将向您解释条款内容。如果您不同意本协议的任何内容，或者无法准确理解随缘客对条款的解释，请不要点选“接受/同意”，也不要参与随缘客平台推广活动。&lt;br/&gt;本协议内容包括协议正文及所有随缘客已经发布或将来可能发布的各类规则。所有规则为协议不可分割的一部分，与协议正文具有同等法律效力。以任何方式进入随缘客网站并使用服务即表示您已充分阅读、理解并同意接受本协议的条款和条件(以下合称“条款”)。&amp;nbsp;随缘客有权根据业务需要，在不违反国家有关法律法规的前提下修订“条款”，并以网站公告的形式进行公示，不再单独通知您。经修订的“条款”一经在随缘客网站公布，即产生效力。如您不同意相关修订，请您立即停止使用“服务”。如您继续使用“服务”，则将视为您已接受经修订的“条款”，当您与随缘客发生争议时，应以最新的“条款”为准。&lt;br/&gt;在本协议中，“随缘客”指随缘客平台及其关联公司，“商家”指您，即申请人。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;1、报名商品&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;商家需按照活动的要求选择自己账号关联店铺内的商品进行报名，请仔细确认填写商品的分类、活动价、库存及包邮、发货信息，针对不符合要求的商品或商家，随缘客有权利直接拒绝报名申请。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;2、活动审核&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;2.1、商家提交活动报名后随缘客审核专员会按照提交顺序、活动类型进行审核，整个审核的范围包括但不限于商品质量、价格、历史评价，以及商家信誉等级、当季热销品类、同行业同类型商品的性价比等方面内容。随缘客在商家提交报名申请之日起在20个工作日内给予结果，在此期间您可随时登录报名系统查询审核状态。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;2.2、审核通过的，系统会提示您进行相应的下一步操作，请根据系统提示尽快补充相应的资料信息，超时未处理的随缘客有权取消本次活动审核。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;2.3、如果您的活动报名申请被设置为“未通过”，请根据随缘客审核专员的审核留言对活动进行调整、或更换符合要求的其他商品再来报名，经3次未通过后频繁重复提交的，随缘客有权锁定对应的报名信息填报系统，您将无法继续报名。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3、审核状态说明&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; 随缘客审核条件非常严格，先后经过7道工序，全部通过后再发布上线，即：初审-复审-洽谈-样品邮寄-样品体验-样品备案-排期-上线。商家应保证其提供的商品不违反法律法规，不侵犯任何第三人的知识产权或其他合法权利。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.1、招商专员会经过两轮的活动筛选，即初审、复审，确定您的商品是否适合参加本站活动；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.2、在待洽谈状态时，请主动点击与该活动对应的招商专员QQ与其取得联系（必须是该活动对应的店铺的QQ）；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.3、在样品邮寄状态时，请寄送活动报名对应商品的样品，将快递（含快递名称、快递单号、寄出时间等）信息填写到系统中，以便招商专员能够第一时间反馈样品接收状态并核对样品信息；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.4、您确认并同意：随缘客招商专员在收到样品时，将您的活动状态改为“样品体验”，“样品体验”即随缘客招商专员仅以普通或非专业人员的知识水平标准评估您寄来样品并结合活动条件和规模确定是否符合您所报名的活动推广条件；无论样品是否符合易购活动推广条件，样品均不予退还，随缘客有权对样品进行任何方式的支配和处理。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.5、经随缘客判断符合活动条件的样品，由随缘客留样备案。您确认并同意在活动期间及活动结束后，如随缘客发现消费者投诉或经易购抽检的商品质量有争议的，随缘客有权仅以此样品与争议商品进行比对，您对样品无异议。争议商品与样品是否存在差异以及差异程度以易购主观判断为准。您应保证当次活动所有发货的商品与样品完全一致（包括且不限于商品批次、商品包装、商品分量、同色商品颜色、同规格/尺码商品的规格/尺码及商品材质等各个方面）。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.6、样品体验符合随缘客活动条件的，招商专员会将对应的活动进行初步的排期，如果您对排期问题有异议也可以直接联系招商专员进行调整，确认排期后需要您按照随缘客的指示根据活动商品的活动价、库存销量、技术服务费率和保证金要求进行支付相应的活动保证金和技术服务费。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;3.7、您已缴纳活动保证金后，即进入随缘客排期时间，您的活动将根据系统排期发布上线，您可以登录随缘客首页查看您的活动详情；商家未按时缴纳保证金导致活动未能按时发布上线的由商家自行承担一切后果；在活动进行中请勿私自修改商品信息或状态，包括但不限于商品标题、图片、SKU信息、价格、库存、邮费设置、宝贝详情信息以及设置商品下架或卖光状态。如商家私自变更商品信息或状态的，随缘客有权将活动商品下架并扣除相应的保证金作为处罚。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4、活动保证金&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;商家的具体应缴保证金数额根据随缘客招商标准及商家的具体情况由随缘客确定。随缘客有权根据商家之业务变化及实际履约情况通知商家调整保证金金额，商家应在收到随缘客通知后的5个自然日内向随缘客交齐保证金，否则，随缘客有权中止或解除本协议。有关保证金的具体内容详见&lt;/span&gt;&lt;a href=&quot;http://www.waanwang.com/help-read-id-8.html&quot; target=&quot;_blank&quot; style=&quot;color: rgb(94, 94, 94); text-decoration: underline; outline: none medium; font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;《随缘客商家保证金协议》&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4.1、商家在报名参加随缘客推广活动交纳保证金，保证金主要用于保证商家按照随缘客的规则进行经营，商家有任何违规行为或违约行为的，随缘客有权扣除保证金。保证金扣除相关情形具体参见&lt;/span&gt;&lt;a href=&quot;http://www.waanwang.com/help-read-id-9.html&quot; target=&quot;_blank&quot; style=&quot;color: rgb(94, 94, 94); text-decoration: underline; outline: none medium; font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;《随缘客商家违规/违约处罚条例》&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4.2、随缘客招商专员会根据商家报名活动商品的类型、活动数量综合计算该商家需要缴纳的保证金额度，具体标准可参见&lt;/span&gt;&lt;a href=&quot;http://www.waanwang.com/help-read-id-8.html&quot; target=&quot;_blank&quot; style=&quot;color: rgb(94, 94, 94); text-decoration: underline; outline: none medium; font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;《随缘客家保证金协议》&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;。在保证金额度不足的情况下,随缘客有权要求商家限期补足保证金。商家需在收到易购通知后十（10）个自然日内补足保证金金额。如果没有及时交齐保证金的易购有权中止提供相应的技术推广服务，直至商家交齐保证金。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4.3、由于保证金不充抵服务费用或其他费用，非因商家原因被扣除的，保证金始终存于商家的易购账户中并处于冻结状态，如合作终止且商家无任何违规或违约行为，则保证金仍无息退还商家。因此随缘客对商家缴纳的保证金不提供收据或发票，敬请谅解。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;span style=&quot;font-family: 宋体, SimSun; color: red;&quot;&gt;4.4、商家在随缘客网活动期间无任何违规或违约行为的，最后一个活动结束超过17天，且所有交易环节（包括：交易、费用结算、售后处理及买家维权处理）完成，商家可自行申请解冻保证金至商家的易购网账户内。此期间，若随缘客发现商家存在或可能存在违规或违约行为且在该17天内无法处理完毕的，随缘客有权将保证金冻结时间延长30天或操作紧急扣除保证金，待商家违规/违约行为处理完毕后视具体情况解冻或退还。但商家有欠款未向易购付清的，保证金仍无法解冻或退还。&lt;/span&gt;&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4.5、因资质、商品造假等原因被清退的违规商家，随缘客将不返还保证金，因违规或违约行为扣除的保证金亦不予返还，如扣除保证金仍不足以弥补因其行为给随缘客及消费用户造成的损失的，违规商家还应承担相应的损失赔偿责任。具体保证金扣取情况参见&lt;/span&gt;&lt;a href=&quot;http://www.waanwang.com/help-read-id-8.html&quot; target=&quot;_blank&quot; style=&quot;color: rgb(94, 94, 94); text-decoration: underline; outline: none medium; font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;《随缘客商家违规/违约处罚条例》&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;4.6、随缘客将根据国家经济情况、市场状况及随缘客经营情况适时适当调整保证金制度及保证金标准。保证金的调整会提前以公告形式在易购网站公布。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;5、商家账户充值及提现规则&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;5.1充值&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（1）充值须以活动为目的，随缘客账户仅限充值活动保证金。保证金具体金额根据随缘客招商标准及商家的具体情况如商家资质、信誉状况、预估销售规模、单月销售额水平、合作次数、历史活动评分、商品类目及商品单价等由随缘客招商专员在商家提交报名审核时具体确定；&lt;br/&gt;&amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（2）随缘客确定的与活动相关的充值产生的相应手续费由随缘客承担。商家不得利用随缘客平台向易购账户充入与活动无关的任何费用，否则一经发现，随缘客有权采取相应措施，包括但不限于冻结账号余额、拒绝提现。因此产生的手续费由商家自行承担，随缘客已经支付的手续费有权向商家追偿。因此给随缘客造成的任何损失，商家应承担赔偿责任；&lt;br/&gt;&amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（3）采用信用卡方式充值的，自充值之日起超过90日申请提现的，付款无法原路退回，随缘客将以转账方式付款到您充值时使用的信用卡账户，转账手续费将在转账时从您的提现金额中即时扣除，手续费费率以银行转账手续费费率为准；&lt;br/&gt;&amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（4）商家在随缘客平台的一切活动均应遵守国家法律、法规及国家政策，易购随缘客有理由怀疑商家充入资金来源不合法或存在其他不正当目的的，有权向相关部门举报，并将积极配合有关部门调查；&lt;br/&gt;&amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（5）如商家充值资金来源不合法或存在其他不正当目的，被相关部门查处的，一切责任由商家承担；因此造成随缘客任何损失的，商家应承担赔偿责任。&lt;br/&gt;&amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;5.2余额提现&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（1）活动期间或活动结束后您可对您已充值的随缘客账户余额办理提现。您申请余额提现时，将一律以原路退回方式付款到您充值时使用的支付账户。采用信用卡方式充值的，自充值之日起超过90日申请提现的，付款无法原路退回，随缘客将以转账方式付款到您充值时使用的信用卡账户，转账手续费将在转账时从您的提现金额中即时扣除，手续费费率以银行转账手续费费率为准。&lt;br/&gt;&amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（2）系统仅允许一笔处理中的提现申请，如申请提现时仍有上一笔提现未处理完毕的，将无法继续提交提现申请；每个自然月内最多允许成功提现两次；单笔提现金额不得超出账户内余额；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（3）通过支付宝账户申请提现的，因提现产生的相应手续费由商家承担，即：商家提现时将从提现金额中即时扣除小额手续费，具体以支付宝有关手续费的规定比例为准；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（4）为了更好的保护您的账户和资金安全，避免因您的账号信息泄露导致恶意提现或变更，请您务必妥善保管好自己的易购账户信息。如因您个人原因导致账号被盗或余额被提现的，随缘客不承担任何责任。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;6、违约责任&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;商家有任何违反本协议条款之行为的，按照&lt;/span&gt;&lt;a href=&quot;http://www.waanwang.com/help-read-id-7.html&quot; target=&quot;_blank&quot; style=&quot;color: rgb(94, 94, 94); text-decoration: underline; outline: none medium; font-family: 宋体, SimSun;&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;《随缘客商家违规处罚条例》&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;的规定扣除相应保证金并（或）进行其他相应的处罚。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;7、责任免除情形&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（1）因战争、自然灾害、政府行为、互联网灾难、互联网通讯提供商等导致随缘客网络平台服务器不能正常运行的；&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（2）因随缘客网站遭遇不法分子攻击或非法劫持导致随缘客网络平台服务器临时性不能正常运行或随缘客网站不能正常访问的。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;（3）您理解并同意，如遇大型促销活动期间，用户访问量巨大时，网络环境可能存在一定的不稳定性，易购随缘客系统平台偶尔出现短时无法访问属正常现象。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;8、协议效力&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;本协议适用于以任何形式参加随缘客平台推广活动的所有商家，商家在任何时候参加随缘客活动均受本协议约束，本协议对双方均发生法律效力。&lt;br/&gt;&amp;nbsp; &amp;nbsp; &amp;nbsp;&lt;/span&gt;&lt;/p&gt;&lt;p class=&quot;fontbold&quot; style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;9、法律适用及争议解决&lt;/span&gt;&lt;/p&gt;&lt;p style=&quot;margin-top: 0px; margin-bottom: 0px; padding: 0px; color: rgb(94, 94, 94); font-family: &amp;quot;Microsoft Yahei&amp;quot;, Tahoma, Helvetica, Arial, 宋体, sans-serif, 宋体; font-size: 12px; white-space: normal; background-color: rgb(255, 255, 255);&quot;&gt;&lt;span style=&quot;font-family: 宋体, SimSun;&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; 本协议的生效、解释、执行、管辖、争议的解决均适用中华人民共和国法律。&lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;', 1435672310);

INSERT INTO `#__express` (`express_id`, `express_name`, `express_state`, `express_code`, `express_letter`, `express_order`, `express_url`) VALUES
(1, '安信达', '0', 'AXD', 'A', '2', 'http://www.anxinda.com'),
(2, '包裹平邮', '1', 'YZPY', 'B', '2', 'http://yjcx.chinapost.com.cn'),
(3, 'CCES', '1', 'CCES', 'C', '2', 'http://www.cces.com.cn'),
(4, '传喜物流', '1', 'CXHY', 'C', '2', 'http://www.cxcod.com'),
(5, 'DHL快递', '1', 'DHL', 'D', '2', 'http://www.cn.dhl.com'),
(6, '大田物流', '1', 'DTWL', 'D', '2', 'http://www.dtw.com.cn'),
(7, '德邦物流', '1', 'DBL', 'D', '2', 'http://www.deppon.com'),
(8, 'EMS', '1', 'EMS', 'E', '2', 'http://www.ems.com.cn'),
(9, 'EMS国际', '1', 'EMSGJ', 'E', '2', '###'),
(10, '飞康达', '1', 'FKD', 'F', '2', 'http://www.fkd.com.cn'),
(11, 'FedEx(国际)', '1', 'FKD_GJ', 'F', '2', 'http://fedex.com/cn'),
(12, '凡客如风达', '1', 'rufengda', 'F', '2', 'http://www.rufengda.com'),
(13, '迦递快递', '1', 'GAI', 'G', '2', 'https://www.trackingmore.com'),
(14, '广通', '1', 'GTONG', 'G', '2', 'http://gto315.com'),
(15, '共速达', '1', 'GSD', 'G', '2', 'http://www.gongsuda.com/mall/Search.aspx'),
(16, '华宇物流', '1', 'HOAU', 'H', '2', 'http://www.hoau.net'),
(17, '京东快递', '1', 'JD', 'J', '2', 'http://www.jdwl.com'),
(18, '佳吉快运', '1', 'JJKY', 'J', '2', 'http://www.jiaji.com'),
(19, '佳怡物流', '1', 'JYWL', 'J', '2', 'http://www.jiayi56.com'),
(20, '急先达', '1', 'JXD', 'J', '2', 'http://www.joust.cn'),
(21, '快捷速递', '1', 'FAST', 'K', '2', 'http://www.fastexpress.com.cn'),
(22, '龙邦快递', '1', 'LB', 'L', '2', 'http://www.lbex.com.cn'),
(23, '联邦快递', '1', 'FEDEX', 'L', '2', 'http://cndxp.apac.fedex.com/dxp.html'),
(24, '联昊通', '1', 'LHT', 'L', '2', 'http://www.lhtex.com.cn'),
(25, '全一快递', '1', 'UAPEX', 'Q', '2', 'http://www.apex100.com'),
(26, '全峰快递', '1', 'QFKD', 'Q', '2', 'http://www.qfkd.com.cn'),
(27, '全日通', '1', 'QRT', 'Q', '2', 'http://www.at-express.com'),
(28, '申通快递', '1', 'STO', 'S', '2', 'http://www.sto.cn'),
(29, '顺丰快递', '1', 'SF', 'S', '1', 'http://www.sf-express.com'),
(30, '速尔快递', '1', 'SURE', 'S', '2', 'http://www.sure56.com'),
(31, 'TNT快递', '1', 'TNT', 'T', '2', 'http://www.tnt.com.cn'),
(32, '天天快递', '1', 'HHTT', 'T', '2', 'http://www.ttkdex.com'),
(33, '天地华宇', '1', 'HOAU', 'T', '2', 'http://www.hoau.net'),
(34, 'UPS快递', '1', 'UPS', 'U', '2', 'http://www.ups.com/cn'),
(35, 'USPS', '1', 'USPS', 'U', '2', 'http://www.kuaidi100.com/all/usps.shtml'),
(36, '迅驰物流', '1', 'XCWL', 'X', '2', 'https://cn.made-in-china.com'),
(37, '信丰物流', '1', 'XFEX', 'X', '2', 'http://www.xf-express.com.cn'),
(38, '希优特', '1', 'XYT', 'X', '2', 'http://www.hqepay.com'),
(39, '新杰物流', '1', 'XJ', 'X', '2', 'http://www.sunjex.com/'),
(40, '圆通快递', '1', 'YTO', 'Y', '1', 'http://www.yto.net.cn'),
(41, '韵达快递', '1', 'YD', 'Y', '1', 'http://www.yundaex.com'),
(42, '邮政包裹', '1', 'YZPY', 'Y', '2', 'http://yjcx.chinapost.com.cn'),
(43, '优速快递', '1', 'UC', 'Y', '2', 'http://www.uc56.com'),
(44, '中通快递', '1', 'ZTO', 'Z', '1', 'http://www.zto.cn'),
(45, '中铁快运', '1', 'ZTKY', 'Z', '2', 'http://www.cre.cn'),
(46, '宅急送', '1', 'ZJS', 'Z', '2', 'http://www.zjs.com.cn'),
(47, '中邮物流', '1', 'ZYWL', 'Z', '2', 'http://www.cnpl.com.cn');



INSERT INTO `#__help` (`help_id`, `help_sort`, `help_title`, `help_info`, `help_url`, `help_updatetime`, `helptype_id`, `page_show`) VALUES
(96, 1, '招商方向', '后台->店铺->开店首页->入驻指南->编辑内容', '', 1399284217, 1, 1),
(97, 2, '招商标准', '后台->店铺->开店首页->入驻指南->编辑内容', '', 1399281053, 1, 1),
(98, 3, '资质要求', '后台->店铺->开店首页->入驻指南->编辑内容', '', 1399282350, 1, 1),
(99, 4, '资费标准', '后台->店铺->开店首页->入驻指南->编辑内容', '', 1399282379, 1, 1),
(101, 155, '签署入驻协议', '签署入驻协议(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392949932, 99, 1),
(102, 156, '商家信息提交', '商家信息提交(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392949961, 99, 1),
(103, 157, '平台审核资质', '平台审核资质(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392949991, 99, 1),
(104, 158, '商家缴纳费用', '商家缴纳费用(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950031, 99, 1),
(105, 159, '店铺开通', '店铺开通(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950076, 99, 1),
(106, 255, '商品发布规则', '商品发布规则(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950396, 91, 1),
(107, 255, '商品规格及属性', '商品规格及属性(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950481, 92, 1),
(108, 255, '限时折扣说明', '限时折扣说明(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950523, 93, 1),
(109, 255, '订单商品退款', '订单商品退款(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950670, 94, 1),
(110, 255, '续约流程及费用', '续约流程及费用(后台->店铺->店铺帮助->帮助内容->编辑内容)', '', 1392950739, 95, 1);

INSERT INTO `#__helptype` (`helptype_id`, `helptype_name`, `helptype_sort`, `helptype_code`, `helptype_show`, `page_show`) VALUES
  (91, '规则体系', 91, 'sys_rules', 1, 1),
  (92, '商品管理', 92, 'sys_goods', 1, 1),
  (93, '促销方式', 93, 'sys_sales', 1, 1),
  (94, '订单及售后', 94, 'sys_order', 1, 1),
  (95, '店铺续约', 95, 'sys_renew', 1, 1),
  (99, '入驻流程', 99, 'store_in', 1, 1);

INSERT INTO `#__informsubject` (`informsubject_id`, `informsubject_content`, `informsubject_type_id`, `informsubject_type_name`, `informsubject_state`) VALUES (1, '管制刀具、弓弩类、其他武器等', 1, '出售禁售品', 1),
(2, '赌博用具类', 1, '出售禁售品', 1),
(3, '枪支弹药', 1, '出售禁售品', 1),
(4, '毒品及吸毒工具', 1, '出售禁售品', 1),
(5, '色差大，质量差。', 2, '产品质量问题', 1);

INSERT INTO `#__informsubjecttype` (`informtype_id`, `informtype_name`, `informtype_desc`, `informtype_state`) VALUES (1, '出售禁售品', '销售商城禁止和限制交易规则下所规定的所有商品。', 1),
(2, '产品质量问题', '产品质量差，与描述严重不相符。', 1);


INSERT INTO `#__mailmsgtemlates` (`mailmt_name`, `mailmt_title`, `mailmt_code`, `mailmt_content`) VALUES
('<strong>[用户]</strong>账号注册通知', '账号注册通知 - ${site_name}', 'register', '您正在申请注册会员，动态码：${code}。'),
('<strong>[用户]</strong>账号登录通知', '账号登录通知 - ${site_name}', 'login', '您正在申请登录，动态码：${code}。'),
('<strong>[用户]</strong>重置密码通知', '重置密码通知 - ${site_name}', 'reset_password', '您正在申请重置登录密码，动态码：${code}。'),
('<strong>[用户]</strong>身份验证通知', '账户安全认证 - ${site_name}', 'authenticate', '您正在提交账户安全验证，验证码是：${code}。'),
('<strong>[用户]</strong>邮箱验证通知', '邮箱验证通知 - ${site_name}', 'bind_email', '<p>您好！</p>\r\n<p>请在24小时内点击以下链接完成邮箱验证</p>\r\n<p><a href="${verify_url}" target="_blank">马上验证</a></p>\r\n<p>如果您不能点击上面链接，还可以将以下链接复制到浏览器地址栏中访问</p>\r\n<p>${verify_url}</p>'),
('<strong>[用户]</strong>手机验证通知', '手机验证通知 - ${site_name}', 'modify_mobile', '您正在申请绑定手机号，验证码是：${code}。'),
('<strong>[用户]</strong>代收通知', '门店代收通知 - ${site_name}', 'send_pickup_code', '您的订单已到达门店，请上门取货！提货时请提供手机号/订单号/运单号及提货码：${pickup_code}。'),
('<strong>[用户]</strong>虚拟兑换码通知', '虚拟兑换码通知 - ${site_name}', 'send_vr_code', '您的虚拟兑换码是：${vr_code}。');

INSERT INTO `#__mallconsulttype` (`mallconsulttype_id`, `mallconsulttype_name`, `mallconsulttype_introduce`, `mallconsulttype_sort`) VALUES
(1, '商品咨询', '&lt;p&gt;\r\n	请写明商品链接，或平台货号。\r\n&lt;/p&gt;\r\n&lt;p&gt;\r\n	如果您对商品规格、介绍等有疑问，可以在商品详情页“购买咨询”处发起咨询，会得到及时专业的回复。\r\n&lt;/p&gt;', 255),
(2, '订单咨询', '&lt;p&gt;\r\n	请写明要咨询的订单编号。\r\n&lt;/p&gt;\r\n&lt;p&gt;\r\n	如需处理交易中产生的纠纷，请选择投诉。\r\n&lt;/p&gt;', 255);

INSERT INTO `#__membermsgtpl` (`membermt_code`, `membermt_name`, `membermt_message_switch`, `membermt_message_content`, `membermt_short_switch`, `membermt_short_content`, `membermt_mail_switch`, `membermt_mail_subject`, `membermt_mail_content`) VALUES
('arrival_notice', '到货通知提醒', 1, '您关注的商品 “${goods_name}” 已经到货。<a href="${goods_url}" target="_blank">点击查看商品</a>', 1, '您关注的商品 “${goods_name}” 已经到货。', 0, '${site_name}提醒：您关注的商品  “${goods_name}” 已经到货。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您关注的商品 “${goods_name}” 已经到货。\r\n</p>\r\n<p>\r\n	<a href="${goods_url}" target="_blank">点击查看商品</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>'),
('consult_goods_reply', '商品咨询回复提醒', 1, '您关于商品 “${goods_name}”的咨询，商家已经回复。<a href="${consult_url}" target="_blank">点击查看回复</a>', 0, '您关于商品 “${goods_name}” 的咨询，商家已经回复。', 0, '${site_name}提醒：您关于商品 “${goods_name}”的咨询，商家已经回复。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您关注的商品“${goods_name}” 已经到货。\r\n</p>\r\n<p>\r\n	<a href="${consult_url}" target="_blank">点击查看回复</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<br />\r\n<div class="firebugResetStyles firebugBlockBackgroundColor">\r\n	<div style="background-color:transparent ! important;" class="firebugResetStyles">\r\n	</div>\r\n</div>'),
('consult_mall_reply', '平台客服回复提醒', 1, '您的平台客服咨询已经回复。<a href="${consult_url}" target="_blank">点击查看回复</a>', 0, '您的平台客服咨询已经回复。', 0, '${site_name}提醒：您的平台客服咨询已经回复。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的平台客服咨询已经回复。\r\n</p>\r\n<p>\r\n	<a href="${consult_url}" target="_blank">点击查看回复</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>'),
('order_deliver_success', '商品出库提醒', 1, '您的订单已经出库。<a href="${order_url}" target="_blank">点击查看订单</a>', 1, '您的订单已经出库。订单编号 ${order_sn}。', 0, '${site_name}提醒：您的订单已经出库。订单编号 ${order_sn}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的订单已经出库。订单编号 ${order_sn}。<br />\r\n<a href="${order_url}" target="_blank">点击查看订单</a>\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<br />'),
('order_payment_success', '付款成功提醒', 1, '关于订单：${order_sn}的款项已经收到，请留意出库通知。<a href="${order_url}" target="_blank">点击查看订单详情</a>', 1, '${order_sn}的款项已经收到，请留意出库通知。', 0, '${site_name}提醒：${order_sn}的款项已经收到，请留意出库通知。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	${order_sn}的款项已经收到，请留意出库通知。\r\n</p>\r\n<p>\r\n	<a href="${order_url}" target="_blank">点击查看订单详情</a>\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<br />'),
('predeposit_change', '余额变动提醒', 1, '你的账户于 ${time} 账户资金有变化，描述：${desc}，可用金额变化 ：${av_amount}元，冻结金额变化：${freeze_amount}元。<a href="${pd_url}" target="_blank">点击查看余额</a>', 0, '你的账户于 ${time} 账户资金有变化，描述：${desc}，可用金额变化： ${av_amount}元，冻结金额变化：${freeze_amount}元。', 0, '${site_name}提醒：你的账户于 ${time} 账户资金有变化，描述：${desc}，可用金额变化： ${av_amount}元，冻结金额变化：${freeze_amount}元。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	你的账户于 ${time} 账户资金有变化，描述：${desc}，可用金额变化：${av_amount}元，冻结金额变化：${freeze_amount}元。\r\n</p>\r\n<p>\r\n	<a href="${pd_url}" target="_blank">点击查看余额</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>'),
('recharge_card_balance_change', '充值卡余额变动提醒', 1, '你的账户于 ${time} 充值卡余额有变化，描述：${description}，可用充值卡余额变化 ：${available_amount}元，冻结充值卡余额变化：${freeze_amount}元。<a href="${url}" target="_blank">点击查看充值卡余额</a>', 0, '你的账户于 ${time} 充值卡余额有变化，描述：${description}，可用充值卡余额变化： ${available_amount}元，冻结充值卡余额变化：${freeze_amount}元。', 0, '${site_name}提醒：你的账户于 ${time} 充值卡余额有变化，描述：${description}，可用充值卡余额变化： ${available_amount}元，冻结充值卡余额变化：${freeze_amount}元。', '<p>\r\n    ${site_name}提醒：\r\n</p>\r\n<p>\r\n  你的账户于 ${time} 充值卡余额有变化，描述：${description}，可用充值卡余额变化：${available_amount}元，冻结充值卡余额变化：${freeze_amount}元。\r\n</p>\r\n<p>\r\n  <a href="${url}" target="_blank">点击查看余额</a> \r\n</p>\r\n<p>\r\n  <br />\r\n</p>\r\n<p>\r\n   <br />\r\n</p>\r\n<p>\r\n   <br />\r\n</p>\r\n<p style="text-align:right;">\r\n ${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n   ${mail_send_time}\r\n</p>'),
('refund_return_notice', '退款退货提醒', 1, '您的退款退货单有了变化。<a href="${refund_url}" target="_blank">点击查看</a>', 1, '您的退款退货单有了变化。退款退货单编号：${refund_sn}。', 0, '${site_name}提醒：您的退款退货单有了变化。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的退款退货单有了变化。退款退货单编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	&lt;a href="${refund_url}" target="_blank"&gt;点击查看&lt;/a&gt;\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<br />'),
('voucher_use', '代金券使用提醒', 1, '您有代金券已经使用，代金券编号：${voucher_code}。<a href="${voucher_url}" target="_blank">点击查看</a>', 0, '您有代金券已经使用，代金券编号：${voucher_code}。', 0, '${site_name}提醒：您有代金券已经使用，代金券编号：${voucher_code}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有代金券已经使用，代金券编号：${voucher_code}。\r\n</p>\r\n<p>\r\n	&lt;a href="${voucher_url}" target="_blank"&gt;点击查看&lt;/a&gt;\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>'),
('voucher_will_expire', '代金券即将到期提醒', 1, '您有一个代金券即将在${indate}过期，请记得使用。<a href="${voucher_url}" target="_blank">点击查看</a>', 0, '您有一个代金券即将在${indate}过期，请记得使用。', 0, '${site_name}提醒：您有一个代金券即将在${indate}过期，请记得使用。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有一个代金券即将在${indate}过期，请记得使用。\r\n</p>\r\n<p>\r\n	<a href="${voucher_url}" target="_blank">点击查看</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>'),
('vr_code_will_expire', '兑换码即将到期提醒', 1, '您有一组兑换码即将在${indate}过期，请记得使用。<a href="${vr_order_url}" target="_blank">点击查看</a>', 0, '您有一组兑换码即将在${indate}过期，请记得使用。', 0, '${site_name}提醒：您有一组兑换码即将在${indate}过期，请记得使用。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有一组兑换码即将在${indate}过期，请记得使用。\r\n</p>\r\n<p>\r\n	&lt;a href="${vr_order_url}" target="_blank"&gt;点击查看&lt;/a&gt;\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>');


INSERT INTO `#__refundreason` (`reason_id`, `reason_info`, `reason_sort`, `reason_updatetime`) VALUES
(1, '效果不好不喜欢', 1, 1393480261),
(2, '商品破损、有污渍', 2, 1393480261),
(3, '保质期不符', 3, 1393480261),
(4, '认为是假货', 4, 1393480261),
(5, '不能按时发货', 5, 1393480261);

INSERT INTO `#__seo` (`seo_id`, `seo_title`, `seo_keywords`, `seo_description`, `seo_type`) VALUES (1, '{sitename} - 程序来源于惠利玛', 'DSMALL,PHP商城系统,DSMALL商城系统,多用户商城系统,电商ERP,电商CRM,电子商务解决方案', '', 'index'),
(2, '{sitename} - 抢购', 'DSMALL,{sitename}', '', 'group'),
(3, '{sitename} - {name}', 'DSMALL,{name},{sitename}', 'DSMALL,{name},{sitename}', 'group_content'),
(4, '{sitename} - 品牌', 'DSMALL,{sitename}', 'DSMALL,{sitename}', 'brand'),
(5, '{sitename} - {name}', 'DSMALL,{sitename},{name}', 'DSMALL,{sitename},{name}', 'brand_list'),
(7, '{sitename} - {name}', 'DSMALL,{sitename},{name}', 'DSMALL,{sitename},{name}', 'coupon_content'),
(8, '{sitename} - 积分商城', 'DSMALL,{sitename}', 'DSMALL,{sitename}', 'point'),
(9, '{sitename} - {name}', 'DSMALL,{sitename},{key}', 'DSMALL,{sitename},{description}', 'point_content'),
(10, '{sitename} - {article_class}', 'DSMALL,{sitename}', 'DSMALL,{sitename}', 'article'),
(11, '{sitename} - {name}', 'DSMALL,{sitename},{key}', 'DSMALL,{sitename},{description}', 'article_content'),
(12, '{sitename} - {shopname}', 'DSMALL,{sitename},{key}', 'DSMALL,{sitename},{description}', 'shop'),
(13, '{name} - {sitename}', 'DSMALL,{sitename},{key}', 'DSMALL,{sitename},{description}', 'product'),
(14, '看{name}怎么淘到好的宝贝-{sitename}', 'DSMALL,{sitename},{name}', 'DSMALL,{sitename},{name}', 'sns');

INSERT INTO `#__storeclass` (`storeclass_id`, `storeclass_name`, `storeclass_bail`, `storeclass_sort`) VALUES
(1, '珠宝/首饰', 0, 8),
(2, '服装鞋包', 0, 1),
(3, '3C数码', 0, 2),
(4, '美容护理', 0, 3),
(5, '家居用品', 0, 4),
(6, '食品/保健', 0, 5),
(7, '母婴用品', 0, 6),
(8, '文体/汽车', 0, 7),
(9, '收藏/爱好', 0, 9),
(10, '生活/服务', 0, 10);

INSERT INTO `#__storemsgtpl` (`storemt_code`, `storemt_name`, `storemt_message_switch`, `storemt_message_content`, `storemt_message_forced`, `storemt_short_switch`, `storemt_short_content`, `smt_short_forced`, `storemt_mail_switch`, `storemt_mail_subject`, `storemt_mail_content`, `storemt_mail_forced`) VALUES
('complain', '商品被投诉提醒', 1, '您售出的商品被投诉，等待商家申诉。投诉单编号：${complain_id}。', 1, 1, '您售出的商品被投诉，等待商家申诉。投诉单编号：${complain_id}。', 1, 1, '${site_name}提醒：您售出的商品被投诉，等待商家申诉。投诉单编号：${complain_id}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您售出的商品被投诉，等待商家申诉。投诉单编号：${complain_id}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 1),
('goods_storage_alarm', '商品库存预警', 1, '您的商品库存不足，请及时补货。平台货号：${common_id}，SKU：${sku_id}。', 1, 0, '您的商品库存不足，请及时补货。平台货号：${common_id}，SKU：${sku_id}。', 0, 0, '${site_name}提醒：您的商品库存不足，请及时补货。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的商品库存不足，请及时补货。平台货号：${common_id}，SKU：${sku_id}。\r\n</p>\r\n<p>\r\n	点击下面链接查看商品详细信息\r\n</p>\r\n<p>\r\n	<a href="http://${shop_site_url}/goods/index.html?goods_id=${sku_id}" target="_blank">http://${shop_site_url}/goods/index.html?goods_id=${sku_id}</a> \r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<br />', 0),
('goods_verify', '商品审核失败提醒', 1, '您的商品没有通过管理员审核，原因：“${remark}”。平台货号：${common_id}。', 1, 0, '您的商品没有通过管理员审核，原因：“${remark}”。平台货号：${common_id}。', 0, 0, '${site_name}提醒：您的商品没有通过管理员审核。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的商品没有通过管理员审核，原因：“${remark}”。平台货号：${common_id}。\r\n	</p><p>\r\n		<br />\r\n	</p>\r\n	<p>\r\n		<br />\r\n	</p>\r\n	<p style="text-align:right;">\r\n		${site_name}\r\n	</p>\r\n	<p style="text-align:right;">\r\n		${mail_send_time}\r\n	</p>', 0),
('goods_violation', '商品违规被下架', 1, '您的商品被违规下架，原因：“${remark}”。平台货号：${common_id}。', 1, 0, '您的商品被违规下架，原因：“${remark}”。平台货号：${common_id}。', 0, 0, '${site_name}提醒：您的商品被违规下架。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的商品被违规下架。，原因：“${remark}”。平台货号：${common_id}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 0),
('new_order', '新订单提醒', 1, '您有订单需要处理，订单编号：${order_sn}。', 1, 1, '您有订单需要处理，订单编号：${order_sn}。', 1, 0, '${site_name}提醒：您有订单需要处理。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有订单需要处理，订单编号：${order_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<br />', 0),
('refund', '退款提醒', 1, '您有一个${type}退款单需要处理，退款编号：${refund_sn}。', 1, 0, '您有一个${type}退款单需要处理，退款编号：${refund_sn}。', 1, 0, '${site_name}提醒：您有一个${type}退款单需要处理，退款编号：${refund_sn}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有一个${type}退款单需要处理，退款编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 1),
('refund_auto_process', '退款自动处理提醒', 1, '您的${type}退款单超期未处理，已自动同意买家退款申请。退款单编号：${refund_sn}。', 1, 0, '您的${type}退款单超期未处理，已自动同意买家退款申请。退款单编号：${refund_sn}。', 0, 0, '{site_name}提醒：您的${type}退款单超期未处理，已自动同意买家退款申请。退款单编号：${refund_sn}。', '<p>\r\n	{site_name}提醒：\r\n</p>\r\n<p>\r\n	您的${type}退款单超期未处理，已自动同意买家退款申请。退款单编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 0),
('return', '退货提醒', 1, '您有一个${type}退货单需要处理。退货编号：${refund_sn}。', 1, 0, '您有一个${type}退货单需要处理。退货编号：${refund_sn}。', 0, 0, '${site_name}提醒：您有一个${type}退货单需要处理。退货编号：${refund_sn}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有一个${type}退货单需要处理。退货编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<br />', 0),
('return_auto_process', '退货自动处理提醒', 1, '您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。', 1, 0, '您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。', 0, 0, '${site_name}提醒：您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>', 0),
('return_auto_receipt', '退货未收货自动处理提醒', 1, '您的${type}退货单不处理收货超期未处理，已自动按弃货处理。退货单编号：${refund_sn}。', 1, 0, '您的${type}退货单不处理收货超期未处理，已自动按弃货处理。退货单编号：${refund_sn}。', 0, 0, '${site_name}提醒：您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您的${type}退货单超期未处理，已自动同意买家退货申请（弃货）。退货单编号：${refund_sn}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 0),
('store_bill_affirm', '结算单等待确认提醒', 1, '您有新的结算单等待确认，开始时间：${state_time}，结束时间：${end_time}，结算单号：${bill_no}。', 1, 0, '您有新的结算单等待确认，开始时间：${state_time}，结束时间：${end_time}，结算单号：${bill_no}。', 0, 0, '${site_name}提醒：您有新的结算单等待确认。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有新的结算单等待确认，起止时间：开始时间：${state_time}，结束时间：${end_time}，结算单号：${bill_no}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 0),
('store_bill_gathering', '结算单已经付款提醒', 1, '您的结算单平台已付款，请注意查收，结算单编号：${bill_no}。', 1, 0, '您的结算单平台已付款，请注意查收，结算单编号：${bill_no}。', 0, 0, '${site_name}提醒：您的结算单平台已付款，请注意查收。', '<p>\r\n	</p><p>\r\n		${site_name}提醒：\r\n	</p>\r\n\r\n<p>\r\n	您的结算单平台已付款，请注意查收，结算单编号：${bill_no}。\r\n	</p><p>\r\n		<br />\r\n	</p>\r\n	<p>\r\n		<br />\r\n	</p>\r\n	<p>\r\n		<br />\r\n	</p>\r\n	<p style="text-align:right;">\r\n		${site_name}\r\n	</p>\r\n	<p style="text-align:right;">\r\n		${mail_send_time}\r\n	</p>\r\n\r\n<br />', 0),
('store_cost', '店铺消费提醒', 1, '您有一条新的店铺消费记录，金额：${price}，操作人：${seller_name}，备注：${remark}。', 1, 1, '您有一条新的店铺消费记录，金额：${price}，操作人：${seller_name}，备注：${remark}。', 1, 0, '${site_name}提醒：您有一条新的店铺消费记录。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	您有一条新的店铺消费记录，金额：${price}，操作人：${seller_name}，备注：${remark}。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>', 0),
('store_expire', '店铺到期提醒', 1, '你的店铺即将到期，请及时续期。', 1, 0, '你的店铺即将到期，请及时续期。', 0, 0, '${site_name}提醒：你的店铺即将到期，请及时续期。', '<p>\r\n	${site_name}提醒：\r\n</p>\r\n<p>\r\n	你的店铺即将到期，请及时续期。\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p>\r\n	<br />\r\n</p>\r\n<p style="text-align:right;">\r\n	${site_name}\r\n</p>\r\n<p style="text-align:right;">\r\n	${mail_send_time}\r\n</p>\r\n<p>\r\n	<br />\r\n</p>', 0);

INSERT INTO `#__storegrade` (`storegrade_id`, `storegrade_name`, `storegrade_goods_limit`, `storegrade_album_limit`, `storegrade_space_limit`, `storegrade_template_number`, `storegrade_template`, `storegrade_price`, `storegrade_description`, `storegrade_sort`) VALUES (1, '系统默认', 100, 500, 100, 6, 'default|style1|style2|style3|style4|style5', '100', '用户选择“默认等级”，可以立即开通。', 0),
(2, '白金店铺', 200, 1000, 100, 6, 'default|style1|style2|style3|style4|style5', '200', '享受更多特权', 2),
(3, '钻石店铺', 0, 1000, 100, 6, 'default|style1|style2|style3|style4|style5', '1000', '', 100);


INSERT INTO `#__advposition` (`ap_id`, `ap_name`, `ap_intro`, `ap_isuse`, `ap_width`, `ap_height`) VALUES
(1, '首页-轮播图', '', 1, 1920, 400),
(2, '首页-促销图', '', 1, 240, 164),
(3, '首页-楼层1底部广告', '', 1, 1200, 125),
(4, '首页-楼层2底部广告', '', 1, 1200, 125),
(5, '首页-楼层3底部广告', '', 1, 1200, 125),
(6, '首页-楼层4底部广告', '', 1, 1200, 125),
(7, '首页-楼层5底部广告', '', 1, 1200, 125),
(8, '首页-楼层1侧边广告', '', 1, 229, 614),
(9, '首页-楼层2侧边广告', '', 1, 229, 614),
(10, '首页-楼层3侧边广告', '', 1, 229, 614),
(11, '首页-楼层4侧边广告', '', 1, 229, 614),
(12, '首页-楼层5侧边广告', '', 1, 229, 614),
(16, '闲置首页中部横栏广告', '', 1, 1200, 61),
(17, '闲置首页中部短栏广告1', '', 1, 290, 100),
(18, '闲置首页中部短栏广告2', '', 1, 290, 100),
(19, '闲置首页中部短栏广告3', '', 1, 290, 100),
(20, '闲置首页中部短栏广告4', '', 1, 290, 100),
(21, '首页-顶部广告图', '', 1, 1200, 100);

INSERT INTO `#__adv` (`adv_id`, `ap_id`, `adv_title`, `adv_link`, `adv_code`, `adv_startdate`, `adv_enddate`, `adv_sort`, `adv_enabled`, `adv_clicknum`, `adv_bgcolor`) VALUES
(1, 1, '首页轮播图1', '', '5a4341aeb0372.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(2, 1, '首页轮播图2', '', '5a4341c011073.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(3, 2, '首页促销图-1', '', '5a4355443eaad.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(4, 2, '首页促销图-2', '', '5a43555f3590a.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(5, 2, '首页促销图-3', '', '5a43556e94bb6.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(6, 2, '首页促销图-4', '', '5a43557f91fb5.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(7, 2, '首页促销图-5', '', '5a43558d3d004.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(8, 2, '首页促销图-6', '', '5a4355999c09c.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(9, 2, '首页促销图-7', '', '5a4355a53c2d4.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(10, 2, '首页促销图-8', '', '5a4355b51b338.jpg', 1199116800, 1830268800, 0, 1, 0, NULL),
(11, 3, '首页-楼层1底部广告', '', '5c07551df18ec.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(12, 4, '首页-楼层2底部广告', '', '5c07552da2194.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(13, 5, '首页-楼层3底部广告', '', '5c0755264e32d.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(14, 6, '首页-楼层4底部广告', '', '5c0755356c311.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(15, 7, '首页-楼层5底部广告', '', '5c07551683f36.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(16, 8, '首页-楼层1侧边广告', '', '5c07553eeca3a.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(17, 9, '首页-楼层2侧边广告', '', '5c07555395d8f.png', 1514304000, 1830268800, 0, 1, 0, NULL),
(18, 10, '首页-楼层3侧边广告', '', '5c07553eeca3a.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(19, 11, '首页-楼层4侧边广告', '', '5c07555395d8f.png', 1514304000, 1830268800, 0, 1, 0, NULL),
(20, 12, '首页-楼层5侧边广告', '', '5c07553eeca3a.jpg', 1514304000, 1830268800, 0, 1, 0, NULL),
(35, 21, '首页-顶部广告图1', '', '5d5f86eb3119b.jpg', 1566489600, 1974816000, 0, 1, 2, '#db001c');

INSERT INTO `#__albumclass` VALUES ('1','默认相册','1','','255','','1506020826','1');

INSERT INTO `#__appadvposition` (`ap_id`, `ap_name`, `ap_intro`, `ap_isuse`, `ap_width`, `ap_height`) VALUES
(1, '首页轮播图', '首页轮播图', 1, 720, 350),
(2, '首页促销', '首页促销', 1, 375, 160),
(3, '首页导航图', '', 1, 60, 60),
(4, '首页横图广告', '', 1, 375, 115);

INSERT INTO `#__appadv` (`adv_id`, `ap_id`, `adv_title`, `adv_type`, `adv_typedate`, `adv_code`, `adv_startdate`, `adv_enddate`, `adv_sort`, `adv_enabled`) VALUES
(1, 1, '首页轮播图', NULL, NULL, '5a460095839c8.jpg', 1514476800, 1902412800, 255, 1),
(2, 1, '首页轮播图', NULL, NULL, '5a4600a260e0f.jpg', 1514476800, 1902412800, 255, 1),
(3, 1, '首页轮播图', NULL, NULL, '5a4600c518da8.jpg', 1514476800, 1902412800, 255, 1),
(4, 2, '首页促销左(320X260)', NULL, NULL, '5a44c828b411b.jpg', 1514476800, 1902412800, 255, 1),
(5, 2, '首页促销右上(320X130)', NULL, NULL, '5a44c84ace6ca.jpg', 1514476800, 1902412800, 255, 1),
(6, 2, '首页促销右下(320X130)', NULL, NULL, '5a44c85ca3b46.jpg', 1514476800, 1902412800, 255, 1),
(7, 4, '首页横图广告1', NULL, NULL, '5cb590f2ae5c6.gif', 1555344000, 1902412800, 1, 1),
(8, 4, '首页横图广告2', NULL, NULL, '5cb5980bbac26.jpg', 1555344000, 1902412800, 2, 1),
(9, 4, '首页横图广告3', NULL, NULL, '5cb59d7e78073.gif', 1555344000, 1902412800, 255, 1);

INSERT INTO `#__fleaclassindex` (`fcindex_id`, `fcindex_class`, `fcindex_code`, `fcindex_id1`, `fcindex_name1`, `fcindex_id2`, `fcindex_name2`, `fcindex_id3`, `fcindex_name3`, `fcindex_id4`, `fcindex_name4`) VALUES
(1, '数码', 'shuma', '1', '手机', '4', '相机/摄像', '11', '电脑/配件', '19', '数码3C'),
(2, '装扮', 'zhuangban', '27', '服装/服饰', '35', '美容/美颜', '42', '家具/日用', '48', '食品/保健'),
(3, '居家', 'jujia', '51', '电器/影音', '60', '母婴/玩具', '67', '宠物/用品', '72', '生活/卡券'),
(4, '兴趣', 'xingqu', '80', '书刊/音像', '88', '汽摩/电动', '95', '珠宝/黄金', '102', '艺术/收藏'),
(5, '母婴', 'muying', '107', '其他闲置', '4', '相机/摄像', '19', '数码3C', '27', '服装/服饰');

INSERT INTO `#__editable_page_model` (`editable_page_model_id`, `editable_page_model_name`, `editable_page_model_intro`, `editable_page_model_type`, `editable_page_theme`, `editable_page_model_client`, `editable_page_model_content`) VALUES
(1, '轮播图', '', '', '', '', ''),
(2, '富文本', '', '', '', '', ''),
(3, '三列商品', '', 'store', '', 'pc', ''),
(4, '一个商品', '', 'store', '', 'pc', ''),
(5, '两列商品', '', 'store', '', 'pc', ''),
(6, '商品列表', '', '', '', 'h5', ''),
(7, '一个商品', '', 'store', '', 'pc', ''),
(8, '商品分类和轮播图', '', 'mall', '', 'pc', ''),
(9, '分类商品列表', '', 'mall', '', 'pc', ''),
(10, '两列分类商品列表', '', 'mall', '', 'pc', ''),
(11, '分类切换商品列表', '', 'mall', '', 'pc', ''),
(12, '导航列表', '', '', '', 'h5', ''),
(13, '滚动通知', '', '', '', 'h5', ''),
(14, '搜索', '', '', '', 'h5', ''),
(15, '魔方', '', '', '', 'h5', ''),
(16, '辅助空白', '', '', '', 'h5', ''),
(17, '视频', '', '', '', 'h5', ''),
(18, '砍价', '', '', '', 'h5', ''),
(19, '抢购', '', '', '', 'h5', ''),
(20, '拼团', '', '', '', 'h5', ''),
(21, '预售', '', '', '', 'h5', ''),
(22, '秒杀', '', '', '', 'h5', '');


INSERT INTO `#__chain` (`chain_id`, `store_id`, `chain_name`, `chain_passwd`, `chain_truename`, `chain_mobile`, `chain_telephony`, `chain_addressname`, `chain_area_2`, `chain_area_3`, `chain_area_info`, `chain_address`, `chain_idcard`, `chain_idcardimage`, `chain_addtime`, `chain_state`, `chain_failreason`, `chain_longitude`, `chain_latitude`, `chain_if_pickup`, `chain_if_collect`) VALUES 
(1, 1, 'seller', 'e10adc3949ba59abbe56e057f20f883e', 'seller', '15111111111', NULL, '一号门店', 213, 2271, '湖南省 长沙市 开福区', '新时代广场-北栋', '', '', 1642836114, 1, NULL, '112.994308', '28.226065', 1, 1);
